<?php

namespace Modules\OpcData\Http\Controllers\Api\zaoquan;

use App\Http\Controllers\Api\BaseController;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Modules\OpcData\Services\zaoquan\ZQDcsApiService;

/**
 * 枣泉自动化——东井通风
 */
class ZQDcsFanController  extends BaseController
{

    private $db_name="etl_zaoquan";

    protected $apiService;
    protected $apiUrl = /** @lang text */
        "http://7.250.4.3:4300/v1/common/GetPointRealDataByPageV3";

    private $xuan = ["对旋1","对旋2","对旋2"];
    private $kong = ["近控","遥控","远控"];
    private $guzhang = ["无故障","前级故障","后级故障"];
    private $open = ["打开","关闭"];


    public function __construct(ZQDcsApiService $apiService)
    {
        parent::__construct();
        $this->apiService = $apiService;
    }

    public function getList(Request $request) {
        $sysCode = isset($request->sys_code) ? $request->sys_code : null;     // 矿分类
        if ($sysCode == null) {
            $msg="参数为空";
            $code=-1;
            return $this->error($code, $msg);
        } else {
            switch ($sysCode) {
                case "east": // 东井
                    return $this->getEastList();
                case "west": // 西井
                    return $this->getWestList();
                case "5fq": // 五分区
                    return $this->get5fqList();
                case "1314": // 1314立井
                    return $this->get1314List();
                case "1200sm": // 1200石门 * 150201回风巷通风机
                    return $this->get1200smList();
                case "1200car": // 1200车场 * 150201机巷通风机
                    return $this->get1200CarFanList();
                case "220708fzx": // 220708辅助巷
                    return $this->get220708fzxList();
                case "220708hfx": // 220708回风巷
                    return $this->get220708hfxList();
                case "220708jdx": // 220708胶带巷
                    return $this->get220708jdxList();
                case "110207hfx": // 110207回风巷
                    return $this->get110207hfxList();
                case "110207jx": // 110207机巷
                    return $this->get110207jxList();
                case "250602hfx": // 250602回风巷
                    return $this->get250602hfxList();
                case "13207jx": // 13207机巷
                    return $this->get13207jxList();
                case "1295hfx": // 1295回风巷
                    return $this->get1295hfxList();
                case "index": //
                    return $this->getInfoList();
                default:
                    $msg="未知数据";
                    $code=-2;
                    return $this->error($code, $msg);
            }
        }
    }

    /*
     * 通风入口接口
     * */
    public function getInfoList() {

        $keys=[
            "2074993339513857_2", "2074993343917057_2", // 13207机巷
            "2074957345481729_1", // 110207机巷电流
            "2074957345532929_1", // 110207机巷电流
            "2074957345598465_1", // 110207机巷电流
            "2074957345651713_1", // 110207机巷电流
            "2074957345965057_1", // 110207机巷电流
            "2074957346026497_1", // 110207机巷电流
            "2074957344244737_1", // 110207机巷电流
            "2074957344297985_1", // 110207机巷电流
            "2074957344345089_1", // 110207机巷电流
            "2074957344390145_1", // 110207机巷电流
            "2074957344433153_1", // 110207机巷电流
            "2074957344476161_1", // 110207机巷电流
// 13207机巷
            "2074993339513857_2", // 主机前级合闸运行
            "2074993340347393_2", // 主机后级合闸运行
            "2074993343917057_2", // 副机前级合闸运行
            "2074993344812033_2", // 副机后级合闸运行

            // 250602回风巷
            "2063316486075393_2", // 主机前级合闸运行
            "2063316486712321_2", // 主机后级合闸运行
            "2063316488862721_2", // 副机前级合闸运行
            "2063316489612289_2", // 副机后级合闸运行

            // 110207


            // 110207机巷
            "2074957336810497_2", // 主机前级合闸运行
            "2074957337701377_2", // 主机后级合闸运行
            "2074957340046337_2", // 副机前级合闸运行
            "2074957341252609_2", // 副机后级合闸运行

            // 五六分区220708胶带巷
            "2046522721719297_2", // 主机前级合闸运行
            "2046522722276353_2", // 主机后级合闸运行
            "2046522723800065_2", // 副机前级合闸运行
            "2046522724375553_2", // 副机后级合闸运行

            // 五六分区220708回风巷
            "2074999786576897_2", // 主机前级合闸运行
            "2074999787508737_2", // 主机后级合闸运行
            "2074999790310401_2", // 副机前级合闸运行
            "2074999791086593_2", // 副机后级合闸运行

            // 220708辅助巷
            "2046535459097601_2", // 主机前级合闸运行
            "2046535459722241_2", // 主机后级合闸运行
            "2046535461911553_2", // 副机后级合闸运行
            "2046535461340161_2", // 副机前级合闸运行

            // 150201机巷
            "2049479004468225_2", // 主机前级合闸运行
            "2049479004826625_2", // 主机后级合闸运行
            "2049479005195265_2", // 副机前级合闸运行
            "2049479006194689_2", // 副机后级合闸运行

            // 150201回风巷
            "2049479114750977_2", // 主机前级合闸运行
            "2049479115330561_2", // 主机后级合闸运行
            "2049479117224961_2", // 副机前级合闸运行
            "2049479117835265_2", // 副机后级合闸运行


            // 1314通风
            "2009721035631617_2", // 1314通风1_风门开到位
            "2009721047067649_2", // 1314通风2_风门开到位

            // 五分区
            "2008681964219393_2", // 1号通风_主风门全开
            "2008682656793601_2", // 2号通风_主风门全开

            // 西井
            "2009735056108545_2", // 1#变频器运行信号
            "2009735056409601_2", // 2#变频器运行信号
            "2009735056749569_2", // 3#变频器运行信号
            "2009735056929793_2", // 4#变频器运行信号

            // 东井
            "2008298771018753_2", // 1号电机合闸反馈
            "2008298771328001_2", // 2号电机合闸反馈
            "2008298771655681_2", // 3号电机合闸反馈
            "2008298771829761_2", // 4号电机合闸反馈

        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)["data"];

        // 获取风门数据
        // 自动风门 http://7.250.4.5:1434/zqk/api/AutomaticAirDoors/AutomaticAirDoor
        // 自动风窗 http://7.250.4.5:1434/zqk/api/AutomaticWindDevices/AutomaticWindDevice
        // 变频局扇 http://7.250.4.5:1434/zqk/api/LocalFans/LocalFan

        $autoAirDoorsUrl = "http://7.250.4.5:1434/zqk/api/AutomaticAirDoors/AutomaticAirDoor";
        $autoWindDevicesUrl = "http://7.250.4.5:1434/zqk/api/AutomaticWindDevices/AutomaticWindDevice";
        $LocalFansUrl = "http://7.250.4.5:1434/zqk/api/LocalFans/LocalFan";


        $autoAirDoorsData = $this->apiService->getApiData($autoAirDoorsUrl);
        $autoWindDevicesData = $this->apiService->getApiData($autoWindDevicesUrl);
        $LocalFansData = $this->apiService->getApiData($LocalFansUrl);

        // 获取饼图数据（数据库）
        // cq.wind.online_chart
        $data = $this->getDBDataFrom("data_websocket", "sys_type='cq.wind.online_chart'");
        $dataStr = $data[0]->data;
        $data = str_replace("'", "'", $dataStr);
        $windData = json_decode($data, true);

        $info = [
            "chartData_1"=>[
                "series"=>[
                    [
                        "data"=>[
                            [
                                "name"=>"有效风",
                                "value"=>round($windData["vaildWindRate"], 1)
                            ],
                            [
                                "name"=>"无效风",
                                "value"=>round(1-$windData["vaildWindRate"], 1)
                            ]
                        ]
                    ]
                ]
            ],
            "chartData_2"=>[
                "series"=>[
                    [
                        "data"=>[
                            [
                                "name"=>"供风量",
                                "value"=>$windData["needTotalQuantity"]
                            ],
                            [
                                "name"=>"需风量",
                                "value"=>$windData["needQuantity"]
                            ]
                        ]
                    ]
                ]
            ],
            "info"=>[
                [
                    "label"=>"自动风门",
                    "value"=>count($autoAirDoorsData["data"])."扇"
                ],
                [
                    "label"=>"自动风窗",
                    "value"=>count($autoWindDevicesData["data"])."扇"
                ],
                [
                    "label"=>"变频风扇",
                    "value"=>count($LocalFansData["data"])."扇"
                ]
            ],
            "list"=>[
                [
                    "title"=>"东井通风机",
                    "sys_code"=>"east",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2008298771018753_2"] + $baseData["2008298771328001_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2008298771018753_2"] + $baseData["2008298771328001_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2008298771655681_2"] + $baseData["2008298771829761_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2008298771655681_2"] + $baseData["2008298771829761_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ],
                [
                    "title"=>"西井通风机",
                    "sys_code"=>"west",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2009735056108545_2"] + $baseData["2009735056409601_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2009735056108545_2"] + $baseData["2009735056409601_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2009735056749569_2"] + $baseData["2009735056929793_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2009735056749569_2"] + $baseData["2009735056929793_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ],
                [
                    "title"=>"五分区通风机",
                    "sys_code"=>"5fq",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2008681964219393_2"] ?? 0,
                            "text"=>$baseData["2008681964219393_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2008682656793601_2"] ?? 0,
                            "text"=>$baseData["2008682656793601_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ],
                [
                    "title"=>"1314通风机",
                    "sys_code"=>"1314",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2009721035631617_2"] ?? 0,
                            "text"=>$baseData["2009721035631617_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2009721047067649_2"] ?? 0,
                            "text"=>$baseData["2009721047067649_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ],

                [
                    "title"=>"150201回风巷通风机",
                    "sys_code"=>"1200sm",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2049479114750977_2"] + $baseData["2049479115330561_2"] >= 1 ? 1 : 0,
                            "text"=>$baseData["2049479114750977_2"] + $baseData["2049479115330561_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2049479117224961_2"] + $baseData["2049479117835265_2"] >= 1 ? 1 : 0,
                            "text"=>$baseData["2049479117224961_2"] + $baseData["2049479117835265_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ],
                [
                    "title"=>"150201机巷通风机",
                    "sys_code"=>"1200car",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2049479004468225_2"] + $baseData["2049479004826625_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2049479004468225_2"] + $baseData["2049479004826625_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2049479005195265_2"] + $baseData["2049479006194689_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2049479005195265_2"] + $baseData["2049479006194689_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ],
                [
                    "title"=>"220708辅助巷通风机",
                    "sys_code"=>"220708fzx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2046535459097601_2"] + $baseData["2046535459722241_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2046535459097601_2"] + $baseData["2046535459722241_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2046535461911553_2"] + $baseData["2046535461340161_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2046535461911553_2"] + $baseData["2046535461340161_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ],
                [
                    "title"=>"220708回风巷通风机",
                    "sys_code"=>"220708hfx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2074999786576897_2"] + $baseData["2074999787508737_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2074999786576897_2"] + $baseData["2074999787508737_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2074999790310401_2"] + $baseData["2074999791086593_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2074999790310401_2"] + $baseData["2074999791086593_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ],
                [
                    "title"=>"220708胶带巷通风机",
                    "sys_code"=>"220708jdx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2046522721719297_2"] + $baseData["2046522722276353_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2046522721719297_2"] + $baseData["2046522722276353_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2046522723800065_2"] + $baseData["2046522724375553_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2046522723800065_2"] + $baseData["2046522724375553_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ],
                [
                    "title"=>"110207回风巷",
                    "sys_code"=>"110207hfx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2074957336810497_2"] + $baseData["2074957337701377_2"] > 0 ? 1 : 0,
                            "text"=>"停止"
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2074957340046337_2"] + $baseData["2074957341252609_2"] > 0 ? 1 : 0,
                            "text"=>"运行"
                        ]
                    ]
                ],
                [
                    "title"=>"110207机巷通风机",
                    "sys_code"=>"110207jx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2074957336810497_2"] + $baseData["2074957337701377_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2074957336810497_2"] + $baseData["2074957337701377_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2074957340046337_2"] + $baseData["2074957341252609_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2074957340046337_2"] + $baseData["2074957340046337_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ],
                [
                    "title"=>"250602回风巷通风机",
                    "sys_code"=>"250602hfx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2063316486075393_2"] + $baseData["2063316486712321_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2063316486075393_2"] + $baseData["2063316486712321_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2063316488862721_2"] + $baseData["2063316489612289_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2063316488862721_2"] + $baseData["2063316489612289_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ],
                [
                    "title"=>"13207机巷通风机",
                    "sys_code"=>"13207jx",
                    "info"=>[
                        [
                            "label"=>"1#风机",
                            "state"=>$baseData["2074993339513857_2"] + $baseData["2074993340347393_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2074993339513857_2"] + $baseData["2074993340347393_2"] > 0 ? "运行" : "停止",
                        ],
                        [
                            "label"=>"2#风机",
                            "state"=>$baseData["2074993343917057_2"] + $baseData["2074993344812033_2"] > 0 ? 1 : 0,
                            "text"=>$baseData["2074993343917057_2"] + $baseData["2074993344812033_2"] > 0 ? "运行" : "停止",
                        ]
                    ]
                ]
            ]
        ];

        return json_encode($info);
    }

    /*
     * 13207机巷
     */
    public function get13207jxList() {

        $keys = [

            "2074993339513857_2", // 主机前级合闸运行
            "2074993340347393_2", // 主机后级合闸运行
            "2074993343917057_2", // 副机前级合闸运行
            "2074993344812033_2", // 副机后级合闸运行

            "2074993348156417_1", // 主风机IA1电流
            "2074993348262913_1", // 主风机IB1电流
            "2074993348373505_1", // 主风机IC1电流

            "2074993349594113_1", // 副风机IA1电流
            "2074993349702657_1", // 副风机IB1电流
            "2074993349803009_1", // 副风机IC1电流

            "2074993348207617_1", // 主风机IA2电流
            "2074993348316161_1", // 主风机IB2电流
            "2074993348426753_1", // 主风机IC2电流

            "2074993349647361_1", // 副风机IA2电流
            "2074993349753857_1", // 副风机IB2电流
            "2074993349852161_1", // 副风机IC2电流

            "2074993350050817_1", // 风速
            "2074993348475905_1", // 主风机电压
            "2074993349905409_1", // 副风机电压

            "2074993340834817_2", // 主机对旋1模式
            "2074993340867585_2", // 主机对旋2模式
            "2074993340898305_2", // 主机对旋3模式

            "2074993345459201_2", // 副机对旋1模式
            "2074993345487873_2", // 副机对旋2模式
            "2074993345530881_2", // 副机对旋3模式

            "2074993341709313_2", // 主机近控
            "2074993341793281_2", // 主机遥控
            "2074993341750273_2", // 主机远控

            "2074993346049025_2", // 副机近控
            "2074993346116609_2", // 副机遥控
            "2074993346081793_2", // 副机远控

            "2074993339606017_2", // 主机前级无故障
            "2074993340498945_2", // 主机后级无故障
            "2074993344015361_2", // 副机前级无故障
            "2074993344912385_2", // 副机后级无故障

            "2074993340935169_2", // 主机带载
            "2074993345563649_2", // 副机带载

            "2074993341305857_2", // 主机欠压保护打开
            "2074993345631233_2", // 副机欠压保护打开

            "2074993341559809_2", // 主机过压保护打开
            "2074993345905665_2", // 副机过压保护打开

            "2074993338950657_2", // 主机主备选择备机
            "2074993343380481_2", // 副机主备选择备机

        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        // 工作方式
        $workMode = ["",""];
        if ($baseData["2074993340834817_2"] == 1) {
            $workMode[0] = "对旋1";
        } else if ($baseData["2074993340867585_2"] == 1) {
            $workMode[0] = "对旋2";
        } else if ($baseData["2074993340898305_2"] == 1) {
            $workMode[0] = "对旋3";
        }

        if ($baseData["2074993345459201_2"] == 1) {
            $workMode[1] = "对旋1";
        } else if ($baseData["2074993345487873_2"] == 1) {
            $workMode[1] = "对旋2";
        } else if ($baseData["2074993345530881_2"] == 1) {
            $workMode[1] = "对旋3";
        }

        $ctrlMode = ["",""];
        if ($baseData["2074993341709313_2"] == 1) {
            $ctrlMode[0] = "近控";
        } else if ($baseData["2074993341793281_2"] == 1) {
            $ctrlMode[0] = "遥控";
        } else if ($baseData["2074993341750273_2"] == 1) {
            $ctrlMode[0] = "远控";
        }

        if ($baseData["2074993346049025_2"] == 1) {
            $ctrlMode[1] = "近控";
        } else if ($baseData["2074993346116609_2"] == 1) {
            $ctrlMode[1] = "遥控";
        } else if ($baseData["2074993346081793_2"] == 1) {
            $ctrlMode[1] = "远控";
        }

        $fault = ["",""];
        if ($baseData["2074993339606017_2"] == 0) {
            $fault[0] = "前级故障";
        }
        if ($baseData["2074993340498945_2"] == 0) {
            $fault[0] = "后级故障";
        }
        if (empty($fault[0])) {
            $fault[0] = "无故障";
        }
        if ($baseData["2074993344015361_2"] == 0) {
            $fault[1] = "前级故障";
        }
        if ($baseData["2074993344912385_2"] == 0) {
            $fault[1] = "后级故障";
        }
        if (empty($fault[1])) {
            $fault[1] = "无故障";
        }

        $data["tab"]=[
            [
                "title"=>"主风机",
                "state"=>$baseData["2074993339513857_2"] + $baseData["2074993340347393_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ],
            [
                "title"=>"副风机",
                "state"=>$baseData["2074993343917057_2"] + $baseData["2074993344812033_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ]
        ];

        $data["table_1"]=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    "value_1"=>$baseData["2074993348156417_1"] ?? 0,
                    "value_2"=>$baseData["2074993349594113_1"] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    "value_1"=>$baseData["2074993348262913_1"] ?? 0,
                    "value_2"=>$baseData["2074993349702657_1"] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    "value_1"=>$baseData["2074993348373505_1"] ?? 0,
                    "value_2"=>$baseData["2074993349803009_1"] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    "value_1"=>$baseData["2074993348207617_1"] ?? 0,
                    "value_2"=>$baseData["2074993349647361_1"] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    "value_1"=>$baseData["2074993348316161_1"] ?? 0,
                    "value_2"=>$baseData["2074993349753857_1"] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    "value_1"=>$baseData["2074993348426753_1"] ?? 0,
                    "value_2"=>$baseData["2074993349852161_1"] ?? 0,
                ],
                [
                    "label"=>"电压（V）",
                    "value_1"=>$baseData["2074993348475905_1"] ?? 0,
                    "value_2"=>$baseData["2074993349905409_1"] ?? 0,
                ],
                [
                    "label"=>"工作方式",
                    "value_1"=>$workMode[0],
                    "value_2"=>$workMode[1],
                ],
                [
                    "label"=>"控制方式",
                    "value_1"=>$ctrlMode[0],
                    "value_2"=>$ctrlMode[1],
                ],
                [
                    "label"=>"故障状态",
                    "value_1"=>$fault[0],
                    "value_2"=>$fault[1],
                ],
                [
                    "label"=>"负荷设备",
                    "value_1"=>$baseData["2074993340935169_2"] == 1 ? "带载" : "空载",
                    "value_2"=>$baseData["2074993345563649_2"] == 1 ? "带载" : "空载",
                ],
                [
                    "label"=>"欠压保护",
                    "value_1"=>$baseData["2074993341305857_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2074993345631233_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"过压保护",
                    "value_1"=>$baseData["2074993341559809_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2074993345905665_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"主备选择",
                    "value_1"=>$baseData["2074993338950657_2"] == 0 ? "主机" : "备机",
                    "value_2"=>$baseData["2074993343380481_2"] == 0 ? "主机" : "备机",
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 1295回风巷
     */
    public function get1295hfxList() {

        $keys = [
            "2104728871521281_1",  // "1295回风巷通风机_主机前级状态"
            "2104728871715841_1",  // "1295回风巷通风机_主机后级状态"
            "2104728875791361_1",  // "1295回风巷通风机_副机前级状态"
            "2104728876463105_1",  // "1295回风巷通风机_副机后级状态"

            "2104728877978625_1",  // "1295回风巷通风机_风速"

            "2104728872152065_1",  // "1295回风巷通风机_主机系统电压"

            "2104728877591553_1",  // "1295回风巷通风机_副机系统电压"


            "2104728871367681_1",  // "1295回风巷通风机_主机前级A相电流"
            "2104728871414785_1",  // "1295回风巷通风机_主机前级B相电流"
            "2104728871463937_1",  // "1295回风巷通风机_主机前级C相电流"

            "2104728871568385_1",  // "1295回风巷通风机_主机后级A相电流"
            "2104728871619585_1",  // "1295回风巷通风机_主机后级B相电流"
            "2104728871668737_1",  // "1295回风巷通风机_主机后级C相电流"

            "2104728874243073_1",  // "1295回风巷通风机_副机前级A相电流"
            "2104728874750977_1",  // "1295回风巷通风机_副机前级B相电流"
            "2104728875435009_1",  // "1295回风巷通风机_副机前级C相电流"

            "2104728876125185_1",  // "1295回风巷通风机_副机后级A相电流"
            "2104728876305409_1",  // "1295回风巷通风机_副机后级B相电流"
            "2104728876383233_1",  // "1295回风巷通风机_副机后级C相电流"

            "2104728872752129_1",  // "1295回风巷通风机_主机额定电流"
            "2104728877810689_1",  // "1295回风巷通风机_副机额定电流"

            "2104728872494081_1",  // "1295回风巷通风机_主机额定电压"
            "2104728877757441_1",  // "1295回风巷通风机_副机额定电压"


            "2104728872051713_1",  // "1295回风巷通风机_主机欠压系数"
            "2104728876811265_1",  // "1295回风巷通风机_副机欠压系数"

            "2104728871926785_1",  // "1295回风巷通风机_主机欠压时间"
            "2104728876639233_1",  // "1295回风巷通风机_副机欠压时间"

            "2104728872313857_1",  // "1295回风巷通风机_主机过压系数"
            "2104728877706241_1",  // "1295回风巷通风机_副机过压系数"

            "2104728872215553_1",  // "1295回风巷通风机_主机过压时间"
            "2104728877655041_1",  // "1295回风巷通风机_副机过压时间"

            "2104728871316481_1",  // "1295回风巷通风机_主机不平衡系数"
            "2104728873632769_1",  // "1295回风巷通风机_副机不平衡系数"

            "2104728871220225_1",  // "1295回风巷通风机_主机不平衡保护时间"
            "2104728873106433_1",  // "1295回风巷通风机_副机不平衡保护时间"

            "2104728871764993_1",  // "1295回风巷通风机_主机启动器类型"
            "2104728876522497_1",  // "1295回风巷通风机_副机启动器类型"

            "2104728871879681_1",  // "1295回风巷通风机_主机工作模式"
            "2104728876581889_1",  // "1295回风巷通风机_副机工作模式"

            "2104728867851265_2",  // "1295回风巷通风机_主机前级合闸"
            "2104728869229569_2",  // "1295回风巷通风机_副机前级合闸"

            "2104728868600833_2",  // "1295回风巷通风机_主机后级合闸"
            "2104728869612545_2",  // "1295回风巷通风机_副机后级合闸"

            "2104891492305921_2",  // "1295回风巷通风机_主机短路功能"
            "2104891492623361_2",  // "1295回风巷通风机_副机短路功能"

            "2104891492588545_2",  // "1295回风巷通风机_主机欠压功能"
            "2104891492832257_2",  // "1295回风巷通风机_副机欠压功能"

            "2104891492684801_2",  // "1295回风巷通风机_主机过载功能"
            "2104891493096449_2",  // "1295回风巷通风机_副机过载功能"

            "2104891492656129_2",  // "1295回风巷通风机_主机过压功能"
            "2104891492948993_2",  // "1295回风巷通风机_副机过压功能"

            "2104893388291073_2",  // "1295回风巷通风机_主机不平衡功能"
            "2104891492744193_2",  // "1295回风巷通风机_副机不平衡功能"

            "2104728877927425_1",  // "1295回风巷通风机_电池芯总电压"

            "2104728870532097_2",  // "1295回风巷通风机_电池充电使能"
            "2104728871001089_2",  // "1295回风巷通风机_电池放电使能"

            "2104728870579201_2",  // "1295回风巷通风机_电池充电状态"
            "2104728871033857_2",  // "1295回风巷通风机_电池放电状态"

            "2104728877861889_1",  // "1295回风巷通风机_电池剩余电量"

        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];


        $data["tab"]=[
            [
                "title"=>"主风机",
                "state"=>$baseData["2104728871521281_1"] + $baseData["2104728871715841_1"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ],
            [
                "title"=>"副风机",
                "state"=>$baseData["2104728875791361_1"] + $baseData["2104728876463105_1"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ]
        ];

        $data["table_1"]=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    "value_1"=>$baseData["2104728871367681_1"] ?? 0,
                    "value_2"=>$baseData["2104728874243073_1"] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    "value_1"=>$baseData["2104728871414785_1"] ?? 0,
                    "value_2"=>$baseData["2104728874750977_1"] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    "value_1"=>$baseData["2104728871463937_1"] ?? 0,
                    "value_2"=>$baseData["2104728875435009_1"] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    "value_1"=>$baseData["2104728871568385_1"] ?? 0,
                    "value_2"=>$baseData["2104728876125185_1"] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    "value_1"=>$baseData["2104728871619585_1"] ?? 0,
                    "value_2"=>$baseData["2104728876305409_1"] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    "value_1"=>$baseData["2104728871668737_1"] ?? 0,
                    "value_2"=>$baseData["2104728876383233_1"] ?? 0,
                ],
                [
                    "label"=>"额定电流（A）",
                    "value_1"=>$baseData["2104728872752129_1"] ?? 0,
                    "value_2"=>$baseData["2104728877810689_1"] ?? 0,
                ],
                [
                    "label"=>"额定电压（V）",
                    "value_1"=>$baseData["2104728872494081_1"] ?? 0,
                    "value_2"=>$baseData["2104728877757441_1"] ?? 0,
                ],
                [
                    "label"=>"欠压倍数（%）",
                    "value_1"=>$baseData["2104728872051713_1"] ?? 0,
                    "value_2"=>$baseData["2104728876811265_1"] ?? 0,
                ],
                [
                    "label"=>"欠压时间（s）",
                    "value_1"=>$baseData["2104728871926785_1"] ?? 0,
                    "value_2"=>$baseData["2104728876639233_1"] ?? 0,
                ],
                [
                    "label"=>"过压倍数（%）",
                    "value_1"=>$baseData["2104728872313857_1"] ?? 0,
                    "value_2"=>$baseData["2104728877706241_1"] ?? 0,
                ],
                [
                    "label"=>"过压时间（s）",
                    "value_1"=>$baseData["2104728872215553_1"] ?? 0,
                    "value_2"=>$baseData["2104728877655041_1"] ?? 0,
                ],
                [
                    "label"=>"不平衡倍数（%）",
                    "value_1"=>$baseData["2104728871316481_1"] ?? 0,
                    "value_2"=>$baseData["2104728873632769_1"] ?? 0,
                ],
                [
                    "label"=>"不平衡保护时间（s）",
                    "value_1"=>$baseData["2104728871220225_1"] ?? 0,
                    "value_2"=>$baseData["2104728873106433_1"] ?? 0,
                ],
                [
                    "label"=>"启动器类型",
                    "value_1"=>($baseData["2104728871764993_1"] ?? 0) == 0 ? "主机" : "备机",
                    "value_2"=>($baseData["2104728876522497_1"] ?? 0) == 0 ? "主机" : "备机",
                ],
                [
                    "label"=>"工作方式",
                    "value_1"=>($baseData["2104728871879681_1"] ?? 0) == 0 ? "" : "主机对等",
                    "value_2"=>($baseData["2104728876581889_1"] ?? 0) == 0 ? "" : "主机对等",
                ],
                [
                    "label"=>"前级状态",
                    "value_1"=>($baseData["2104728867851265_2"] ?? 0) == 0 ? "分闸" : "合闸",
                    "value_2"=>($baseData["2104728869229569_2"] ?? 0) == 0 ? "分闸" : "合闸",
                ],
                [
                    "label"=>"后级状态",
                    "value_1"=>($baseData["2104728868600833_2"] ?? 0) == 0 ? "分闸" : "合闸",
                    "value_2"=>($baseData["2104728869612545_2"] ?? 0) == 0 ? "分闸" : "合闸",
                ],
                [
                    "label"=>"短路功能",
                    "value_1"=>($baseData["2104891492305921_2"] ?? 0) == 0 ? "关闭" : "打开",
                    "value_2"=>($baseData["2104891492623361_2"] ?? 0) == 0 ? "关闭" : "打开",
                ],
                [
                    "label"=>"欠压功能",
                    "value_1"=>($baseData["2104891492588545_2"] ?? 0) == 0 ? "关闭" : "打开",
                    "value_2"=>($baseData["2104891492832257_2"] ?? 0) == 0 ? "关闭" : "打开",
                ],
                [
                    "label"=>"过载功能",
                    "value_1"=>($baseData["2104891492684801_2"] ?? 0) == 0 ? "关闭" : "打开",
                    "value_2"=>($baseData["2104891493096449_2"] ?? 0) == 0 ? "关闭" : "打开",
                ],
                [
                    "label"=>"过压功能",
                    "value_1"=>($baseData["2104891492656129_2"] ?? 0) == 0 ? "关闭" : "打开",
                    "value_2"=>($baseData["2104891492948993_2"] ?? 0) == 0 ? "关闭" : "打开",
                ],
                [
                    "label"=>"不平衡功能",
                    "value_1"=>($baseData["2104893388291073_2"] ?? 0) == 0 ? "关闭" : "打开",
                    "value_2"=>($baseData["2104891492744193_2"] ?? 0) == 0 ? "关闭" : "打开",
                ],
                [
                    "label"=>"电池总压",
                    "value_1"=>$baseData["2104728877927425_1"] ?? 0,
                    "value_2"=>$baseData["2104728877927425_1"] ?? 0,
                ],
                [
                    "label"=>"进电状态",
                    "value_1"=>($baseData["2104728870532097_2"] ?? 0) == 0 ? "无进电" : "有进电",
                    "value_2"=>($baseData["2104728870532097_2"] ?? 0) == 0 ? "无进电" : "有进电",
                ],
                [
                    "label"=>"出电状态",
                    "value_1"=>($baseData["2104728871001089_2"] ?? 0) == 0 ? "无出电" : "无出电",
                    "value_2"=>($baseData["2104728871001089_2"] ?? 0) == 0 ? "无出电" : "无出电",
                ],
                [
                    "label"=>"充电状态",
                    "value_1"=>($baseData["2104728870579201_2"] ?? 0) == 0 ? "关闭" : "打开",
                    "value_2"=>($baseData["2104728870579201_2"] ?? 0) == 0 ? "关闭" : "打开",
                ],
                [
                    "label"=>"放电状态",
                    "value_1"=>($baseData["2104728870579201_2"] ?? 0) == 0 ? "关闭" : "打开",
                    "value_2"=>($baseData["2104728870579201_2"] ?? 0) == 0 ? "关闭" : "打开",
                ],
                [
                    "label"=>"电池电量",
                    "value_1"=>($baseData["2104728877861889_1"] ?? 0) == 0 ? "关闭" : "打开",
                    "value_2"=>($baseData["2104728877861889_1"] ?? 0) == 0 ? "关闭" : "打开",
                ],
            ]
        ];
        return json_encode($data);
    }

    /*
     * 250602回风巷
     */
    public function get250602hfxList() {

        $keys = [
            "2063316486075393_2", // 主机前级合闸运行
            "2063316486712321_2", // 主机后级合闸运行
            "2063316488862721_2", // 副机前级合闸运行
            "2063316489612289_2", // 副机后级合闸运行

            "2063316491957249_1", // 主风机IA1电流
            "2063316492041217_1", // 主风机IB1电流
            "2063316492125185_1", // 主风机IC1电流

            "2063316492788737_1", // 副风机IA1电流
            "2063316492878849_1", // 副风机IB1电流
            "2063316492964865_1", // 副风机IC1电流

            "2063316491998209_1", // 主风机IA2电流
            "2063316492084225_1", // 主风机IB2电流
            "2063316492168193_1", // 主风机IC2电流

            "2063316492835841_1", // 副风机IA2电流
            "2063316492923905_1", // 副风机IB2电流
            "2063316493007873_1", // 副风机IC2电流


            "2063316493194241_1", // 风速
            "2063316492209153_1", // 主风机电压
            "2063316493054977_1", // 副风机电压

            "2063316487095297_2", // 主机对旋1模式
            "2063316487130113_2", // 主机对旋2模式
            "2063316487160833_2", // 主机对旋3模式

            "2063316489995265_2", // 副机对旋1模式
            "2063316490028033_2", // 副机对旋2模式
            "2063316490058753_2", // 副机对旋3模式

            "2063316487590913_2", // 主机近控
            "2063316487648257_2", // 主机遥控
            "2063316487619585_2", // 主机远控

            "2063316490490881_2", // 副机近控
            "2063316490550273_2", // 副机遥控
            "2063316490521601_2", // 副机远控

            "2063316486167553_2", // 主机前级无故障
            "2063316486814721_2", // 主机后级无故障

            "2063316488983553_2", // 副机前级无故障
            "2063316489706497_2", // 副机后级无故障

            "2063316487189505_2", // 主机带载
            "2063316490087425_2", // 副机带载

            "2063316487250945_2", // 主机欠压保护打开
            "2063316490144769_2", // 副机欠压保护打开
            "2063316487474177_2", // 主机过压保护打开
            "2063316490374145_2", // 副机过压保护打开

            "2063316485768193_2", // 主机主备选择备机
            "2063316488530945_2", // 副机主备选择备机

        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        // 工作方式
        $workMode = ["",""];
        if ($baseData["2063316487095297_2"] == 1) {
            $workMode[0] = "对旋1";
        } else if ($baseData["2063316487130113_2"] == 1) {
            $workMode[0] = "对旋2";
        } else if ($baseData["2063316487160833_2"] == 1) {
            $workMode[0] = "对旋3";
        }

        if ($baseData["2063316489995265_2"] == 1) {
            $workMode[1] = "对旋1";
        } else if ($baseData["2063316490028033_2"] == 1) {
            $workMode[1] = "对旋2";
        } else if ($baseData["2063316490058753_2"] == 1) {
            $workMode[1] = "对旋3";
        }

        $ctrlMode = ["",""];
        if ($baseData["2063316487590913_2"] == 1) {
            $ctrlMode[0] = "近控";
        } else if ($baseData["2063316487648257_2"] == 1) {
            $ctrlMode[0] = "遥控";
        } else if ($baseData["2063316487619585_2"] == 1) {
            $ctrlMode[0] = "远控";
        }

        if ($baseData["2063316490490881_2"] == 1) {
            $ctrlMode[1] = "近控";
        } else if ($baseData["2063316490550273_2"] == 1) {
            $ctrlMode[1] = "遥控";
        } else if ($baseData["2063316490521601_2"] == 1) {
            $ctrlMode[1] = "远控";
        }

        $fault = ["",""];
        if ($baseData["2063316486167553_2"] == 0) {
            $fault[0] = "前级故障";
        }
        if ($baseData["2063316486814721_2"] == 0) {
            $fault[0] = "后级故障";
        }
        if (empty($fault[0])) {
            $fault[0] = "无故障";
        }
        if ($baseData["2063316488983553_2"] == 0) {
            $fault[1] = "前级故障";
        }
        if ($baseData["2063316489706497_2"] == 0) {
            $fault[1] = "后级故障";
        }
        if (empty($fault[1])) {
            $fault[1] = "无故障";
        }

        $data["tab"]=[
            [
                "title"=>"主风机",
                "state"=>$baseData["2063316486075393_2"] + $baseData["2063316486712321_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ],
            [
                "title"=>"副风机",
                "state"=>$baseData["2063316488862721_2"] + $baseData["2063316489612289_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ]
        ];

        $data["table_1"]=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    "value_1"=>$baseData["2063316491957249_1"] ?? 0,
                    "value_2"=>$baseData["2063316492788737_1"] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    "value_1"=>$baseData["2063316492041217_1"] ?? 0,
                    "value_2"=>$baseData["2063316492878849_1"] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    "value_1"=>$baseData["2063316492125185_1"] ?? 0,
                    "value_2"=>$baseData["2063316492964865_1"] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    "value_1"=>$baseData["2063316491998209_1"] ?? 0,
                    "value_2"=>$baseData["2063316492835841_1"] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    "value_1"=>$baseData["2063316492084225_1"] ?? 0,
                    "value_2"=>$baseData["2063316492923905_1"] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    "value_1"=>$baseData["2063316492168193_1"] ?? 0,
                    "value_2"=>$baseData["2063316493007873_1"] ?? 0,
                ],
                [
                    "label"=>"电压（V）",
                    "value_1"=>$baseData["2063316492209153_1"] ?? 0,
                    "value_2"=>$baseData["2063316493054977_1"] ?? 0,
                ],
                [
                    "label"=>"工作方式",
                    "value_1"=>$workMode[0],
                    "value_2"=>$workMode[1],
                ],
                [
                    "label"=>"控制方式",
                    "value_1"=>$ctrlMode[0],
                    "value_2"=>$ctrlMode[1],
                ],
                [
                    "label"=>"故障状态",
                    "value_1"=>$fault[0],
                    "value_2"=>$fault[1],
                ],
                [
                    "label"=>"负荷设备",
                    "value_1"=>$baseData["2063316487189505_2"] == 1 ? "带载" : "空载",
                    "value_2"=>$baseData["2063316490087425_2"] == 1 ? "带载" : "空载",
                ],
                [
                    "label"=>"欠压保护",
                    "value_1"=>$baseData["2063316487250945_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2063316490144769_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"过压保护",
                    "value_1"=>$baseData["2063316487474177_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2063316490374145_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"主备选择",
                    "value_1"=>$baseData["2063316485768193_2"] == 0 ? "主机" : "备机",
                    "value_2"=>$baseData["2063316488530945_2"] == 0 ? "主机" : "备机",
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 110207回风巷
     * 数据不对
     */
    public function get110207hfxList() {

        $keys=[
            "2059629797024769_1","2059629797067777_1","2059629797108737_1","2059629797192705_1",
            "2059629797233665_1","2059629797274625_1","2059629795988481_1","2059629796031489_1",
            "2059629796072449_1","2059629796158465_1","2059629796199425_1","2059629796238337_1",
            "2059629794612225_2","2059629795228673_2","2059629794855937_2","2059629795525633_2",
            "2059629798036481_1","2059629796819969_1","2059629796609025_1","2059629797950465_1",
            "2059629797708801_1","2060356330568705_1","2060356330460161_1","2059629796858881_1",
            "2059629797995521_1",
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        $data["tab"]=[
            [
                "title"=>"主风机",
                "state"=>  $baseData["2059629794612225_2"] ?? 0,
                "list"=>[
                    [
                        "label"=>"风速",
                        "unit"=>"m/s",
                        "num"=> $baseData["2059629798036481_1"] ?? 0,
                    ],
                    [
                        "label"=>"电池电压",
                        "unit"=>"V",
                        "num"=> $baseData["2060356330568705_1"] ?? 0,
                    ],
                    [
                        "label"=>"1号电机",
                        "unit"=>"",
                        "num"=> $baseData["2059629794612225_2"] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=> $baseData["2059629794855937_2"] ?? 0,
                    ],
                ]
            ],
            [
                "title"=>"副风机",
                "state"=>$baseData["2059629795228673_2"] ?? 0,
                "list"=>[
                    [
                        "label"=>"风速",
                        "unit"=>"m/s",
                        "num"=> $baseData["2059629798036481_1"] ?? 0,
                    ],
                    [
                        "label"=>"电池电量",
                        "unit"=>"%",
                        "num"=> $baseData["2060356330460161_1"] ?? 0,
                    ],
                    [
                        "label"=>"1号电机",
                        "unit"=>"",
                        "num"=>$baseData["2059629795228673_2"] ?? 0,
                    ],
                    [
                        "label"=>"2号电机",
                        "unit"=>"",
                        "num"=>$baseData["2059629795525633_2"] ?? 0,
                    ],
                ]
            ]
        ];

        $data["table_1"]=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"电压（V）",
                    "value_1"=>$baseData["2059629796609025_1"] ?? 0,
                    "value_2"=>$baseData["2059629797708801_1"] ?? 0,
                ],
                [
                    "label"=>"前级A相电流（A）",
                    "value_1"=>$baseData["2059629795988481_1"] ?? 0,
                    "value_2"=>$baseData["2059629797024769_1"] ?? 0,
                ],
                [
                    "label"=>"前级B相电流（A）",
                    "value_1"=>$baseData["2059629796031489_1"] ?? 0,
                    "value_2"=>$baseData["2059629797067777_1"] ?? 0,
                ],
                [
                    "label"=>"前级C相电流（A）",
                    "value_1"=>$baseData["2059629796072449_1"] ?? 0,
                    "value_2"=>$baseData["2059629797108737_1"] ?? 0,
                ],
                [
                    "label"=>"后级A相电流（A）",
                    "value_1"=>$baseData["2059629796158465_1"] ?? 0,
                    "value_2"=>$baseData["2059629797192705_1"] ?? 0,
                ],
                [
                    "label"=>"后级B相电流（A）",
                    "value_1"=>$baseData["2059629796199425_1"] ?? 0,
                    "value_2"=>$baseData["2059629797233665_1"] ?? 0,
                ],
                [
                    "label"=>"后级C相电流（A）",
                    "value_1"=>$baseData["2059629796238337_1"] ?? 0,
                    "value_2"=>$baseData["2059629797274625_1"] ?? 0,
                ],
                [
                    "label"=>"额定电流（A）",
                    "value_1"=>$baseData["2059629796858881_1"] ?? 0,
                    "value_2"=>$baseData["2059629797995521_1"] ?? 0,
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 110207机巷
     */
    public function get110207jxList() {

        $keys = [
            "2074957336810497_2", // 主机前级合闸运行
            "2074957337701377_2", // 主机后级合闸运行
            "2074957340046337_2", // 副机前级合闸运行
            "2074957341252609_2", // 副机后级合闸运行

            "2074957344244737_1", // 主风机IA1电流
            "2074957344345089_1", // 主风机IB1电流
            "2074957344433153_1", // 主风机IC1电流

            "2074957345481729_1", // 副风机IA1电流
            "2074957345598465_1", // 副风机IB1电流
            "2074957345965057_1", // 副风机IC1电流

            "2074957344297985_1", // 主风机IA2电流
            "2074957344390145_1", // 主风机IB2电流
            "2074957344476161_1", // 主风机IC2电流

            "2074957345532929_1", // 副风机IA2电流
            "2074957345651713_1", // 副风机IB2电流
            "2074957346026497_1", // 副风机IC2电流

            "2074957346257921_1", // 风速
            "2074957344537601_1", // 主风机电压
            "2074957346079745_1", // 副风机电压

            "2074957338092545_2", // 主机对旋1模式
            "2074957338123265_2", // 主机对旋2模式
            "2074957338153985_2", // 主机对旋3模式

            "2074957341643777_2", // 副机对旋1模式
            "2074957341676545_2", // 副机对旋2模式
            "2074957341707265_2", // 副机对旋3模式

            "2074957338598401_2", // 主机近控
            "2074957338668033_2", // 主机遥控
            "2074957338635265_2", // 主机远控

            "2074957342182401_2", // 副机近控
            "2074957342241793_2", // 副机遥控
            "2074957342211073_2", // 副机远控

            "2074957336919041_2", // 主机前级无故障
            "2074957337805825_2", // 主机后级无故障

            "2074957340161025_2", // 副机前级无故障
            "2074957341361153_2", // 副机后级无故障

            "2074957338182657_2", // 主机带载
            "2074957341735937_2", // 副机带载

            "2074957338242049_2", // 主机欠压保护打开
            "2074957341813761_2", // 副机欠压保护打开

            "2074957338475521_2", // 主机过压保护打开
            "2074957342041089_2", // 副机过压保护打开

            "2074957336370177_2", // 主机主备选择备机
            "2074957339655169_2", // 副机主备选择备机

        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        // 工作方式
        $workMode = ["",""];
        if ($baseData["2074957338092545_2"] == 1) {
            $workMode[0] = "对旋1";
        } else if ($baseData["2074957338123265_2"] == 1) {
            $workMode[0] = "对旋2";
        } else if ($baseData["2074957338153985_2"] == 1) {
            $workMode[0] = "对旋3";
        }

        if ($baseData["2074957341643777_2"] == 1) {
            $workMode[1] = "对旋1";
        } else if ($baseData["2074957341676545_2"] == 1) {
            $workMode[1] = "对旋2";
        } else if ($baseData["2074957341707265_2"] == 1) {
            $workMode[1] = "对旋3";
        }

        $ctrlMode = ["",""];
        if ($baseData["2074957338598401_2"] == 1) {
            $ctrlMode[0] = "近控";
        } else if ($baseData["2074957338668033_2"] == 1) {
            $ctrlMode[0] = "遥控";
        } else if ($baseData["2074957338635265_2"] == 1) {
            $ctrlMode[0] = "远控";
        }

        if ($baseData["2074957342182401_2"] == 1) {
            $ctrlMode[1] = "近控";
        } else if ($baseData["2074957342241793_2"] == 1) {
            $ctrlMode[1] = "遥控";
        } else if ($baseData["2074957342211073_2"] == 1) {
            $ctrlMode[1] = "远控";
        }

        $fault = ["",""];
        if ($baseData["2074957336919041_2"] == 0) {
            $fault[0] = "前级故障";
        }
        if ($baseData["2074957337805825_2"] == 0) {
            $fault[0] = "后级故障";
        }
        if (empty($fault[0])) {
            $fault[0] = "无故障";
        }
        if ($baseData["2074957340161025_2"] == 0) {
            $fault[1] = "前级故障";
        }
        if ($baseData["2074957341361153_2"] == 0) {
            $fault[1] = "后级故障";
        }
        if (empty($fault[1])) {
            $fault[1] = "无故障";
        }

        $data["tab"]=[
            [
                "title"=>"主风机",
                "state"=>$baseData["2074957336810497_2"] + $baseData["2074957337701377_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ],
            [
                "title"=>"副风机",
                "state"=>$baseData["2074957340046337_2"] + $baseData["2074957341252609_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ]
        ];

        $data["table_1"]=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    "value_1"=>$baseData["2074957344244737_1"] ?? 0,
                    "value_2"=>$baseData["2074957345481729_1"] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    "value_1"=>$baseData["2074957344345089_1"] ?? 0,
                    "value_2"=>$baseData["2074957345598465_1"] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    "value_1"=>$baseData["2074957344433153_1"] ?? 0,
                    "value_2"=>$baseData["2074957345965057_1"] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    "value_1"=>$baseData["2074957344297985_1"] ?? 0,
                    "value_2"=>$baseData["2074957345532929_1"] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    "value_1"=>$baseData["2074957344390145_1"] ?? 0,
                    "value_2"=>$baseData["2074957345651713_1"] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    "value_1"=>$baseData["2074957344476161_1"] ?? 0,
                    "value_2"=>$baseData["2074957346026497_1"] ?? 0,
                ],
                [
                    "label"=>"电压（V）",
                    "value_1"=>$baseData["2074957344537601_1"] ?? 0,
                    "value_2"=>$baseData["2074957346079745_1"] ?? 0,
                ],
                [
                    "label"=>"工作方式",
                    "value_1"=>$workMode[0],
                    "value_2"=>$workMode[1],
                ],
                [
                    "label"=>"控制方式",
                    "value_1"=>$ctrlMode[0],
                    "value_2"=>$ctrlMode[1],
                ],
                [
                    "label"=>"故障状态",
                    "value_1"=>$fault[0],
                    "value_2"=>$fault[1],
                ],
                [
                    "label"=>"负荷设备",
                    "value_1"=>$baseData["2074957338182657_2"] == 1 ? "带载" : "空载",
                    "value_2"=>$baseData["2074957341735937_2"] == 1 ? "带载" : "空载",
                ],
                [
                    "label"=>"欠压保护",
                    "value_1"=>$baseData["2074957338242049_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2074957341813761_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"过压保护",
                    "value_1"=>$baseData["2074957338475521_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2074957342041089_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"主备选择",
                    "value_1"=>$baseData["2074957336370177_2"] == 0 ? "主机" : "备机",
                    "value_2"=>$baseData["2074957339655169_2"] == 0 ? "主机" : "备机",
                ]
            ]
        ];
        return json_encode($data);
    }
    /*
     * 五六分区220708胶带巷
     */
    public function get220708jdxList() {

        $keys = [
            "2046522721719297_2", // 主机前级合闸运行
            "2046522722276353_2", // 主机后级合闸运行
            "2046522723800065_2", // 副机前级合闸运行
            "2046522724375553_2", // 副机后级合闸运行

            "2046522726140929_1", // 主风机IA1电流
            "2046522726222849_1", // 主风机IB1电流
            "2046522726312961_1", // 主风机IC1电流

            "2046522726851585_1", // 副风机IA1电流
            "2046522726927361_1", // 副风机IB1电流
            "2046522726999041_1", // 副风机IC1电流

            "2046522726181889_1", // 主风机IA2电流
            "2046522726267905_1", // 主风机IB2电流
            "2046522726351873_1", // 主风机IC2电流

            "2046522726888449_1", // 副风机IA2电流
            "2046522726962177_1", // 副风机IB2电流
            "2046522727037953_1", // 副风机IC2电流

            "2066324824214529_1", // 风速

            "2046522726392833_1", // 主风机电压
            "2046522727113729_1", // 副风机电压

            "2046522722565121_2", // 主机对旋1模式
            "2046522722589697_2", // 主机对旋2模式
            "2046522722612225_2", // 主机对旋3模式

            "2046522724668417_2", // 副机对旋1模式
            "2046522724692993_2", // 副机对旋2模式
            "2046522724717569_2", // 副机对旋3模式

            "2046522725059585_2", // 副机近控
            "2046522725110785_2", // 副机遥控
            "2046522725086209_2", // 副机远控

            "2046522722980865_2", // 主机近控
            "2046522723046401_2", // 主机遥控
            "2046522723015681_2", // 主机远控

            "2046522721793025_2", // 主机前级无故障
            "2046522722348033_2", // 主机后级无故障

            "2046522723873793_2", // 副机前级无故障
            "2046522724447233_2", // 副机后级无故障

            "2046522722638849_2", // 主机带载
            "2046522724740097_2", // 副机带载

            "2046522722694145_2", // 主机欠压保护打开
            "2046522724789249_2", // 副机欠压保护打开

            "2046522722878465_2", // 主机过压保护打开
            "2046522724961281_2", // 副机过压保护打开

            "2046522721430529_2", // 主机主备选择备机
            "2046522723517441_2", // 副机主备选择备机
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        // 工作方式
        $workMode = ["",""];
        if ($baseData["2046522722565121_2"] == 1) {
            $workMode[0] = "对旋1";
        } else if ($baseData["2046522722589697_2"] == 1) {
            $workMode[0] = "对旋2";
        } else if ($baseData["2046522722612225_2"] == 1) {
            $workMode[0] = "对旋3";
        }

        if ($baseData["2046522724668417_2"] == 1) {
            $workMode[1] = "对旋1";
        } else if ($baseData["2046522724692993_2"] == 1) {
            $workMode[1] = "对旋2";
        } else if ($baseData["2046522724717569_2"] == 1) {
            $workMode[1] = "对旋3";
        }

        $ctrlMode = ["",""];
        if ($baseData["2046522725059585_2"] == 1) {
            $ctrlMode[0] = "近控";
        } else if ($baseData["2046522725110785_2"] == 1) {
            $ctrlMode[0] = "遥控";
        } else if ($baseData["2046522725086209_2"] == 1) {
            $ctrlMode[0] = "远控";
        }

        if ($baseData["2046522722980865_2"] == 1) {
            $ctrlMode[1] = "近控";
        } else if ($baseData["2046522723046401_2"] == 1) {
            $ctrlMode[1] = "遥控";
        } else if ($baseData["2046522723015681_2"] == 1) {
            $ctrlMode[1] = "远控";
        }

        $fault = ["",""];
        if ($baseData["2046522721793025_2"] == 0) {
            $fault[0] = "前级故障";
        }
        if ($baseData["2046522722348033_2"] == 0) {
            $fault[0] = "后级故障";
        }
        if (empty($fault[0])) {
            $fault[0] = "无故障";
        }
        if ($baseData["2046522723873793_2"] == 0) {
            $fault[1] = "前级故障";
        }
        if ($baseData["2046522724447233_2"] == 0) {
            $fault[1] = "后级故障";
        }
        if (empty($fault[1])) {
            $fault[1] = "无故障";
        }

        $data["tab"]=[
            [
                "title"=>"主风机",
                "state"=>$baseData["2046522721719297_2"] + $baseData["2046522722276353_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ],
            [
                "title"=>"副风机",
                "state"=>$baseData["2046522723800065_2"] + $baseData["2046522724375553_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ]
        ];

        $data["table_1"]=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    "value_1"=>$baseData["2046522726140929_1"] ?? 0,
                    "value_2"=>$baseData["2046522726851585_1"] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    "value_1"=>$baseData["2046522726222849_1"] ?? 0,
                    "value_2"=>$baseData["2046522726927361_1"] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    "value_1"=>$baseData["2046522726312961_1"] ?? 0,
                    "value_2"=>$baseData["2046522726999041_1"] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    "value_1"=>$baseData["2046522726181889_1"] ?? 0,
                    "value_2"=>$baseData["2046522726888449_1"] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    "value_1"=>$baseData["2046522726267905_1"] ?? 0,
                    "value_2"=>$baseData["2046522726962177_1"] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    "value_1"=>$baseData["2046522726351873_1"] ?? 0,
                    "value_2"=>$baseData["2046522727037953_1"] ?? 0,
                ],
                [
                    "label"=>"电压（V）",
                    "value_1"=>$baseData["2046522726392833_1"] ?? 0,
                    "value_2"=>$baseData["2046522727113729_1"] ?? 0,
                ],
                [
                    "label"=>"工作方式",
                    "value_1"=>$workMode[0],
                    "value_2"=>$workMode[1],
                ],
                [
                    "label"=>"控制方式",
                    "value_1"=>$ctrlMode[0],
                    "value_2"=>$ctrlMode[1],
                ],
                [
                    "label"=>"故障状态",
                    "value_1"=>$fault[0],
                    "value_2"=>$fault[1],
                ],
                [
                    "label"=>"负荷设备",
                    "value_1"=>$baseData["2046522722638849_2"] == 1 ? "带载" : "空载",
                    "value_2"=>$baseData["2046522724740097_2"] == 1 ? "带载" : "空载",
                ],
                [
                    "label"=>"欠压保护",
                    "value_1"=>$baseData["2046522722694145_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2046522724789249_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"过压保护",
                    "value_1"=>$baseData["2046522722878465_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2046522724961281_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"主备选择",
                    "value_1"=>$baseData["2046522721430529_2"] == 0 ? "主机" : "备机",
                    "value_2"=>$baseData["2046522723517441_2"] == 0 ? "主机" : "备机",
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 五六分区220708回风巷
     */
    public function get220708hfxList() {

        $keys = [
            "2074999786576897_2", // 主机前级合闸运行
            "2074999787508737_2", // 主机后级合闸运行
            "2074999790310401_2", // 副机前级合闸运行
            "2074999791086593_2", // 副机后级合闸运行

            "2074999793785857_1", // 主风机IA1电流
            "2074999793900545_1", // 主风机IB1电流
            "2074999793992705_1", // 主风机IC1电流

            "2074999794951169_1", // 副风机IA1电流
            "2074999795059713_1", // 副风机IB1电流
            "2074999795184641_1", // 副风机IC1电流

            "2074999793845249_1", // 主风机IA2电流
            "2074999793945601_1", // 主风机IB2电流
            "2074999794043905_1", // 主风机IC2电流

            "2074999795008513_1", // 副风机IA2电流
            "2074999795127297_1", // 副风机IB2电流
            "2074999795237889_1", // 副风机IC2电流

            "2074999794095105_1", // 主风机电压
            "2074999795319809_1", // 副风机电压

            "2074999788104705_2", // 主机对旋1模式
            "2074999788137473_2", // 主机对旋2模式
            "2074999788170241_2", // 主机对旋3模式

            "2074999791510529_2", // 副机对旋1模式
            "2074999791543297_2", // 副机对旋2模式
            "2074999791576065_2", // 副机对旋3模式

            "2074999788717057_2", // 主机近控
            "2074999788788737_2", // 主机遥控
            "2074999788751873_2", // 主机远控

            "2074999792088065_2", // 副机近控
            "2074999792151553_2", // 副机遥控
            "2074999792120833_2", // 副机远控

            "2074999786685441_2", // 主机前级无故障
            "2074999787619329_2", // 主机后级无故障

            "2074999791195137_2", // 副机后级无故障
            "2074999790408705_2", // 副机前级无故障

            "2074999788209153_2", // 主机带载
            "2074999791606785_2", // 副机带载

            "2074999788280833_2", // 主机欠压保护打开
            "2074999791668225_2", // 副机欠压保护打开

            "2074999788567553_2", // 主机过压保护打开
            "2074999791954945_2", // 副机过压保护打开


            "2074999786189825_2", // 主机主备选择备机
            "2074999789917185_2", // 副机主备选择备机

        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        // 工作方式
        $workMode = ["",""];
        if ($baseData["2074999788104705_2"] == 1) {
            $workMode[0] = "对旋1";
        } else if ($baseData["2074999788137473_2"] == 1) {
            $workMode[0] = "对旋2";
        } else if ($baseData["2074999788170241_2"] == 1) {
            $workMode[0] = "对旋3";
        }

        if ($baseData["2074999791510529_2"] == 1) {
            $workMode[1] = "对旋1";
        } else if ($baseData["2074999791543297_2"] == 1) {
            $workMode[1] = "对旋2";
        } else if ($baseData["2074999791576065_2"] == 1) {
            $workMode[1] = "对旋3";
        }

        $ctrlMode = ["",""];
        if ($baseData["2074999788717057_2"] == 1) {
            $ctrlMode[0] = "近控";
        } else if ($baseData["2074999788788737_2"] == 1) {
            $ctrlMode[0] = "遥控";
        } else if ($baseData["2074999788751873_2"] == 1) {
            $ctrlMode[0] = "远控";
        }

        if ($baseData["2074999792088065_2"] == 1) {
            $ctrlMode[1] = "近控";
        } else if ($baseData["2074999792151553_2"] == 1) {
            $ctrlMode[1] = "遥控";
        } else if ($baseData["2074999792120833_2"] == 1) {
            $ctrlMode[1] = "远控";
        }

        $fault = ["",""];
        if ($baseData["2074999786685441_2"] == 0) {
            $fault[0] = "前级故障";
        }
        if ($baseData["2074999787619329_2"] == 0) {
            $fault[0] = "后级故障";
        }
        if (empty($fault[0])) {
            $fault[0] = "无故障";
        }
        if ($baseData["2074999791195137_2"] == 0) {
            $fault[1] = "前级故障";
        }
        if ($baseData["2074999790408705_2"] == 0) {
            $fault[1] = "后级故障";
        }
        if (empty($fault[1])) {
            $fault[1] = "无故障";
        }

        $data["tab"]=[
            [
                "title"=>"主风机",
                "state"=>$baseData["2074999786576897_2"] + $baseData["2074999787508737_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ],
            [
                "title"=>"副风机",
                "state"=>$baseData["2074999790310401_2"] + $baseData["2074999791086593_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ]
        ];

        $data["table_1"]=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    "value_1"=>$baseData["2074999793785857_1"] ?? 0,
                    "value_2"=>$baseData["2074999794951169_1"] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    "value_1"=>$baseData["2074999793900545_1"] ?? 0,
                    "value_2"=>$baseData["2074999795059713_1"] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    "value_1"=>$baseData["2074999793992705_1"] ?? 0,
                    "value_2"=>$baseData["2074999795184641_1"] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    "value_1"=>$baseData["2074999793845249_1"] ?? 0,
                    "value_2"=>$baseData["2074999795008513_1"] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    "value_1"=>$baseData["2074999793945601_1"] ?? 0,
                    "value_2"=>$baseData["2074999795127297_1"] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    "value_1"=>$baseData["2074999794043905_1"] ?? 0,
                    "value_2"=>$baseData["2074999795237889_1"] ?? 0,
                ],
                [
                    "label"=>"电压（V）",
                    "value_1"=>$baseData["2074999794095105_1"] ?? 0,
                    "value_2"=>$baseData["2074999795319809_1"] ?? 0,
                ],
                [
                    "label"=>"工作方式",
                    "value_1"=>$workMode[0],
                    "value_2"=>$workMode[1],
                ],
                [
                    "label"=>"控制方式",
                    "value_1"=>$ctrlMode[0],
                    "value_2"=>$ctrlMode[1],
                ],
                [
                    "label"=>"故障状态",
                    "value_1"=>$fault[0],
                    "value_2"=>$fault[1],
                ],
                [
                    "label"=>"负荷设备",
                    "value_1"=>$baseData["2074999788209153_2"] == 1 ? "带载" : "空载",
                    "value_2"=>$baseData["2074999791606785_2"] == 1 ? "带载" : "空载",
                ],
                [
                    "label"=>"欠压保护",
                    "value_1"=>$baseData["2074999788280833_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2074999791668225_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"过压保护",
                    "value_1"=>$baseData["2074999788567553_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2074999791954945_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"主备选择",
                    "value_1"=>$baseData["2074999786189825_2"] == 0 ? "主机" : "备机",
                    "value_2"=>$baseData["2074999789917185_2"] == 0 ? "主机" : "备机",
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 五六分区
     * 220708辅助巷
     */
    public function get220708fzxList() {

        $keys = [
            "2046535459097601_2", // 主机前级合闸运行
            "2046535459722241_2", // 主机后级合闸运行
            "2046535461911553_2", // 副机后级合闸运行
            "2046535461340161_2", // 副机前级合闸运行

            "2046535463324673_1", // 主风机IA1电流
            "2046535463404545_1", // 主风机IB1电流
            "2046535463496705_1", // 主风机IC1电流

            "2046535463621633_1", // 副风机IA1电流
            "2046535463697409_1", // 副风机IB1电流
            "2046535463771137_1", // 副风机IC1电流

            "2046535463363585_1", // 主风机IA2电流
            "2046535463457793_1", // 主风机IB2电流
            "2046535463541761_1", // 主风机IC2电流

            "2046535463658497_1", // 副风机IA2电流
            "2046535463732225_1", // 副风机IB2电流
            "2046535463814145_1", // 副风机IC2电流

            "2066323762850817_1", // 风速
            "2046535463582721_1", // 主风机电压
            "2046535463857153_1", // 副风机电压

            "2046535460068353_2", // 主机对旋1模式
            "2046535460099073_2", // 主机对旋2模式
            "2046535460133889_2", // 主机对旋3模式

            "2046535462243329_2", // 副机对旋1模式
            "2046535462269953_2", // 副机对旋2模式
            "2046535462296577_2", // 副机对旋3模式

            "2046535460506625_2", // 主机近控
            "2046535460574209_2", // 主机遥控
            "2046535460547585_2", // 主机远控

            "2046535462714369_2", // 副机近控
            "2046535462769665_2", // 副机遥控
            "2046535462743041_2", // 副机远控

            "2046535459806209_2", // 主机后级无故障
            "2046535459177473_2", // 主机前级无故障

            "2046535461999617_2", // 副机后级无故障
            "2046535461415937_2", // 副机前级无故障

            "2046535460164609_2", // 主机带载
            "2046535462325249_2", // 副机带载

            "2046535460219905_2", // 主机欠压保护打开
            "2046535462392833_2", // 副机欠压保护打开

            "2046535460400129_2", // 主机过压保护打开
            "2046535462593537_2", // 副机过压保护打开

            "2046535458790401_2", // 主机主备选择备机
            "2046535461028865_2", // 副机主备选择备机
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        // 工作方式
        $workMode = ["",""];
        if ($baseData["2046535460068353_2"] == 1) {
            $workMode[0] = "对旋1";
        } else if ($baseData["2046535460099073_2"] == 1) {
            $workMode[0] = "对旋2";
        } else if ($baseData["2046535460133889_2"] == 1) {
            $workMode[0] = "对旋3";
        }

        if ($baseData["2046535462243329_2"] == 1) {
            $workMode[1] = "对旋1";
        } else if ($baseData["2046535462269953_2"] == 1) {
            $workMode[1] = "对旋2";
        } else if ($baseData["2046535462296577_2"] == 1) {
            $workMode[1] = "对旋3";
        }

        $ctrlMode = ["",""];
        if ($baseData["2046535460506625_2"] == 1) {
            $ctrlMode[0] = "近控";
        } else if ($baseData["2046535460574209_2"] == 1) {
            $ctrlMode[0] = "遥控";
        } else if ($baseData["2046535460547585_2"] == 1) {
            $ctrlMode[0] = "远控";
        }

        if ($baseData["2046535462714369_2"] == 1) {
            $ctrlMode[1] = "近控";
        } else if ($baseData["2046535462769665_2"] == 1) {
            $ctrlMode[1] = "遥控";
        } else if ($baseData["2046535462743041_2"] == 1) {
            $ctrlMode[1] = "远控";
        }

        $fault = ["",""];
        if ($baseData["2046535459806209_2"] == 0) {
            $fault[0] = "前级故障";
        }
        if ($baseData["2046535459177473_2"] == 0) {
            $fault[0] = "后级故障";
        }
        if (empty($fault[0])) {
            $fault[0] = "无故障";
        }
        if ($baseData["2046535461999617_2"] == 0) {
            $fault[1] = "前级故障";
        }
        if ($baseData["2046535461415937_2"] == 0) {
            $fault[1] = "后级故障";
        }
        if (empty($fault[1])) {
            $fault[1] = "无故障";
        }

        $data["tab"]=[
            [
                "title"=>"主风机",
                "state"=>$baseData["2046535459097601_2"] + $baseData["2046535459722241_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ],
            [
                "title"=>"副风机",
                "state"=>$baseData["2046535461911553_2"] + $baseData["2046535461340161_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ]
        ];

        $data["table_1"]=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    "value_1"=>$baseData["2046535463324673_1"] ?? 0,
                    "value_2"=>$baseData["2046535463621633_1"] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    "value_1"=>$baseData["2046535463404545_1"] ?? 0,
                    "value_2"=>$baseData["2046535463697409_1"] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    "value_1"=>$baseData["2046535463496705_1"] ?? 0,
                    "value_2"=>$baseData["2046535463771137_1"] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    "value_1"=>$baseData["2046535463363585_1"] ?? 0,
                    "value_2"=>$baseData["2046535463658497_1"] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    "value_1"=>$baseData["2046535463457793_1"] ?? 0,
                    "value_2"=>$baseData["2046535463732225_1"] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    "value_1"=>$baseData["2046535463541761_1"] ?? 0,
                    "value_2"=>$baseData["2046535463814145_1"] ?? 0,
                ],
                [
                    "label"=>"风机电压（V）",
                    "value_1"=>$baseData["2046535463582721_1"] ?? 0,
                    "value_2"=>$baseData["2046535463857153_1"] ?? 0,
                ],
                [
                    "label"=>"工作方式",
                    "value_1"=>$workMode[0],
                    "value_2"=>$workMode[1],
                ],
                [
                    "label"=>"控制方式",
                    "value_1"=>$ctrlMode[0],
                    "value_2"=>$ctrlMode[1],
                ],
                [
                    "label"=>"故障状态",
                    "value_1"=>$fault[0],
                    "value_2"=>$fault[1],
                ],
                [
                    "label"=>"负荷设备",
                    "value_1"=>$baseData["2046535460164609_2"] == 1 ? "带载" : "空载",
                    "value_2"=>$baseData["2046535462325249_2"] == 1 ? "带载" : "空载",
                ],
                [
                    "label"=>"欠压保护",
                    "value_1"=>$baseData["2046535460219905_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2046535462392833_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"过压保护",
                    "value_1"=>$baseData["2046535460400129_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2046535462593537_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"主备选择",
                    "value_1"=>$baseData["2046535458790401_2"] == 1 ? "备机" : "主机",
                    "value_2"=>$baseData["2046535461028865_2"] == 1 ? "备机" : "主机",
                ]
            ]
        ];
        return json_encode($data);
    }
    /*
     * 五六分区1200车场
     * 150201机巷通风机
     */
    public function get1200CarFanList() {

        $keys = [

            "2049479004468225_2", // 主机前级合闸运行
            "2049479004826625_2", // 主机后级合闸运行

            "2049479005195265_2", // 副机前级合闸运行
            "2049479006194689_2", // 副机后级合闸运行

            "2049479011619841_1", // 主风机IA1电流
            "2049479011662849_1", // 主风机IB1电流
            "2049479009928193_1", // 主风机IC1电流

            "2049479011355649_1", // 副风机IA1电流
            "2049479011396609_1", // 副风机IB1电流
            "2049479011456001_1", // 副风机IC1电流

            "2049479010350081_1", // 主风机IA2电流
            "2049479010540545_1", // 主风机IB2电流
            "2049479010722817_1", // 主风机IC2电流

            "2049479011499009_1", // 副风机IA2电流
            "2049479011537921_1", // 副风机IB2电流
            "2049479011576833_1", // 副风机IC2电流

            "2063093856705537_1", // 通风机风速
            "2049479011267585_1", // 主风机电压
            "2049479011308545_1", // 副风机电压

            "2049479006569473_2", // 主机对旋1模式
            "2049479006598145_2", // 主机对旋2模式
            "2049479006624769_2", // 主机对旋3模式

            "2049479006700545_2", // 副机对旋1模式
            "2049479006731265_2", // 副机对旋2模式
            "2049479006755841_2", // 副机对旋3模式

            "2049479006815233_2", // 主机近控
            "2049479006866433_2", // 主机遥控
            "2049479006839809_2", // 主机远控

            "2049479006893057_2", // 副机近控
            "2049479006946305_2", // 副机遥控
            "2049479006919681_2", // 副机远控

            "2049479004519425_2", // 主机前级无故障
            "2049479004879873_2", // 主机后级无故障

            "2049479005246465_2", // 副机前级无故障
            "2049479006247937_2", // 副机后级无故障

            "2049479008232449_2", // 主机带载
            "2049479009162241_2", // 副机带载

            "2049479008869377_2", // 主机欠压保护打开
            "2049479009836033_2", // 副机欠压保护打开

            "2049479008924673_2", // 主机过压保护打开
            "2049479009893377_2", // 副机过压保护打开

            "2049479008050177_2", // 主机主备选择主机
            "2049479008963585_2", // 副机主备选择主机

        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        // 工作方式
        $workMode = ["",""];
        if ($baseData["2049479006569473_2"] == 1) {
            $workMode[0] = "对旋1";
        } else if ($baseData["2049479006598145_2"] == 1) {
            $workMode[0] = "对旋2";
        } else if ($baseData["2049479006624769_2"] == 1) {
            $workMode[0] = "对旋3";
        }

        if ($baseData["2049479006700545_2"] == 1) {
            $workMode[1] = "对旋1";
        } else if ($baseData["2049479006731265_2"] == 1) {
            $workMode[1] = "对旋2";
        } else if ($baseData["2049479006755841_2"] == 1) {
            $workMode[1] = "对旋3";
        }

        $ctrlMode = ["",""];
        if ($baseData["2049479006815233_2"] == 1) {
            $ctrlMode[0] = "近控";
        } else if ($baseData["2049479006866433_2"] == 1) {
            $ctrlMode[0] = "遥控";
        } else if ($baseData["2049479006839809_2"] == 1) {
            $ctrlMode[0] = "远控";
        }

        if ($baseData["2049479006893057_2"] == 1) {
            $ctrlMode[1] = "近控";
        } else if ($baseData["2049479006946305_2"] == 1) {
            $ctrlMode[1] = "遥控";
        } else if ($baseData["2049479006919681_2"] == 1) {
            $ctrlMode[1] = "远控";
        }

        $fault = ["",""];
        if ($baseData["2049479004519425_2"] == 0) {
            $fault[0] = "前级故障";
        }
        if ($baseData["2049479004879873_2"] == 0) {
            $fault[0] = "后级故障";
        }
        if (empty($fault[0])) {
            $fault[0] = "无故障";
        }
        if ($baseData["2049479005246465_2"] == 0) {
            $fault[1] = "前级故障";
        }
        if ($baseData["2049479006247937_2"] == 0) {
            $fault[1] = "后级故障";
        }
        if (empty($fault[1])) {
            $fault[1] = "无故障";
        }

        $data["tab"]=[
            [
                "title"=>"主风机",
                "state"=>$baseData["2049479004468225_2"] + $baseData["2049479004826625_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ],
            [
                "title"=>"副风机",
                "state"=>$baseData["2049479005195265_2"] + $baseData["2049479006194689_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ]
        ];

        $data["table_1"]=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    "value_1"=>$baseData["2049479011619841_1"] ?? 0,
                    "value_2"=>$baseData["2049479011355649_1"] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    "value_1"=>$baseData["2049479011662849_1"] ?? 0,
                    "value_2"=>$baseData["2049479011396609_1"] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    "value_1"=>$baseData["2049479009928193_1"] ?? 0,
                    "value_2"=>$baseData["2049479011456001_1"] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    "value_1"=>$baseData["2049479010350081_1"] ?? 0,
                    "value_2"=>$baseData["2049479011499009_1"] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    "value_1"=>$baseData["2049479010540545_1"] ?? 0,
                    "value_2"=>$baseData["2049479011537921_1"] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    "value_1"=>$baseData["2049479010722817_1"] ?? 0,
                    "value_2"=>$baseData["2049479011576833_1"] ?? 0,
                ],
                [
                    "label"=>"电压（V）",
                    "value_1"=>$baseData["2049479011267585_1"] ?? 0,
                    "value_2"=>$baseData["2049479011308545_1"] ?? 0,
                ],
                [
                    "label"=>"工作方式",
                    "value_1"=>$workMode[0],
                    "value_2"=>$workMode[1],
                ],
                [
                    "label"=>"控制方式",
                    "value_1"=>$ctrlMode[0],
                    "value_2"=>$ctrlMode[1],
                ],
                [
                    "label"=>"故障状态",
                    "value_1"=>$fault[0],
                    "value_2"=>$fault[1],
                ],
                [
                    "label"=>"负荷设备",
                    "value_1"=>$baseData["2049479008232449_2"] == 1 ? "带载" : "空载",
                    "value_2"=>$baseData["2049479009162241_2"] == 1 ? "带载" : "空载",
                ],
                [
                    "label"=>"欠压保护",
                    "value_1"=>$baseData["2049479008869377_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2049479009836033_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"过压保护",
                    "value_1"=>$baseData["2049479008924673_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2049479009893377_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"主备选择",
                    "value_1"=>$baseData["2049479008050177_2"] == 1 ? "主机" : "备机",
                    "value_2"=>$baseData["2049479008963585_2"] == 1 ? "主机" : "备机",
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 五六分区1200石门
     * 150201回风巷通风机
     */
    public function get1200smList() {

        $keys = [
            "2049479114750977_2", // 主机前级合闸运行
            "2049479115330561_2", // 主机后级合闸运行
            "2049479117224961_2", // 副机前级合闸运行
            "2049479117835265_2", // 副机后级合闸运行

            "2049479119457281_1", // 主风机IA1电流
            "2049479119539201_1", // 主风机IB1电流
            "2049479119623169_1", // 主风机IC1电流

            "2049479120241665_1", // 副风机IA1电流
            "2049479120333825_1", // 副风机IB1电流
            "2049479120442369_1", // 副风机IC1电流

            "2049479119500289_1", // 主风机IA2电流
            "2049479119582209_1", // 主风机IB2电流
            "2049479119660033_1", // 主风机IC2电流

            "2049479120284673_1", // 副风机IA2电流
            "2049479120399361_1", // 副风机IB2电流
            "2049479120485377_1", // 副风机IC2电流

            "2061938360599553_1", // 风速
            "2049479119709185_1", // 主风机电压
            "2049479120528385_1", // 副风机电压

            "2049479115654145_2", // 主机对旋1模式
            "2049479115678721_2", // 主机对旋2模式
            "2049479115709441_2", // 主机对旋3模式

            "2049479118173185_2", // 副机对旋1模式
            "2049479118201857_2", // 副机对旋2模式
            "2049479118257153_2", // 副机对旋3模式

            "2049479116092417_2", // 主机近控
            "2049479116143617_2", // 主机遥控
            "2049479116116993_2", // 主机远控

            "2049479118652417_2", // 副机近控
            "2049479118705665_2", // 副机遥控
            "2049479118679041_2", // 副机远控

            "2049479114828801_2", // 主机前级无故障
            "2049479115412481_2", // 主机后级无故障
            "2049479117300737_2", // 副机前级无故障
            "2049479117919233_2", // 副机后级无故障

            "2049479115738113_2", // 主机带载
            "2049479115852801_2", // 主机空载

            "2049479118287873_2", // 副机带载
            "2049479118402561_2", // 副机空载

            "2049479119709185_1", // 主风机电压
            "2049479120528385_1", // 副风机电压

            "2049479115797505_2", // 主机欠压保护打开
            "2049479118347265_2", // 副机欠压保护打开

            "2049479115985921_2", // 主机过压保护打开
            "2049479118541825_2", // 副机过压保护打开

            "2049479114433537_2", // 主机主备选择主机
            "2049479116903425_2", // 副机主备选择主机
        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        // 工作方式
//        $workMode = ["",""];
//        if ($baseData["2049479115654145_2"] == 1) {
//            $workMode[0] = "对旋1";
//        } else if ($baseData["2049479115678721_2"] == 1) {
//            $workMode[0] = "对旋2";
//        } else if ($baseData["2049479115709441_2"] == 1) {
//            $workMode[0] = "对旋3";
//        }
//        if ($baseData["2049479118173185_2"] == 1) {
//            $workMode[1] = "对旋1";
//        } else if ($baseData["2049479118201857_2"] == 1) {
//            $workMode[1] = "对旋2";
//        } else if ($baseData["2049479118257153_2"] == 1) {
//            $workMode[1] = "对旋3";
//        }

        $workMode[0] = $this->getXuanState([$baseData["2049479115654145_2"],$baseData["2049479115678721_2"],$baseData["2049479115709441_2"]]);
        $workMode[1] = $this->getXuanState([$baseData["2049479118173185_2"],$baseData["2049479118201857_2"],$baseData["2049479118257153_2"]]);


        $ctrlMode = ["",""];
        if ($baseData["2049479116092417_2"] == 1) {
            $ctrlMode[0] = "近控";
        } else if ($baseData["2049479116143617_2"] == 1) {
            $ctrlMode[0] = "遥控";
        } else if ($baseData["2049479116116993_2"] == 1) {
            $ctrlMode[0] = "远控";
        }

        if ($baseData["2049479118652417_2"] == 1) {
            $ctrlMode[1] = "近控";
        } else if ($baseData["2049479118705665_2"] == 1) {
            $ctrlMode[1] = "遥控";
        } else if ($baseData["2049479118679041_2"] == 1) {
            $ctrlMode[1] = "远控";
        }

        $fault = ["",""];
        if ($baseData["2049479114828801_2"] == 0) {
            $fault[0] = "前级故障";
        }
        if ($baseData["2049479115412481_2"] == 0) {
            $fault[0] = "后级故障";
        }
        if (empty($fault[0])) {
            $fault[0] = "无故障";
        }
        if ($baseData["2049479117300737_2"] == 0) {
            $fault[1] = "前级故障";
        }
        if ($baseData["2049479117919233_2"] == 0) {
            $fault[1] = "后级故障";
        }
        if (empty($fault[1])) {
            $fault[1] = "无故障";
        }

        $data["tab"]=[
            [
                "title"=>"主风机",
                "state"=>$baseData["2049479114750977_2"] + $baseData["2049479115330561_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ],
            [
                "title"=>"副风机",
                "state"=>$baseData["2049479117224961_2"] + $baseData["2049479117835265_2"] >= 1 ? 1 : 0,
                "list"=>[
                ]
            ]
        ];

        $data["table_1"]=[
            "thead"=>[
                "参数名称", "主风机", "副风机"
            ],
            "tbody"=>[
                [
                    "label"=>"Ia1电流（A）",
                    "value_1"=>$baseData["2049479119457281_1"] ?? 0,
                    "value_2"=>$baseData["2049479120241665_1"] ?? 0,
                ],
                [
                    "label"=>"Ib1电流（A）",
                    "value_1"=>$baseData["2049479119539201_1"] ?? 0,
                    "value_2"=>$baseData["2049479120333825_1"] ?? 0,
                ],
                [
                    "label"=>"Ic1电流（A）",
                    "value_1"=>$baseData["2049479119623169_1"] ?? 0,
                    "value_2"=>$baseData["2049479120442369_1"] ?? 0,
                ],
                [
                    "label"=>"Ia2电流（A）",
                    "value_1"=>$baseData["2049479119500289_1"] ?? 0,
                    "value_2"=>$baseData["2049479120284673_1"] ?? 0,
                ],
                [
                    "label"=>"Ib2电流（A）",
                    "value_1"=>$baseData["2049479119582209_1"] ?? 0,
                    "value_2"=>$baseData["2049479120399361_1"] ?? 0,
                ],
                [
                    "label"=>"Ic2电流（A）",
                    "value_1"=>$baseData["2049479119660033_1"] ?? 0,
                    "value_2"=>$baseData["2049479120485377_1"] ?? 0,
                ],
                [
                    "label"=>"电压（V）",
                    "value_1"=>$baseData["2049479119709185_1"] ?? 0,
                    "value_2"=>$baseData["2049479120528385_1"] ?? 0,
                ],
                [
                    "label"=>"工作方式",
                    "value_1"=>$workMode[0],
                    "value_2"=>$workMode[1],
                ],
                [
                    "label"=>"控制方式",
                    "value_1"=>$ctrlMode[0],
                    "value_2"=>$ctrlMode[1],
                ],
                [
                    "label"=>"故障状态",
                    "value_1"=>$fault[0],
                    "value_2"=>$fault[1],
                ],
                [
                    "label"=>"负荷设备",
                    "value_1"=>$baseData["2049479115738113_2"] == 1 ? "带载" : "空载",
                    "value_2"=>$baseData["2049479118287873_2"] == 1 ? "带载" : "空载",
                ],
                [
                    "label"=>"欠压保护",
                    "value_1"=>$baseData["2049479115797505_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2049479118347265_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"过压保护",
                    "value_1"=>$baseData["2049479115985921_2"] == 1 ? "打开" : "关闭",
                    "value_2"=>$baseData["2049479118541825_2"] == 1 ? "打开" : "关闭",
                ],
                [
                    "label"=>"主备选择",
                    "value_1"=>$baseData["2049479114433537_2"] == 1 ? "主机" : "备机",
                    "value_2"=>$baseData["2049479116903425_2"] == 1 ? "主机" : "备机",
                ]
            ]
        ];
        return json_encode($data);
    }

    /*
     * 1314通风
     */
    public function get1314List() {


        $keys = [
            "2009721035631617_2", // 1314通风1_风门开到位
            "2009721047067649_2", // 1314通风2_风门开到位

            "2009721038003201_1", // 1314通风1_入口压力
            "2009721049187329_1", // 1314通风2_入口压力

            "2009721038402561_1", // 1314通风1_压力系数
            "2009721049609217_1", // 1314通风2_压力系数

            "2009721037939713_1", // 1314通风1_风量
            "2009721049115649_1", // 1314通风2_风量

            "2009721037816833_1", // 1314通风1_运行电流
            "2009721048990721_1", // 1314通风2_运行电流

            "2009721037796353_1", // 1314通风1_运行频率
            "2009721048970241_1", // 1314通风2_运行频率

            "2009721037777921_1", // 1314通风1_X轴振动
            "2009721048953857_1", // 1314通风2_X轴振动

            "2009721037757441_1", // 1314通风1_Y轴振动
            "2009721048919041_1", // 1314通风2_Y轴振动

            "2009721038035969_1", // 1314通风1_前轴温度
            "2009721038019585_1", // 1314通风1_后轴温度
            "2009721038052353_1", // 1314通风1_绕组温度U
            "2009721038083073_1", // 1314通风1_绕组温度V
            "2009721038113793_1", // 1314通风1_绕组温度W

            "2009721049226241_1", // 1314通风2_前轴温度
            "2009721049205761_1", // 1314通风2_后轴温度
            "2009721049244673_1", // 1314通风2_绕组温度U
            "2009721049283585_1", // 1314通风2_绕组温度V
            "2009721049318401_1", // 1314通风2_绕组温度W


        ];


        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];
        // 电流、功率、振动、负压取的西井通风的点
        $data["tab"]=[
            [
                "title"=>"1#风机",
                "state"=>$baseData["2009721035631617_2"] ?? 0,
                "list"=>[
                ]
            ],
            [
                "title"=>"2#风机",
                "state"=>$baseData["2009721047067649_2"] ?? 0,
                "list"=>[
                ]
            ]
        ];
        $data["table_1"]=[
            "thead"=>[
                "参数名称", "1#风机", "2#风机"
            ],
            "tbody"=>[
                [
                    "label"=>"压力(pa)",
                    "value_1"=>round($baseData["2009721038003201_1"] * $baseData["2009721038402561_1"], 2),
                    "value_2"=>round($baseData["2009721049187329_1"] * $baseData["2009721049609217_1"], 2),
                ],
                [
                    "label"=>"风量(m³/s)",
                    "value_1"=>$baseData["2009721037939713_1"] ?? 0,
                    "value_2"=>$baseData["2009721049115649_1"] ?? 0,
                ],
                [
                    "label"=>"电流反馈(A)",
                    "value_1"=>$baseData["2009721037816833_1"] ?? 0,
                    "value_2"=>$baseData["2009721048990721_1"] ?? 0,
                ],
                [
                    "label"=>"频率反馈（HZ)",
                    "value_1"=>$baseData["2009721037796353_1"] ?? 0,
                    "value_2"=>$baseData["2009721048970241_1"] ?? 0,
                ],
                [
                    "label"=>"X振动（mm/s)",
                    "value_1"=>$baseData["2009721037777921_1"] ?? 0,
                    "value_2"=>$baseData["2009721048953857_1"] ?? 0,
                ],
                [
                    "label"=>"Y振动（mm/s)",
                    "value_1"=>$baseData["2009721037757441_1"] ?? 0,
                    "value_2"=>$baseData["2009721048919041_1"] ?? 0,
                ]
            ]
        ];
        $data["table_2"]=[
            "thead"=>[
                "参数名称", "前级", "后级"
            ],
            "tbody"=>[
                [
                    "label"=>"压力(pa)",
                    "value_1"=>round($baseData["2009721038003201_1"] * $baseData["2009721038402561_1"], 2),
                    "value_2"=>round($baseData["2009721049187329_1"] * $baseData["2009721049609217_1"], 2),
                ],
                [
                    "label"=>"风量(m³/s)",
                    "value_1"=>$baseData["2009721037939713_1"] ?? 0,
                    "value_2"=>$baseData["2009721049115649_1"] ?? 0,
                ],
                [
                    "label"=>"电流反馈(A)",
                    "value_1"=>$baseData["2009721037816833_1"] ?? 0,
                    "value_2"=>$baseData["2009721048990721_1"] ?? 0,
                ],
                [
                    "label"=>"频率反馈（HZ)",
                    "value_1"=>$baseData["2009721037796353_1"] ?? 0,
                    "value_2"=>$baseData["2009721048970241_1"] ?? 0,
                ],
                [
                    "label"=>"X振动（mm/s)",
                    "value_1"=>$baseData["2009721037777921_1"] ?? 0,
                    "value_2"=>$baseData["2009721048953857_1"] ?? 0,
                ],
                [
                    "label"=>"Y振动（mm/s)",
                    "value_1"=>$baseData["2009721037757441_1"] ?? 0,
                    "value_2"=>$baseData["2009721048919041_1"] ?? 0,
                ]
            ]
        ];
        $data["chartData_1"]=[
            "categories"=>["1-1#电机", "1-2#电机"],
            "series"=>[
                [
                    "name"=>"前轴温度",
                    "data"=>[
                        $baseData["2009721038035969_1"] ?? 0,
                        $baseData["2009721038035969_1"] ?? 0,
                    ],
                ],
                [
                    "name"=>"后轴温度",
                    "data"=>[
                        $baseData["2009721038019585_1"] ?? 0,
                        $baseData["2009721038019585_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度u",
                    "data"=>[
                        $baseData["2009721038052353_1"] ?? 0,
                        $baseData["2009721038052353_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度v",
                    "data"=>[
                        $baseData["2009721038083073_1"] ?? 0,
                        $baseData["2009721038083073_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度w",
                    "data"=>[
                        $baseData["2009721038113793_1"] ?? 0,
                        $baseData["2009721038113793_1"] ?? 0,
                    ],
                ],
            ]
        ];
        $data["chartData_2"]=[
            "categories"=>["2-1#电机", "2-2#电机"],
            "series"=>[
                [
                    "name"=>"前轴温度",
                    "data"=>[
                        $baseData["2009721049226241_1"] ?? 0,
                        $baseData["2009721049226241_1"] ?? 0,
                    ],
                ],
                [
                    "name"=>"后轴温度",
                    "data"=>[
                        $baseData["2009721049205761_1"] ?? 0,
                        $baseData["2009721049205761_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度u",
                    "data"=>[
                        $baseData["2009721049244673_1"] ?? 0,
                        $baseData["2009721049244673_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度v",
                    "data"=>[
                        $baseData["2009721049283585_1"] ?? 0,
                        $baseData["2009721049283585_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度w",
                    "data"=>[
                        $baseData["2009721049318401_1"] ?? 0,
                        $baseData["2009721049318401_1"] ?? 0,
                    ],
                ],
            ]
        ];
        return json_encode($data);
    }

    /*
     * 五分区通风系统
     */
    public function get5fqList() {

        $keys = [
            "2008681964219393_2", // 1号通风_主风门全开
            "2008682656793601_2", // 2号通风_主风门全开

            "2008681965886465_1", // 1号通风_风机全压
            "2008682658477057_1", // 2号通风_风机全压

            "2008681965952001_1", // 1号通风_风机负压
            "2008682658571265_1", // 2号通风_风机负压

            "2008681965968385_1", // 1号通风_风机风速
            "2008682658585601_1", // 2号通风_风机风速

            "2008681965235201_1", // 1号通风_五分区风量
            "2008682657807361_1", // 2号通风_五分区风量

            // 1号通风
            "2008681965351937_1", // 1号通风_变频1电流反馈
            "2008681965386753_1", // 1号通风_变频2电流反馈

            "2008681965368321_1", // 1号通风_变频1频率反馈
            "2008681965407233_1", // 1号通风_变频2频率反馈

            "2008681965919233_1", // 1号通风_风机水平震动1
            "2008681965933569_1", // 1号通风_风机水平震动2

            "2008681965898753_1", // 1号通风_风机垂直震动1
            "2008681965908993_1", // 1号通风_风机垂直震动2

            "2008681964536833_2", // 1号通风_变频1远程报警
            "2008681964751873_2", // 1号通风_变频2远程报警

            "2008681964434433_2", // 1号通风_变频1故障指示
            "2008681964655617_2", // 1号通风_变频2故障指示

            "2008681964383233_2", // 1号通风_变频1就绪
            "2008681964594177_2", // 1号通风_变频2就绪

            "2008681964790785_2", // 1号通风_外控1指示
            "2008681964805121_2", // 1号通风_外控2指示

            "2008681964422145_2", // 1号通风_变频1指示
            "2008681964643329_2", // 1号通风_变频2指示

            "2008681964463105_2", // 1号通风_变频1正转指示
            "2008681964682241_2", // 1号通风_变频2正转指示

            "2008681964491777_2", // 1号通风_变频1禁止开机
            "2008681964704769_2", // 1号通风_变频2禁止开机


            // 2号通风
            "2008682657917953_1", // 2号通风_变频1电流反馈
            "2008682657948673_1", // 2号通风_变频2电流反馈

            "2008682657932289_1", // 2号通风_变频1频率反馈
            "2008682657967105_1", // 2号通风_变频2频率反馈

            "2008682658540545_1", // 2号通风_风机水平震动1
            "2008682658558977_1", // 2号通风_风机水平震动2

            "2008682658497537_1", // 2号通风_风机垂直震动1
            "2008682658520065_1", // 2号通风_风机垂直震动2

            "2008682657094657_2", // 2号通风_变频1远程报警
            "2008682657350657_2", // 2号通风_变频2远程报警

            "2008682656979969_2", // 2号通风_变频1故障指示
            "2008682657248257_2", // 2号通风_变频2故障指示

            "2008682656934913_2", // 2号通风_变频1就绪
            "2008682657172481_2", // 2号通风_变频2就绪

            "2008682657383425_2", // 2号通风_外控1指示
            "2008682657395713_2", // 2号通风_外控2指示

            "2008682656965633_2", // 2号通风_变频1指示
            "2008682657235969_2", // 2号通风_变频2指示

            "2008682657008641_2", // 2号通风_变频1正转指示
            "2008682657278977_2", // 2号通风_变频2正转指示

            "2008682657035265_2", // 2号通风_变频1禁止开机
            "2008682657303553_2", // 2号通风_变频2禁止开机

            // 1号通风温度
            "2008681965462529_1", // 1号通风_定子1A温度
            "2008681965478913_1", // 1号通风_定子1B温度
            "2008681965495297_1", // 1号通风_定子1C温度

            "2008681965509633_1", // 1号通风_定子2A温度
            "2008681965523969_1", // 1号通风_定子2B温度
            "2008681965542401_1", // 1号通风_定子2C温度

            "2008681965425665_1", // 1号通风_后轴1温度
            "2008681965444097_1", // 1号通风_后轴2温度

            "2008681965315073_1", // 1号通风_前轴1温度
            "2008681965333505_1", // 1号通风_前轴2温度

            // 2号通风温度
            "2008682658026497_1", // 2号通风_定子1A温度
            "2008682658044929_1", // 2号通风_定子1B温度
            "2008682658065409_1", // 2号通风_定子1C温度

            "2008682658083841_1", // 2号通风_定子2A温度
            "2008682658100225_1", // 2号通风_定子2B温度
            "2008682658118657_1", // 2号通风_定子2C温度

            "2008682657983489_1", // 2号通风_后轴1温度
            "2008682658003969_1", // 2号通风_后轴2温度

            "2008682657885185_1", // 2号通风_前轴1温度
            "2008682657901569_1", // 2号通风_前轴2温度

        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        $data["tab"]=[
            [
                "title"=>"1#风机",
                "state"=>$baseData["2008681964219393_2"] ?? 0,
                "list"=>[
                    [
                        "label"=>"全压",
                        "unit"=>"KPa",
                        "num"=>$baseData["2008681965886465_1"] ?? 0,
                    ],
                    [
                        "label"=>"负压",
                        "unit"=>"KPa",
                        "num"=>$baseData["2008681965952001_1"] ?? 0,
                    ],
                    [
                        "label"=>"风速",
                        "unit"=>"m/s",
                        "num"=>$baseData["2008681965968385_1"] ?? 0,
                    ],
                    [
                        "label"=>"风量",
                        "unit"=>"m³/min",
                        "num"=>$baseData["2008681965235201_1"] ?? 0,
                    ],
                ]
            ],
            [
                "title"=>"2#风机",
                "state"=>$baseData["2008682656793601_2"] ?? 0,
                "list"=>[
                    [
                        "label"=>"全压",
                        "unit"=>"KPa",
                        "num"=>$baseData["2008682658477057_1"] ?? 0,
                    ],
                    [
                        "label"=>"负压",
                        "unit"=>"KPa",
                        "num"=>$baseData["2008682658571265_1"] ?? 0,
                    ],
                    [
                        "label"=>"风速",
                        "unit"=>"m/s",
                        "num"=>$baseData["2008682658585601_1"] ?? 0,
                    ],
                    [
                        "label"=>"风量",
                        "unit"=>"m³/min",
                        "num"=>$baseData["2008682657807361_1"] ?? 0,
                    ],
                ]
            ]
        ];

        $data["table_1"]=[
            "thead"=>[
                "参数名称", "1-1", "1-2"
            ],
            "tbody"=>[
                [
                    "label"=>"电流反馈（A）",
                    "value_1"=>$baseData["2008681965351937_1"] ?? 0,
                    "value_2"=>$baseData["2008681965386753_1"] ?? 0,
                ],
                [
                    "label"=>"频率反馈（Hz）",
                    "value_1"=>$baseData["2008681965368321_1"] ?? 0,
                    "value_2"=>$baseData["2008681965407233_1"] ?? 0,
                ],
                [
                    "label"=>"水平振动（mm/s)",
                    "value_1"=>$baseData["2008681965919233_1"] ?? 0,
                    "value_2"=>$baseData["2008681965933569_1"] ?? 0,
                ],
                [
                    "label"=>"垂直振动（mm/s)",
                    "value_1"=>$baseData["2008681965898753_1"] ?? 0,
                    "value_2"=>$baseData["2008681965908993_1"] ?? 0,
                ],
                [
                    "label"=>"报警",
                    "value_1"=>$baseData["2008681964536833_2"]==0 ? "正常":"报警",
                    "value_2"=>$baseData["2008681964751873_2"]==0 ? "正常":"报警",
                ],
                [
                    "label"=>"变频器故障",
                    "value_1"=>$baseData["2008681964434433_2"]==1 ? "故障":"无故障",
                    "value_2"=>$baseData["2008681964655617_2"]==1 ? "故障":"无故障",
                ],
                [
                    "label"=>"变频器就绪",
                    "value_1"=>$baseData["2008681964383233_2"]==1 ? "就绪":"未就绪",
                    "value_2"=>$baseData["2008681964594177_2"]==1 ? "就绪":"未就绪",
                ],
                [
                    "label"=>"集控/就地",
                    "value_1"=>$baseData["2008681964790785_2"]==1 ? "集控":"就地",
                    "value_2"=>$baseData["2008681964805121_2"]==1 ? "集控":"就地",
                ],
                [
                    "label"=>"工/变频",
                    "value_1"=>$baseData["2008681964422145_2"]==1 ? "变频":"工频",
                    "value_2"=>$baseData["2008681964643329_2"]==1 ? "变频":"工频",
                ],
                [
                    "label"=>"正/反转",
                    "value_1"=>$baseData["2008681964463105_2"]==1 ? "正转":"反转",
                    "value_2"=>$baseData["2008681964682241_2"]==1 ? "正转":"反转",
                ],
                [
                    "label"=>"允许开机",
                    "value_1"=>$baseData["2008681964491777_2"]==0 ? "允许":"禁止",
                    "value_2"=>$baseData["2008681964704769_2"]==0 ? "允许":"禁止",
                ],
            ]
        ];
        $data["table_2"]=[
            "thead"=>[
                "参数名称", "2-1", "2-2"
            ],
            "tbody"=>[
                [
                    "label"=>"电流反馈（A）",
                    "value_1"=>$baseData["2008682657917953_1"] ?? 0,
                    "value_2"=>$baseData["2008682657948673_1"] ?? 0,
                ],
                [
                    "label"=>"频率反馈（Hz）",
                    "value_1"=>$baseData["2008682657932289_1"] ?? 0,
                    "value_2"=>$baseData["2008682657967105_1"] ?? 0,
                ],
                [
                    "label"=>"水平振动（mm/s)",
                    "value_1"=>$baseData["2008682658540545_1"] ?? 0,
                    "value_2"=>$baseData["2008682658558977_1"] ?? 0,
                ],
                [
                    "label"=>"垂直振动（mm/s)",
                    "value_1"=>$baseData["2008682658497537_1"] ?? 0,
                    "value_2"=>$baseData["2008682658520065_1"] ?? 0,
                ],
                [
                    "label"=>"报警",
                    "value_1"=>$baseData["2008682657094657_2"]==0 ? "正常":"报警",
                    "value_2"=>$baseData["2008682657350657_2"]==0 ? "正常":"报警",
                ],
                [
                    "label"=>"变频器故障",
                    "value_1"=>$baseData["2008682656979969_2"]==1 ? "故障":"无故障",
                    "value_2"=>$baseData["2008682657248257_2"]==1 ? "故障":"无故障",
                ],
                [
                    "label"=>"变频器就绪",
                    "value_1"=>$baseData["2008682656934913_2"]==1 ? "就绪":"未就绪",
                    "value_2"=>$baseData["2008682657172481_2"]==1 ? "就绪":"未就绪",
                ],
                [
                    "label"=>"集控/就地",
                    "value_1"=>$baseData["2008682657383425_2"]==1 ? "集控":"就地",
                    "value_2"=>$baseData["2008682657395713_2"]==1 ? "集控":"就地",
                ],
                [
                    "label"=>"工/变频",
                    "value_1"=>$baseData["2008682656965633_2"]==1 ? "变频":"工频",
                    "value_2"=>$baseData["2008682657235969_2"]==1 ? "变频":"工频",
                ],
                [
                    "label"=>"正/反转",
                    "value_1"=>$baseData["2008682657008641_2"]==1 ? "正传":"反转",
                    "value_2"=>$baseData["2008682657278977_2"]==1 ? "正传":"反转",
                ],
                [
                    "label"=>"允许开机",
                    "value_1"=>$baseData["2008682657035265_2"]==0 ? "允许":"禁止",
                    "value_2"=>$baseData["2008682657303553_2"]==0 ? "允许":"禁止",
                ],
            ]
        ];
        $data["chartData_1"]=[
            "categories"=>["1-1#电机", "1-2#电机"],
            "series"=>[
                [
                    "name"=>"前轴温度",
                    "data"=>[
                        $baseData["2008681965315073_1"] ?? 0,
                        $baseData["2008681965333505_1"] ?? 0,
                    ],
                ],
                [
                    "name"=>"后轴温度",
                    "data"=>[
                        $baseData["2008681965425665_1"] ?? 0,
                        $baseData["2008681965444097_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"定子A温度",
                    "data"=>[
                        $baseData["2008681965462529_1"] ?? 0,
                        $baseData["2008681965509633_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"定子B温度",
                    "data"=>[
                        $baseData["2008681965478913_1"] ?? 0,
                        $baseData["2008681965523969_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"定子C温度",
                    "data"=>[
                        $baseData["2008681965542401_1"] ?? 0,
                        $baseData["2008681965495297_1"] ?? 0,
                    ],
                ],
            ]
        ];
        $data["chartData_2"]=[
            "categories"=>["2-1#电机", "2-2#电机"],
            "series"=>[
                [
                    "name"=>"前轴温度",
                    "data"=>[
                        $baseData["2008682657885185_1"] ?? 0,
                        $baseData["2008682657901569_1"] ?? 0,
                    ],
                ],
                [
                    "name"=>"后轴温度",
                    "data"=>[
                        $baseData["2008682657983489_1"] ?? 0,
                        $baseData["2008682658003969_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度u",
                    "data"=>[
                        $baseData["2008682658026497_1"] ?? 0,
                        $baseData["2008682658083841_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度v",
                    "data"=>[
                        $baseData["2008682658044929_1"] ?? 0,
                        $baseData["2008682658100225_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度w",
                    "data"=>[
                        $baseData["2008682658065409_1"] ?? 0,
                        $baseData["2008682658118657_1"] ?? 0,
                    ],
                ],
            ]
        ];
        return json_encode($data);
    }

    /*
     * 西井通风
     */
    public function getWestList() {

        $keys = [
            "2009735056108545_2", // 1#变频器运行信号
            "2009735056409601_2", // 2#变频器运行信号
            "2009735056749569_2", // 3#变频器运行信号
            "2009735056929793_2", // 4#变频器运行信号

            "2009735057501185_1", // 负压1-1
            "2009735057515521_1", // 负压1-2
            "2009735057529857_1", // 负压2-1
            "2009735057546241_1", // 负压2-2

            "2009735057103873_1", // 1#变频输出电流
            "2009735057193985_1", // 2#变频输出电流
            "2009735057300481_1", // 3#变频输出电流
            "2009735057392641_1", // 4#变频输出电流

            "2009735057116161_1", // 1#变频运行频率
            "2009735057212417_1", // 2#变频运行频率
            "2009735057314817_1", // 3#变频运行频率
            "2009735057413121_1", // 4#变频运行频率

            "2009735057177601_1", // 1#风机水平振动
            "2009735057282049_1", // 2#风机水平振动
            "2009735057378305_1", // 3#风机水平振动
            "2009735057484801_1", // 4#风机水平振动

            "2009735057146881_1", // 1#风机垂直振动
            "2009735057247233_1", // 2#风机垂直振动
            "2009735057349633_1", // 3#风机垂直振动
            "2009735057449985_1", // 4#风机垂直振动

            "2009735057161217_1", // 1#风机功率
            "2009735057263617_1", // 2#风机功率
            "2009735057363969_1", // 3#风机功率
            "2009735057468417_1", // 4#风机功率

            "2009735056086017_2", // 1#变频器故障信号
            "2009735056387073_2", // 2#变频器故障信号
            "2009735056724993_2", // 3#变频器故障信号
            "2009735056907265_2", // 4#变频器故障信号

            "2009735056098305_2", // 1#变频器允许信号
            "2009735056399361_2", // 2#变频器允许信号
            "2009735056737281_2", // 3#变频器允许信号
            "2009735056919553_2", // 4#变频器允许信号

            "2008290869144577_1", // 1号风机前轴温度1
            "2008290869222401_1", // 1号风机后轴温度2
            "2008290869236737_1", // 1号风机绕组温度1
            "2008290869253121_1", // 1号风机绕组温度2
            "2008290869267457_1", // 1号风机绕组温度3

            "2008290869279745_1", // 2号风机前轴温度1
            "2008290869292033_1", // 2号风机后轴温度2
            "2008290869308417_1", // 2号风机绕组温度1
            "2008290869326849_1", // 2号风机绕组温度2
            "2008290869345281_1", // 2号风机绕组温度3

            "2008290869365761_1", // 3号风机前轴温度1
            "2008290869384193_1", // 3号风机后轴温度2
            "2008290869404673_1", // 3号风机绕组温度1
            "2008290869421057_1", // 3号风机绕组温度2
            "2008290869439489_1", // 3号风机绕组温度3

            "2008290869457921_1", // 4号风机前轴温度1
            "2008290869474305_1", // 4号风机后轴温度2
            "2008290869484545_1", // 4号风机绕组温度1
            "2008290869498881_1", // 4号风机绕组温度2
            "2008290869519361_1", // 4号风机绕组温度3

        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        // 风速和电压是假数据，风门状态不确定

        $data["tab"]=[
            [
                "title"=>"1#风机",
                "state"=>$baseData["2009735056108545_2"] + $baseData["2009735056409601_2"] > 0 ? 1 : 0,
                "list"=>[
                    [
                        "label"=>"体积流量",
                        "unit"=>"Pa",
                        "num"=>rand(81000, 87000) / 10.0,
                    ],
                    [
                        "label"=>"出口风速",
                        "unit"=>"m/s",
                        "num"=>6.4,
                    ],
                ]
            ],
            [
                "title"=>"2#风机",
                "state"=>$baseData["2009735056749569_2"] + $baseData["2009735056929793_2"] > 0 ? 1 : 0,
                "list"=>[
                    [
                        "label"=>"体积流量",
                        "unit"=>"Pa",
                        "num"=>0,
                    ],
                    [
                        "label"=>"出口风速",
                        "unit"=>"m/s",
                        "num"=>0.0,
                    ],
                ]
            ]
        ];
        $data["table_1"]=[
            "thead"=>[
                "参数名称", "1-1", "1-2"
            ],
            "tbody"=>[
                [
                    "label"=>"负压（Pa)",
                    "type"=>"val",
                    "value_1"=>round($baseData["2009735057501185_1"] * 1000, 1) ?? 0,
                    "value_2"=>round($baseData["2009735057515521_1"] * 1000, 1) ?? 0,
                ],
                [
                    "label"=>"电流反馈（A)",
                    "type"=>"val",
                    "value_1"=>round($baseData["2009735057103873_1"], 2) ?? 0,
                    "value_2"=>round($baseData["2009735057193985_1"], 2) ?? 0,
                ],
                [
                    "label"=>"频率反馈（HZ)",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735057116161_1"] ?? 0,
                    "value_2"=>$baseData["2009735057212417_1"] ?? 0,
                ],
                [
                    "label"=>"水平振动(mm/s)",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735057177601_1"] ?? 0,
                    "value_2"=>$baseData["2009735057282049_1"] ?? 0,
                ],
                [
                    "label"=>"垂直振动(mm/s)",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735057146881_1"] ?? 0,
                    "value_2"=>$baseData["2009735057247233_1"] ?? 0,
                ],
                [
                    "label"=>"运行电压（V)",
                    "type"=>"val",
                    "value_1"=>381,
                    "value_2"=>384,
                ],
                [
                    "label"=>"运行功率(kw)",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735057161217_1"] ?? 0,
                    "value_2"=>$baseData["2009735057263617_1"] ?? 0,
                ],
                [
                    "label"=>"故障信息",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735056086017_2"] == 0 ? "正常" : "故障",
                    "value_2"=>$baseData["2009735056387073_2"] == 0 ? "正常" : "故障",
                ],
                [
                    "label"=>"运行状态",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735056108545_2"] == 1 ? "运行" : "停止",
                    "value_2"=>$baseData["2009735056409601_2"] == 1 ? "运行" : "停止",
                ],
                [
                    "label"=>"允许信号",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735056098305_2"] == 1 ? "允许" : "未允许",
                    "value_2"=>$baseData["2009735056399361_2"] == 1 ? "允许" : "未允许",
                ],
            ]
        ];
        $data["table_2"]=[
            "thead"=>[
                "参数名称", "2-1", "2-2"
            ],
            "tbody"=>[
                [
                    "label"=>"负压（Pa)",
                    "type"=>"val",
                    "value_1"=>round($baseData["2009735057529857_1"] * 1000, 1) ?? 0,
                    "value_2"=>round($baseData["2009735057546241_1"] * 1000, 1) ?? 0,
                ],
                [
                    "label"=>"电流反馈（A)",
                    "type"=>"val",
                    "value_1"=>round($baseData["2009735057300481_1"], 2) ?? 0,
                    "value_2"=>round($baseData["2009735057392641_1"], 2) ?? 0,
                ],
                [
                    "label"=>"频率反馈（HZ)",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735057314817_1"] ?? 0,
                    "value_2"=>$baseData["2009735057413121_1"] ?? 0,
                ],
                [
                    "label"=>"水平振动(mm/s)",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735057378305_1"] ?? 0,
                    "value_2"=>$baseData["2009735057484801_1"] ?? 0,
                ],
                [
                    "label"=>"垂直振动(mm/s)",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735057349633_1"] ?? 0,
                    "value_2"=>$baseData["2009735057449985_1"] ?? 0,
                ],
                [
                    "label"=>"运行电压（V)",
                    "type"=>"val",
                    "value_1"=>383,
                    "value_2"=>380,
                ],
                [
                    "label"=>"运行功率(kw)",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735057363969_1"] ?? 0,
                    "value_2"=>$baseData["2009735057468417_1"] ?? 0,
                ],
                [
                    "label"=>"故障信息",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735056724993_2"] == 0 ? "正常" : "故障",
                    "value_2"=>$baseData["2009735056907265_2"] == 0 ? "正常" : "故障",
                ],
                [
                    "label"=>"运行状态",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735056749569_2"] == 1 ? "运行" : "停止",
                    "value_2"=>$baseData["2009735056929793_2"] == 1 ? "运行" : "停止",
                ],
                [
                    "label"=>"允许信号",
                    "type"=>"val",
                    "value_1"=>$baseData["2009735056737281_2"] == 1 ? "允许" : "未允许",
                    "value_2"=>$baseData["2009735056919553_2"] == 1 ? "允许" : "未允许",
                ],
            ]
        ];
        $data["chartData_1"]=[
            "categories"=>["1-1#电机", "1-2#电机"],
            "series"=>[
                [
                    "name"=>"前轴温度",
                    "data"=>[
                        $baseData["2008290869144577_1"] ?? 0,
                        $baseData["2008290869279745_1"] ?? 0,
                    ],
                ],
                [
                    "name"=>"后轴温度",
                    "data"=>[
                        $baseData["2008290869222401_1"] ?? 0,
                        $baseData["2008290869292033_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度1",
                    "data"=>[
                        $baseData["2008290869236737_1"] ?? 0,
                        $baseData["2008290869308417_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度2",
                    "data"=>[
                        $baseData["2008290869253121_1"] ?? 0,
                        $baseData["2008290869326849_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度3",
                    "data"=>[
                        $baseData["2008290869267457_1"] ?? 0,
                        $baseData["2008290869345281_1"] ?? 0,
                    ],
                ],
            ]
        ];
        $data["chartData_2"]=[
            "categories"=>["2-1#电机", "2-2#电机"],
            "series"=>[
                [
                    "name"=>"前轴温度",
                    "data"=>[
                        $baseData["2008290869365761_1"] ?? 0,
                        $baseData["2008290869457921_1"] ?? 0,
                    ],
                ],
                [
                    "name"=>"后轴温度",
                    "data"=>[
                        $baseData["2008290869384193_1"] ?? 0,
                        $baseData["2008290869474305_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度1",
                    "data"=>[
                        $baseData["2008290869404673_1"] ?? 0,
                        $baseData["2008290869484545_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度2",
                    "data"=>[
                        $baseData["2008290869421057_1"] ?? 0,
                        $baseData["2008290869498881_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度3",
                    "data"=>[
                        $baseData["2008290869439489_1"] ?? 0,
                        $baseData["2008290869519361_1"] ?? 0,
                    ],
                ],
            ]
        ];
        return json_encode($data);
    }

    /*
     * 东井通风
     */
    public function getEastList() {

        $keys = [
            "2008319841133569_2", // 1号风门开到位
            "2008319841389569_2", // 2号风门开到位

            "2008298771018753_2", // 1号电机合闸反馈
            "2008298771328001_2", // 2号电机合闸反馈
            "2008298771655681_2", // 3号电机合闸反馈
            "2008298771829761_2", // 4号电机合闸反馈

            "2008298772069377_1", // 1号负压
            "2008298772388865_1", // 2号负压
            "2008298772323329_1", // 1号风量
            "2008298772677633_1", // 2号风量

            "2008298771987457_1", // 1-1号电流反馈
            "2008298772354049_1", // 1-2号电流反馈
            "2008298772003841_1", // 1-1号频率反馈
            "2008298772370433_1", // 1-2号频率反馈
            "2008298771971073_1", // 1-1号设定频率
            "2008298772339713_1", // 1-2号设定频率
            "2008298772163585_1", // 1-1 1-2 水平震动
            "2008298772149249_1", // 1-1 1-2 垂直震动

            "2008298770955265_2", // 1-1号变频器状态
            "2008298771299329_2", // 1-2号变频器状态
            "2008298770912257_2", // 1-1号变频器就绪
            "2008298771235841_2", // 1-2号变频器就绪
            "2008298770922497_2", // 1-1号变频器故障
            "2008298771252225_2", // 1-2号变频器故障

            "2008298772714497_1", // 2-1号电流反馈
            "2008298772763649_1", // 2-2号电流反馈
            "2008298772730881_1", // 2-1号频率反馈
            "2008298772780033_1", // 2-2号频率反馈
            "2008298772696065_1", // 2-1号设定频率
            "2008298772747265_1", // 2-2号设定频率
            "2008298772542465_1", // 2-1 2-2 水平震动
            "2008298772524033_1", // 2-1 2-2 垂直震动

            "2008298771627009_2",  // 2-1号变频器状态
            "2008298771809281_2",  // 2-2号变频器状态
            "2008298771575809_2",  // 2-1号变频器就绪
            "2008298771760129_2",  // 2-2号变频器就绪
            "2008298771590145_2",  // 2-1号变频器故障
            "2008298771774465_2",  // 2-2号变频器故障


            "2008298772108289_1", // 1号风机1号电机定子温度1
            "2008298772118529_1", // 1号风机1号电机定子温度2
            "2008298772132865_1", // 1号风机1号电机定子温度3
            "2008298772089857_1", // 1号风机1号电机轴承温度1
            "2008298772098049_1", // 1号风机1号电机轴承温度2

            "2008298772239361_1", // 1号风机2号电机定子温度1
            "2008298772255745_1", // 1号风机2号电机定子温度2
            "2008298772274177_1", // 1号风机2号电机定子温度3
            "2008298772208641_1", // 1号风机2号电机轴承温度1
            "2008298772225025_1", // 1号风机2号电机轴承温度2

            "2008298772464641_1", // 2号风机1号电机定子温度1
            "2008298772485121_1", // 2号风机1号电机定子温度2
            "2008298772503553_1", // 2号风机1号电机定子温度3
            "2008298772425729_1", // 2号风机1号电机轴承温度1
            "2008298772444161_1", // 2号风机1号电机轴承温度2

            "2008298772624385_1", // 2号风机2号电机定子温度1
            "2008298772642817_1", // 2号风机2号电机定子温度2
            "2008298772657153_1", // 2号风机2号电机定子温度3
            "2008298772589569_1", // 2号风机2号电机轴承温度1
            "2008298772605953_1", // 2号风机2号电机轴承温度2

        ];

        $dataFromGetRequest = $this->apiService->postPointRealData($this->apiUrl, $keys);

        if($dataFromGetRequest["data"] == 0) {
            $msg = $dataFromGetRequest["Message"];
            return $this->error(-1, $msg);
        }

        $baseData = $dataFromGetRequest["data"];

        // 风量从接口取的对不上数据
        $data["tab"]=[
            [
                "title"=>"1#风机",
                "state"=>$baseData["2008298771018753_2"] + $baseData["2008298771328001_2"] > 0 ? 1 : 0,
                "list"=>[
                    [
                        "label"=>"负压",
                        "unit"=>"Pa",
                        "num"=>$baseData["2008298772069377_1"] ?? 0,
                    ],
                    [
                        // 接口数据对不上
                        "label"=>"风量",
                        "unit"=>"m³/min",
                        "num"=>$baseData["2008298772323329_1"] ?? 0,
                    ],
                ]
            ],
            [
                "title"=>"2#风机",
                "state"=>$baseData["2008298771655681_2"] + $baseData["2008298771829761_2"] > 0 ? 1 : 0,
                "list"=>[
                    [
                        "label"=>"负压",
                        "unit"=>"Pa",
                        "num"=>$baseData["2008298772388865_1"] ?? 0,
                    ],
                    [
                        "label"=>"风量",
                        "unit"=>"m³/min",
                        "num"=>$baseData["2008298772677633_1"] ?? 0,
                    ],
                ]
            ]
        ];
        $data["table_1"]=[
            "thead"=>[
                "参数名称", "1-1", "1-2"
            ],
            "tbody"=>[
                [
                    "label"=>"电流反馈（A)",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298771987457_1"] ?? 0,
                    "value_2"=>$baseData["2008298772354049_1"] ?? 0,
                ],
                [
                    "label"=>"频率反馈（HZ)",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298772003841_1"] ?? 0,
                    "value_2"=>$baseData["2008298772370433_1"] ?? 0,
                ],
                [
                    "label"=>"设定频率（HZ)",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298771971073_1"] ?? 0,
                    "value_2"=>$baseData["2008298772339713_1"] ?? 0,
                ],
                [
                    "label"=>"水平振动（mm/s)",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298772163585_1"] ?? 0,
                    "value_2"=>$baseData["2008298772163585_1"] ?? 0,
                ],
                [
                    "label"=>"垂直振动（mm/s)",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298772149249_1"] ?? 0,
                    "value_2"=>$baseData["2008298772149249_1"] ?? 0,
                ],
                [
                    "label"=>"变频器状态",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298770955265_2"] == 1 ? "运行" : "停止",
                    "value_2"=>$baseData["2008298771299329_2"] == 1 ? "运行" : "停止",
                ],
                [
                    "label"=>"变频器就绪",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298770912257_2"] == 1 ? "就绪" : "未就绪",
                    "value_2"=>$baseData["2008298771235841_2"] == 1 ? "就绪" : "未就绪",
                ],
                [
                    "label"=>"变频器故障",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298770922497_2"] == 0 ? "无故障" : "故障",
                    "value_2"=>$baseData["2008298771252225_2"] == 0 ? "无故障" : "故障",
                ],
            ]
        ];
        $data["table_2"]=[
            "thead"=>[
                "参数名称", "2-1", "2-2"
            ],
            "tbody"=>[
                [
                    "label"=>"电流反馈（A)",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298772714497_1"] ?? 0,
                    "value_2"=>$baseData["2008298772763649_1"] ?? 0,
                ],
                [
                    "label"=>"频率反馈（HZ)",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298772730881_1"] ?? 0,
                    "value_2"=>$baseData["2008298772780033_1"] ?? 0,
                ],
                [
                    "label"=>"设定频率（HZ)",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298772696065_1"] ?? 0,
                    "value_2"=>$baseData["2008298772747265_1"] ?? 0,
                ],
                [
                    "label"=>"水平振动（mm/s)",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298772542465_1"] ?? 0,
                    "value_2"=>$baseData["2008298772542465_1"] ?? 0,
                ],
                [
                    "label"=>"垂直振动（mm/s)",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298772524033_1"] ?? 0,
                    "value_2"=>$baseData["2008298772524033_1"] ?? 0,
                ],
                [
                    "label"=>"变频器状态",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298771627009_2"] == 1 ? "运行" : "停止",
                    "value_2"=>$baseData["2008298771809281_2"] == 1 ? "运行" : "停止",
                ],
                [
                    "label"=>"变频器就绪",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298771575809_2"] == 1 ? "就绪" : "未就绪",
                    "value_2"=>$baseData["2008298771760129_2"] == 1 ? "就绪" : "未就绪",
                ],
                [
                    "label"=>"变频器故障",
                    "type"=>"val",
                    "value_1"=>$baseData["2008298771590145_2"] == 0 ? "无故障" : "故障",
                    "value_2"=>$baseData["2008298771774465_2"] == 0 ? "无故障" : "故障",
                ],
            ]
        ];
        $data["chartData_1"]=[
            "categories"=>["1-1#电机", "1-2#电机"],
            "series"=>[
                [
                    "name"=>"绕组温度1",
                    "data"=>[
                        $baseData["2008298772108289_1"] ?? 0,
                        $baseData["2008298772239361_1"] ?? 0,
                    ],
                ],
                [
                    "name"=>"绕组温度2",
                    "data"=>[
                        $baseData["2008298772118529_1"] ?? 0,
                        $baseData["2008298772255745_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度3",
                    "data"=>[
                        $baseData["2008298772132865_1"] ?? 0,
                        $baseData["2008298772274177_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"轴承温度1",
                    "data"=>[
                        $baseData["2008298772089857_1"] ?? 0,
                        $baseData["2008298772208641_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"轴承温度2",
                    "data"=>[
                        $baseData["2008298772098049_1"] ?? 0,
                        $baseData["2008298772225025_1"] ?? 0,
                    ],
                ],
            ]
        ];
        $data["chartData_2"]=[
            "categories"=>["2-1#电机", "2-2#电机"],
            "series"=>[
                [
                    "name"=>"绕组温度1",
                    "data"=>[
                        $baseData["2008298772464641_1"] ?? 0,
                        $baseData["2008298772624385_1"] ?? 0,
                    ],
                ],
                [
                    "name"=>"绕组温度2",
                    "data"=>[
                        $baseData["2008298772485121_1"] ?? 0,
                        $baseData["2008298772642817_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"绕组温度3",
                    "data"=>[
                        $baseData["2008298772503553_1"] ?? 0,
                        $baseData["2008298772657153_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"轴承温度1",
                    "data"=>[
                        $baseData["2008298772425729_1"] ?? 0,
                        $baseData["2008298772589569_1"] ?? 0,

                    ],
                ],
                [
                    "name"=>"轴承温度2",
                    "data"=>[
                        $baseData["2008298772444161_1"] ?? 0,
                        $baseData["2008298772605953_1"] ?? 0,
                    ],
                ],
            ]
        ];
        return json_encode($data);
    }


    public function getDBDataFrom($tb_name, $where="") {
        // 构建 SQL 查询
        $sqlStr = "select * from $tb_name where ($where)";
        return $this->executeSql($sqlStr, 3);
    }

    public function executeSql($sqlStr, $modelname = -1) {

        try{
            $opcDB =  DB::connection($this->db_name);
            return $opcDB->select($sqlStr);
        } catch (Exception $e) {
            switch ($modelname) {
                case 1:
                    return $this->error(-1, "东井通风");
                case 2:
                    return $this->error(-1, "统计日超速出错！");
                case 4:
                    return $this->error(-1, "获取详细列表出错！");
                default:
                    return $this->error(-1, "数据库查询错误！");
            }

        }
    }

    private function getXuanState($data = []) {
        if (empty($data)) {
            return false;
        }
        for ($i = 0; $i < count($data); $i++) {
            $state = $data[$i];
            if ($state == 1) {
                return $this->xuan[$i];
            }
        }
        return $this->xuan[0];
    }

}
