<?php

namespace Modules\OpcData\Http\Controllers\Api\zaoquan;

use App\Http\Controllers\Api\BaseController;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Modules\OpcData\Services\zaoquan\ZQDcsApiService;

/**
 * 枣泉自动化——排水
 */
class ZQDcsPumpController  extends BaseController
{

    private $db_name='etl_zaoquan';

    protected $apiService;
    protected $apiUrl = 'http://7.250.4.3:4300/v1/common/GetPointRealDataByPageV3';

    public function __construct(ZQDcsApiService $apiService)
    {
        $this->apiService = $apiService;
    }

    public function getList(Request $request) {
        $sysCode = isset($request->sys_code) ? $request->sys_code : null;     // 矿分类
        if ($sysCode == null) {
            $msg="参数为空";
            $code=-1;
            return $this->error($code, $msg);
        }

        switch ($sysCode) {
            case 'list':
                return $this->getOverviewList();
            case '929':
                return $this->get929List(); //
            case '720':
                return $this->get720List();
            case '880':
                return $this->get880List();
            case '950':
                return $this->get950List();
            case '980':
                return $this->get980List();
            case '13207':
                return $this->get13207List();
            case '2000f':
                return $this->get2000fList();
            case '5000f':
                return $this->get5000fList();
            case 'p1000':
                return $this->getP1000List();
            case '5fq':
                return $this->get5fqfList();
            case 'qsb':
                return $this->getQsbfList();
            default:
                $msg="未知数据";
                $code=-2;
                return $this->error($code, $msg);
        }
    }



    /*
     * 多级排水
     * */
    public function getOverviewList() {

        $keys=[
            "2044914762050561_1", // 13207机巷排水系统_1号流量计
            "2044914761948161_2", // 13207机巷排水系统_1号水泵运行反馈
            "2044914762093569_1", // 13207机巷排水系统_2号流量计
            "2044914761968641_2", // 13207机巷排水系统_2号水泵运行反馈
            "2044914761923585_2", // 13207机巷排水系统_3号水泵运行反馈
            "2044914761907201_2", // 13207机巷排水系统_4号水泵运行反馈
            "2044914762105857_1", // 13207机巷排水系统_水仓容量

            "2024461835248641_1", // 720水泵房_1号管路流量
            "2024441687903233_2", // 720水泵房_1号水泵运行信号
            "2024461918829569_1", // 720水泵房_2号管路流量
            "2024441740917761_2", // 720水泵房_2号水泵运行信号
            "2024441811375105_2", // 720水泵房_3号水泵运行信号

            "2008602972865537_2", // 880水泵房_1号泵电机启停反馈
            "2008602973852673_1", // 880水泵房_1号流量
            "2008602973135873_2", // 880水泵房_2号泵电机启停反馈
            "2008602973967361_1", // 880水泵房_2号流量
            "2008602973436929_2", // 880水泵房_3号泵电机启停反馈
            "2008602974075905_1", // 880水泵房_3号流量

            "2008460125357057_2", // 929水泵房_1号水泵运行
            "2008460125535233_2", // 929水泵房_2号水泵运行
            "2008460125723649_2", // 929水泵房_3号水泵运行
            "2008460126180353_1", // 929水泵房_流量1
            "2008460126198785_1", // 929水泵房_流量2

            "2008448543620097_2", // 950水泵房_1号电机运行反馈
            "2008448543804417_2", // 950水泵房_2号电机运行反馈
            "2008448543990785_2", // 950水泵房_3号电机运行反馈
            "2008448544351233_1", // 950水泵房_流量1
            "2008448544369665_1", // 950水泵房_流量2

            "2008615794158593_2", // 980水泵房_1号电机运行反馈
            "2008615796304897_1", // 980水泵房_1号流量
            "2008615794633729_2", // 980水泵房_2号电机运行反馈
            "2008615796360193_1", // 980水泵房_2号流量
            "2008615795129345_2", // 980水泵房_3号电机运行反馈
            "2008615796413441_1", // 980水泵房_3号流量
            "2008615795635201_2", // 980水泵房_4号电机运行反馈
            "2008615796143105_2", // 980水泵房_5号电机运行反馈

            "2044372313740289_2", // 多级排水_880水泵房联动
            "2043992695585793_2", // 多级排水_980水泵房联动
            "2044016878388225_1", // 多级排水系统_液位1
            "2044016878400513_1", // 多级排水系统_液位2

            "2012602962545665_2", // 五分区水泵房_水泵1启停状态
            "2012602962572289_2", // 五分区水泵房_水泵2启停状态
            "2012602962603009_2", // 五分区水泵房_水泵3启停状态
            "2012605463241729_1",  // 五分区水泵房_液位1

            "2044707426964481_2",
            "2044707426978817_2",
            "2044707426939905_2",
            "2044707426954241_2",
            "2044909612874753_2",
            "2044909612889089_2"
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $stateData = [];
        $stateInfoData = [];
        foreach ($baseData as $key => $val) {

            $stateInfoData[$key] = $baseData[$key] == 0 ? "关闭" : "开启";

            if ($val == -9999) {
                $baseData[$key] = '未知';
                $stateData[$key] = 0;
                $stateInfoData[$key] = "未知";

            } else {
                $stateData[$key] = $baseData[$key];
            }

        }


        $info = [
            "info_paishui"=>[
                [
                    "label"=> "1号水池液位",
                    "value"=> $baseData['2044016878388225_1'] ?? 0,
                ],
                [
                    "label"=> "2号水池液位",
                    "value"=> $baseData['2044016878400513_1'] ?? 0,
                ],
            ],
            "info_gongshui"=>[
                [
                    "label"=> "补清水量",
                    "value"=> ($baseData['2076907605797889_1'] ?? 0).'m³',
                ],
                [
                    "label"=> "复用水累计流量",
                    "value"=> ($baseData['2076907036916737_1'] ?? 0).'m³',
                ],
            ],
            "list"=>[
                [
                    "title"=>"720水泵房",
                    "sys_code"=>"720",
                    "info"=>[
                        [
                            "label"=>"1#水泵",
                            "state"=>$baseData['2024441687903233_2'] ?? 0,
                            "text"=>($baseData['2024441687903233_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"2#水泵",
                            "state"=>$baseData['2024441740917761_2'] ?? 0,
                            "text"=>($baseData['2024441740917761_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"3#水泵",
                            "state"=>$baseData['2024441811375105_2'] ?? 0,
                            "text"=>($baseData['2024441811375105_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                    ]
                ],
                [
                    "title"=>"880水泵房",
                    "sys_code"=>"880",
                    "info"=>[
                        [
                            "label"=>"1#水泵",
                            "state"=>$baseData['2008602972865537_2'] ?? 0,
                            "text"=>($baseData['2008602972865537_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"2#水泵",
                            "state"=>$baseData['2008602973135873_2'] ?? 0,
                            "text"=>($baseData['2008602973135873_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"3#水泵",
                            "state"=>$baseData['2008602973436929_2'] ?? 0,
                            "text"=>($baseData['2008602973436929_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                    ]
                ],
                [
                    "title"=>"929水泵房",
                    "sys_code"=>"929",
                    "info"=>[
                        [
                            "label"=>"1#水泵",
                            "state"=>$baseData['2008460125357057_2'] ?? 0,
                            "text"=>($baseData['2008460125357057_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"2#水泵",
                            "state"=>$baseData['2008460125535233_2'] ?? 0,
                            "text"=>($baseData['2008460125535233_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"3#水泵",
                            "state"=>$baseData['2008460125723649_2'] ?? 0,
                            "text"=>($baseData['2008460125723649_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                    ]
                ],
                [
                    "title"=>"950水泵房",
                    "sys_code"=>"950",
                    "info"=>[
                        [
                            "label"=>"1#水泵",
                            "state"=>$baseData['2008448543620097_2'] ?? 0,
                            "text"=>($baseData['2008448543620097_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"2#水泵",
                            "state"=>$baseData['2008448543804417_2'] ?? 0,
                            "text"=>($baseData['2008448543804417_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"3#水泵",
                            "state"=>$baseData['2008448543990785_2'] ?? 0,
                            "text"=>($baseData['2008448543990785_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                    ]
                ],
                [
                    "title"=>"980水泵房",
                    "sys_code"=>"980",
                    "info"=>[
                        [
                            "label"=>"1#水泵",
                            "state"=>$baseData['2008615794158593_2'] ?? 0,
                            "text"=>($baseData['2008615794158593_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"2#水泵",
                            "state"=>$baseData['2008615794633729_2'] ?? 0,
                            "text"=>($baseData['2008615794633729_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"3#水泵",
                            "state"=>$baseData['2008615795129345_2'] ?? 0,
                            "text"=>($baseData['2008615795129345_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"4#水泵",
                            "state"=>$baseData['2008615795635201_2'] ?? 0,
                            "text"=>($baseData['2008615795635201_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"5#水泵",
                            "state"=>$baseData['2008615796143105_2'] ?? 0,
                            "text"=>($baseData['2008615796143105_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                    ]
                ],
                [
                    "title"=>"130207水泵房",
                    "sys_code"=>"130207",
                    "info"=>[
                        [
                            "label"=>"1#水泵",
                            "state"=>$baseData['2044914761948161_2'] ?? 0,
                            "text"=>($baseData['2044914761948161_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"2#水泵",
                            "state"=>$baseData['2044914761968641_2'] ?? 0,
                            "text"=>($baseData['2044914761968641_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"3#水泵",
                            "state"=>$baseData['2044914761923585_2'] ?? 0,
                            "text"=>($baseData['2044914761923585_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"4#水泵",
                            "state"=>$baseData['2044914761907201_2'] ?? 0,
                            "text"=>($baseData['2044914761907201_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                    ]
                ],
                [
                    "title"=>"五分区950水泵房",
                    "sys_code"=>"5fq",
                    "info"=>[
                        [
                            "label"=>"1#水泵",
                            "state"=>$baseData['2012602962545665_2'] ?? 0,
                            "text"=>($baseData['2012602962545665_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"2#水泵",
                            "state"=>$baseData['2012602962572289_2'] ?? 0,
                            "text"=>($baseData['2012602962572289_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"3#水泵",
                            "state"=>$baseData['2012602962603009_2'] ?? 0,
                            "text"=>($baseData['2012602962603009_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                    ]
                ],
                [
                    "title"=>"清水泵房",
                    "sys_code"=>"qsb",
                    "info"=>[
                        [
                            "label"=>"1#水泵",
                            "state"=>$baseData['2044707426964481_2'] ?? 0,
                            "text"=>($baseData['2044707426964481_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"2#水泵",
                            "state"=>$baseData['2044707426978817_2'] ?? 0,
                            "text"=>($baseData['2044707426978817_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"5#水泵",
                            "state"=>$baseData['2044707426939905_2'] ?? 0,
                            "text"=>($baseData['2044707426939905_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"6#水泵",
                            "state"=>$baseData['2044707426954241_2'] ?? 0,
                            "text"=>($baseData['2044707426954241_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                    ]
                ],
                [
                    "title"=>"正1000水泵房",
                    "sys_code"=>"p1000",
                    "info"=>[
                        [
                            "label"=>"1#污水泵",
                            "state"=>$baseData['2044909612874753_2'] ?? 0,
                            "text"=>($baseData['2044909612874753_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                        [
                            "label"=>"2#污水泵",
                            "state"=>$baseData['2044909612889089_2'] ?? 0,
                            "text"=>($baseData['2044909612889089_2'] ?? 0) > 0 ? "开启" : "停止"
                        ],
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 929
     * */
    public function get929List() {

        $valKeys=[
            "2008460126180353_1", // 929水泵房_流量1
            "2008460126198785_1", // 929水泵房_流量2
            "2008460126446593_1", // 929水泵房_2号水仓液位

            "2008460126276609_1", // 929水泵房_1号水泵正压
            "2008460126297089_1", // 929水泵房_1号水泵负压

            "2008460126495745_1", // 929水泵房_2号水泵正压
            "2008460126510081_1", // 929水泵房_2号水泵负压

            "2008460126673921_1", // 929水泵房_3号水泵正压
            "2008460126686209_1", // 929水泵房_3号水泵负压

        ];

        $stateKeys = [

            "2008460125357057_2", // 929水泵房_1号水泵运行
            "2008460125535233_2", // 929水泵房_2号水泵运行
            "2008460125723649_2", // 929水泵房_3号水泵运行

            "2008460125367297_2", // 929水泵房_1号水泵运行选择
            "2008460125301761_2", // 929水泵房_1号水泵备用选择
            "2008460125312001_2", // 929水泵房_1号水泵检修选择
            "2008460125324289_2", // 929水泵房_1号水泵禁启
            "2008460125377537_2", // 929水泵房_1号水泵选择

            "2008460125547521_2", // 929水泵房_2号水泵运行选择
            "2008460125469697_2", // 929水泵房_2号水泵备用选择
            "2008460125481985_2", // 929水泵房_2号水泵检修选择
            "2008460125492225_2", // 929水泵房_2号水泵禁启
            "2008460125559809_2", // 929水泵房_2号水泵选择

            "2008460125735937_2", // 929水泵房_3号水泵运行选择
            "2008460125656065_2", // 929水泵房_3号水泵备用选择
            "2008460125666305_2", // 929水泵房_3号水泵检修选择
            "2008460125678593_2", // 929水泵房_3号水泵禁启
            "2008460125750273_2", // 929水泵房_3号水泵选择

        ];

        // 获取点位数据
        $valData = $this->apiService->postPointRealData($this->apiUrl, $valKeys)['data'];

        // 获取点位数据
        $stateData = $this->apiService->postPointRealData($this->apiUrl, $stateKeys)['data'];

        $info = [
            "main"=>[
                [
                    "label"=>"1#管路流量",
                    "value"=> $valData['2008460126180353_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"2#管路流量",
                    "value"=> $valData['2008460126198785_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"水仓总容量",
                    "value"=> "1917",
                    "unit"=>"m³/h"
                ],
//                [
//                    "label"=>"水仓液位",
//                    "value"=> $baseData['2008460126446593_1'] ?? 0,
//                    "unit"=>"m³/h"
//                ],
            ],
            "info_929"=>[
                [
                    "title"=>"1#水泵",
                    "state"=>($stateData['2008460125357057_2'] ?? 0) > 0 ? 0  : 1,
                    "data"=>[
                        [
                            "label"=>"正常",
                            "state"=>($stateData['2008460125367297_2'] ?? 0) > 0 ? 0 : 1,
                        ],
                        [
                            "label"=>"备用",
                            "state"=>($stateData['2008460125301761_2'] ?? 0) > 0 ? 0  : 1,
                        ],
                        [
                            "label"=>"检修",
                            "state"=>($stateData['2008460125312001_2'] ?? 0) > 0 ? 0  : 1,
                        ],
                        [
                            "label"=>"禁启",
                            "state"=>($stateData['2008460125324289_2'] ?? 0) > 0 ? 0  : 1,
                        ],
                        [
                            "label"=>"选择",
                            "state"=>($stateData['2008460125377537_2'] ?? 0) > 0 ? 0  : 1,
                        ],
                    ],
                    "table"=>[
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($valData['2008460126276609_1'] ?? 0)."Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($valData['2008460126297089_1'] ?? 0)."Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($valData['未知'] ?? 28.5)."℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($valData['未知'] ?? 27.5)."℃",
                            ],
                            [
                                "label"=>"定子温度",
                                "value"=>($valData['未知'] ?? 27.5)."℃",
                            ],
                        ]
                    ]
                ],
                [
                    "title"=>"2#水泵",
                    "state"=>($stateData['2008460125535233_2'] ?? 0) > 0 ? 0 : 1,
                    "data"=>[
                        [
                            "label"=>"正常",
                            "state"=>($stateData['2008460125547521_2'] ?? 0) > 0 ? 0 : 1,
                        ],
                        [
                            "label"=>"备用",
                            "state"=>($stateData['2008460125469697_2'] ?? 0) > 0 ? 0 : 1,
                        ],
                        [
                            "label"=>"检修",
                            "state"=>($stateData['2008460125481985_2'] ?? 0) > 0 ? 0 : 1,
                        ],
                        [
                            "label"=>"禁启",
                            "state"=>($stateData['2008460125492225_2'] ?? 0) > 0 ? 0 : 1,
                        ],
                        [
                            "label"=>"选择",
                            "state"=>($stateData['2008460125559809_2'] ?? 0) > 0 ? 0 : 1,
                        ],
                    ],
                    "table"=>[
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($valData['2008460126495745_1'] ?? 0)."Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($valData['2008460126510081_1'] ?? 0)."Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($valData['2008460126462977_1'] ?? 0)."℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($valData['2008460126481409_1'] ?? 0)."℃",
                            ],
                            [
                                "label"=>"定子温度",
                                "value"=>($valData['未知'] ?? 27.5)."℃",
                            ],
                        ]
                    ]
                ],
                [
                    "title"=>"3#水泵",
                    "state"=>($stateData['2008460125723649_2'] ?? 0) > 0 ? 0 : 1,
                    "data"=>[
                        [
                            "label"=>"正常",
                            "state"=>($stateData['2008460125735937_2'] ?? 0) > 0 ? 0 : 1,
                        ],
                        [
                            "label"=>"备用",
                            "state"=>($stateData['2008460125656065_2'] ?? 0) > 0 ? 0 : 1,
                        ],
                        [
                            "label"=>"检修",
                            "state"=>($stateData['2008460125666305_2'] ?? 0) > 0 ? 0 : 1,
                        ],
                        [
                            "label"=>"禁启",
                            "state"=>($stateData['2008460125678593_2'] ?? 0) > 0 ? 0 : 1,
                        ],
                        [
                            "label"=>"选择",
                            "state"=>($stateData['2008460125750273_2'] ?? 0) > 0 ? 0 : 1,
                        ],
                    ],
                    "table"=>[
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($valData['2008460126673921_1'] ?? 0)."Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($valData['2008460126686209_1'] ?? 0)."Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($valData['未知'] ?? 27)."℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($valData['未知'] ?? 29)."℃",
                            ],
                            [
                                "label"=>"定子温度",
                                "value"=>($valData['未知'] ?? 27.5)."℃",
                            ],
                        ]
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 720
     * */
    public function get720List() {

        $keys=[
            "2024461835248641_1", // 720水泵房_1号管路流量
            "2024461918829569_1", // 720水泵房_2号管路流量

            "2024409445010433_1", // 720水泵房_1号水仓液位
            "2024409445026817_1", // 720水泵房_液位2

            "2024441687903233_2", // 720水泵房_1号水泵运行信号
            "2024409445045249_1", // 720水泵房_1号水泵正压
            "2024409444891649_1", // 720水泵房_1号水泵负压
            "2024409444801537_1", // 720水泵房_1号水泵前轴温度
            "2024409444785153_1", // 720水泵房_1号水泵后轴温度

            "2024441740917761_2", // 720水泵房_2号水泵运行信号
            "2024409445102593_1", // 720水泵房_2号水泵正压
            "2024409444924417_1", // 720水泵房_2号水泵负压

            "2024441811375105_2", // 720水泵房_3号水泵运行信号
            "2024409445080065_1", // 720水泵房_3号水泵正压
            "2024409444908033_1", // 720水泵房_3号水泵负压
            "2024409444852737_1", // 720水泵房_3号水泵前轴温度
            "2024409444869121_1", // 720水泵房_3号水泵后轴温度
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $stateData = [];
        $stateInfoData = [];
        foreach ($baseData as $key => $val) {

            $stateInfoData[$key] = $baseData[$key] == 0 ? "关闭" : "开启";

            if ($val == -9999) {
                $baseData[$key] = '未知';
                $stateData[$key] = 0;
                $stateInfoData[$key] = "未知";

            } else {
                $stateData[$key] = $baseData[$key];
            }

        }


        $info = [
            "main"=>[
                [
                    "label"=>"1#管路流量",
                    "value"=> $baseData['2024461835248641_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"2#管路流量",
                    "value"=> $baseData['2024461918829569_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"水仓总容量",
                    "value"=> "1400",
                    "unit"=>"m³"
                ],
                [
                    "label"=>"1#水仓液位",
                    "value"=> $baseData['2024409445010433_1'] ?? 0,
                    "unit"=>"m"
                ],
                [
                    "label"=>"2#水仓液位",
                    "value"=> $baseData['2024409445026817_1'] ?? 0,
                    "unit"=>"m"
                ],
            ],
            "info"=>[
                [
                    "label"=>"1#水泵",
                    "state"=> $stateData['2024441687903233_2'] ?? "0",
                    "text"=> $stateInfoData['2024441687903233_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2024409445045249_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2024409444891649_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2024409444801537_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2024409444785153_1'] ?? 0)." ℃",
                            ],
                        ],
                    ],
                ],
                [
                    "label"=>"2#水泵",
                    "state"=> $stateData['2024441740917761_2'] ?? "0",
                    "text"=> $stateInfoData['2024441740917761_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[

                            [
                                "label"=>"正压",
                                "value"=>($baseData['2024409445102593_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2024409444924417_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['未知'] ?? 37.5)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['未知'] ?? 36.7)." ℃",
                            ],
                        ],
                    ],
                ],
                [
                    "label"=>"3#水泵",
                    "state"=> $stateData['2024441811375105_2'] ?? "0",
                    "text"=> $stateInfoData['2024441811375105_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2024409445080065_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2024409444908033_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2024409444852737_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2024409444869121_1'] ?? 0)." ℃",
                            ],
                        ],
                    ],
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 880
     * */
    public function get880List() {

        $keys=[

            "2008602973852673_1", //880水泵房_1号流量
            "2008602973967361_1", //880水泵房_2号流量
            "2008602974075905_1", //880水泵房_3号流量
            "2008602974163969_1", //880水泵房_液位2

            "2008602972906497_2", //880水泵房_1号泵闸阀开反馈
            "2008602973832193_1", //880水泵房_1号正压
            "2008602973875201_1", //880水泵房_1号负压
            "2008602973764609_1", //880水泵房_1号前轴温度
            "2008602973789185_1", //880水泵房_1号后轴温度
            "2008602973811713_1", //880水泵房_1号定子温度

            "2008602973176833_2", //880水泵房_2号泵闸阀开反馈
            "2008602973953025_1", //880水泵房_2号正压
            "2008602973987841_1", //880水泵房_2号负压
            "2008602973897729_1", //880水泵房_2号前轴温度
            "2008602973918209_1", //880水泵房_2号后轴温度
            "2008602973936641_1", //880水泵房_2号定子温度

            "2008602973481985_2", //880水泵房_3号泵闸阀开反馈
            "2008602974059521_1", //880水泵房_3号正压
            "2008602974094337_1", //880水泵房_3号负压
            "2008602974006273_1", //880水泵房_3号前轴温度
            "2008602974024705_1", //880水泵房_3号后轴温度
            "2008602974041089_1", //880水泵房_3号定子温度

            "2008602972865537_2", // 880水泵房_1号泵电机启停反馈
            "2008602973135873_2", // 880水泵房_2号泵电机启停反馈
            "2008602973436929_2", // 880水泵房_3号泵电机启停反馈
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $stateData = [];
        $stateInfoData = [];
        foreach ($baseData as $key => $val) {

            $stateInfoData[$key] = $baseData[$key] == 0 ? "关闭" : "开启";

            if ($val == -9999) {
                $baseData[$key] = '未知';
                $stateData[$key] = 0;
                $stateInfoData[$key] = "未知";

            } else {
                $stateData[$key] = $baseData[$key];
            }

        }

        $info = [
            "main"=>[
                [
                    "label"=>"1#管路流量",
                    "value"=> $baseData['2008602973852673_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"2#管路流量",
                    "value"=> $baseData['2008602973967361_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"3#管路流量",
                    "value"=> $baseData['2008602974075905_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"水仓总容量",
                    "value"=> "2149.0",
                    "unit"=>"m³"
                ],
                [
                    "label"=>"当前仓容量",
                    "value"=> "548.2",
                    "unit"=>"m³"
                ],
                [
                    "label"=>"水仓液位",
                    "value"=> $baseData['2008602974163969_1'] ?? 0,
                    "unit"=>"m"
                ],
            ],
            "info"=>[
                [
                    "label"=>"1#水泵",
                    "state"=> $stateData['2008602972865537_2'] ?? "0",
                    "text"=> $stateInfoData['2008602972865537_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2008602973832193_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2008602973875201_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2008602973764609_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2008602973789185_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"定子温度",
                                "value"=>($baseData['2008602973811713_1'] ?? 0)." ℃",
                            ],

                        ],
                    ],
                ],
                [
                    "label"=>"2#水泵",
                    "state"=> $stateData['2008602973135873_2'] ?? "0",
                    "text"=> $stateInfoData['2008602973135873_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2008602973953025_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2008602973987841_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2008602973897729_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2008602973918209_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"定子温度",
                                "value"=>($baseData['2008602973936641_1'] ?? 0)." ℃",
                            ],

                        ],
                    ],
                ],
                [
                    "label"=>"3#水泵",
                    "state"=> $stateData['2008602973436929_2'] ?? "0",
                    "text"=> $stateInfoData['2008602973436929_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2008602974059521_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2008602974094337_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2008602974006273_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2008602974024705_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"定子温度",
                                "value"=>($baseData['2008602974041089_1'] ?? 0)." ℃",
                            ],
                        ],
                    ],
                ],
            ]
        ];
        return json_encode($info);
    }

    /*
     * 950
     * */
    public function get950List() {

        $keys=[
            "2008448544351233_1", // 950水泵房_流量1
            "2008448544369665_1", // 950水泵房_流量2
            "2008448544388097_1", // 950水泵房_水仓液位

            "2008448543620097_2", // 950水泵房_1号电机运行反馈
            "2008448544461825_1", // 950水泵房_1号泵正压
            "2008448544478209_1", // 950水泵房_1号泵负压
            "2008448544087041_1", // 950水泵房_1号前轴温度
            "2008448544226305_1", // 950水泵房_1号定子温度

            "2008448543804417_2", // 950水泵房_2号电机运行反馈
            "2008448544492545_1", // 950水泵房_2号泵正压
            "2008448544506881_1", // 950水泵房_2号泵负压
            "2008448544134145_1", // 950水泵房_2号前轴温度
            "2008448544191489_1", // 950水泵房_2号后轴温度

            "2008448543990785_2", // 950水泵房_3号电机运行反馈
            "2008448544523265_1", // 950水泵房_3号泵正压
            "2008448544541697_1", // 950水泵房_3号泵负压
            "2008448544154625_1", // 950水泵房_3号前轴温度
            "2008448544207873_1", // 950水泵房_3号后轴温度
            "2008448544261121_1", // 950水泵房_3号定子温度
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        foreach ($baseData as $key => $val) {

            $stateInfoData[$key] = $baseData[$key] == 0 ? "关闭" : "开启";

            if ($val == -9999) {
                $baseData[$key] = '未知';
                $stateData[$key] = 0;
                $stateInfoData[$key] = "未知";

            } else {
                $stateData[$key] = $baseData[$key];
            }

        }

        $info = [
            "main"=>[
                [
                    "label"=>"1#管路流量",
                    "value"=> $baseData['2008448544351233_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"2#管路流量",
                    "value"=> $baseData['2008448544369665_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"水仓总容量",
                    "value"=> "2710.0",
                    "unit"=>"m³"
                ],
                [
                    "label"=>"水仓液位",
                    "value"=> $baseData['2008448544388097_1'] ?? 0,
                    "unit"=>"m"
                ],
            ],
            "info"=>[
                [
                    "label"=>"1#水泵",
                    "state"=> $stateData['2008448543620097_2'] ?? "0",
                    "text"=> $stateInfoData['2008448543620097_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2008448544461825_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2008448544478209_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2008448544087041_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>(33.9 ?? 0)." ℃",
                            ],
                            [
                                "label"=>"定子温度",
                                "value"=>($baseData['2008448544226305_1'] ?? 0)." ℃",
                            ],

                        ],
                    ],
                ],
                [
                    "label"=>"2#水泵",
                    "state"=> $stateData['2008448543804417_2'] ?? "0",
                    "text"=> $stateInfoData['2008448543804417_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2008448544492545_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2008448544506881_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2008448544134145_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2008448544191489_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"定子温度",
                                "value"=>($baseData['2008448544191489_1'] ?? 0)." ℃",
                            ],

                        ],
                    ],
                ],
                [
                    "label"=>"3#水泵",
                    "state"=> $stateData['2008448543990785_2'] ?? "0",
                    "text"=> $stateInfoData['2008448543990785_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2008448544523265_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2008448544541697_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2008448544154625_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2008448544207873_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"定子温度",
                                "value"=>($baseData['2008448544261121_1'] ?? 0)." ℃",
                            ],
                        ],
                    ],
                ],
            ]
        ];
        return json_encode($info);
    }

    /*
     * 980
     * */
    public function get980List() {

        $keys=[
            "2008615796304897_1", // 980水泵房_1号流量
            "2008615796360193_1", // 980水泵房_2号流量
            "2008615796413441_1", // 980水泵房_3号流量

            "2008615794158593_2", // 980水泵房_1号电机运行反馈
            "2008615796284417_1", // 980水泵房_1号正压
            "2008615796323329_1", // 980水泵房_1号负压

            "2008615794633729_2", // 980水泵房_2号电机运行反馈
            "2008615796341761_1", // 980水泵房_2号正压
            "2008615796378625_1", // 980水泵房_2号负压

            "2008615795129345_2", // 980水泵房_3号电机运行反馈
            "2008615796395009_1", // 980水泵房_3号正压
            "2008615796431873_1", // 980水泵房_3号负压

            "2008615795635201_2", // 980水泵房_4号电机运行反馈
            "2008615796452353_1", // 980水泵房_4号正压
            "2008615796470785_1", // 980水泵房_4号负压

            "2008615796143105_2", // 980水泵房_5号电机运行反馈
            "2008615796489217_1", // 980水泵房_5号正压
            "2008615796503553_1", // 980水泵房_5号负压


        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $stateData = [];
        $stateInfoData = [];
        foreach ($baseData as $key => $val) {

            $stateInfoData[$key] = $baseData[$key] == 0 ? "关闭" : "开启";

            if ($val == -9999) {
                $baseData[$key] = '未知';
                $stateData[$key] = 0;
                $stateInfoData[$key] = "未知";

            } else {
                $stateData[$key] = $baseData[$key];
            }

        }

        $info = [
            "main"=>[
                [
                    "label"=>"1#管路流量",
                    "value"=> $baseData['2008615796304897_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"2#管路流量",
                    "value"=> $baseData['2008615796360193_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"3#管路流量",
                    "value"=> $baseData['2008615796413441_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"水仓总容量",
                    "value"=> "3373.0",
                    "unit"=>"m³"
                ],
                [
                    "label"=>"当前仓容量",
                    "value"=> "1213.8",
                    "unit"=>"m³"
                ],
                [
                    "label"=>"水仓液位",
                    "value"=> "0",
                    "unit"=>"m"
                ],
            ],
            "info"=>[
                [
                    "label"=>"1#水泵",
                    "state"=> $stateData['2008615794158593_2'] ?? "0",
                    "text"=> $stateInfoData['2008615794158593_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2008615796284417_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2008615796323329_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>(26 ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>(26 ?? 0)." ℃",
                            ],
                            [
                                "label"=>"电机温度",
                                "value"=>(29 ?? 0)." ℃",
                            ],

                        ],
                    ],
                ],
                [
                    "label"=>"2#水泵",
                    "state"=> $stateData['2008615794633729_2'] ?? "0",
                    "text"=> $stateInfoData['2008615794633729_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2008615796341761_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2008615796378625_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>(30 ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>(31 ?? 0)." ℃",
                            ],
                            [
                                "label"=>"电机温度",
                                "value"=>(30 ?? 0)." ℃",
                            ],

                        ],
                    ],
                ],
                [
                    "label"=>"3#水泵",
                    "state"=> $stateData['2008615795129345_2'] ?? "0",
                    "text"=> $stateInfoData['2008615795129345_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2008615796395009_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2008615796431873_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>(30 ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>(31 ?? 0)." ℃",
                            ],
                            [
                                "label"=>"电机温度",
                                "value"=>(30 ?? 0)." ℃",
                            ],

                        ],
                    ],
                ],
                [
                    "label"=>"4#水泵",
                    "state"=> $stateData['2008615795635201_2'] ?? "0",
                    "text"=> $stateInfoData['2008615795635201_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2008615796452353_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2008615796470785_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>(29 ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>(32 ?? 0)." ℃",
                            ],
                            [
                                "label"=>"电机温度",
                                "value"=>(34 ?? 0)." ℃",
                            ],

                        ],
                    ],
                ],
                [
                    "label"=>"5#水泵",
                    "state"=> $stateData['2008615796143105_2'] ?? "0",
                    "text"=> $stateInfoData['2008615796143105_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2008615796489217_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2008615796503553_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>(28 ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>(26 ?? 0)." ℃",
                            ],
                            [
                                "label"=>"电机温度",
                                "value"=>(30 ?? 0)." ℃",
                            ],

                        ],
                    ],
                ],
            ]
        ];
        return json_encode($info);
    }

    /*
     * 13207
     * */
    public function get13207List() {

        $keys=[
            "2049337304566785_1", // 13207泵房泵号选择
            "2044914761958401_2", // 13207机巷排水系统_1号潜水泵运行反馈
            "2044914761978881_2", // 13207机巷排水系统_2号潜水泵运行反馈
            "2044914761915393_2", // 13207机巷排水系统_3号潜水泵运行反馈
            "2044914761933825_2", // 13207机巷排水系统_4号潜水泵运行反馈

            "2045085417917441_1", // 多级排水_13207低容量设定
            "2045085261796353_1", // 多级排水_13207高容量设定

            "2044914761948161_2", // 13207机巷排水系统_1号水泵运行反馈
            "2044914761968641_2", // 13207机巷排水系统_2号水泵运行反馈
            "2044914761923585_2", // 13207机巷排水系统_3号水泵运行反馈
            "2044914761907201_2", // 13207机巷排水系统_4号水泵运行反馈

            "2044914761958401_2", // 13207机巷排水系统_1号潜水泵运行反馈
            "2044914761978881_2", // 13207机巷排水系统_2号潜水泵运行反馈
            "2044914761915393_2", // 13207机巷排水系统_3号潜水泵运行反馈
            "2044914761933825_2", // 13207机巷排水系统_4号潜水泵运行反馈
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $stateData = [];
        $stateInfoData = [];
        foreach ($baseData as $key => $val) {

            $stateInfoData[$key] = $baseData[$key] == 0 ? "关闭" : "开启";

            if ($val == -9999) {
                $baseData[$key] = '未知';
                $stateData[$key] = 0;
                $stateInfoData[$key] = "未知";

            } else {
                $stateData[$key] = $baseData[$key];
            }

        }

        $info = [
            "main"=>[
                [
                    "label"=>"1#管路流量",
                    "value"=> $baseData['2044914762050561_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"2#管路流量",
                    "value"=> $baseData['2044914762093569_1'] ?? 0,
                    "unit"=>"m³/h"
                ],
                [
                    "label"=>"水仓容量",
                    "value"=> $baseData['2044914762105857_1'] ?? 0,
                    "unit"=>"m³"
                ],
                [
                    "label"=>"泵房泵号选择",
                    "value"=> $baseData['2049337304566785_1'] ?? 0,
                    "unit"=>"m³"
                ],
                [
                    "label"=>"仓容上限",
                    "value"=> $baseData['2045085261796353_1'] ?? 0,
                    "unit"=>"m³"
                ],
                [
                    "label"=>"仓容下限",
                    "value"=> $baseData['2045085417917441_1'] ?? 0,
                    "unit"=>"m³"
                ],
            ],
            "info"=>[
                [
                    "label"=>"1#水泵",
                    "state"=> $stateData['2044914761948161_2'] ?? "0",
                    "text"=> $stateInfoData['2044914761948161_2'] ?? "未知",
                    "table"=>[
                    ],
                ],
                [
                    "label"=>"1#潜水泵",
                    "state"=> $stateData['2044914761958401_2'] ?? "0",
                    "text"=> $stateInfoData['2044914761958401_2'] ?? "未知",
                    "table"=>[
                    ],
                ],
                [
                    "label"=>"2#水泵",
                    "state"=> $stateData['2044914761968641_2'] ?? "0",
                    "text"=> $stateInfoData['2044914761968641_2'] ?? "未知",
                    "table"=>[
                    ],
                ],
                [
                    "label"=>"2#潜水泵",
                    "state"=> $stateData['2044914761978881_2'] ?? "0",
                    "text"=> $stateInfoData['2044914761978881_2'] ?? "未知",
                    "table"=>[
                    ],
                ],
                [
                    "label"=>"3#水泵",
                    "state"=> $stateData['2044914761923585_2'] ?? "0",
                    "text"=> $stateInfoData['2044914761923585_2'] ?? "未知",
                    "table"=>[
                    ],
                ],
                [
                    "label"=>"3#潜水泵",
                    "state"=> $stateData['2044914761915393_2'] ?? "0",
                    "text"=> $stateInfoData['2044914761915393_2'] ?? "未知",
                    "table"=>[
                    ],
                ],
                [
                    "label"=>"4#水泵",
                    "state"=> $stateData['2044914761907201_2'] ?? "0",
                    "text"=> $stateInfoData['2044914761907201_2'] ?? "未知",
                    "table"=>[
                    ],
                ],
                [
                    "label"=>"4#潜水泵",
                    "state"=> $stateData['2044914761933825_2'] ?? "0",
                    "text"=> $stateInfoData['2044914761933825_2'] ?? "未知",
                    "table"=>[
                    ],
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 2000方高位水池系统
     * */
    public function get2000fList() {

        $keys=[
            "2047540909153281_1", // 2000方水池_出口压力
            "2047540919704577_1", // 2000方水池_井下出口压力
            "2047540909112321_1", // 2000方水池_水池容量
            "2047540909075457_1", // 2000方水池_水池液位

            "2047540908495873_2", // 2000方水池_地面1号泵工频运行
            "2047540908469249_2", // 2000方水池_地面1号泵变频运行

            "2047540908547073_2", // 2000方水池_地面2号泵工频运行
            "2047540908522497_2", // 2000方水池_地面2号泵变频运行

            "2047540908598273_2", // 2000方水池_地面3号泵工频运行2
            "2047540908573697_2", // 2000方水池_地面3号泵变频运行1

            "2047540919536641_2", // 2000方水池_二泵号手动启动12

            "2047540919243777_2", // 2000方水池_井下1号泵变频运行
            "2047540919270401_2", // 2000方水池_井下1号泵工频运行
            "2047540919294977_2", // 2000方水池_井下2号泵变频运行
            "2047540919319553_2", // 2000方水池_井下2号泵工频运行
            "2047540919344129_2", // 2000方水池_井下3号泵变频运行
            "2047540919368705_2", // 2000方水池_井下3号泵工频运行
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $stateData = [];
        $stateInfoData = [];
        foreach ($baseData as $key => $val) {

            $stateInfoData[$key] = $baseData[$key] == 0 ? "关闭" : "开启";

            if ($val == -9999) {
                $baseData[$key] = '未知';
                $stateData[$key] = 0;
                $stateInfoData[$key] = "未知";

            } else {
                $stateData[$key] = $baseData[$key];
            }

        }

        $info = [
            "main"=>[
                [
                    "label"=>"井下供水压力",
                    "value"=> round($baseData['2047540919704577_1'] ?? 0 / 100, 2),
                    "unit"=>"Mpa"
                ],
                [
                    "label"=>"洗煤厂供水压力",
                    "value"=> round($baseData['2047540909153281_1'] ?? 0 / 100, 2),
                    "unit"=>"Mpa"
                ],
                [
                    "label"=>"当前容量",
                    "value"=> $baseData['2047540909112321_1'] ?? 0,
                    "unit"=>"m³"
                ],
                [
                    "label"=>"当前液位",
                    "value"=> $baseData['2047540909075457_1'] ?? 0,
                    "unit"=>"m"
                ],
            ],
            "info"=>[
                [
                    "label"=>"地面1#水泵",
                    "state"=>$baseData['2047540908469249_2'] + $baseData['2047540908495873_2'] > 0 ? 1 : 0,
                    "text"=>$baseData['2047540908469249_2'] + $baseData['2047540908495873_2'] > 0 ? "开":"关",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"工频运行",
                                "value"=>$baseData['2047540908495873_2'] > 0 ? '是' : '否'
                            ],
                            [
                                "label"=>"变频运行",
                                "value"=>$baseData['2047540908469249_2'] > 0 ? '是' : '否'
                            ],
                        ],
                    ],
                ],
                [
                    "label"=>"地面2#水泵",
                    "state"=>$baseData['2047540908547073_2'] + $baseData['2047540908522497_2'] > 0 ? 1 : 0,
                    "text"=>$baseData['2047540908547073_2'] + $baseData['2047540908522497_2'] > 0 ? "开":"关",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"工频运行",
                                "value"=>$baseData['2047540908547073_2'] > 0 ? '是' : '否'
                            ],
                            [
                                "label"=>"变频运行",
                                "value"=>$baseData['2047540908522497_2'] > 0 ? '是' : '否'
                            ],
                        ],
                    ],
                ],
                [
                    "label"=>"地面3#水泵",
                    "state"=>$baseData['2047540908573697_2'] + $baseData['2047540908598273_2'] > 0 ? 1 : 0,
                    "text"=>$baseData['2047540908573697_2'] + $baseData['2047540908598273_2'] > 0 ? "开":"关",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"工频运行",
                                "value"=>$baseData['2047540908598273_2'] > 0 ? '是' : '否'
                            ],
                            [
                                "label"=>"变频运行",
                                "value"=>$baseData['2047540908573697_2'] > 0 ? '是' : '否'
                            ],

                        ],
                    ],
                ],

                [
                    "label"=>"井下1#水泵",
                    "state"=>$baseData['2047540919243777_2'] + $baseData['2047540919270401_2'] > 0 ? 1 : 0,
                    "text"=>$baseData['2047540919243777_2'] + $baseData['2047540919270401_2'] > 0 ? "开":"关",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[

                            [
                                "label"=>"工频运行",
                                "value"=>$baseData['2047540919270401_2'] > 0 ? '是' : '否'
                            ],
                            [
                                "label"=>"变频运行",
                                "value"=>$baseData['2047540919243777_2'] > 0 ? '是' : '否'
                            ],
                        ],
                    ],
                ],
                [
                    "label"=>"井下2#水泵",
                    "state"=>$baseData['2047540919319553_2'] + $baseData['2047540919294977_2'] > 0 ? 1 : 0,
                    "text"=>$baseData['2047540919319553_2'] + $baseData['2047540919294977_2'] > 0 ? "开":"关",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"工频运行",
                                "value"=>$baseData['2047540919319553_2'] > 0 ? '是' : '否'
                            ],
                            [
                                "label"=>"变频运行",
                                "value"=>$baseData['2047540919294977_2'] > 0 ? '是' : '否'
                            ],
                        ],
                    ],
                ],
                [
                    "label"=>"井下3#水泵",
                    "state"=>$baseData['2047540919368705_2'] + $baseData['2047540919344129_2'] > 0 ? 1 : 0,
                    "text"=>$baseData['2047540919368705_2'] + $baseData['2047540919344129_2'] > 0 ? "开":"关",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"工频运行",
                                "value"=>$baseData['2047540919368705_2'] > 0 ? '是' : '否'
                            ],
                            [
                                "label"=>"变频运行",
                                "value"=>$baseData['2047540919344129_2'] > 0 ? '是' : '否'
                            ],
                        ],
                    ],
                ],
            ]
        ];
        return json_encode($info);
    }


    /*
     * 5000方高位水池系统
     * */
    public function get5000fList() {

        $keys=[
            "2044016878083073_2", // 多级排水系统_闸阀1开到位
            "2044016878164993_2", // 多级排水系统_闸阀2开到位
            "2044016878232577_2", // 多级排水系统_闸阀3开到位
            "2044016878296065_2", // 多级排水系统_闸阀4开到位

            "2044016878388225_1", // 多级排水系统_液位1
            "2044016878400513_1", // 多级排水系统_液位2

            "2044016878451713_1", // 多级排水系统_水池1超高液位设定
            "2044016878416897_1", // 多级排水系统_水池1低液位设定
            "2044016878431233_1", // 多级排水系统_水池1高液位设定

            "2044016878504961_1", // 多级排水系统_水池2超高液位设定
            "2044016878466049_1", // 多级排水系统_水池2低液位设定
            "2044016878480385_1", // 多级排水系统_水池2高液位设定
            "2052698829423617_1", // 矿井水总进水量累计流量
            "2052671000642561_1", // 累计流量
            "2052698691959809_1", // 污水处理厂累计流量
            "2049343208078337_2", // 5000方水池1超高液位报警
            "2049343147056129_2", // 5000方水池1高液位报警
            "2049343267609601_2", // 5000方水池2超高液位报警
            "2049343309526017_2", // 5000方水池2高液位报警
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $stateData = [];
        $stateInfoData = [];
        foreach ($baseData as $key => $val) {

            $stateInfoData[$key] = $baseData[$key] == 0 ? "关闭" : "开启";

            if ($val == -9999) {
                $baseData[$key] = '未知';
                $stateData[$key] = 0;
                $stateInfoData[$key] = "未知";

            } else {
                $stateData[$key] = $baseData[$key];
            }

        }

        $info = [
            "info"=> [
                [
                    "title"=>"来自950水泵房",
                    "data"=>[
                        [
                            "label"=>"1号闸阀",
                            "state" => $baseData['2044016878083073_2']
                        ],
                        [
                            "label"=>"3号闸阀",
                            "state" => $baseData['2044016878232577_2']
                        ],
                    ]
                ],
                [
                    "title"=>"来自950水泵房",
                    "data"=>[
                        [
                            "label"=>"2号闸阀",
                            "state" => $baseData['2044016878164993_2']
                        ],
                        [
                            "label"=>"4号闸阀",
                            "state" => $baseData['2044016878296065_2']
                        ],
                    ]
                ],
            ],
            "tab_info"=>[
                [
                    "title"=>"累计流量",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"矿井水总进水量累计流量（m³）",
                                "value"=>$baseData['2052698829423617_1']
                            ],
                            [
                                "label"=>"累计流量（m³）",
                                "value"=>$baseData['2052671000642561_1']
                            ],
                            [
                                "label"=>"污水处理厂累计流量（m）",
                                "value"=>$baseData['2052698691959809_1']
                            ]
                        ]
                    ]
                ],
                [
                    "title"=>"1号水池",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"液位（m）",
                                "value"=>$baseData['2044016878388225_1']
                            ],
                            [
                                "label"=>"超高液位设定值（m）",
                                "value"=>$baseData['2044016878451713_1']
                            ],
                            [
                                "label"=>"高液位设定值（m）",
                                "value"=>$baseData['2044016878431233_1']
                            ],
                            [
                                "label"=>"低液位设定值（m）",
                                "value"=>$baseData['2044016878416897_1']
                            ]
                        ]
                    ]
                ],
                [
                    "title"=>"2号水池",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"液位（m）",
                                "value"=>$baseData['2044016878400513_1']
                            ],
                            [
                                "label"=>"超高液位设定值（m）",
                                "value"=>$baseData['2044016878504961_1']
                            ],
                            [
                                "label"=>"高液位设定值（m）",
                                "value"=>$baseData['2044016878480385_1']
                            ],
                            [
                                "label"=>"低液位设定值（m）",
                                "value"=>$baseData['2044016878466049_1']
                            ]
                        ]
                    ]
                ]
            ],
        ];

        return json_encode($info);
    }


    /*
     * 正1000方高位水池系统
     * */
    public function getP1000List() {

        $keys=[
            "2044707428887553_1", // 清水泵房_流量1


            "2044909612874753_2", // 1000水泵房系统_污泵电机反馈信号1
            "2044909612889089_2", // 1000水泵房系统_污泵电机反馈信号2

            "2044909612987393_1", // 1000水泵房系统_1号污水泵正压1
            "2044909613003777_1", // 1000水泵房系统_1号污水泵负压1

            "2044909613020161_1", // 1000水泵房系统_2号污水泵正压2
            "2044909613036545_1", // 1000水泵房系统_2号污水泵负压2

            "2044707427773441_1", // 清水泵房_二号水泵前轴温度
            "2044707427785729_1", // 清水泵房_二号水泵后轴温度

            "2044909612758017_2", // 1000水泵房系统_抽气球阀关到位1
            "2044909612796929_2", // 1000水泵房系统_抽气球阀关到位2
            "2044909612821505_2", // 1000水泵房系统_抽气球阀开到位2

            "2044909612932097_2", // 1000水泵房系统_电动闸阀开到位1
            "2044909612897281_2", // 1000水泵房系统_电动闸阀关到位1

            "2044909612942337_2", // 1000水泵房系统_电动闸阀开到位2
            "2044909612921857_2", // 1000水泵房系统_电动闸阀关到位2

            "2044909612723201_2", // 1000水泵房系统_射流球阀关到位1
            "2044909612731393_2", // 1000水泵房系统_射流球阀关到位2
            "2044909612739585_2", // 1000水泵房系统_射流球阀开到位1
            "2044909612747777_2", // 1000水泵房系统_射流球阀开到位2

            "2044909612964865_1", // 1000水泵房系统_流量计
            "2044909612950529_1", // 1000水泵房系统_污水泵液位

            "2044909612837889_2", // 1000水泵房系统_水仓关到位
            "2044909612856321_2", // 1000水泵房系统_水仓开到位

            "2044707427501057_2", // 清水泵房_五号水泵变频器正转
            "2044707427548161_2", // 清水泵房_六号水泵变频器正转点动
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $stateData = [];
        $stateInfoData = [];
        foreach ($baseData as $key => $val) {

            $stateInfoData[$key] = $baseData[$key] == 0 ? "关闭" : "开启";

            if ($val == -9999) {
                $baseData[$key] = '未知';
                $stateData[$key] = 0;
                $stateInfoData[$key] = "未知";

            } else {
                $stateData[$key] = $baseData[$key];
            }

        }


        $info = [
            "main"=>[
                [
                    "label"=>"水仓总容量",
                    "value"=> $baseData['2044707428887553_1'] ?? 0,
                    "unit"=>"m³"
                ],
                [
                    "label"=>"水仓水位",
                    "value"=> $baseData['2044909612950529_1'] ?? 0,
                    "unit"=>"M"
                ]
            ],
            "info"=>[
                [
                    "label"=>"1号污水泵",
                    "state"=> $stateData['2044909612874753_2'] ?? "0",
                    "text"=> $stateInfoData['2044909612874753_2'] ?? "未知",
                    "table"=>[
                        "table"=>[
                            "thead"=>["参数名称", "值"],
                            "tbody"=>[
                                [
                                    "label"=>"正压",
                                    "value"=>($baseData['2044909612987393_1'] ?? 0)." Mpa",
                                ],
                                [
                                    "label"=>"负压",
                                    "value"=>($baseData['2044909613003777_1'] ?? 0)." Mpa",
                                ],
                                [
                                    "label"=>"前轴温度",
                                    "value"=>($baseData['2044707427773441_1'] ?? 0)." ℃",
                                ],
                                [
                                    "label"=>"后轴温度",
                                    "value"=>($baseData['2044707427785729_1'] ?? 0)." ℃",
                                ],
                                [
                                    "label"=>"电机温度",
                                    "value"=>($baseData['2044707427785729_1'] ?? 0)." ℃",
                                ],
                            ]
                        ]
                    ],
                ],
                [
                    "label"=>"2号污水泵",
                    "state"=> $stateData['2044909612889089_2'] ?? "0",
                    "text"=> $stateInfoData['2044909612889089_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2044909613020161_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2044909613036545_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2044707427773441_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2044707427785729_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"点击温度",
                                "value"=>($baseData['2044707427785729_1'] ?? 0)." ℃",
                            ],
                        ]

                    ],
                ],
            ]
        ];
        return json_encode($info);
    }

    /*
     * 五分区水泵房
     * */
    public function get5fqfList() {

        $keys=[
            "2012605462658049_1", // 五分区水泵房_2号水仓液位 3

            "2012605463241729_1", // 五分区水泵房_液位1
            "2012605463258113_1", // 五分区水泵房_液位2 3.4

            "2012605462629377_1", // 五分区水泵房_1号管流量
            "2012605462643713_1", // 五分区水泵房_2号流量

            "2012602962203649_2", // 五分区水泵房_进水阀1开
            "2012602962224129_2", // 五分区水泵房_进水阀2开
            "2012602962250753_2", // 五分区水泵房_进水阀3开

            "2012602962277377_2", // 五分区水泵房_真空阀1开
            "2012602962301953_2", // 五分区水泵房_真空阀2开
            "2012602962326529_2", // 五分区水泵房_真空阀3开

            "2012602962062337_2", // 五分区水泵房_射流阀1开
            "2012602962084865_2", // 五分区水泵房_射流阀2开
            "2012602962107393_2", // 五分区水泵房_射流阀3开
            "2012602962134017_2", // 五分区水泵房_射流阀4开
            "2012602962156545_2", // 五分区水泵房_射流阀5开
            "2012602962183169_2", // 五分区水泵房_射流阀6开

            "2012602962545665_2", // 五分区水泵房_水泵1启停状态
            "2012605463550977_1", // 五分区水泵房_1号泵正压
            "2012605462791169_1", // 五分区水泵房_负压1
            "2012605463491585_1", // 五分区水泵房_振动1
            "2012605463297025_1", // 五分区水泵房_温度1
            "2012605463315457_1", // 五分区水泵房_温度2
            "2012605463415809_1", // 五分区水泵房_小时1
            "2012605462739969_1", // 五分区水泵房_分1

            "2012602962572289_2", // 五分区水泵房_水泵2启停状态
            "2012605463571457_1", // 五分区水泵房_2号泵正压
            "2012605462809601_1", // 五分区水泵房_负压2
            "2012605463512065_1", // 五分区水泵房_2号泵振动
            "2012605463354369_1", // 五分区水泵房_温度4
            "2012605463333889_1", // 五分区水泵房_温度3
            "2012605463428097_1", // 五分区水泵房_小时2
            "2012605462758401_1", // 五分区水泵房_分2

            "2012602962603009_2", // 五分区水泵房_水泵3启停状态
            "2012605463587841_1", // 五分区水泵房_3号泵正压
            "2012605462825985_1", // 五分区水泵房_负压3
            "2012605463530497_1", // 五分区水泵房_3号泵振动
            "2012605463366657_1", // 五分区水泵房_温度5
            "2012605463297025_1", // 五分区水泵房_温度1
            "2012605463446529_1", // 五分区水泵房_小时3
            "2012605462774785_1", // 五分区水泵房_分3

            "2012605463041025_1", // 五分区水泵房_流量1
            "2012605463057409_1", // 五分区水泵房_流量2
            "2044707428887553_1",
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $stateData = [];
        $stateInfoData = [];
        foreach ($baseData as $key => $val) {

            $stateInfoData[$key] = $baseData[$key] == 0 ? "关闭" : "开启";

            if ($val == -9999) {
                $baseData[$key] = '未知';
                $stateData[$key] = 0;
                $stateInfoData[$key] = "未知";

            } else {
                $stateData[$key] = $baseData[$key];
            }

        }

        $info = [
            "main"=>[
//                [
//                    "label"=>"水仓容量",
//                    "value"=> $baseData['2044707428887553_1'] ?? 0,
//                    "unit"=>"m³"
//                ],
                [
                    "label"=>"1#水仓水位1",
                    "value"=> $baseData['2012605463258113_1'] ?? 0,
                    "unit"=>"M"
                ],
                [
                    "label"=>"1#水仓水位2",
                    "value"=> $baseData['2012605462658049_1'] ?? 0,
                    "unit"=>"M"
                ],
                [
                    "label"=>"2#水仓水位1",
                    "value"=> $baseData['2012605462658049_1'] ?? 0,
                    "unit"=>"M"
                ],
                [
                    "label"=>"2#水仓水位2",
                    "value"=> $baseData['2012605463258113_1'] ?? 0,
                    "unit"=>"M"
                ]
            ],
            "data"=>[
                [
                    "label"=>"进水阀1",
                    "state"=>$baseData['2012602962203649_2'] ?? 0
                ],
                [
                    "label"=>"真空阀1",
                    "state"=>$baseData['2012602962277377_2'] ?? 0
                ],
                [
                    "label"=>"进水阀2",
                    "state"=>$baseData['2012602962224129_2'] ?? 0
                ],
                [
                    "label"=>"真空阀2",
                    "state"=>$baseData['2012602962301953_2'] ?? 0
                ],
                [
                    "label"=>"进水阀3",
                    "state"=>$baseData['2012602962250753_2'] ?? 0
                ],
                [
                    "label"=>"真空阀3",
                    "state"=>$baseData['2012602962326529_2'] ?? 0
                ],

                [
                    "label"=>"射流阀1",
                    "state"=>$baseData['2012602962062337_2'] ?? 0
                ],
                [
                    "label"=>"射流阀2",
                    "state"=>$baseData['2012602962084865_2'] ?? 0
                ],
                [
                    "label"=>"射流阀3",
                    "state"=>$baseData['2012602962107393_2'] ?? 0
                ],
                [
                    "label"=>"射流阀4",
                    "state"=>$baseData['2012602962134017_2'] ?? 0
                ],
                [
                    "label"=>"射流阀5",
                    "state"=>$baseData['2012602962156545_2'] ?? 0
                ],
                [
                    "label"=>"射流阀6",
                    "state"=>$baseData['2012602962183169_2'] ?? 0
                ],
            ],
            "info"=>[
                [
                    "label"=>"1#水泵",
                    "state"=> $stateData['2012602962545665_2'] ?? "0",
                    "text"=> $stateInfoData['2012602962545665_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2012605463550977_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2012605462791169_1'] ?? 0)."Mpa",
                            ],
                            [
                                "label"=>"振动",
                                "value"=>($baseData['2012605463491585_1'] ?? 0)."℃",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2012605463297025_1'] ?? 0)."℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2012605463315457_1'] ?? 0)."℃",
                            ],
                            [
                                "label"=>"运行时间",
                                "value"=>$baseData['2012605463415809_1']."时".$baseData['2012605462739969_1']."分",
                            ],
                        ]
                    ],
                ],
                [
                    "label"=>"2#水泵",
                    "state"=> $stateData['2012602962572289_2'] ?? "0",
                    "text"=> $stateInfoData['2012602962572289_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2012605463571457_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2012605462809601_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"振动",
                                "value"=>($baseData['2012605463512065_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2012605463354369_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2012605463333889_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"运行时间",
                                "value"=>$baseData['2012605463428097_1']."时".$baseData['2012605462758401_1']."分",
                            ],
                        ]
                    ],
                ],
                [
                    "label"=>"3#水泵",
                    "state"=> $stateData['2012602962603009_2'] ?? "0",
                    "text"=> $stateInfoData['2012602962603009_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"正压",
                                "value"=>($baseData['2012605463587841_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"负压",
                                "value"=>($baseData['2012605462825985_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=>"振动",
                                "value"=>($baseData['2012605463530497_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2012605463366657_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2012605463297025_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"运行时间",
                                "value"=>$baseData['2012605463446529_1']."时".$baseData['2012605462774785_1']."分",
                            ],
                        ]
                    ],
                ],
            ]
        ];
        return json_encode($info);
    }

    /*
     * 清水泵房
     * */
    public function getQsbfList() {

        $keys=[
            "2012605462658049_1", // 水位
            "2044707428860929_1", // 总管压力

            "2044707428887553_1", // 清水泵房_流量1
            "2044707428899841_1", // 清水泵房_流量2
            "2044707428916225_1", // 清水泵房_流量3

            "2044707426964481_2", // 清水泵房_一号水泵变频器运行反馈
            "2044707428183041_1", // 清水泵房_一号水泵变频器输出电压
            "2044707428195329_1", // 清水泵房_一号水泵变频器输出电流
            "2044707428236289_1", // 清水泵房_一号水泵变频器输出转矩
            "2044707428207617_1", // 清水泵房_一号水泵变频器运行转速
            "2044707428221953_1", // 清水泵房_一号水泵变频器输出功率
            "2044707428135937_1", // 清水泵房_一号水泵压力
            "2044707428158465_1", // 清水泵房_一号水泵变频器运行频率
            "2044707427800065_1", // 清水泵房_一号水泵前轴温度
            "2044707427814401_1", // 清水泵房_一号水泵后轴温度
            "2044707427683329_1", //清水泵房_一号水泵后轴低温报警设定值
            "2044707427699713_1", //清水泵房_一号水泵后轴高温报警设定值
            "2044707428072449_1", //清水泵房_一号水泵前轴低温报警设定值
            "2044707427666945_1", //清水泵房_一号水泵前轴高温报警设定值

            "2044707426978817_2", // 清水泵房_二号水泵变频器运行反馈
            "2044707428350977_1", // 清水泵房_二号水泵变频器输出电压
            "2044707428365313_1", // 清水泵房_二号水泵变频器输出电流
            "2044707428406273_1", // 清水泵房_二号水泵变频器输出转矩
            "2044707428381697_1", // 清水泵房_二号水泵变频器运行转速
            "2044707428393985_1", // 清水泵房_二号水泵变频器输出功率
            "2044707428279297_1", // 清水泵房_二号水泵压力
            "2044707428320257_1", // 清水泵房_二号水泵变频器运行频率
            "2044707427773441_1", // 清水泵房_二号水泵前轴温度
            "2044707427785729_1", // 清水泵房_二号水泵后轴温度
            "2044707428045825_1", //清水泵房_二号水泵后轴低温报警设定值
            "2044707428060161_1", //清水泵房_二号水泵后轴高温报警设定值
            "2044707428019201_1", //清水泵房_二号水泵前轴低温报警设定值
            "2044707428031489_1", //清水泵房_二号水泵前轴高温报警设定值


            "2044707426939905_2", // 清水泵房_五号水泵变频器运行反馈
            "2044707428529153_1", // 清水泵房_五号水泵变频器输出电压
            "2044707428545537_1", // 清水泵房_五号水泵变频器输出电流
            "2044707428586497_1", // 清水泵房_五号水泵变频器输出转矩
            "2044707428561921_1", // 清水泵房_五号水泵变频器运行转速
            "2044707428572161_1", // 清水泵房_五号水泵变频器输出功率
            "2044707428416513_1", // 清水泵房_五号水泵压力
            "2044707428488193_1", // 清水泵房_五号水泵变频器运行频率
            "2044707427746817_1", // 清水泵房_五号水泵前轴温度
            "2044707427761153_1", // 清水泵房_五号水泵后轴温度
            "2044707427994625_1", //清水泵房_五号水泵后轴低温报警设定值
            "2044707428006913_1", //清水泵房_五号水泵后轴高温报警设定值
            "2044707427963905_1", //清水泵房_五号水泵前轴低温报警设定值
            "2044707427978241_1", //清水泵房_五号水泵前轴高温报警设定值

            "2044707426954241_2", // 清水泵房_六号水泵变频器运行反馈
            "2044707428748289_1", // 清水泵房_六号水泵变频器输出电压
            "2044707428760577_1", // 清水泵房_六号水泵变频器输出电流
            "2044707428799489_1", // 清水泵房_六号水泵变频器输出转矩

            "2044707428787201_1", // 清水泵房_六号水泵变频器输出功率
            "2044707428639745_1", // 清水泵房_六号水泵压力
            "2044707428652033_1", // 清水泵房_六号水泵变频器频率
            "2044707427716097_1", // 清水泵房_六号水泵前轴温度
            "2044707427732481_1", // 清水泵房_六号水泵后轴温度
            "2044707427910657_1", //清水泵房_六号水泵后轴低温报警设定值
            "2044707427943425_1", //清水泵房_六号水泵后轴高温报警设定值
            "2044707427828737_1", //清水泵房_六号水泵前轴低温报警设定值
            "2044707427841025_1", //清水泵房_六号水泵前轴高温报警设定值


        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $stateData = [];
        $stateInfoData = [];
        foreach ($baseData as $key => $val) {

            $stateInfoData[$key] = $baseData[$key] == 0 ? "关闭" : "开启";

            if ($val == -9999) {
                $baseData[$key] = '未知';
                $stateData[$key] = 0;
                $stateInfoData[$key] = "未知";

            } else {
                $stateData[$key] = $baseData[$key];
            }

        }

        $info = [
            "main"=>[
                [
                    "label"=>"水仓水位2",
                    "value"=> $baseData['2012605462658049_1'] ?? 0,
                    "unit"=>"m³"
                ],
                [
                    "label"=>"总管压力",
                    "value"=> $baseData['2044707428860929_1'] ?? 0,
                    "unit"=>"Mpa"
                ],
                [
                    "label"=>"流量1",
                    "value"=> $baseData['2044707428887553_1'] ?? 0,
                    "unit"=>"M"
                ],
                [
                    "label"=>"流量2",
                    "value"=> $baseData['2044707428899841_1'] ?? 0,
                    "unit"=>"M"
                ],
                [
                    "label"=>"流量3",
                    "value"=> $baseData['2044707428916225_1'] ?? 0,
                    "unit"=>"M"
                ],
            ],
            "info"=>[
                [
                    "label"=>"1号清水泵",
                    "state"=> $stateData['2044707426964481_2'] ?? "0",
                    "text"=> $stateInfoData['2044707426964481_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"电压",
                                "value"=>($baseData['2044707428183041_1'] ?? 0)." V",
                            ],
                            [
                                "label"=>"电流",
                                "value"=>($baseData['2044707428195329_1'] ?? 0)." A",
                            ],
                            [
                                "label"=>"转矩",
                                "value"=>($baseData['2044707428236289_1'] ?? 0)." N.m",
                            ],
                            [
                                "label"=>"转速",
                                "value"=>($baseData['2044707428207617_1'] ?? 0)." m/min",
                            ],
                            [
                                "label"=>"功率",
                                "value"=>($baseData['2044707428221953_1'] ?? 0)." Kw",
                            ],
                            [
                                "label"=>"泵压",
                                "value"=>$baseData['2044707428135937_1']." Mp",
                            ],
                            [
                                "label"=>"频率",
                                "value"=>$baseData['2044707428158465_1']." Hz",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>$baseData['2044707427800065_1']." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>$baseData['2044707427814401_1']." ℃",
                            ],
                            [
                                "label"=>"前轴低温",
                                "value"=>$baseData['2044707427683329_1']." ℃",
                            ],
                            [
                                "label"=>"前轴高温",
                                "value"=>$baseData['2044707427699713_1']." ℃",
                            ],
                            [
                                "label"=>"后轴低温",
                                "value"=>$baseData['2044707428072449_1']." ℃",
                            ],
                            [
                                "label"=>"后轴高温",
                                "value"=>$baseData['2044707427666945_1']." ℃",
                            ],
                        ]
                    ],
                ],
                [
                    "label"=>"2号清水泵",
                    "state"=> $stateData['2044707426978817_2'] ?? "0",
                    "text"=> $stateInfoData['2044707426978817_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"电压",
                                "value"=>($baseData['2044707428350977_1'] ?? 0)." V",
                            ],
                            [
                                "label"=>"电流",
                                "value"=>($baseData['2044707428365313_1'] ?? 0)." A",
                            ],
                            [
                                "label"=>"转矩",
                                "value"=>($baseData['2044707428406273_1'] ?? 0)." N.m",
                            ],
                            [
                                "label"=>"转速",
                                "value"=>($baseData['2044707428381697_1'] ?? 0)." m/min",
                            ],
                            [
                                "label"=>"功率",
                                "value"=>($baseData['2044707428393985_1'] ?? 0)." Kw",
                            ],
                            [
                                "label"=>"泵压",
                                "value"=>($baseData['2044707428279297_1'] ?? 0)." Mp",
                            ],
                            [
                                "label"=>"频率",
                                "value"=>($baseData['2044707428320257_1'] ?? 0)." Hz",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>($baseData['2044707427773441_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>($baseData['2044707427785729_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"前轴低温",
                                "value"=>($baseData['2044707428045825_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"前轴高温",
                                "value"=>($baseData['2044707428060161_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴低温",
                                "value"=>($baseData['2044707428019201_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=>"后轴高温",
                                "value"=>($baseData['2044707428031489_1'] ?? 0)." ℃",
                            ],
                        ]
                    ],
                ],
                [
                    "title"=>"5号清水泵",
                    "state"=> $stateData['2044707426939905_2'] ?? "0",
                    "text"=> $stateInfoData['2044707426939905_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"电压",
                                "value"=>($baseData['2044707428529153_1'] ?? 0)." V",
                            ],
                            [
                                "label"=>"电流",
                                "value"=>($baseData['2044707428545537_1'] ?? 0)." A",
                            ],
                            [
                                "label"=>"转矩",
                                "value"=>($baseData['2044707428586497_1'] ?? 0)." N.m",
                            ],
                            [
                                "label"=>"转速",
                                "value"=>($baseData['2044707428561921_1'] ?? 0)." m/min",
                            ],
                            [
                                "label"=>"功率",
                                "value"=>($baseData['2044707428572161_1'] ?? 0)." Kw",
                            ],
                            [
                                "label"=>"泵压",
                                "value"=>$baseData['2044707428416513_1']." Mp",
                            ],
                            [
                                "label"=>"频率",
                                "value"=>$baseData['2044707428488193_1']." Hz",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>$baseData['2044707427746817_1']." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>$baseData['2044707427761153_1']." ℃",
                            ],
                            [
                                "label"=>"前轴低温",
                                "value"=>$baseData['2044707427994625_1']." ℃",
                            ],
                            [
                                "label"=>"前轴高温",
                                "value"=>$baseData['2044707428006913_1']." ℃",
                            ],
                            [
                                "label"=>"后轴低温",
                                "value"=>$baseData['2044707427963905_1']." ℃",
                            ],
                            [
                                "label"=>"后轴高温",
                                "value"=>$baseData['2044707427978241_1']." ℃",
                            ],
                        ]
                    ],
                ],
                [
                    "title"=>"6号清水泵",
                    "state"=> $stateData['2044707426954241_2'] ?? "0",
                    "text"=> $stateInfoData['2044707426954241_2'] ?? "未知",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"电压",
                                "value"=>($baseData['2044707428748289_1'] ?? 0)." V",
                            ],
                            [
                                "label"=>"电流",
                                "value"=>($baseData['2044707428760577_1'] ?? 0)." A",
                            ],
                            [
                                "label"=>"转矩",
                                "value"=>($baseData['2044707428799489_1'] ?? 0)." N.m",
                            ],
                            [
                                "label"=>"转速",
                                "value"=>($baseData['2044707428207617_1'] ?? 0)." m/min",
                            ],
                            [
                                "label"=>"功率",
                                "value"=>($baseData['2044707428787201_1'] ?? 0)." Kw",
                            ],
                            [
                                "label"=>"泵压",
                                "value"=>$baseData['2044707428639745_1']." Mp",
                            ],
                            [
                                "label"=>"频率",
                                "value"=>$baseData['2044707428652033_1']." Hz",
                            ],
                            [
                                "label"=>"前轴温度",
                                "value"=>$baseData['2044707427716097_1']." ℃",
                            ],
                            [
                                "label"=>"后轴温度",
                                "value"=>$baseData['2044707427732481_1']." ℃",
                            ],
                            [
                                "label"=>"前轴低温",
                                "value"=>$baseData['2044707427910657_1']." ℃",
                            ],
                            [
                                "label"=>"前轴高温",
                                "value"=>$baseData['2044707427943425_1']." ℃",
                            ],
                            [
                                "label"=>"后轴低温",
                                "value"=>$baseData['2044707427828737_1']." ℃",
                            ],
                            [
                                "label"=>"后轴高温",
                                "value"=>$baseData['2044707427841025_1']." ℃",
                            ],
                        ]
                    ],
                ],
            ]
        ];
        return json_encode($info);
    }
}
