<?php

namespace Modules\OpcData\Http\Controllers\Api\zaoquan;

use App\Http\Controllers\Api\BaseController;
use DateTime;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Modules\OpcData\Services\zaoquan\ZQDcsApiService;

/**
 * 枣泉自动化——东井通风
 */
class ZQDcsWorkFaceController  extends BaseController
{

    private $db_name='etl_zaoquan';

    protected $apiService;
    protected $apiUrl = 'http://7.250.4.3:4300/v1/common/GetPointRealDataByPageV3';

    public function __construct(ZQDcsApiService $apiService)
    {
        parent::__construct();
        $this->apiService = $apiService;
    }

    public function getList(Request $request) {
        $sysCode = isset($request->sys_code) ? $request->sys_code : null;     // 矿分类
        if ($sysCode == null) {
            $msg="参数为空";
            $code=-1;
            return $this->error($code, $msg);
        } else {
            switch ($sysCode) {
                case '220707gzm': // 220707工作面
                    return $this->get220707GzmList();
                case '150202gzm': // 150202工作面
                    return $this->get150202GzmList();
                case 'rhb': // 乳化泵
                    return $this->getRhbList();
                case 'cmj': // 采煤机
                    return $this->getCmjList();
                case 'sj': // 三机
                    return $this->getSjList();
                case 'ky': // 矿压
                    return $this->getKyList();
                case 'znzj':
                    return $this->getExcList();
                default:
                    $msg="未知数据";
                    $code=-2;
                    return $this->error($code, $msg);
            }
        }
    }

    /*
     * 220707工作面
     * */
    public function get220707GzmList() {

        $keys=[
            "2045462760791041_1", "2045462763287553_1", "2045462765548545_1", // 1\2\3号乳化泵运行状态
            "2045462780937217_1", // 增压泵状态
            "2045462760676353_1", "2045462763166721_1", // 1、2清水泵状态
            "2045462760600577_1", "2045462763088897_1", // 1、2号清水泵油温
            "2045462760713217_1","2045462763203585_1","2045462765470721_1", // 1、2、3号乳化泵油温
            "2045462780849153_1", // 乳化泵油温
            "2045462774410241_1", "2045462774860801_1","2045462780767233_1","2045462774537217_1", // 牵引速度、俯仰角、倾角、瓦斯浓度
            "2045462780728321_1","2045462777420801_1","2045462781619201_1", // 破碎机、刮板机运行状态、转载机电流
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $info = [
            "info"=>[
                [
                    "label"=> "设计可采长度",
                    "value"=> "2159M"
                ],
                [
                    "label"=> "开采煤层",
                    "value"=> "7"
                ],
                [
                    "label"=> "面积",
                    "value"=> "450301㎡"
                ],
                [
                    "label"=> "煤层总厚",
                    "value"=> "3.9M"
                ],
                [
                    "label"=> "工作面采高",
                    "value"=> "2.6M"
                ],
                [
                    "label"=> "支架数目",
                    "value"=> "128"
                ],
                [
                    "label"=> "循环刀数",
                    "value"=> "9"
                ],
                [
                    "label"=> "回踩日期",
                    "value"=> "2023.2"
                ]
            ],
            "ruhuabeng"=>[
                [
                    "label"=>"1#液泵",
                    "state"=>($baseData['2045462760791041_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462760791041_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"乳化增压泵",
                    "state"=>($baseData['2045462780937217_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462780937217_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"2#液泵",
                    "state"=>($baseData['2045462763287553_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462763287553_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"1#水泵",
                    "state"=>($baseData['2045462760676353_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462760676353_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"3#液泵",
                    "state"=>($baseData['2045462765548545_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462765548545_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"2#水泵",
                    "state"=>($baseData['2045462763166721_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462763166721_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
            ],
            "caimeiji"=>[
                "state"=>0,
                "data"=>[
                    [
                        "label"=>"牵引速度",
                        "value"=>($baseData['2045462774410241_1'] ?? 0)."m/min",
                    ],
                    [
                        "label"=>"俯仰角",
                        "value"=>($baseData['2045462774860801_1'] ?? 0)."°",
                    ],
                    [
                        "label"=>"瓦斯浓度",
                        "value"=>($baseData['2045462774537217_1'] ?? 0)."%",
                    ],
                    [
                        "label"=>"倾角",
                        "value"=>($baseData['2045462780767233_1'] ?? 0)."°",
                    ],
                ]
            ],
            "sanji"=>[
                [
                    "label"=>"转载机运行状态",
                    "state"=>($baseData['2045462780728321_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462780728321_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"破碎机运行状态",
                    "state"=>($baseData['2045462777420801_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462777420801_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"刮板机运行状态",
                    "state"=>($baseData['2045462781619201_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462781619201_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 150202工作面
     * */
    public function get150202GzmList() {

        $keys=[
            // 1~4号乳化泵运行状态
            "2096055429854209_1",
            "2096055430059009_1",
            "2096055430265857_1",
            "2096055430689793_1",
            "2096055436942337_1", // 破碎机运行状态
            "2096055435967489_1", // 转载机运行状态

            "2096055432721409_1", // 前部运输机机头电机温度
            "2096055431805953_1", // 前部运输机机尾电机温度

            "2096055435078657_1", // 后部运输机机头电机
            "2096055433845761_1", // 后部运输机机尾电机

            "2045462774410241_1", "2045462774860801_1","2045462780767233_1","2045462774537217_1", // 牵引速度、俯仰角、倾角、瓦斯浓度
            "2045462780728321_1","2045462777420801_1","2045462781619201_1", // 破碎机、刮板机运行状态、转载机电流
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $info = [
            "info"=>[
                [
                    "label"=> "设计可采长度",
                    "value"=> "2159M"
                ],
                [
                    "label"=> "开采煤层",
                    "value"=> "7"
                ],
                [
                    "label"=> "面积",
                    "value"=> "450301㎡"
                ],
                [
                    "label"=> "煤层总厚",
                    "value"=> "3.9M"
                ],
                [
                    "label"=> "工作面采高",
                    "value"=> "2.6M"
                ],
                [
                    "label"=> "支架数目",
                    "value"=> "130"
                ],
                [
                    "label"=> "循环刀数",
                    "value"=> "12"
                ],
                [
                    "label"=> "回踩日期",
                    "value"=> "2023.11"
                ]
            ],
            "ruhuabeng"=>[
                [
                    "label"=>"1#乳化泵",
                    "state"=>($baseData['2096055429854209_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2096055429854209_1'] ?? 0) > 0 ? "运行" : "停止",
                ],
                [
                    "label"=>"2#乳化泵",
                    "state"=>($baseData['2096055430059009_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2096055430059009_1'] ?? 0) > 0 ? "运行" : "停止",
                ],
                [
                    "label"=>"3#乳化泵",
                    "state"=>($baseData['2096055430265857_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2096055430265857_1'] ?? 0) > 0 ? "运行" : "停止",
                ],
                [
                    "label"=>"4#乳化泵",
                    "state"=>($baseData['2096055430689793_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2096055430689793_1'] ?? 0) > 0 ? "运行" : "停止",
                ],
            ],
            "caimeiji"=>[
                "state"=>0,
                "data"=>[
                    [
                        "label"=>"前部运输机机头电机",
                        "value"=>($baseData['2096055432721409_1'] ?? 0)."℃",
                    ],
                    [
                        "label"=>"前部运输机机尾电机",
                        "value"=>($baseData['2096055431805953_1'] ?? 0)."℃",
                    ],
                    [
                        "label"=>"前部运输机机头电机",
                        "value"=>($baseData['2096055435078657_1'] ?? 0)."℃",
                    ],
                    [
                        "label"=>"前部运输机机尾电机",
                        "value"=>($baseData['2096055433845761_1'] ?? 0)."℃",
                    ],
                ]
            ],
            "sanji"=>[
                [
                    "label"=>"破碎机运行状态",
                    "state"=>($baseData['2096055436942337_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2096055436942337_1'] ?? 0) > 0 ? "运行" : "停止",
                ],
                [
                    "label"=>"转载机运行状态",
                    "state"=>($baseData['2096055435967489_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2096055435967489_1'] ?? 0) > 0 ? "运行" : "停止",
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 乳化泵
     * */
    public function getRhbList() {

        $keys=[

            "2096055430921217_1", // 泵站_1号喷雾泵水温
            "2096055430968321_1", // 泵站_1号喷雾泵油压
            "2096055429913601_1", // 泵站_1号乳化泵油温
            "2096055429964801_1", // 泵站_1号乳化泵油压
            "2096055429854209_1", // 泵站_1号乳化泵运行状态
            "2096055431156737_1", // 泵站_2号喷雾泵水温
            "2096055431273473_1", // 泵站_2号喷雾泵油压
            "2096055430108161_1", // 泵站_2号乳化泵油温
            "2096055430155265_1", // 泵站_2号乳化泵油压
            "2096055430059009_1", // 泵站_2号乳化泵运行状态
            "2096055431474177_1", // 泵站_3号喷雾泵水温
            "2096055431535617_1", // 泵站_3号喷雾泵油压
            "2096055430351873_1", // 泵站_3号乳化泵油温
            "2096055430446081_1", // 泵站_3号乳化泵油压
            "2096055430265857_1", // 泵站_3号乳化泵运行状态
            "2096055430736897_1", // 泵站_4号乳化泵油温
            "2096055430784001_1", // 泵站_4号乳化泵油压
            "2096055430689793_1", // 泵站_4号乳化泵运行状态

        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "info"=>[
                [
                    "label"=> "1#乳化泵",
                    "state"=> ($baseData['2096055429854209_1'] ?? 0),
                    "text"=>($baseData['2096055429854209_1'] ?? 0) > 0 ? "运行" : "停止",
                    "info"=>[
                        [
                            "label"=>"润滑油温（℃）",
                            "value"=>($baseData['2096055429913601_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2096055430968321_1'] ?? 0),
                        ]
                    ]
                ],
                [
                    "label"=> "2#乳化泵",
                    "state"=> ($baseData['2096055430059009_1'] ?? 0),
                    "text"=>($baseData['2096055430059009_1'] ?? 0) > 0 ? "运行" : "停止",
                    "info"=>[
                        [
                            "label"=>"润滑油温（℃）",
                            "value"=>($baseData['2096055430108161_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2096055430155265_1'] ?? 0),
                        ]
                    ]
                ],
                [
                    "label"=> "3#乳化泵",
                    "state"=> ($baseData['2096055430265857_1'] ?? 0),
                    "text"=>($baseData['2096055430265857_1'] ?? 0) > 0 ? "运行" : "停止",
                    "info"=>[
                        [
                            "label"=>"润滑油温（℃）",
                            "value"=>($baseData['2096055430351873_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2096055430446081_1'] ?? 0),
                        ]
                    ]
                ],
                [
                    "label"=> "4#乳化泵",
                    "state"=> ($baseData['2096055430689793_1'] ?? 0),
                    "text"=>($baseData['2096055430689793_1'] ?? 0) > 0 ? "运行" : "停止",
                    "info"=>[
                        [
                            "label"=>"润滑油温（℃）",
                            "value"=>($baseData['2096055430736897_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2096055430784001_1'] ?? 0),
                        ]
                    ]
                ],
                [
                    "label"=> "1#喷雾泵",
                    "state"=> 1,
                    "text"=>"",
                    "info"=>[
                        [
                            "label"=>"润滑水温（℃）",
                            "value"=>($baseData['2096055430921217_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2096055430968321_1'] ?? 0),
                        ]
                    ]
                ],
                [
                    "label"=> "2#喷雾泵",
                    "state"=> 1,
                    "text"=>"",
                    "info"=>[
                        [
                            "label"=>"润滑水温（℃）",
                            "value"=>($baseData['2096055431156737_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2096055431273473_1'] ?? 0),
                        ]
                    ]
                ],
                [
                    "label"=> "3#喷雾泵",
                    "state"=> 1,
                    "text"=>"",
                    "info"=>[
                        [
                            "label"=>"润滑水温（℃）",
                            "value"=>($baseData['2096055431474177_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2096055431535617_1'] ?? 0),
                        ]
                    ]
                ],
            ],
            "chartData_1"=>[
                "categories"=>[
                    "00:00", "00:00","00:00","00:00","00:00","00:00",
                ],
                "series"=>[
                    [
                        "name"=>"位置",
                        "data"=>[0, 0, 0, 0, 0, 0]
                    ]
                ]
            ]
        ];

        return json_encode($info);
    }

    /*
     * 采煤机
     * */
    public function getCmjList() {

        $keys=[

            // 1~4号乳化泵运行状态
            "2096055429854209_1",
            "2096055430059009_1",
            "2096055430265857_1",
            "2096055430689793_1",
            "2096055436942337_1", // 破碎机运行状态
            "2096055435967489_1", // 转载机运行状态

            "2097614315774977_1", // 150202工作面
            "2054247007056897_1", // 150202工作面回风巷670米
            "2008885025967105_1", // 五分区150202辅助运输巷100米
            "2014189073822721_1", // 五分区150202机巷650米
            "2054247007235073_1", // 五分区150202切眼100#架
            "2096397705581569_1", // 150202辅助巷800米
            "2008885030214657_1", // 五分区150202回风巷100米
            "2008885030710273_1", // 五分区150202机巷100米
            "2014188820456449_1", // 五分区150202机巷1120米
            "2014183004019713_1", // 五分区150202机巷580米

            "2096055432721409_1", // 前部运输机机头电机温度
            "2096055431805953_1", // 前部运输机机尾电机温度

            "2096055435078657_1", // 后部运输机机头电机
            "2096055433845761_1", // 后部运输机机尾电机

        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        // 获取历史数据

        // 设置时区为东八区，即 UTC+8
        date_default_timezone_set('Asia/Shanghai');

        // 获取当前时间
        $endTime = new DateTime('now');
        // 获取当前时间向前推1小时的时间
        $startTime = clone $endTime; // 复制当前时间的实例
        $startTime->modify('-3 hour'); // 向前推1小时

        // 输出昨天和今天的日期时间
        $starttime = $startTime->format('Y-m-d\TH:i:sP');
        $endtime = $endTime->format('Y-m-d\TH:i:sP');

        // 输出昨天和今天的日期时间
        $starttime = $startTime->format('Y-m-d\TH:i:sP');
        $endtime = $endTime->format('Y-m-d\TH:i:sP');

//        $url = "http://7.250.4.3:4200/Tripartite/getRealData";
        $pointIds = [
            "2096055420285953_1"
        ];

        // 获取点位数据
        $hisData = $this->apiService->postDcsHisData($pointIds, $starttime, $endtime);
        $hisDataPoint = $hisData[0]['PointDatas'];
        $hisTime = array_column($hisDataPoint, 'T');
        $hisVal = array_column($hisDataPoint, 'V');

        // 使用 DateTime 类格式化日期
        $hisTime = array_map(function($date) {
            $dateTime = new DateTime($date);
            return $dateTime->format('H:i');
        }, $hisTime);

        $info = [
            "info"=>[
                [
                    "label"=>"1#乳化泵",
                    "state"=>($baseData['2096055429854209_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2096055429854209_1'] ?? 0) > 0 ? "运行" : "停止",
                ],
                [
                    "label"=>"2#乳化泵",
                    "state"=>($baseData['2096055430059009_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2096055430059009_1'] ?? 0) > 0 ? "运行" : "停止",
                ],
                [
                    "label"=>"3#乳化泵",
                    "state"=>($baseData['2096055430265857_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2096055430265857_1'] ?? 0) > 0 ? "运行" : "停止",
                ],
                [
                    "label"=>"4#乳化泵",
                    "state"=>($baseData['2096055430689793_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2096055430689793_1'] ?? 0) > 0 ? "运行" : "停止",
                ],
            ],
            "table_data"=>[
                [
                    "title"=>"采煤机基础信息",
                    "thread"=>["参数名称", "数值"],
                    "tbody"=>[
                        [
                            "label"=> "机身高度",
                            "value"=> "1321mm"
                        ],
                        [
                            "label"=> "总装机功率",
                            "value"=> "1660kw"
                        ],
                        [
                            "label"=> "滚筒转速",
                            "value"=> "36.2r/min"
                        ],
                        [
                            "label"=> "摇臂长度",
                            "value"=> "32656mm"
                        ],
                        [
                            "label"=> "采高范围",
                            "value"=> "1.9~3.7m"
                        ],
                    ]
                ],
                [
                    "title"=>"采煤机基础信息",
                    "thread"=>["参数名称", "数值"],
                    "tbody"=>[
                        [
                            "label"=> "机身高度",
                            "value"=> "1321mm"
                        ],
                        [
                            "label"=> "总装机功率",
                            "value"=> "1660kw"
                        ],
                        [
                            "label"=> "滚筒转速",
                            "value"=> "36.2r/min"
                        ],
                        [
                            "label"=> "摇臂长度",
                            "value"=> "32656mm"
                        ],
                        [
                            "label"=> "采高范围",
                            "value"=> "1.9~3.7m"
                        ],
                    ]
                ],
                [
                    "title"=>"工作面人员环境信息",
                    "thread"=>["参数名称", "数值"],
                    "tbody"=>[
                        [
                            "label"=>"150202工作面",
                            "value"=>($baseData['2097614315774977_1'] ?? 0),
                        ],
                        [
                            "label"=>"150202回风巷100m",
                            "value"=>($baseData['2008885030214657_1'] ?? 0),
                        ],
                        [
                            "label"=>"150202机巷100m",
                            "value"=>($baseData['2008885030710273_1'] ?? 0),
                        ],
                        [
                            "label"=>"150202机巷580m",
                            "value"=>($baseData['2014183004019713_1'] ?? 0),
                        ],
                        [
                            "label"=>"150202机巷1120m",
                            "value"=>($baseData['2014188820456449_1'] ?? 0),
                        ],
                    ]
                ],
                [
                    "title"=>"采煤机信息",
                    "thread"=>["参数名称", "数值"],
                    "tbody"=>[
                        [
                            "label"=>"前部运输机机头电机",
                            "value"=>($baseData['2096055432721409_1'] ?? 0)."℃",
                        ],
                        [
                            "label"=>"前部运输机机尾电机",
                            "value"=>($baseData['2096055431805953_1'] ?? 0)."℃",
                        ],
                        [
                            "label"=>"前部运输机机头电机",
                            "value"=>($baseData['2096055435078657_1'] ?? 0)."℃",
                        ],
                        [
                            "label"=>"前部运输机机尾电机",
                            "value"=>($baseData['2096055433845761_1'] ?? 0)."℃",
                        ],
                    ]
                ],
            ],
            "chartData_1"=>[
                "categories"=>[
                    "09/08", "09/09","09/10","09/11","09/12","09/13",
                ],
                "series"=>[
                    [
                        "name"=>"日产量",
                        "data"=>[1.3, 1.1, 1.2, 1.4, 1.5, 1.2]
                    ]
                ]
            ],
            "chartData_2"=>[
                "categories"=>$hisTime,
//                ["00:00", "00:00","00:00","00:00","00:00","00:00",],
                "series"=>[
                    [
                        "name"=>"位置",
                        "data"=>$hisVal
//                        [0, 0, 0, 0, 0, 0]
                    ]
                ]
            ]
        ];

        return json_encode($info);
    }

    /*
     * 三机
     * */
    public function getSjList() {

        $keys=[
            "2045462777420801_1",	//"枣泉煤矿220707工作面_刮板机运行状态"

            "2045462776265729_1",	//"枣泉煤矿220707工作面_刮板机头给定速度"
            "2045462776667137_1",	//"枣泉煤矿220707工作面_刮板机头直流母线电压"
            "2045462776486913_1",	//"枣泉煤矿220707工作面_刮板机头内腔湿度"
            "2045462776185857_1",	//"枣泉煤矿220707工作面_刮板机头电阻温度"
            "2045462776531969_1",	//"枣泉煤矿220707工作面_刮板机头逆变水冷板温度"
            "2045462776570881_1",	//"枣泉煤矿220707工作面_刮板机头腔体温度"
            "2045462776624129_1",	//"枣泉煤矿220707工作面_刮板机头整流侧水冷板温度"
            "2045462776224769_1",	//"枣泉煤矿220707工作面_刮板机头对地绝缘"
            "2045462776097793_1",	//"枣泉煤矿220707工作面_刮板机头电机转矩"
            "2045462776017921_1",	//"枣泉煤矿220707工作面_刮板机头电机电流"
            "2045462776142849_1",	//"枣泉煤矿220707工作面_刮板机头电机转速"
            "2045462776450049_1",	//"枣泉煤矿220707工作面_刮板机头减速器输入轴温度"
            "2045462776304641_1",	//"枣泉煤矿220707工作面_刮板机头减速器冷却水温度"
            "2045462776378369_1",	//"枣泉煤矿220707工作面_刮板机头减速器润滑油温度"
            "2045462776343553_1",	//"枣泉煤矿220707工作面_刮板机头减速器冷却水压力"
            "2045462775979009_1",	//"枣泉煤矿220707工作面_刮板机头电动机轴承温度"
            "2045462776056833_1",	//"枣泉煤矿220707工作面_刮板机头电机定子绕组温度"
            "2045462776413185_1",	//"枣泉煤矿220707工作面_刮板机头减速器润滑油油位"

            "2045462776986625_1",	//"枣泉煤矿220707工作面_刮板机尾给定速度"
            "2045462777377793_1",	//"枣泉煤矿220707工作面_刮板机尾直流母线电压"
            "2045462777218049_1",	//"枣泉煤矿220707工作面_刮板机尾内腔湿度"
            "2045462776914945_1",	//"枣泉煤矿220707工作面_刮板机尾电阻温度"
            "2045462777256961_1",	//"枣泉煤矿220707工作面_刮板机尾逆变水冷板温度"
            "2045462777297921_1",	//"枣泉煤矿220707工作面_刮板机尾腔体温度"
            "2045462777338881_1",	//"枣泉煤矿220707工作面_刮板机尾整流侧水冷板温度"
            "2045462776951809_1",	//"枣泉煤矿220707工作面_刮板机尾对地绝缘"
            "2045462776843265_1",	//"枣泉煤矿220707工作面_刮板机尾电机转矩"
            "2045462776767489_1",	//"枣泉煤矿220707工作面_刮板机尾电机电流"
            "2045462776880129_1",	//"枣泉煤矿220707工作面_刮板机尾电机转速"
            "2045462777177089_1",	//"枣泉煤矿220707工作面_刮板机尾减速器输入轴温度"
            "2045462777023489_1",	//"枣泉煤矿220707工作面_刮板机尾减速器冷却水温度"
            "2045462777103361_1",	//"枣泉煤矿220707工作面_刮板机尾减速器润滑油温度"
            "2045462777066497_1",	//"枣泉煤矿220707工作面_刮板机尾减速器冷却水压力"
            "2045462776724481_1",	//"枣泉煤矿220707工作面_刮板机尾电动机轴承温度"
            "2045462776804353_1",	//"枣泉煤矿220707工作面_刮板机尾电机定子绕组温度"
            "2045462777140225_1",	//"枣泉煤矿220707工作面_刮板机尾减速器润滑油油位"

            "2045462780288001_1",	//"枣泉煤矿220707工作面_破碎机隔离开关合闸状态"
            "2045462780249089_1",	//"枣泉煤矿220707工作面_破碎机隔离开关电压"
            "2045462780371969_1",	//"枣泉煤矿220707工作面_破碎机回路启停状态"
            "2045462780331009_1",	//"枣泉煤矿220707工作面_破碎机回路电流"

            "2045462774193153_1",	//"枣泉煤矿220707工作面_采煤机隔离开关合闸状态"
            "2045462774154241_1",	//"枣泉煤矿220707工作面_采煤机隔离开关电压"
            "2045462774273025_1",	//"枣泉煤矿220707工作面_采煤机回路启停状态"
            "2045462774230017_1",	//"枣泉煤矿220707工作面_采煤机回路电流"

            "2045462780623873_1",	//"枣泉煤矿220707工作面_破碎机减速器输入轴温度"
            "2045462780410881_1",	//"枣泉煤矿220707工作面_破碎机减速器冷却水温度"
            "2045462780523521_1",	//"枣泉煤矿220707工作面_破碎机减速器润滑油温度"
            "2045462780474369_1",	//"枣泉煤矿220707工作面_破碎机减速器冷却水压力"
            "2045462780163073_1",	//"枣泉煤矿220707工作面_破碎机电动机轴承温度"
            "2045462780199937_1",	//"枣泉煤矿220707工作面_破碎机电机定子绕组温度"
            "2045462780566529_1",	//"枣泉煤矿220707工作面_破碎机减速器润滑油油位"

            "2045462780728321_1",	//"枣泉煤矿220707工作面_破碎机运行状态"

            "2045462782241793_1",	//"枣泉煤矿220707工作面_转载机运行状态"
            "2045462781852673_1",	//"枣泉煤矿220707工作面_转载机给定速度"
            "2045462782321665_1",	//"枣泉煤矿220707工作面_转载机直流母线电压"
            "2045462782088193_1",	//"枣泉煤矿220707工作面_转载机内腔湿度"
            "2045462781772801_1",	//"枣泉煤矿220707工作面_转载机电阻温度"
            "2045462782127105_1",	//"枣泉煤矿220707工作面_转载机逆变水冷板温度"
            "2045462782163969_1",	//"枣泉煤矿220707工作面_转载机腔体温度"
            "2045462782282753_1",	//"枣泉煤矿220707工作面_转载机整流侧水冷板温度"
            "2045462781811713_1",	//"枣泉煤矿220707工作面_转载机对地绝缘"
            "2045462781694977_1",	//"枣泉煤矿220707工作面_转载机电机转矩"
            "2045462781619201_1",	//"枣泉煤矿220707工作面_转载机电机电流"
            "2045462781733889_1",	//"枣泉煤矿220707工作面_转载机电机转速"
            "2045462782049281_1",	//"枣泉煤矿220707工作面_转载机减速器输入轴温度"
            "2045462781893633_1",	//"枣泉煤矿220707工作面_转载机减速器冷却水温度"
            "2045462781969409_1",	//"枣泉煤矿220707工作面_转载机减速器润滑油温度"
            "2045462781932545_1",	//"枣泉煤矿220707工作面_转载机减速器冷却水压力"
            "2045462781582337_1",	//"枣泉煤矿220707工作面_转载机电动机轴承温度"
            "2045462781658113_1",	//"枣泉煤矿220707工作面_转载机电机定子绕组温度"
            "2045462782010369_1",	//"枣泉煤矿220707工作面_转载机减速器润滑油油位"

        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            [
                "label"=>"转载机设备信息",
                "state"=> ($baseData['2045462782241793_1'] ?? 0) > 0 ? 1 : 0,
                "text"=>($baseData['2045462782241793_1'] ?? 0) > 0 ? "启动" : "停止",
                "table"=>[
                    [
                        "title"=>"转载机设备信息",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "给定速度",
                                "value"=> ($baseData['2045462781852673_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "直流母线电压",
                                "value"=> ($baseData['2045462782321665_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "内腔湿度",
                                "value"=> ($baseData['2045462782088193_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电阻温度",
                                "value"=> ($baseData['2045462781772801_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "逆变水冷板温度",
                                "value"=> ($baseData['2045462782127105_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "腔体温度",
                                "value"=> ($baseData['2045462782163969_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "整流侧水冷板温度",
                                "value"=> ($baseData['2045462782282753_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "对地绝缘",
                                "value"=> ($baseData['2045462781811713_1'] ?? 0)." MΩ",
                            ],
                            [
                                "label"=> "电机转柜",
                                "value"=> ($baseData['2045462781694977_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电机电流",
                                "value"=> ($baseData['2045462781619201_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "电机转速",
                                "value"=> ($baseData['2045462781733889_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462782049281_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462781893633_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462781969409_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462781932545_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462781582337_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462781658113_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462782010369_1'] ?? 0)." m",
                            ],
                        ]
                    ]
                ]
            ],
            [
                "label"=>"采煤机破碎机设备信息",
                "state"=> ($baseData['2045462780728321_1'] ?? 0) > 0 ? 1 : 0,
                "text"=>($baseData['2045462780728321_1'] ?? 0) > 0 ? "启动" : "停止",
                "table"=>[
                    [
                        "title"=>"采煤机破碎机设备信息",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "破碎机隔离开关状态",
                                "value"=> ($baseData['2045462780288001_1'] ?? 0) > 0 ? "合闸" : "分闸",
                            ],
                            [
                                "label"=> "破碎机隔离开关电压",
                                "value"=> ($baseData['2045462780249089_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "破碎机回路启停状态",
                                "value"=> ($baseData['2045462780371969_1'] ?? 0) > 0 ? "启动" : "停止",
                            ],
                            [
                                "label"=> "破碎机回路电流",
                                "value"=> ($baseData['2045462780331009_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "采煤机隔离开关合闸状态",
                                "value"=> ($baseData['2045462774193153_1'] ?? 0) > 0 ? "合闸" : "分闸",
                            ],
                            [
                                "label"=> "采煤机隔离开关电压",
                                "value"=> ($baseData['2045462774154241_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "采煤机回路启停状态",
                                "value"=> ($baseData['2045462774273025_1'] ?? 0) > 0 ? "启动" : "停止",
                            ],
                            [
                                "label"=> "采煤机回路电流",
                                "value"=> ($baseData['2045462774230017_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462780623873_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462780410881_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462780523521_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462780474369_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462780163073_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462780199937_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462780566529_1'] ?? 0)." m",
                            ],
                        ]
                    ]
                ]
            ],
            [
                "label"=>"刮板机设备信息",
                "state"=> ($baseData['2045462777420801_1'] ?? 0) > 0 ? 1 : 0,
                "text"=>($baseData['2045462777420801_1'] ?? 0) > 0 ? "启动" : "停止",
                "table"=>[
                    [
                        "title"=>"刮板机设备信息-机头",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "给定速度",
                                "value"=> ($baseData['2045462776265729_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "直流母线电压",
                                "value"=> ($baseData['2045462776667137_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "内腔湿度",
                                "value"=> ($baseData['2045462776486913_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电阻温度",
                                "value"=> ($baseData['2045462776185857_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "逆变水冷板温度",
                                "value"=> ($baseData['2045462776531969_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "腔体温度",
                                "value"=> ($baseData['2045462776570881_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "整流侧水冷板温度",
                                "value"=> ($baseData['2045462776624129_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "对地绝缘",
                                "value"=> ($baseData['2045462776224769_1'] ?? 0)." MΩ",
                            ],
                            [
                                "label"=> "电机转柜",
                                "value"=> ($baseData['2045462776097793_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电机电流",
                                "value"=> ($baseData['2045462776017921_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "电机转速",
                                "value"=> ($baseData['2045462776142849_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462776450049_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462776304641_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462776378369_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462776343553_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462775979009_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462776056833_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462776413185_1'] ?? 0)." m",
                            ],
                        ]
                    ],
                    [
                        "title"=>"刮板机设备信息-机尾",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "给定速度",
                                "value"=> ($baseData['2045462776986625_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "直流母线电压",
                                "value"=> ($baseData['2045462777377793_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "内腔湿度",
                                "value"=> ($baseData['2045462777218049_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电阻温度",
                                "value"=> ($baseData['2045462776914945_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "逆变水冷板温度",
                                "value"=> ($baseData['2045462777256961_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "腔体温度",
                                "value"=> ($baseData['2045462777297921_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "整流侧水冷板温度",
                                "value"=> ($baseData['2045462777338881_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "对地绝缘",
                                "value"=> ($baseData['2045462776951809_1'] ?? 0)." MΩ",
                            ],
                            [
                                "label"=> "电机转柜",
                                "value"=> ($baseData['2045462776843265_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电机电流",
                                "value"=> ($baseData['2045462776767489_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "电机转速",
                                "value"=> ($baseData['2045462776880129_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462777177089_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462777023489_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462777103361_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462777066497_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462776724481_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462776804353_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462777140225_1'] ?? 0)." m",
                            ],
                        ]
                    ],
                ]
            ],
        ];

        return json_encode($info);
    }

    /**
     * 智能综掘
     */
    public function getExcList() {

        $keys=[
            "2104319665503233_1", // 机身俯仰角度
            "2104319665583105_1", // 机身水平角度
            "2104319665402881_1", // 机身翻滚角度
            "2104319665830913_1", // 掘进机行走速度
            "2104319665880065_1", // 母线电压
            "2104319665236993_1", // 回转角度
            "2104319666027521_1" // 升降角度
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $info = [
            "info"=>[
                [
                    "label"=>"工作面名称",
                    "value"=>"150201工作面胶带巷"
                ],
                [
                    "label"=>"施工单位",
                    "value"=>"综掘二队"
                ],
                [
                    "label"=>"生产组织模式",
                    "value"=>"两掘一修"
                ],
                [
                    "label"=>"综掘机型号",
                    "value"=>"EBZ200M-2A"
                ],
                [
                    "label"=>"载割功率",
                    "value"=>"200KW"
                ],
                [
                    "label"=>"巷道长度",
                    "value"=>"2667"
                ],
                [
                    "label"=>"掘进断面",
                    "value"=>"23.31㎡"
                ],
                [
                    "label"=>"永久支护工艺",
                    "value"=>"锚、网、索、W钢桁联合支护"
                ],
                [
                    "label"=>"胶带机型号",
                    "value"=>"DSJ100/40/160胶带输送机"
                ],
                [
                    "label"=>"胶带机控制方式",
                    "value"=>"集控"
                ],
            ],
            "juejinji"=>[
                "data"=>[
                    [
                        "label"=>"未掘进距离",
                        "value"=>"324.8m"
                    ],
                    [
                        "label"=>"已掘进距离",
                        "value"=>"2344.2m"
                    ],
                ]
            ],
            "tab_info"=>[
                [
                    "title"=>"机身姿态",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"倾仰角度(°)",
                                "value"=>$baseData['2104319665503233_1'] ?? 0
                            ],
                            [
                                "label"=>"水平角度(°)",
                                "value"=>$baseData['2104319665583105_1'] ?? 0
                            ],
                            [
                                "label"=>"翻滚角度(°)",
                                "value"=>$baseData['2104319665402881_1'] ?? 0
                            ],
                        ]
                    ]
                ],
                [
                    "title"=>"旋臂姿态",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"回旋角度(°)",
                                "value"=>$baseData['2104319665236993_1'] ?? 0
                            ],
                            [
                                "label"=>"升降角度(°)",
                                "value"=>$baseData['2104319666027521_1'] ?? 0
                            ],
                        ]
                    ]
                ],
                [
                    "title"=>"输入电压",
                    "table"=>[
                        "thead"=>["参数名称", "值"],
                        "tbody"=>[
                            [
                                "label"=>"母线电压(V)",
                                "value"=>$baseData['2104319665880065_1'] ?? 0
                            ],
                        ]
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }

    public function getKyList() {

        $keys=[
            "2045462777420801_1",	//"枣泉煤矿220707工作面_刮板机运行状态"

            "2045462776265729_1",	//"枣泉煤矿220707工作面_刮板机头给定速度"
            "2045462776667137_1",	//"枣泉煤矿220707工作面_刮板机头直流母线电压"
            "2045462776486913_1",	//"枣泉煤矿220707工作面_刮板机头内腔湿度"
            "2045462776185857_1",	//"枣泉煤矿220707工作面_刮板机头电阻温度"
            "2045462776531969_1",	//"枣泉煤矿220707工作面_刮板机头逆变水冷板温度"
            "2045462776570881_1",	//"枣泉煤矿220707工作面_刮板机头腔体温度"
            "2045462776624129_1",	//"枣泉煤矿220707工作面_刮板机头整流侧水冷板温度"
            "2045462776224769_1",	//"枣泉煤矿220707工作面_刮板机头对地绝缘"
            "2045462776097793_1",	//"枣泉煤矿220707工作面_刮板机头电机转矩"
            "2045462776017921_1",	//"枣泉煤矿220707工作面_刮板机头电机电流"
            "2045462776142849_1",	//"枣泉煤矿220707工作面_刮板机头电机转速"
            "2045462776450049_1",	//"枣泉煤矿220707工作面_刮板机头减速器输入轴温度"
            "2045462776304641_1",	//"枣泉煤矿220707工作面_刮板机头减速器冷却水温度"
            "2045462776378369_1",	//"枣泉煤矿220707工作面_刮板机头减速器润滑油温度"
            "2045462776343553_1",	//"枣泉煤矿220707工作面_刮板机头减速器冷却水压力"
            "2045462775979009_1",	//"枣泉煤矿220707工作面_刮板机头电动机轴承温度"
            "2045462776056833_1",	//"枣泉煤矿220707工作面_刮板机头电机定子绕组温度"
            "2045462776413185_1",	//"枣泉煤矿220707工作面_刮板机头减速器润滑油油位"

            "2045462776986625_1",	//"枣泉煤矿220707工作面_刮板机尾给定速度"
            "2045462777377793_1",	//"枣泉煤矿220707工作面_刮板机尾直流母线电压"
            "2045462777218049_1",	//"枣泉煤矿220707工作面_刮板机尾内腔湿度"
            "2045462776914945_1",	//"枣泉煤矿220707工作面_刮板机尾电阻温度"
            "2045462777256961_1",	//"枣泉煤矿220707工作面_刮板机尾逆变水冷板温度"
            "2045462777297921_1",	//"枣泉煤矿220707工作面_刮板机尾腔体温度"
            "2045462777338881_1",	//"枣泉煤矿220707工作面_刮板机尾整流侧水冷板温度"
            "2045462776951809_1",	//"枣泉煤矿220707工作面_刮板机尾对地绝缘"
            "2045462776843265_1",	//"枣泉煤矿220707工作面_刮板机尾电机转矩"
            "2045462776767489_1",	//"枣泉煤矿220707工作面_刮板机尾电机电流"
            "2045462776880129_1",	//"枣泉煤矿220707工作面_刮板机尾电机转速"
            "2045462777177089_1",	//"枣泉煤矿220707工作面_刮板机尾减速器输入轴温度"
            "2045462777023489_1",	//"枣泉煤矿220707工作面_刮板机尾减速器冷却水温度"
            "2045462777103361_1",	//"枣泉煤矿220707工作面_刮板机尾减速器润滑油温度"
            "2045462777066497_1",	//"枣泉煤矿220707工作面_刮板机尾减速器冷却水压力"
            "2045462776724481_1",	//"枣泉煤矿220707工作面_刮板机尾电动机轴承温度"
            "2045462776804353_1",	//"枣泉煤矿220707工作面_刮板机尾电机定子绕组温度"
            "2045462777140225_1",	//"枣泉煤矿220707工作面_刮板机尾减速器润滑油油位"

            "2045462780288001_1",	//"枣泉煤矿220707工作面_破碎机隔离开关合闸状态"
            "2045462780249089_1",	//"枣泉煤矿220707工作面_破碎机隔离开关电压"
            "2045462780371969_1",	//"枣泉煤矿220707工作面_破碎机回路启停状态"
            "2045462780331009_1",	//"枣泉煤矿220707工作面_破碎机回路电流"

            "2045462774193153_1",	//"枣泉煤矿220707工作面_采煤机隔离开关合闸状态"
            "2045462774154241_1",	//"枣泉煤矿220707工作面_采煤机隔离开关电压"
            "2045462774273025_1",	//"枣泉煤矿220707工作面_采煤机回路启停状态"
            "2045462774230017_1",	//"枣泉煤矿220707工作面_采煤机回路电流"

            "2045462780623873_1",	//"枣泉煤矿220707工作面_破碎机减速器输入轴温度"
            "2045462780410881_1",	//"枣泉煤矿220707工作面_破碎机减速器冷却水温度"
            "2045462780523521_1",	//"枣泉煤矿220707工作面_破碎机减速器润滑油温度"
            "2045462780474369_1",	//"枣泉煤矿220707工作面_破碎机减速器冷却水压力"
            "2045462780163073_1",	//"枣泉煤矿220707工作面_破碎机电动机轴承温度"
            "2045462780199937_1",	//"枣泉煤矿220707工作面_破碎机电机定子绕组温度"
            "2045462780566529_1",	//"枣泉煤矿220707工作面_破碎机减速器润滑油油位"

            "2045462780728321_1",	//"枣泉煤矿220707工作面_破碎机运行状态"

            "2045462782241793_1",	//"枣泉煤矿220707工作面_转载机运行状态"
            "2045462781852673_1",	//"枣泉煤矿220707工作面_转载机给定速度"
            "2045462782321665_1",	//"枣泉煤矿220707工作面_转载机直流母线电压"
            "2045462782088193_1",	//"枣泉煤矿220707工作面_转载机内腔湿度"
            "2045462781772801_1",	//"枣泉煤矿220707工作面_转载机电阻温度"
            "2045462782127105_1",	//"枣泉煤矿220707工作面_转载机逆变水冷板温度"
            "2045462782163969_1",	//"枣泉煤矿220707工作面_转载机腔体温度"
            "2045462782282753_1",	//"枣泉煤矿220707工作面_转载机整流侧水冷板温度"
            "2045462781811713_1",	//"枣泉煤矿220707工作面_转载机对地绝缘"
            "2045462781694977_1",	//"枣泉煤矿220707工作面_转载机电机转矩"
            "2045462781619201_1",	//"枣泉煤矿220707工作面_转载机电机电流"
            "2045462781733889_1",	//"枣泉煤矿220707工作面_转载机电机转速"
            "2045462782049281_1",	//"枣泉煤矿220707工作面_转载机减速器输入轴温度"
            "2045462781893633_1",	//"枣泉煤矿220707工作面_转载机减速器冷却水温度"
            "2045462781969409_1",	//"枣泉煤矿220707工作面_转载机减速器润滑油温度"
            "2045462781932545_1",	//"枣泉煤矿220707工作面_转载机减速器冷却水压力"
            "2045462781582337_1",	//"枣泉煤矿220707工作面_转载机电动机轴承温度"
            "2045462781658113_1",	//"枣泉煤矿220707工作面_转载机电机定子绕组温度"
            "2045462782010369_1",	//"枣泉煤矿220707工作面_转载机减速器润滑油油位"

        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            [
                "label"=>"转载机设备信息",
                "state"=> ($baseData['2045462782241793_1'] ?? 0) > 0 ? 1 : 0,
                "text"=>($baseData['2045462782241793_1'] ?? 0) > 0 ? "启动" : "停止",
                "table"=>[
                    [
                        "title"=>"转载机设备信息",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "给定速度",
                                "value"=> ($baseData['2045462781852673_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "直流母线电压",
                                "value"=> ($baseData['2045462782321665_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "内腔湿度",
                                "value"=> ($baseData['2045462782088193_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电阻温度",
                                "value"=> ($baseData['2045462781772801_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "逆变水冷板温度",
                                "value"=> ($baseData['2045462782127105_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "腔体温度",
                                "value"=> ($baseData['2045462782163969_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "整流侧水冷板温度",
                                "value"=> ($baseData['2045462782282753_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "对地绝缘",
                                "value"=> ($baseData['2045462781811713_1'] ?? 0)." MΩ",
                            ],
                            [
                                "label"=> "电机转柜",
                                "value"=> ($baseData['2045462781694977_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电机电流",
                                "value"=> ($baseData['2045462781619201_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "电机转速",
                                "value"=> ($baseData['2045462781733889_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462782049281_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462781893633_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462781969409_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462781932545_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462781582337_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462781658113_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462782010369_1'] ?? 0)." m",
                            ],
                        ]
                    ]
                ]
            ],
            [
                "label"=>"采煤机破碎机设备信息",
                "state"=> ($baseData['2045462780728321_1'] ?? 0) > 0 ? 1 : 0,
                "text"=>($baseData['2045462780728321_1'] ?? 0) > 0 ? "启动" : "停止",
                "table"=>[
                    [
                        "title"=>"采煤机破碎机设备信息",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "破碎机隔离开关状态",
                                "value"=> ($baseData['2045462780288001_1'] ?? 0) > 0 ? "合闸" : "分闸",
                            ],
                            [
                                "label"=> "破碎机隔离开关电压",
                                "value"=> ($baseData['2045462780249089_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "破碎机回路启停状态",
                                "value"=> ($baseData['2045462780371969_1'] ?? 0) > 0 ? "启动" : "停止",
                            ],
                            [
                                "label"=> "破碎机回路电流",
                                "value"=> ($baseData['2045462780331009_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "采煤机隔离开关合闸状态",
                                "value"=> ($baseData['2045462774193153_1'] ?? 0) > 0 ? "合闸" : "分闸",
                            ],
                            [
                                "label"=> "采煤机隔离开关电压",
                                "value"=> ($baseData['2045462774154241_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "采煤机回路启停状态",
                                "value"=> ($baseData['2045462774273025_1'] ?? 0) > 0 ? "启动" : "停止",
                            ],
                            [
                                "label"=> "采煤机回路电流",
                                "value"=> ($baseData['2045462774230017_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462780623873_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462780410881_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462780523521_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462780474369_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462780163073_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462780199937_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462780566529_1'] ?? 0)." m",
                            ],
                        ]
                    ]
                ]
            ],
            [
                "label"=>"刮板机设备信息",
                "state"=> ($baseData['2045462777420801_1'] ?? 0) > 0 ? 1 : 0,
                "text"=>($baseData['2045462777420801_1'] ?? 0) > 0 ? "启动" : "停止",
                "table"=>[
                    [
                        "title"=>"刮板机设备信息-机头",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "给定速度",
                                "value"=> ($baseData['2045462776265729_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "直流母线电压",
                                "value"=> ($baseData['2045462776667137_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "内腔湿度",
                                "value"=> ($baseData['2045462776486913_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电阻温度",
                                "value"=> ($baseData['2045462776185857_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "逆变水冷板温度",
                                "value"=> ($baseData['2045462776531969_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "腔体温度",
                                "value"=> ($baseData['2045462776570881_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "整流侧水冷板温度",
                                "value"=> ($baseData['2045462776624129_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "对地绝缘",
                                "value"=> ($baseData['2045462776224769_1'] ?? 0)." MΩ",
                            ],
                            [
                                "label"=> "电机转柜",
                                "value"=> ($baseData['2045462776097793_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电机电流",
                                "value"=> ($baseData['2045462776017921_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "电机转速",
                                "value"=> ($baseData['2045462776142849_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462776450049_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462776304641_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462776378369_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462776343553_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462775979009_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462776056833_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462776413185_1'] ?? 0)." m",
                            ],
                        ]
                    ],
                    [
                        "title"=>"刮板机设备信息-机尾",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "给定速度",
                                "value"=> ($baseData['2045462776986625_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "直流母线电压",
                                "value"=> ($baseData['2045462777377793_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "内腔湿度",
                                "value"=> ($baseData['2045462777218049_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电阻温度",
                                "value"=> ($baseData['2045462776914945_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "逆变水冷板温度",
                                "value"=> ($baseData['2045462777256961_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "腔体温度",
                                "value"=> ($baseData['2045462777297921_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "整流侧水冷板温度",
                                "value"=> ($baseData['2045462777338881_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "对地绝缘",
                                "value"=> ($baseData['2045462776951809_1'] ?? 0)." MΩ",
                            ],
                            [
                                "label"=> "电机转柜",
                                "value"=> ($baseData['2045462776843265_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电机电流",
                                "value"=> ($baseData['2045462776767489_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "电机转速",
                                "value"=> ($baseData['2045462776880129_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462777177089_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462777023489_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462777103361_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462777066497_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462776724481_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462776804353_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462777140225_1'] ?? 0)." m",
                            ],
                        ]
                    ],
                ]
            ],
        ];

        return json_encode($info);
    }
}
