<?php

namespace Modules\OpcData\Http\Controllers\Api\zaoquan;

use App\Http\Controllers\Api\BaseController;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Modules\OpcData\Services\zaoquan\ZQDcsApiService;
use Modules\OpcData\Services\zaoquan\ZQDcsOpcService;

/**
 * 枣泉自动化——电力
 */
class ZQDcsPowerController  extends BaseController
{

    private $db_name='etl_zaoquan';

    protected $apiService;
    protected $apiUrl = 'http://7.250.4.3:4300/v1/common/GetPointRealDataByPageV3';

    public function __construct(ZQDcsApiService $apiService)
    {
        parent::__construct();
        $this->apiService = $apiService;
    }

    public function getList(Request $request) {
        $sysCode = isset($request->sys_code) ? $request->sys_code : null;     // 矿分类
        if ($sysCode == null) {
            $msg="参数为空";
            $code=-1;
            return $this->error($code, $msg);
        } else {
            switch ($sysCode) {
                case '720': // 720变电所
                    return $this->get720mpList();
                case '880': // 880变电所
                    return $this->get880mpList();
                case '980': // 980变电所
                    return $this->get980mpList();
                case '1142': // 1142变电所
                    return $this->get1142mpList();
                case '1000low': // 1000低压
                    return $this->get1000mLowList();
                case '1000high': // 1000高压
                    return $this->get1000mHighList();
                case '22low': // 22采区低压
                    return $this->get22DList();
                case '22high': // 22采区高压
                    return $this->get22GList();
                case '5fq950': // 五分区950
                    return $this->get5fq950List();
                case '5fq1200': // 五分区1200
                    return $this->get5fq1200List();
                case 'd929': // 井下929
                    return $this->getd929List();
                case 'd950': // 井下950
                    return $this->getd950List();
                default:
                    $msg="未知数据";
                    $code=-2;
                    return $this->error($code, $msg);
            }
        }
    }

    /*
     * 1000低压变电所
     * */
    public function get1000mLowList() {
        return $this->get1000mHighList();
    }

    /*
     * 1000高压变电所
     * 问题
     * */
    public function get1000mHighList() {

        $keys = [

            // 5401
            "2084033708184577_2", // 1000m变电所_5401开关位置
            "2084033716982785_1", // 1000m变电所_5401母线AB电压
            "2084033718303745_1", // 1000m变电所_5401A相电流
            "2084033710971905_1", // 1000m变电所_5401有功功率
            "2084033719391233_1", // 1000m变电所_5401功率因数

            // 5406
            "2084033708131329_2", // 1000m变电所_5406开关位置
            "2084033716759553_1", // 1000m变电所_5406母线AB电压
            "2084033718227969_1", // 1000m变电所_5406A相电流
            "2084033710924801_1", // 1000m变电所_5406有功功率
            "2084033719346177_1", // 1000m变电所_5406功率因数

            // 5407
            "2084033708102657_2", // 1000m变电所_5407开关位置
            "2084033716306945_1", // 1000m变电所_5407母线AB电压
            "2084033718113281_1", // 1000m变电所_5407A相电流
            "2084033710879745_1", // 1000m变电所_5407有功功率
            "2084033719297025_1", // 1000m变电所_5407功率因数

            // 5408
            "2084033708073985_2", // 1000m变电所_5408开关位置
            "2084033716030465_1", // 1000m变电所_5408母线AB电压
            "2084033718068225_1", // 1000m变电所_5408A相电流
            "2084033710816257_1", // 1000m变电所_5408有功功率
            "2084033719247873_1", // 1000m变电所_5408功率因数


            // 5409
            "2084033708045313_2", // 1000m变电所_5409开关位置
            "2084033715219457_1", // 1000m变电所_5409母线AB电压
            "2084033718023169_1", // 1000m变电所_5409A相电流
            "2084033710748673_1", // 1000m变电所_5409有功功率
            "2084033719178241_1", // 1000m变电所_5409功率因数

            // 5412
            "2084033708014593_2", // 1000m变电所_5412开关位置
            "2084033712354305_1", // 1000m变电所_5412母线AB电压
            "2084033717976065_1", // 1000m变电所_5412A相电流
            "2084033710672897_1", // 1000m变电所_5412有功功率
            "2084033719114753_1", // 1000m变电所_5412功率因数

            // 5001
            "2084033707422721_2", // 1000m变电所_5001开关位置
            "2084033711363073_1", // 1000m变电所_5001母线AB电压
            "2084033717513217_1", // 1000m变电所_5001A相电流
            "2084033710242817_1", // 1000m变电所_5001有功功率
            "2084033718637569_1", // 1000m变电所_5001功率因数

            // 5112
            "2084033707922433_2", // 1000m变电所_5112开关位置
            "2084033712010241_1", // 1000m变电所_5112母线AB电压
            "2084033717847041_1", // 1000m变电所_5112A相电流
            "2084033710572545_1", // 1000m变电所_5112有功功率
            "2084033718955009_1", // 1000m变电所_5112功率因数

            // 5106
            "2084033707889665_2", // 1000m变电所_5106开关位置
            "2084033711961089_1", // 1000m变电所_5106母线AB电压
            "2084033717799937_1", // 1000m变电所_5106A相电流
            "2084033710531585_1", // 1000m变电所_5106有功功率
            "2084033718903809_1", // 1000m变电所_5106功率因数

            // 5105
            "2084033707856897_2", // 1000m变电所_5105开关位置
            "2084033711916033_1", // 1000m变电所_5105母线AB电压
            "2084033717748737_1", // 1000m变电所_5105A相电流
            "2084033710478337_1", // 1000m变电所_5105有功功率
            "2084033718860801_1", // 1000m变电所_5105功率因数

            // 5102
            "2084033707787265_2", // 1000m变电所_5102开关位置
            "2084033711873025_1", // 1000m变电所_5102母线AB电压
            "2084033717703681_1", // 1000m变电所_5102A相电流
            "2084033710427137_1", // 1000m变电所_5102有功功率
            "2084033718819841_1", // 1000m变电所_5102功率因数

            // 5101
            "2084033707742209_2", // 1000m变电所_5101开关位置
            "2084033711764481_1", // 1000m变电所_5101母线AB电压
            "2084033717654529_1", // 1000m变电所_5101A相电流
            "2084033710377985_1", // 1000m变电所_5101有功功率
            "2084033718774785_1", // 1000m变电所_5101功率因数


            // --------------------------------------
            // 5301

            "2084033707045889_2", // 1000m变电所_5301开关位置
            "2084033711021057_1", // 1000m变电所_5301母线AB电压
            "2084033717218305_1", // 1000m变电所_5301A相电流
            "2084033709968385_1", // 1000m变电所_5301有功功率
            "2084033718354945_1", // 1000m变电所_5301功率因数

            // 5303
            "2084033707101185_2", // 1000m变电所_5303开关位置
            "2084033711121409_1", // 1000m变电所_5303母线AB电压
            "2084033717285889_1", // 1000m变电所_5303A相电流
            "2084033710013441_1", // 1000m变电所_5303有功功率
            "2084033718400001_1", // 1000m变电所_5303功率因数

            // 5310
            "2084033707142145_2", // 1000m变电所_5310开关位置
            "2084033711174657_1", // 1000m变电所_5310母线AB电压
            "2084033717332993_1", // 1000m变电所_5310A相电流
            "2084033710060545_1", // 1000m变电所_5310有功功率
            "2084033718455297_1", // 1000m变电所_5310功率因数

            // 5311
            "2084033707176961_2", // 1000m变电所_5311开关位置
            "2084033711223809_1", // 1000m变电所_5311母线AB电压
            "2084033717380097_1", // 1000m变电所_5311A相电流
            "2084033710105601_1", // 1000m变电所_5311有功功率
            "2084033718502401_1", // 1000m变电所_5311功率因数

            // 5312
            "2084033707242497_2", // 1000m变电所_5312开关位置
            "2084033711270913_1", // 1000m变电所_5312母线AB电压
            "2084033717427201_1", // 1000m变电所_5312A相电流
            "2084033710150657_1", // 1000m变电所_5312有功功率
            "2084033718547457_1", // 1000m变电所_5312功率因数

            // 5313
            "2084033707348993_2", // 1000m变电所_5313开关位置
            "2084033711313921_1", // 1000m变电所_5313母线AB电压
            "2084033717470209_1", // 1000m变电所_5313A相电流
            "2084033710195713_1", // 1000m变电所_5313有功功率
            "2084033718592513_1", // 1000m变电所_5313功率因数

            // 5002
            "2084033707965441_2", // 1000m变电所_5002开关位置
            "2084033712110593_1", // 1000m变电所_5002母线AB电压
            "2084033717916673_1", // 1000m变电所_5002A相电流
            "2084033710619649_1", // 1000m变电所_5002有功功率
            "2084033719071745_1", // 1000m变电所_5002功率因数

            // 5202
            "2084033707514881_2", // 1000m变电所_5202开关位置
            "2084033711422465_1", // 1000m变电所_5202母线AB电压
            "2084033717562369_1", // 1000m变电所_5202A相电流
            "2084033710287873_1", // 1000m变电所_5202有功功率
            "2084033718682625_1", // 1000m变电所_5202功率因数

            // 5201
            "2084033707707393_2", // 1000m变电所_5201开关位置
            "2084033711639553_1", // 1000m变电所_5201母线AB电压
            "2084033717611521_1", // 1000m变电所_5201A相电流
            "2084033710332929_1", // 1000m变电所_5201有功功率
            "2084033718725633_1", // 1000m变电所_5201功率因数

            // ------------------------------------------------
            // 10D200
            "2084033708565505_2", // 1000m变电所_10D200开关位置
            "2084033720030209_1", // 1000m变电所_10D200电流
            "2084033721334785_1", // 1000m变电所_10D200电压


            // 10D201
            "2084033708536833_2", // 1000m变电所_10D201开关位置
            "2084033719981057_1", // 1000m变电所_10D201电流
            "2084033721238529_1", // 1000m变电所_10D201电压

            // 10D202
            "2084033708508161_2", // 1000m变电所_10D202开关位置
            "2084033719921665_1", // 1000m变电所_10D202电流
            "2084033721189377_1", // 1000m变电所_10D202电压

            // 10Z201
            "2084033708954625_2", // 1000m变电所_10Z201开关位置
            "2084033722149889_1", // 1000m变电所_10Z201电流
            "2084033721971713_1", // 1000m变电所_10Z201电压

            // 10Z202
            "2084033708995585_2", // 1000m变电所_10Z202开关位置
            "2084033722194945_1", // 1000m变电所_10Z202电流
            "2084033722012673_1", // 1000m变电所_10Z202电压

            // 10Z203
            "2084033709050881_2", // 1000m变电所_10Z203开关位置
            "2084033722242049_1", // 1000m变电所_10Z203电流
            "2084033722057729_1", // 1000m变电所_10Z203电压

            // 10D203
            "2084033708479489_2", // 1000m变电所_10D203开关位置
            "2084033719874561_1", // 1000m变电所_10D203电流
            "2084033721119745_1", // 1000m变电所_10D203电压

            // 10D204
            "2084033708448769_2", // 1000m变电所_10D204开关位置
            "2084033719825409_1", // 1000m变电所_10D204电流
            "2084033721074689_1", // 1000m变电所_10D204电压

            // 10D205
            "2084033708420097_2", // 1000m变电所_10D205开关位置
            "2084033719780353_1", // 1000m变电所_10D205电流
            "2084033721025537_1", // 1000m变电所_10D205电压

            // 10D1-2
            "2093045884869633_2", // 1000变电所_10D1-2开关位置
            "2093045998783489_1", // 1000变电所_10D1-2电流
            "2093046139501569_1", // 1000变电所_10D1-2电压

            // 10D106
            "2084033708391425_2", // 1000m变电所_10D106开关位置
            "2084033719733249_1", // 1000m变电所_10D106电流
            "2084033720982529_1", // 1000m变电所_10D106电压

            // 10D105
            "2084033708358657_2", // 1000m变电所_10D105开关位置
            "2084033719688193_1", // 1000m变电所_10D105电流
            "2084033720939521_1", // 1000m变电所_10D105电压

            // 10D104
            "2084033708329985_2", // 1000m变电所_10D104开关位置
            "2084033719639041_1", // 1000m变电所_10D104电流
            "2084033720892417_1", // 1000m变电所_10D104电压

            // 10D103
            "2084033708301313_2", // 1000m变电所_10D103开关位置
            "2084033719587841_1", // 1000m变电所_10D103电流
            "2084033720845313_1", // 1000m变电所_10D103电压

            // 10Z101
            "2084033708925953_2", // 1000m变电所_10Z101开关位置
            "2093179971699713_1", // 1000m变电所_10Z101电流
            "2093053702714369_1", // 1000m变电所_10Z101电压

            // 10D102
            "2084033708272641_2", // 1000m变电所_10D102开关位置
            "2084033719526401_1", // 1000m变电所_10D102电流
            "2084033720802305_1", // 1000m变电所_10D102电压

            // 10D101
            "2084033708243969_2", // 1000m变电所_10D101开关位置
            "2084033719483393_1", // 1000m变电所_10D101电流
            "2084033720759297_1", // 1000m变电所_10D101电压

            // 10D100
            "2084033708213249_2", // 1000m变电所_10D100开关位置
            "2084033719436289_1", // 1000m变电所_10D100电流
            "2084033720714241_1", // 1000m变电所_10D100电压

            // 10F100
            "2084033708743681_2", // 1000m变电所_10F100开关位置
            "2084033720515585_1", // 1000m变电所_10F100电流
            "2084033721736193_1", // 1000m变电所_10F100电压

            // 10F101
            "2084033708831745_2", // 1000m变电所_10F101开关位置
            "2084033720560641_1", // 1000m变电所_10F101电流
            "2084033721783297_1", // 1000m变电所_10F101电压

            // 10F102
            "2084033708864513_2", // 1000m变电所_10F102开关位置
            "2084033720626177_1", // 1000m变电所_10F102电流
            "2084033721832449_1", // 1000m变电所_10F102电压

            // 10F103
            "2084033708893185_2", // 1000m变电所_10F103开关位置
            "2084033720669185_1", // 1000m变电所_10F103电流
            "2084033721879553_1", // 1000m变电所_10F103电压

            // 10F104
            "2084033708715009_2", // 1000m变电所_10F204开关位置
            "2084033720470529_1", // 1000m变电所_10F204电流
            "2084033721670657_1", // 1000m变电所_10F204电压

            // 10F203
            "2084033708684289_2", // 1000m变电所_10F203开关位置
            "2084033720419329_1", // 1000m变电所_10F203电流
            "2084033721596929_1", // 1000m变电所_10F203电压

            // 10F202
            "2084033708651521_2", // 1000m变电所_10F202开关位置
            "2084033720267777_1", // 1000m变电所_10F202电流
            "2084033721535489_1", // 1000m变电所_10F202电压

            // 10F201
            "2084033708620801_2", // 1000m变电所_10F201开关位置
            "2084033720118273_1", // 1000m变电所_10F201电流
            "2084033721451521_1", // 1000m变电所_10F201电压

            // 10F200
            "2084033708592129_2", // 1000m变电所_10F200开关位置
            "2084033720073217_1", // 1000m变电所_10F200电流
            "2084033721404417_1", // 1000m变电所_10F200电压


        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $info = [
            "tip"=>[
                [
                    "color"=>"#FF0000",
                    "text"=>"开"
                ],
                [
                    "color"=>"#00FF00",
                    "text"=>"关"
                ],
                [
                    "color"=>"#FF7F00",
                    "text"=>"通讯终端"
                ],
            ],
            "state"=>[
                $baseData["2084033708184577_2"], // 1000m变电所_5401开关位置
                "2",
                "2",
                "2",
                "2",
                $baseData["2084033708131329_2"], // 1000m变电所_5406开关位置
                $baseData["2084033708102657_2"], // 1000m变电所_5407开关位置
                $baseData["2084033708073985_2"], // 1000m变电所_5408开关位置
                $baseData["2084033708045313_2"], // 1000m变电所_5409开关位置
                "2",
                "2",
                $baseData["2084033708014593_2"], // 1000m变电所_5412开关位置
                $baseData["2084033707422721_2"], // 1000m变电所_5001开关位置
                $baseData["2084033707922433_2"], // 1000m变电所_5112开关位置
                "2",
                "2",
                "2",
                "2",
                "2",
                $baseData["2084033707889665_2"], // 1000m变电所_5106开关位置
                $baseData["2084033707856897_2"], // 1000m变电所_5105开关位置
                "2",
                "2",
                $baseData["2084033707787265_2"], // 1000m变电所_5102开关位置
                $baseData["2084033707742209_2"], // 1000m变电所_5101开关位置
                // 换行
                $baseData["2084033707045889_2"], // 1000m变电所_5301开关位置
                "2",
                $baseData["2084033707101185_2"], // 1000m变电所_5303开关位置
                "2",
                "2",
                "2",
                "2",
                "2",
                "2",
                $baseData["2084033707142145_2"], // 1000m变电所_5310开关位置
                $baseData["2084033707176961_2"], // 1000m变电所_5311开关位置
                $baseData["2084033707242497_2"], // 1000m变电所_5312开关位置
                $baseData["2084033707348993_2"], // 1000m变电所_5313开关位置
                "2",
                $baseData["2084033707965441_2"], // 1000m变电所_5002开关位置
                $baseData["2084033707514881_2"], // 1000m变电所_5202开关位置
                $baseData["2084033707707393_2"], // 1000m变电所_5201开关位置
                // 换行
                $baseData["2084033708565505_2"], // 1000m变电所_10D200开关位置
                $baseData["2084033708536833_2"], // 1000m变电所_10D201开关位置
                $baseData["2084033708508161_2"], // 1000m变电所_10D202开关位置
                $baseData["2084033708954625_2"], // 1000m变电所_10Z201开关位置
                $baseData["2084033708995585_2"], // 1000m变电所_10Z202开关位置
                $baseData["2084033709050881_2"], // 1000m变电所_10Z203开关位置
                $baseData["2084033708479489_2"], // 1000m变电所_10D203开关位置
                $baseData["2084033708448769_2"], // 1000m变电所_10D204开关位置
                $baseData["2084033708420097_2"], // 1000m变电所_10D205开关位置
                $baseData["2093045884869633_2"], // 1000变电所_10D1-2开关位置
                $baseData["2084033708391425_2"], // 1000m变电所_10D106开关位置
                $baseData["2084033708358657_2"], // 1000m变电所_10D105开关位置
                $baseData["2084033708329985_2"], // 1000m变电所_10D104开关位置
                $baseData["2084033708301313_2"], // 1000m变电所_10D103开关位置
                $baseData["2084033708925953_2"], // 1000m变电所_10Z101开关位置
                $baseData["2084033708272641_2"], // 1000m变电所_10D102开关位置
                $baseData["2084033708243969_2"], // 1000m变电所_10D101开关位置
                $baseData["2084033708213249_2"], // 1000m变电所_10D100开关位置
                $baseData["2084033708743681_2"], // 1000m变电所_10F100开关位置
                $baseData["2084033708831745_2"], // 1000m变电所_10F101开关位置
                $baseData["2084033708864513_2"], // 1000m变电所_10F102开关位置
                $baseData["2084033708893185_2"], // 1000m变电所_10F103开关位置
                $baseData["2084033708715009_2"], // 1000m变电所_10F204开关位置
                $baseData["2084033708684289_2"], // 1000m变电所_10F203开关位置
                $baseData["2084033708651521_2"], // 1000m变电所_10F202开关位置
                $baseData["2084033708620801_2"], // 1000m变电所_10F201开关位置
                $baseData["2084033708592129_2"], // 1000m变电所_10F200开关位置
            ],
            "table_data"=>[
                [
                    "title"=>"1000变电所1",
                    "table"=>[
                        "thead"=>["名称", "负荷用途", "电压", "电流", "有功功率", "功率因数"],
                        "tbody"=>[
                            [
                                "5401",
                                "高压IV回进线",
                                $baseData["2084033716982785_1"], // 1000m变电所_5401母线AB电压
                                $baseData["2084033718303745_1"], // 1000m变电所_5401A相电流
                                $baseData["2084033710971905_1"], // 1000m变电所_5401有功功率
                                $baseData["2084033719391233_1"], // 1000m变电所_5401功率因数
                            ],
                            [
                                "5402",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5403",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5404",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5405",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5406",
                                "720变电所II回",
                                $baseData["2084033716759553_1"], // 1000m变电所_5406母线AB电压
                                $baseData["2084033718227969_1"], // 1000m变电所_5406A相电流
                                $baseData["2084033710924801_1"], // 1000m变电所_5406有功功率
                                $baseData["2084033719346177_1"], // 1000m变电所_5406功率因数
                            ],
                            [
                                "5407",
                                "2#风机变",
                                $baseData["2084033716306945_1"], // 1000m变电所_5407母线AB电压
                                $baseData["2084033718113281_1"], // 1000m变电所_5407A相电流
                                $baseData["2084033710879745_1"], // 1000m变电所_5407有功功率
                                $baseData["2084033719297025_1"], // 1000m变电所_5407功率因数
                            ],
                            [
                                "5408",
                                "929变电所II回",
                                $baseData["2084033715219457_1"], // 1000m变电所_5409母线AB电压
                                $baseData["2084033718023169_1"], // 1000m变电所_5409A相电流
                                $baseData["2084033710748673_1"], // 1000m变电所_5409有功功率
                                $baseData["2084033719178241_1"], // 1000m变电所_5409功率因数

                            ],
                            [
                                "5409",
                                "880变电所II回",
                                $baseData["2084033715219457_1"], // 1000m变电所_5409母线AB电压
                                $baseData["2084033718023169_1"], // 1000m变电所_5409A相电流
                                $baseData["2084033710748673_1"], // 1000m变电所_5409有功功率
                                $baseData["2084033719178241_1"], // 1000m变电所_5409功率因数
                            ],
                            [
                                "5410",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5411",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5412",
                                "2#污水泵",
                                $baseData["2084033712354305_1"], // 1000m变电所_5412母线AB电压
                                $baseData["2084033717976065_1"], // 1000m变电所_5412A相电流
                                $baseData["2084033710672897_1"], // 1000m变电所_5412有功功率
                                $baseData["2084033719114753_1"], // 1000m变电所_5412功率因数
                            ],
                            [
                                "5001",
                                "联络",
                                $baseData["2084033711363073_1"], // 1000m变电所_5001母线AB电压
                                $baseData["2084033717513217_1"], // 1000m变电所_5001A相电流
                                $baseData["2084033710242817_1"], // 1000m变电所_5001有功功率
                                $baseData["2084033718637569_1"], // 1000m变电所_5001功率因数
                            ],
                            [
                                "5112",
                                "1#污水泵",
                                $baseData["2084033712010241_1"], // 1000m变电所_5112母线AB电压
                                $baseData["2084033717847041_1"], // 1000m变电所_5112A相电流
                                $baseData["2084033710572545_1"], // 1000m变电所_5112有功功率
                                $baseData["2084033718955009_1"], // 1000m变电所_5112功率因数
                            ],
                            [
                                "5111",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5110",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5109",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5108",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5107",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5106",
                                "2#动力变",
                                $baseData["2084033711961089_1"], // 1000m变电所_5106母线AB电压
                                $baseData["2084033717799937_1"], // 1000m变电所_5106A相电流
                                $baseData["2084033710531585_1"], // 1000m变电所_5106有功功率
                                $baseData["2084033718903809_1"], // 1000m变电所_5106功率因数
                            ],
                            [
                                "5105",
                                "130205风巷维护",
                                $baseData["2084033711916033_1"], // 1000m变电所_5105母线AB电压
                                $baseData["2084033717748737_1"], // 1000m变电所_5105A相电流
                                $baseData["2084033710478337_1"], // 1000m变电所_5105有功功率
                                $baseData["2084033718860801_1"], // 1000m变电所_5105功率因数
                            ],
                            [
                                "5104",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5103",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5102",
                                "880变电所I回",
                                $baseData["2084033711873025_1"], // 1000m变电所_5102母线AB电压
                                $baseData["2084033717703681_1"], // 1000m变电所_5102A相电流
                                $baseData["2084033710427137_1"], // 1000m变电所_5102有功功率
                                $baseData["2084033718819841_1"], // 1000m变电所_5102功率因数
                            ],
                            [
                                "5101",
                                "高压I回进线",
                                $baseData["2084033711764481_1"], // 1000m变电所_5101母线AB电压
                                $baseData["2084033717654529_1"], // 1000m变电所_5101A相电流
                                $baseData["2084033710377985_1"], // 1000m变电所_5101有功功率
                                $baseData["2084033718774785_1"], // 1000m变电所_5101功率因数
                            ],

                            // --------------------------------------
                            [
                                "5301",
                                "高压III回进线",
                                $baseData["2084033711021057_1"], // 1000m变电所_5301母线AB电压
                                $baseData["2084033717218305_1"], // 1000m变电所_5301A相电流
                                $baseData["2084033709968385_1"], // 1000m变电所_5301有功功率
                                $baseData["2084033718354945_1"], // 1000m变电所_5301功率因数
                            ],
                            [
                                "5302",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5303",
                                "",
                                $baseData["2084033711121409_1"], // 1000m变电所_5303母线AB电压
                                $baseData["2084033717285889_1"], // 1000m变电所_5303A相电流
                                $baseData["2084033710013441_1"], // 1000m变电所_5303有功功率
                                $baseData["2084033718400001_1"], // 1000m变电所_5303功率因数
                            ],
                            [
                                "5304",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5305",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5306",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5307",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5308",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5309",
                                "备用", "0", "0", "0", "0"
                            ],
                            [
                                "5310",
                                "14采区转载皮带",
                                $baseData["2084033711174657_1"], // 1000m变电所_5310母线AB电压
                                $baseData["2084033717332993_1"], // 1000m变电所_5310A相电流
                                $baseData["2084033710060545_1"], // 1000m变电所_5310有功功率
                                $baseData["2084033718455297_1"], // 1000m变电所_5310功率因数
                            ],
                            [
                                "5311",
                                "1#动力变",
                                $baseData["2084033711223809_1"], // 1000m变电所_5311母线AB电压
                                $baseData["2084033717380097_1"], // 1000m变电所_5311A相电流
                                $baseData["2084033710105601_1"], // 1000m变电所_5311有功功率
                                $baseData["2084033718502401_1"], // 1000m变电所_5311功率因数
                            ],
                            [
                                "5312",
                                "13采区转载皮带",
                                $baseData["2084033711270913_1"], // 1000m变电所_5312母线AB电压
                                $baseData["2084033717427201_1"], // 1000m变电所_5312A相电流
                                $baseData["2084033710150657_1"], // 1000m变电所_5312有功功率
                                $baseData["2084033718547457_1"], // 1000m变电所_5312功率因数
                            ],
                            [
                                "5313",
                                "929变电所I回",
                                $baseData["2084033711313921_1"], // 1000m变电所_5313母线AB电压
                                $baseData["2084033717470209_1"], // 1000m变电所_5313A相电流
                                $baseData["2084033710195713_1"], // 1000m变电所_5313有功功率
                                $baseData["2084033718592513_1"], // 1000m变电所_5313功率因数
                            ],
                            [
                                "5002",
                                "联络",
                                $baseData["2084033712110593_1"], // 1000m变电所_5002母线AB电压
                                $baseData["2084033717916673_1"], // 1000m变电所_5002A相电流
                                $baseData["2084033710619649_1"], // 1000m变电所_5002有功功率
                                $baseData["2084033719071745_1"], // 1000m变电所_5002功率因数
                            ],
                            [
                                "5202",
                                "1#风机变",
                                $baseData["2084033711422465_1"], // 1000m变电所_5202母线AB电压
                                $baseData["2084033717562369_1"], // 1000m变电所_5202A相电流
                                $baseData["2084033710287873_1"], // 1000m变电所_5202有功功率
                                $baseData["2084033718682625_1"], // 1000m变电所_5202功率因数
                            ],
                            [
                                "5201",
                                "高压II进线",
                                $baseData["2084033711639553_1"], // 1000m变电所_5201母线AB电压
                                $baseData["2084033717611521_1"], // 1000m变电所_5201A相电流
                                $baseData["2084033710332929_1"], // 1000m变电所_5201有功功率
                                $baseData["2084033718725633_1"], // 1000m变电所_5201功率因数
                            ],
                            // ------------------------------------------------
                            [
                                "10D200",
                                "低压II回进线",
                                $baseData["2084033720030209_1"], // 1000m变电所_10D200电流
                                $baseData["2084033721334785_1"], // 1000m变电所_10D200电压
                                null,null
                            ],
                            [
                                "10D201",
                                "1314改造巷照明",
                                $baseData["2084033719981057_1"], // 1000m变电所_10D201电流
                                $baseData["2084033721238529_1"], // 1000m变电所_10D201电压
                                null,null
                            ],
                            [
                                "10D202",
                                "照明电源II",
                                $baseData["2084033719921665_1"], // 1000m变电所_10D202电流
                                $baseData["2084033721189377_1"], // 1000m变电所_10D202电压
                                null,null
                            ],
                            [
                                "10Z201",
                                "电力监控/UPS/摄像头电源",
                                $baseData["2084033722149889_1"], // 1000m变电所_10Z201电流
                                $baseData["2084033721971713_1"], // 1000m变电所_10Z201电压
                                null,null
                            ],
                            [
                                "10Z202",
                                "所内及车场照明",
                                $baseData["2084033722194945_1"], // 1000m变电所_10Z202电流
                                $baseData["2084033722012673_1"], // 1000m变电所_10Z202电压
                                null,null
                            ],
                            [
                                "10Z203",
                                "双电源胶轮车信号",
                                $baseData["2084033722242049_1"], // 1000m变电所_10Z203电流
                                $baseData["2084033722057729_1"], // 1000m变电所_10Z203电压
                                null,null
                            ],
                            [
                                "10D203",
                                "备用",
                                $baseData["2084033719874561_1"], // 1000m变电所_10D203电流
                                $baseData["2084033721119745_1"], // 1000m变电所_10D203电压
                                null,null
                            ],
                            [
                                "10D204",
                                "1314采区带式输送机大巷南段电源",
                                $baseData["2084033719825409_1"], // 1000m变电所_10D204电流
                                $baseData["2084033721074689_1"], // 1000m变电所_10D204电压
                                null,null
                            ],
                            [
                                "10D205",
                                "2号清水泵可编程控制器电动阀门控制器电源",
                                $baseData["2084033719780353_1"], // 1000m变电所_10D205电流
                                $baseData["2084033721025537_1"], // 1000m变电所_10D205电压
                                null,null
                            ],
                            [
                                "10D1-2",
                                "1-2联络",
                                $baseData["2093045998783489_1"], // 1000变电所_10D1-2电流
                                $baseData["2093046139501569_1"], // 1000变电所_10D1-2电压
                                null,null
                            ],
                            [
                                "10D106",
                                "1314皮带机尾电气平台",
                                $baseData["2084033719733249_1"], // 1000m变电所_10D106电流
                                $baseData["2084033720982529_1"], // 1000m变电所_10D106电压
                                null,null
                            ],
                            [
                                "10D105",
                                "信息化电源",
                                $baseData["2084033719688193_1"], // 1000m变电所_10D105电流
                                $baseData["2084033720939521_1"], // 1000m变电所_10D105电压
                                null,null
                            ],
                            [
                                "10D104",
                                "避难硐室电源",
                                $baseData["2084033719639041_1"], // 1000m变电所_10D104电流
                                $baseData["2084033720892417_1"], // 1000m变电所_10D104电压
                                null,null
                            ],
                            [
                                "10D103",
                                "4G基站/变电所门口照明",
                                $baseData["2084033719587841_1"], // 1000m变电所_10D103电流
                                $baseData["2084033720845313_1"], // 1000m变电所_10D103电压
                                null,null
                            ],
                            [
                                "10Z101",
                                "4G基站",
                                $baseData["2093179971699713_1"], // 1000m变电所_10Z101电流
                                $baseData["2093053702714369_1"], // 1000m变电所_10Z101电压
                                null,null
                            ],
                            [
                                "10D102",
                                "1#清水泵",
                                $baseData["2084033719526401_1"], // 1000m变电所_10D102电流
                                $baseData["2084033720802305_1"], // 1000m变电所_10D102电压
                                null,null
                            ],
                            [
                                "10D101",
                                "1314皮带机尾给煤机",
                                $baseData["2084033719483393_1"], // 1000m变电所_10D101电流
                                $baseData["2084033720759297_1"], // 1000m变电所_10D101电压
                                null,null
                            ],
                            [
                                "10D100",
                                "低压I回进线",
                                $baseData["2084033719436289_1"], // 1000m变电所_10D100电流
                                $baseData["2084033720714241_1"], // 1000m变电所_10D100电压
                                null,null
                            ],
                            [
                                "10F100",
                                "风机I回进线",
                                $baseData["2084033720515585_1"], // 1000m变电所_10F100电流
                                $baseData["2084033721736193_1"], // 1000m变电所_10F100电压
                                null,null
                            ],
                            [
                                "10F101",
                                "14采区车场风机",
                                $baseData["2084033720560641_1"], // 1000m变电所_10F101电流
                                $baseData["2084033721783297_1"], // 1000m变电所_10F101电压
                                null,null
                            ],
                            [
                                "10F102",
                                "备用",
                                $baseData["2084033720626177_1"], // 1000m变电所_10F102电流
                                $baseData["2084033721832449_1"], // 1000m变电所_10F102电压
                                null,null
                            ],
                            [
                                "10F103",
                                "备用",
                                $baseData["2084033720669185_1"], // 1000m变电所_10F103电流
                                $baseData["2084033721879553_1"], // 1000m变电所_10F103电压
                                null,null
                            ],
                            [
                                "10F204",
                                "14采区回风上山延伸段风机",
                                $baseData["2084033720470529_1"], // 1000m变电所_10F204电流
                                $baseData["2084033721670657_1"], // 1000m变电所_10F204电压
                                null,null
                            ],
                            [
                                "10F203",
                                "备用",
                                $baseData["2084033720419329_1"], // 1000m变电所_10F203电流
                                $baseData["2084033721596929_1"], // 1000m变电所_10F203电压
                                null,null
                            ],
                            [
                                "10F202",
                                "14采区辅运下山延伸段风机",
                                $baseData["2084033720267777_1"], // 1000m变电所_10F202电流
                                $baseData["2084033721535489_1"], // 1000m变电所_10F202电压
                                null,null
                            ],
                            [
                                "10F201",
                                "14采区运输上山延伸段风机",
                                $baseData["2084033720118273_1"], // 1000m变电所_10F201电流
                                $baseData["2084033721451521_1"], // 1000m变电所_10F201电压
                                null,null
                            ],
                            [
                                "10F200",
                                "风机II回进线",
                                $baseData["2084033720073217_1"], // 1000m变电所_10F200电流
                                $baseData["2084033721404417_1"], // 1000m变电所_10F200电压
                                null,null
                            ],
                        ]
                    ]
                ]
            ]
        ];
        return json_encode($info);
    }



    /*
     * 720变电所
     * */
    public function get720mpList() {

        $keys=[
            "2046501530766337_1", // 720变电所_5101_UB
            "2046501530696705_1", // 720变电所_5101_IA
            "2046501530809345_1", // 720变电所_5101_P
            "2046501530844161_1", // 720变电所_5101_Q
            "2046501530881025_1", // 720变电所_5101_COS
            "2046501530987521_1", // 720变电所_51_9_1_PTUB
            "2046501530915841_1", // 720变电所_51_9_1_PTIA
            "2046501531030529_1", // 720变电所_51_9_1_PTP
            "2046501531063297_1", // 720变电所_51_9_1_PTQ
            "2046501531100161_1", // 720变电所_51_9_1_PTCOS
            "2046501531220993_1", // 720变电所_5102_UB
            "2046501531134977_1", // 720变电所_5102_IA
            "2046501531257857_1", // 720变电所_5102_P
            "2046501531296769_1", // 720变电所_5102_Q
            "2046501531335681_1", // 720变电所_5102_COS
            "2046501531460609_1", // 720变电所_5103_UB
            "2046501531380737_1", // 720变电所_5103_IA
            "2046501531505665_1", // 720变电所_5103_P
            "2046501531544577_1", // 720变电所_5103_Q
            "2046501531583489_1", // 720变电所_5103_COS
            "2046501531421697_1", // 720变电所_5103_IC
            "2046501531696129_1", // 720变电所_5104_UB
            "2046501531620353_1", // 720变电所_5104_IA
            "2046501531749377_1", // 720变电所_5104_P
            "2046501531790337_1", // 720变电所_5104_Q
            "2046501531831297_1", // 720变电所_5104_COS
            "2046501531950081_1", // 720变电所_5105_UB
            "2046501531872257_1", // 720变电所_5105_IA
            "2046501531993089_1", // 720变电所_5105_P
            "2046501532032001_1", // 720变电所_5105_Q
            "2046501532066817_1", // 720变电所_5105_COS
            "2046501532197889_1", // 720变电所_5106_UB
            "2046501532105729_1", // 720变电所_5106_IA
            "2046501532232705_1", // 720变电所_5106_P
            "2046501532269569_1", // 720变电所_5106_Q
            "2046501532308481_1", // 720变电所_5106_COS
            "2046501532435457_1", // 720变电所_5107_UB
            "2046501532347393_1", // 720变电所_5107_IA
            "2046501532472321_1", // 720变电所_5107_P
            "2046501532513281_1", // 720变电所_5107_Q
            "2046501532548097_1", // 720变电所_5107_COS
            "2046501532662785_1", // 720变电所_5108_UB
            "2046501532587009_1", // 720变电所_5108_IA
            "2046501532701697_1", // 720变电所_5108_P
            "2046501532740609_1", // 720变电所_5108_Q
            "2046501532777473_1", // 720变电所_5108_COS
            "2046501532888065_1", // 720变电所_5001_1-2联络_UB
            "2046501532814337_1", // 720变电所_5001_1-2联络_IA
            "2046501532941313_1", // 720变电所_5001_1-2联络_P
            "2046501532982273_1", // 720变电所_5001_1-2联络_Q
            "2046501533017089_1", // 720变电所_5001_1-2联络_COS
            "2046501533131777_1", // 720变电所_5207_UB
            "2046501533051905_1", // 720变电所_5207_IA
            "2046501533172737_1", // 720变电所_5207_P
            "2046501533211649_1", // 720变电所_5207_Q
            "2046501533248513_1", // 720变电所_5207_COS
            "2046501533377537_1", // 720变电所_5206_UB
            "2046501533287425_1", // 720变电所_5206_IA
            "2046501533414401_1", // 720变电所_5206_P
            "2046501533455361_1", // 720变电所_5206_Q
            "2046501533512705_1", // 720变电所_5206_COS
            "2046501533631489_1", // 720变电所_5205_UB
            "2046501533551617_1", // 720变电所_5205_IA
            "2046501533684737_1", // 720变电所_5205_P
            "2046501533725697_1", // 720变电所_5205_Q
            "2046501533762561_1", // 720变电所_5205_COS
            "2046501533883393_1", // 720变电所_5204_UB
            "2046501533801473_1", // 720变电所_5204_IA
            "2046501533930497_1", // 720变电所_5204_P
            "2046501533971457_1", // 720变电所_5204_Q
            "2046501534012417_1", // 720变电所_5204_COS
            "2046501534137345_1", // 720变电所_5203_UB
            "2046501534057473_1", // 720变电所_5203_IA
            "2046501534178305_1", // 720变电所_5203_P
            "2046501534217217_1", // 720变电所_5203_Q
            "2046501534258177_1", // 720变电所_5203_COS
            "2046501534374913_1", // 720变电所_5202_UB
            "2046501534297089_1", // 720变电所_5202_IA
            "2046501534415873_1", // 720变电所_5202_P
            "2046501534454785_1", // 720变电所_5202_Q
            "2046501534493697_1", // 720变电所_5202_COS
            "2046501534608385_1", // 720变电所_52-9_PTUB
            "2046501534530561_1", // 720变电所_52-9_PTIA
            "2046501534647297_1", // 720变电所_52-9_PTP
            "2046501534682113_1", // 720变电所_52-9_PTQ
            "2046501534716929_1", // 720变电所_52-9_PTCOS
            "2046501534839809_1", // 720变电所_5201_UB
            "2046501534753793_1", // 720变电所_5201_IA
            "2046501534876673_1", // 720变电所_5201_P
            "2046501534921729_1", // 720变电所_5201_Q
            "2046501534960641_1", // 720变电所_5201_COS
            "2046501536588801_1", // 720变电所_20F100_UX
            "2046501536506881_1", // 720变电所_20F100_IA
            "2046501536547841_1", // 720变电所_20F100_IC
            "2046501536670721_1", // 720变电所_20F101_UA
            "2046501536711681_1", // 720变电所_20F101_IA
            "2046501536748545_1", // 720变电所_20F101_IC
            "2046501536828417_1", // 720变电所_20F102_UA
            "2046501536869377_1", // 720变电所_20F102_IA
            "2046501536922625_1", // 720变电所_20F102_IC
            "2046501537000449_1", // 720变电所_20F103_UA
            "2046501537039361_1", // 720变电所_20F103_IA
            "2046501537078273_1", // 720变电所_20F103_IC
            "2046501537160193_1", // 720变电所_20F104_UA
            "2046501537199105_1", // 720变电所_20F104_IA
            "2046501537235969_1", // 720变电所_20F104_IC
            "2046501535720449_1", // 720变电所_20D105_Ux
            "2046501535642625_1", // 720变电所_20D105_IA
            "2046501535681537_1", // 720变电所_20D105_IC
            "2046501535603713_1", // 720变电所_20D104_Ux
            "2046501535509505_1", // 720变电所_20D104_IA
            "2046501535560705_1", // 720变电所_20D104_IC
            "2046501535470593_1", // 720变电所_20D103_Ux
            "2046501535349761_1", // 720变电所_20D103_IA
            "2046501535390721_1", // 720变电所_20D103_IC
            "2046501535310849_1", // 720变电所_20D102_Ux
            "2046501535235073_1", // 720变电所_20D102_IA
            "2046501535271937_1", // 720变电所_20D102_IC
            "2046501535198209_1", // 720变电所_20D101_Ux
            "2046501535118337_1", // 720变电所_20D101_IA
            "2046501535161345_1", // 720变电所_20D101_IC
            "2046501535079425_1", // 720变电所_20D100_Ux
            "2046501535001601_1", // 720变电所_20D100_IA
            "2046501535040513_1", // 720变电所_20D100_IC
            "2046501537731585_1", // 720变电所_2号移变高压侧电压
            "2046501537768449_1", // 720变电所_2号移变高压侧电流
            "2046501537879041_1", // 720变电所_2号移变低压侧电流
            "2046501537838081_1", // 720变电所_2号移变低压侧电压
            "2046501536467969_1", // 720变电所_20D200_Ux
            "2046501536365569_1", // 720变电所_20D200_IA
            "2046501536424961_1", // 720变电所_20D200_IC
            "2046501536324609_1", // 720变电所_20D201_Ux
            "2046501536232449_1", // 720变电所_20D201_IA
            "2046501536283649_1", // 720变电所_20D201_IC
            "2046501536191489_1", // 720变电所_20D202_Ux
            "2046501536117761_1", // 720变电所_20D202_IA
            "2046501536154625_1", // 720变电所_20D202_IC
            "2046501536078849_1", // 720变电所_20D203_Ux
            "2046501536005121_1", // 720变电所_20D203_IA
            "2046501536041985_1", // 720变电所_20D203_IC
            "2046501535966209_1", // 720变电所_20D204_Ux
            "2046501535886337_1", // 720变电所_20D204_IA
            "2046501535929345_1", // 720变电所_20D204_IC
            "2046501535845377_1", // 720变电所_20D205_Ux
            "2046501535757313_1", // 720变电所_20D205_IA
            "2046501535808513_1", // 720变电所_20D205_IC
            "2046501537274881_1", // 720变电所_720Z003_UAB
            "2046501537420289_1", // 720变电所_Z003照明回路_IB
            "2046501537385473_1", // 720变电所_Z003照明回路_IA
            "2046501537457153_1", // 720变电所_Z003信号回路_IC
            "2046501537494017_1", // 720变电所_Z002_UAB
            "2046501537690625_1", // 720变电所_Z002信号回路_IC
            "2046501537573889_1", // 720变电所_Z002_UCA
            "2046501537610753_1", // 720变电所_Z002照明回路_IA
            "2046501537647617_1", // 720变电所_Z002照明回路_IB
            "2046501537960961_1", // 720变电所_13207机巷1号低馈_UB
            "2046501538036737_1", // 720变电所_13207机巷1号低馈_IA
            "2046501538243585_1", // 720变电所_13207机巷2号低馈_IC
            "2046501538126849_1", // 720变电所_13207机巷2号低馈_UB
            "2046501538204673_1", // 720变电所_13207机巷2号低馈_IA
            "2046501538077697_1", // 720变电所_13207机巷1号低馈_IC

            "2046459584472065_2",
            "2046459585027073_2",
            "2046459585592321_2",
            "2046459586163713_2",
            "2046459586737153_2",
            "2046459587267585_2",
            "2046459587804161_2",
            "2046459588338689_2",
            "2046459588924417_2",
            "2046459589495809_2",
            "2046459590081537_2",
            "2046459590722561_2",
            "2046459591306241_2",
            "2046459591969793_2",
            "2046459592600577_2",
            "2046459593180161_2",
            "2046459593747457_2",
            "2046459594376193_2",
            "2046459601812481_2",
            "2046459602105345_2",
            "2046459602154497_2",
            "2046459602201601_2",
            "2046459602248705_2",
            "2046459597734913_2",
            "2046459597198337_2",
            "2046459596606465_2",
            "2046459595996161_2",
            "2046459595447297_2",
            "2046459594863617_2",
            "2046459602881537_2",
            "2046459603129345_2",
            "2046459601193985_2",
            "2046459600661505_2",
            "2046459600047105_2",
            "2046459599434753_2",
            "2046459598844929_2",
            "2046459598314497_2",
            "2046459602293761_2",
            "2046459602605057_2", // 20z002
            "2047223834045441_2", // 20z001
            "2047223939943425_2", // 720_13207_1#
            "2047223940000769_2", // 720_13207_2#
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "tip"=>[
                [
                    "color"=>"#00FF00",
                    "text"=>"关"
                ],
                [
                    "color"=>"#FF0000",
                    "text"=>"开"
                ],
            ],
            "state"=>[
                $baseData["2046459584472065_2"] ?? "0", // 720变电所_5101_开关
                $baseData["2046459585027073_2"] ?? "0", // 720变电所_51-9-1号PT_开关
                $baseData["2046459585592321_2"] ?? "0", // 720变电所_5102_开关
                $baseData["2046459586163713_2"] ?? "0", // 720变电所_5103_开关
                $baseData["2046459586737153_2"] ?? "0", // 720变电所_5104_开关
                $baseData["2046459587267585_2"] ?? "0", // 720变电所_5105_开关
                $baseData["2046459587804161_2"] ?? "0", // 720变电所_5106_开关
                $baseData["2046459588338689_2"] ?? "0", // 720变电所_5107_开关
                $baseData["2046459588924417_2"] ?? "0", // 720变电所_5108_开关
                $baseData["2046459589495809_2"] ?? "0", // 720变电所_50011-2联络_开关
                $baseData["2046459590081537_2"] ?? "0", // 720变电所_5207_开关
                $baseData["2046459590722561_2"] ?? "0", // 720变电所_5206_开关
                $baseData["2046459591306241_2"] ?? "0", // 720变电所_5205_开关
                $baseData["2046459591969793_2"] ?? "0", // 720变电所_5204_开关
                $baseData["2046459592600577_2"] ?? "0", // 720变电所_5203_开关
                $baseData["2046459593180161_2"] ?? "0", // 720变电所_5202_开关
                $baseData["2046459593747457_2"] ?? "0", // 720变电所_52-9PT_开关
                $baseData["2046459594376193_2"] ?? "0", // 720变电所_5201_开关

                $baseData["2046459601812481_2"] ?? "0", // 720变电所_20F100_合闸
                $baseData["2046459602105345_2"] ?? "0", // 720变电所_20F101_合闸
                $baseData["2046459602154497_2"] ?? "0", // 720变电所_20F102_合闸
                $baseData["2046459602201601_2"] ?? "0", // 720变电所_20F103_合闸
                $baseData["2046459602248705_2"] ?? "0", // 720变电所_20F104_合闸

                $baseData["2046459597734913_2"] ?? "0", // 720变电所_20D105_开关合位
                $baseData["2046459597198337_2"] ?? "0", // 720变电所_20D104_开关合位
                $baseData["2046459596606465_2"] ?? "0", // 720变电所_20D103_开关合位
                $baseData["2046459595996161_2"] ?? "0", // 720变电所_20D102_开关合位
                $baseData["2046459595447297_2"] ?? "0", // 720变电所_20D101_开关合位
                $baseData["2046459594863617_2"] ?? "0", // 720变电所_20D100_开关合位

                $baseData["2046459602881537_2"] ?? "0", // 720变电所_2号移变高压侧_开关
                $baseData["2046459603129345_2"] ?? "0", // 720变电所_2号移变低压侧_开关

                $baseData["2046459601193985_2"] ?? "0", // 720变电所_20D200_开关合位
                $baseData["2046459600661505_2"] ?? "0", // 720变电所_20D201_开关合位
                $baseData["2046459600047105_2"] ?? "0", // 720变电所_20D202_开关合位
                $baseData["2046459599434753_2"] ?? "0", // 720变电所_20D203_开关合位
                $baseData["2046459598844929_2"] ?? "0", // 720变电所_20D204_开关合位
                $baseData["2046459598314497_2"] ?? "0", // 720变电所_20D205_开关合位
                $baseData["2046459602293761_2"] ?? "0", // 720变电所_720Z003_开关合位

                $baseData["2046459602605057_2"] ?? "0", // 20z002
                $baseData["2047223834045441_2"] ?? "0", // 20z001

                $baseData["2047223939943425_2"] ?? "0", // 720_13207_1#
                $baseData["2047223940000769_2"] ?? "0", // 720_13207_2#

//                $baseData["2046459601761281_2"] ?? "0", // 720变电所_20D200_开关分闸

            ],
            "table_data"=>[
                [
                    "title"=>"720变电所变接线图",
                    "table"=>[
                        "thead"=>["名称", "Uab", "Ia", "P", "Q", "Cos"] ?? "0",
                        "tbody"=>[
                        [
                            "5101",
                            $baseData["2046501530766337_1"] ?? "0", // 720变电所_5101_UB
                            $baseData["2046501530696705_1"] ?? "0", // 720变电所_5101_IA
                            $baseData["2046501530809345_1"] ?? "0", // 720变电所_5101_P
                            $baseData["2046501530844161_1"] ?? "0", // 720变电所_5101_Q
                            $baseData["2046501530881025_1"] ?? "0", // 720变电所_5101_COS
                        ],
                        [

                            "51-9",
                            $baseData["2046501530987521_1"] ?? "0", // 720变电所_51_9_1_PTUB
                            $baseData["2046501530915841_1"] ?? "0", // 720变电所_51_9_1_PTIA
                            $baseData["2046501531030529_1"] ?? "0", // 720变电所_51_9_1_PTP
                            $baseData["2046501531063297_1"] ?? "0", // 720变电所_51_9_1_PTQ
                            $baseData["2046501531100161_1"] ?? "0", // 720变电所_51_9_1_PTCOS
                        ],
                        [
                            "51-9",
                            $baseData["2046501531220993_1"] ?? "0", // 720变电所_5102_UB
                            $baseData["2046501531134977_1"] ?? "0", // 720变电所_5102_IA
                            $baseData["2046501531257857_1"] ?? "0", // 720变电所_5102_P
                            $baseData["2046501531296769_1"] ?? "0", // 720变电所_5102_Q
                            $baseData["2046501531335681_1"] ?? "0", // 720变电所_5102_COS
                        ],
                        [
                            "5103",
                            $baseData["2046501531460609_1"] ?? "0", // 720变电所_5103_UB
                            $baseData["2046501531380737_1"] ?? "0", // 720变电所_5103_IA
                            $baseData["2046501531505665_1"] ?? "0", // 720变电所_5103_P
                            $baseData["2046501531544577_1"] ?? "0", // 720变电所_5103_Q
                            $baseData["2046501531583489_1"] ?? "0", // 720变电所_5103_COS
                            $baseData["2046501531421697_1"] ?? "0", // 720变电所_5103_IC
                        ],
                        [
                            "5104",
                            $baseData["2046501531696129_1"] ?? "0", // 720变电所_5104_UB
                            $baseData["2046501531620353_1"] ?? "0", // 720变电所_5104_IA
                            $baseData["2046501531749377_1"] ?? "0", // 720变电所_5104_P
                            $baseData["2046501531790337_1"] ?? "0", // 720变电所_5104_Q
                            $baseData["2046501531831297_1"] ?? "0", // 720变电所_5104_COS
                        ],
                        [
                            "5105",
                            $baseData["2046501531950081_1"] ?? "0", // 720变电所_5105_UB
                            $baseData["2046501531872257_1"] ?? "0", // 720变电所_5105_IA
                            $baseData["2046501531993089_1"] ?? "0", // 720变电所_5105_P
                            $baseData["2046501532032001_1"] ?? "0", // 720变电所_5105_Q
                            $baseData["2046501532066817_1"] ?? "0", // 720变电所_5105_COS
                        ],
                        [
                            "5106",
                            $baseData["2046501532197889_1"] ?? "0", // 720变电所_5106_UB
                            $baseData["2046501532105729_1"] ?? "0", // 720变电所_5106_IA
                            $baseData["2046501532232705_1"] ?? "0", // 720变电所_5106_P
                            $baseData["2046501532269569_1"] ?? "0", // 720变电所_5106_Q
                            $baseData["2046501532308481_1"] ?? "0", // 720变电所_5106_COS
                        ],
                        [
                            "5107",
                            $baseData["2046501532435457_1"] ?? "0", // 720变电所_5107_UB
                            $baseData["2046501532347393_1"] ?? "0", // 720变电所_5107_IA
                            $baseData["2046501532472321_1"] ?? "0", // 720变电所_5107_P
                            $baseData["2046501532513281_1"] ?? "0", // 720变电所_5107_Q
                            $baseData["2046501532548097_1"] ?? "0", // 720变电所_5107_COS
                        ],
                        [
                            "5108",
                            $baseData["2046501532662785_1"] ?? "0", // 720变电所_5108_UB
                            $baseData["2046501532587009_1"] ?? "0", // 720变电所_5108_IA
                            $baseData["2046501532701697_1"] ?? "0", // 720变电所_5108_P
                            $baseData["2046501532740609_1"] ?? "0", // 720变电所_5108_Q
                            $baseData["2046501532777473_1"] ?? "0", // 720变电所_5108_COS
                        ],
                        [
                            "50001",
                            $baseData["2046501532888065_1"] ?? "0", // 720变电所_5001_1-2联络_UB
                            $baseData["2046501532814337_1"] ?? "0", // 720变电所_5001_1-2联络_IA
                            $baseData["2046501532941313_1"] ?? "0", // 720变电所_5001_1-2联络_P
                            $baseData["2046501532982273_1"] ?? "0", // 720变电所_5001_1-2联络_Q
                            $baseData["2046501533017089_1"] ?? "0", // 720变电所_5001_1-2联络_COS
                        ],
                        [
                            "5207",
                            $baseData["2046501533131777_1"] ?? "0", // 720变电所_5207_UB
                            $baseData["2046501533051905_1"] ?? "0", // 720变电所_5207_IA
                            $baseData["2046501533172737_1"] ?? "0", // 720变电所_5207_P
                            $baseData["2046501533211649_1"] ?? "0", // 720变电所_5207_Q
                            $baseData["2046501533248513_1"] ?? "0", // 720变电所_5207_COS
                        ],
                        [
                            "5206",
                            $baseData["2046501533377537_1"] ?? "0", // 720变电所_5206_UB
                            $baseData["2046501533287425_1"] ?? "0", // 720变电所_5206_IA
                            $baseData["2046501533414401_1"] ?? "0", // 720变电所_5206_P
                            $baseData["2046501533455361_1"] ?? "0", // 720变电所_5206_Q
                            $baseData["2046501533512705_1"] ?? "0", // 720变电所_5206_COS
                        ],
                        [
                            "5205",
                            $baseData["2046501533631489_1"] ?? "0", // 720变电所_5205_UB
                            $baseData["2046501533551617_1"] ?? "0", // 720变电所_5205_IA
                            $baseData["2046501533684737_1"] ?? "0", // 720变电所_5205_P
                            $baseData["2046501533725697_1"] ?? "0", // 720变电所_5205_Q
                            $baseData["2046501533762561_1"] ?? "0", // 720变电所_5205_COS
                        ],
                        [
                            "5204",
                            $baseData["2046501533883393_1"] ?? "0", // 720变电所_5204_UB
                            $baseData["2046501533801473_1"] ?? "0", // 720变电所_5204_IA
                            $baseData["2046501533930497_1"] ?? "0", // 720变电所_5204_P
                            $baseData["2046501533971457_1"] ?? "0", // 720变电所_5204_Q
                            $baseData["2046501534012417_1"] ?? "0", // 720变电所_5204_COS
                        ],
                        [
                            "5203",
                            $baseData["2046501534137345_1"] ?? "0", // 720变电所_5203_UB
                            $baseData["2046501534057473_1"] ?? "0", // 720变电所_5203_IA
                            $baseData["2046501534178305_1"] ?? "0", // 720变电所_5203_P
                            $baseData["2046501534217217_1"] ?? "0", // 720变电所_5203_Q
                            $baseData["2046501534258177_1"] ?? "0", // 720变电所_5203_COS
                        ],
                        [
                            "5202",
                            $baseData["2046501534374913_1"] ?? "0", // 720变电所_5202_UB
                            $baseData["2046501534297089_1"] ?? "0", // 720变电所_5202_IA
                            $baseData["2046501534415873_1"] ?? "0", // 720变电所_5202_P
                            $baseData["2046501534454785_1"] ?? "0", // 720变电所_5202_Q
                            $baseData["2046501534493697_1"] ?? "0", // 720变电所_5202_COS
                        ],
                        [
                            "52-9",
                            $baseData["2046501534608385_1"] ?? "0", // 720变电所_52-9_PTUB
                            $baseData["2046501534530561_1"] ?? "0", // 720变电所_52-9_PTIA
                            $baseData["2046501534647297_1"] ?? "0", // 720变电所_52-9_PTP
                            $baseData["2046501534682113_1"] ?? "0", // 720变电所_52-9_PTQ
                            $baseData["2046501534716929_1"] ?? "0", // 720变电所_52-9_PTCOS
                        ],

                        [
                            "5201",
                            $baseData["2046501534839809_1"] ?? "0", // 720变电所_5201_UB
                            $baseData["2046501534753793_1"] ?? "0", // 720变电所_5201_IA
                            $baseData["2046501534876673_1"] ?? "0", // 720变电所_5201_P
                            $baseData["2046501534921729_1"] ?? "0", // 720变电所_5201_Q
                            $baseData["2046501534960641_1"] ?? "0", // 720变电所_5201_COS
                        ],
                    ],
                    ]
                ],
                [
                    "title"=>"720变电所变接线图",
                    "table"=>[
                        "thead"=>["名称", "Uab", "Ia", "P"] ?? "0",
                        "tbody"=>[
                        [
                            "20F100",
                            $baseData["2046501536588801_1"] ?? "0", // 720变电所_20F100_UX
                            $baseData["2046501536506881_1"] ?? "0", // 720变电所_20F100_IA
                            $baseData["2046501536547841_1"] ?? "0", // 720变电所_20F100_IC
                        ],
                        [
                            "20F101",
                            $baseData["2046501536670721_1"] ?? "0", // 720变电所_20F101_UA
                            $baseData["2046501536711681_1"] ?? "0", // 720变电所_20F101_IA
                            $baseData["2046501536748545_1"] ?? "0", // 720变电所_20F101_IC
                        ],
                        [
                            "20F102",
                            $baseData["2046501536828417_1"] ?? "0", // 720变电所_20F102_UA
                            $baseData["2046501536869377_1"] ?? "0", // 720变电所_20F102_IA
                            $baseData["2046501536922625_1"] ?? "0", // 720变电所_20F102_IC
                        ],
                        [
                            "20F103",
                            $baseData["2046501537000449_1"] ?? "0", // 720变电所_20F103_UA
                            $baseData["2046501537039361_1"] ?? "0", // 720变电所_20F103_IA
                            $baseData["2046501537078273_1"] ?? "0", // 720变电所_20F103_IC
                        ],
                        [
                            "20F104",
                            $baseData["2046501537160193_1"] ?? "0", // 720变电所_20F104_UA
                            $baseData["2046501537199105_1"] ?? "0", // 720变电所_20F104_IA
                            $baseData["2046501537235969_1"] ?? "0", // 720变电所_20F104_IC
                        ],
                        [
                            "20F105",
                            $baseData["2046501535720449_1"] ?? "0", // 720变电所_20D105_Ux
                            $baseData["2046501535642625_1"] ?? "0", // 720变电所_20D105_IA
                            $baseData["2046501535681537_1"] ?? "0", // 720变电所_20D105_IC
                        ],
                        [
                            "20D104",
                            $baseData["2046501535603713_1"] ?? "0", // 720变电所_20D104_Ux
                            $baseData["2046501535509505_1"] ?? "0", // 720变电所_20D104_IA
                            $baseData["2046501535560705_1"] ?? "0", // 720变电所_20D104_IC
                        ],
                        [
                            "20D103",
                            $baseData["2046501535470593_1"] ?? "0", // 720变电所_20D103_Ux
                            $baseData["2046501535349761_1"] ?? "0", // 720变电所_20D103_IA
                            $baseData["2046501535390721_1"] ?? "0", // 720变电所_20D103_IC
                        ],
                        [
                            "20D102",
                            $baseData["2046501535310849_1"] ?? "0", // 720变电所_20D102_Ux
                            $baseData["2046501535235073_1"] ?? "0", // 720变电所_20D102_IA
                            $baseData["2046501535271937_1"] ?? "0", // 720变电所_20D102_IC
                        ],
                        [
                            "20D101",
                            $baseData["2046501535198209_1"] ?? "0", // 720变电所_20D101_Ux
                            $baseData["2046501535118337_1"] ?? "0", // 720变电所_20D101_IA
                            $baseData["2046501535161345_1"] ?? "0", // 720变电所_20D101_IC
                        ],
                        [
                            "20D100",
                            $baseData["2046501535079425_1"] ?? "0", // 720变电所_20D100_Ux
                            $baseData["2046501535001601_1"] ?? "0", // 720变电所_20D100_IA
                            $baseData["2046501535040513_1"] ?? "0", // 720变电所_20D100_IC
                        ],
                        [
                            "KBSGZY2-T-1250",
                            $baseData["2046501537731585_1"] ?? "0", // 720变电所_2号移变高压侧电压
                            $baseData["2046501537768449_1"] ?? "0", // 720变电所_2号移变高压侧电流
                            ""
                        ],
                        [
                            "KBSGZY2-T-10",
                            $baseData["2046501537879041_1"] ?? "0", // 720变电所_2号移变低压侧电流
                            $baseData["2046501537838081_1"] ?? "0", // 720变电所_2号移变低压侧电压
                            ""
                        ],
                        [
                            "20D200",
                            $baseData["2046501536467969_1"] ?? "0", // 720变电所_20D200_Ux
                            $baseData["2046501536365569_1"] ?? "0", // 720变电所_20D200_IA
                            $baseData["2046501536424961_1"] ?? "0", // 720变电所_20D200_IC
                        ],
                        [
                            "20D201",
                            $baseData["2046501536324609_1"] ?? "0", // 720变电所_20D201_Ux
                            $baseData["2046501536232449_1"] ?? "0", // 720变电所_20D201_IA
                            $baseData["2046501536283649_1"] ?? "0", // 720变电所_20D201_IC
                        ],
                        [
                            "20D202",
                            $baseData["2046501536191489_1"] ?? "0", // 720变电所_20D202_Ux
                            $baseData["2046501536117761_1"] ?? "0", // 720变电所_20D202_IA
                            $baseData["2046501536154625_1"] ?? "0", // 720变电所_20D202_IC
                        ],
                        [
                            "20D203",
                            $baseData["2046501536078849_1"] ?? "0", // 720变电所_20D203_Ux
                            $baseData["2046501536005121_1"] ?? "0", // 720变电所_20D203_IA
                            $baseData["2046501536041985_1"] ?? "0", // 720变电所_20D203_IC
                        ],
                        [
                            "20D204",
                            $baseData["2046501535966209_1"] ?? "0", // 720变电所_20D204_Ux
                            $baseData["2046501535886337_1"] ?? "0", // 720变电所_20D204_IA
                            $baseData["2046501535929345_1"] ?? "0", // 720变电所_20D204_IC
                        ],
                        [
                            "20D205",
                            $baseData["2046501535845377_1"] ?? "0", // 720变电所_20D205_Ux
                            $baseData["2046501535757313_1"] ?? "0", // 720变电所_20D205_IA
                            $baseData["2046501535808513_1"] ?? "0", // 720变电所_20D205_IC
                        ],
                        [
                            "20D003",
                            $baseData["2046501537274881_1"] ?? "0", // 720变电所_720Z003_UAB
                            // $baseData["2046501537420289_1"] ?? "0", // 720变电所_Z003照明回路_IB
                            $baseData["2046501537385473_1"] ?? "0", // 720变电所_Z003照明回路_IA
                            $baseData["2046501537457153_1"] ?? "0", // 720变电所_Z003信号回路_IC
                        ],
                        [
                            "20D001",
                            $baseData["2046501537494017_1"] ?? "0", // 720变电所_Z002_UAB
                            $baseData["2046501537690625_1"] ?? "0", // 720变电所_Z002信号回路_IC
                            ""

                            // $baseData["2046501537573889_1"] ?? "0", // 720变电所_Z002_UCA
                            // $baseData["2046501537610753_1"] ?? "0", // 720变电所_Z002照明回路_IA
                            // $baseData["2046501537647617_1"] ?? "0", // 720变电所_Z002照明回路_IB
                        ],
                        [
                            "20D002",
                            "0",
                            "0",
                            ""
                        ],
                        [
                            "13207机巷1#",
                            $baseData["2046501537960961_1"] ?? "0", // 720变电所_13207机巷1号低馈_UB
                            $baseData["2046501538036737_1"] ?? "0", // 720变电所_13207机巷1号低馈_IA
                            $baseData["2046501538243585_1"] ?? "0", // 720变电所_13207机巷2号低馈_IC
                        ],
                        [
                            "13207机巷2#",
                            $baseData["2046501538126849_1"] ?? "0", // 720变电所_13207机巷2号低馈_UB
                            $baseData["2046501538204673_1"] ?? "0", // 720变电所_13207机巷2号低馈_IA
                            $baseData["2046501538077697_1"] ?? "0", // 720变电所_13207机巷1号低馈_IC
                        ]
                    ]
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 880变电所
     * */
    public function get880mpList() {

        $keys=[
            "2046501468832769_1", //880变电所_5101_UB
            "2046501468761089_1", //880变电所_5101_IA
            "2046501468867585_1", //880变电所_5101_P
            "2046501468904449_1", //880变电所_5101_Q
            "2046501468943361_1", //880变电所_5101_COS
            "2046501469053953_1", //880变电所_5102_UB
            "2046501468978177_1", //880变电所_5102_IA
            "2046501469092865_1", //880变电所_5102_P
            "2046501469133825_1", //880变电所_5102_Q
            "2046501469174785_1", //880变电所_5102_COS
            "2046501469287425_1", //880变电所_5103_UB
            "2046501469213697_1", //880变电所_5103_IA
            "2046501469324289_1", //880变电所_5103_P
            "2046501469363201_1", //880变电所_5103_Q
            "2046501469395969_1", //880变电所_5103_COS
            "2046501469510657_1", //880变电所_5104_UB
            "2046501469434881_1", //880变电所_5104_IA
            "2046501469549569_1", //880变电所_5104_P
            "2046501469590529_1", //880变电所_5104_Q
            "2046501469629441_1", //880变电所_5104_COS
            "2046501469778945_1", //880变电所_5001_UB
            "2046501469666305_1", //880变电所_5001_IA
            "2046501469817857_1", //880变电所_5001_P
            "2046501469856769_1", //880变电所_5001_Q
            "2046501469907969_1", //880变电所_5001_COS
            "2046501470028801_1", //880变电所_5204_UB
            "2046501469948929_1", //880变电所_5204_IA
            "2046501470067713_1", //880变电所_5204_P
            "2046501470104577_1", //880变电所_5204_Q
            "2046501470141441_1", //880变电所_5204_COS
            "2046501470249985_1", //880变电所_5203_UB
            "2046501470176257_1", //880变电所_5203_IA
            "2046501470286849_1", //880变电所_5203_P
            "2046501470323713_1", //880变电所_5203_Q
            "2046501470360577_1", //880变电所_5203_COS
            "2046501470477313_1", //880变电所_5202_UB
            "2046501470395393_1", //880变电所_5202_IA
            "2046501470514177_1", //880变电所_5202_P
            "2046501470548993_1", //880变电所_5202_Q
            "2046501470585857_1", //880变电所_5202_COS
            "2046501470690305_1", //880变电所_5201_UB
            "2046501470620673_1", //880变电所_5201_IA
            "2046501470725121_1", //880变电所_5201_P
            "2046501470759937_1", //880变电所_5201_Q
            "2046501470796801_1", //880变电所_5201_COS


            "2046501471757313_1", //880变电所_88Z_1_UCA
            "2046501471796225_1", //880变电所_88Z_1_IA

            "2046501472384001_1", //880变电所_1号移变高压侧_US
            "2046501472238593_1", //880变电所_1号移变高压侧_IA

            "2046501472730113_1", //880变电所_1号移变低压侧_US
            "2046501472564225_1", //880变电所_1号移变低压侧_IA

            "2084668368153601_1", //14采区+880m变电所（节点）备用电源 88d100 电压
            "2084668368544769_1", //14采区+880m变电所（节点）备用电源 88d100

            "2084668368346113_1", //14采区+880m变电所备用电源 88d101 电压
            "2084668370357249_1", //14采区+880m变电所备用电源 88d101

            "2046501473385473_1", //880变电所_2号移变低压侧_US
            "2046501473235969_1", //880变电所_2号移变低压侧_IA

            "2046501473055745_1", //880变电所_2号移变高压侧_US
            "2046501472912385_1", //880变电所_2号移变高压侧_IA

            "2046501471917057_1", //880变电所_88Z_4_UCA
            "2046501471972353_1", //880变电所_88Z_4_IA

            "2046501472091137_1", //880变电所_88Z_5_UCA
            "2046501472128001_1", //880变电所_88Z_5_IA

            "2046459492846593_2", // 5101
            "2046459493544961_2", // 5102
            "2046459494116353_2", // 5103
            "2046459494673409_2", // 5104

            "2046459495306241_2", // 5001

            "2046459495926785_2", // 5204
            "2046459496530945_2", // 5203
            "2046459497137153_2", // 5202
            "2046459497741313_2", // 5201
            "2046459500686337_2", //880变电所_88Z-1_开关合位
            "2046459501636609_2", //880变电所_1号移变高压侧_开关合位
            "2046459501816833_2", //880变电所_1号移变低压侧_开关合位
            "2047266235374593_2", //880_88D100
            "2047266235317249_2", //880_88D101
            "2047266235264001_2", //880_88D1-2
            "2046459498351617_2", //880变电所_89G203_开关
            "2046459498998785_2", //880变电所_89G202_开关
            "2046459499578369_2", //880变电所_89G201_开关
            "2046459500192769_2", //880变电所_89G200_开关
            "2046459502177281_2", //880变电所_2号移变低压侧_开关合位
            "2046459501990913_2", //880变电所_2号移变高压侧_开关合位
            "2046459500999681_2", //880变电所_88Z-4_开关合位
            "2046459501317121_2", //880变电所_88Z-5_开关合位
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "tip"=>[
                [
                    "color"=>"#00FF00",
                    "text"=>"关"
                ],
                [
                    "color"=>"#FF0000",
                    "text"=>"开"
                ],
            ],
            "state"=>[

                $baseData["2046459492846593_2"] ?? "0", // 5101
                $baseData["2046459493544961_2"] ?? "0", // 5102
                $baseData["2046459494116353_2"] ?? "0", // 5103
                $baseData["2046459494673409_2"] ?? "0", // 5104

                $baseData["2046459495306241_2"] ?? "0", // 5001

                $baseData["2046459495926785_2"] ?? "0", // 5204
                $baseData["2046459496530945_2"] ?? "0", // 5203
                $baseData["2046459497137153_2"] ?? "0", // 5202
                $baseData["2046459497741313_2"] ?? "0", // 5201

                $baseData["2046459500686337_2"] ?? "0", //880变电所_88Z-1_开关合位
                $baseData["2046459501636609_2"] ?? "0", //880变电所_1号移变高压侧_开关合位
                $baseData["2046459501816833_2"] ?? "0", //880变电所_1号移变低压侧_开关合位

                $baseData["2047266235374593_2"] ?? "0", //880_88D100
                $baseData["2047266235317249_2"] ?? "0", //880_88D101
                $baseData["2047266235264001_2"] ?? "0", //880_88D1-2
                $baseData["2046459498351617_2"] ?? "0", //880变电所_89G203_开关
                $baseData["2046459498998785_2"] ?? "0", //880变电所_89G202_开关
                $baseData["2046459499578369_2"] ?? "0", //880变电所_89G201_开关
                $baseData["2046459500192769_2"] ?? "0", //880变电所_89G200_开关

                $baseData["2046459502177281_2"] ?? "0", //880变电所_2号移变低压侧_开关合位
                $baseData["2046459501990913_2"] ?? "0", //880变电所_2号移变高压侧_开关合位
                $baseData["2046459500999681_2"] ?? "0", //880变电所_88Z-4_开关合位
                $baseData["2046459501317121_2"] ?? "0", //880变电所_88Z-5_开关合位
            ],
            "table_data"=>[
                [
                    "title"=>"880变电所变接线1",
                    "table"=>[
                        "thead"=>["名称", "Uab", "Ia", "P", "Q", "Cos"] ?? "0",
                        "tbody"=>[

                            [
                                "5101",
                                $baseData["2046501468832769_1"] ?? "0", //880变电所_5101_UB
                                $baseData["2046501468761089_1"] ?? "0", //880变电所_5101_IA
                                $baseData["2046501468867585_1"] ?? "0", //880变电所_5101_P
                                $baseData["2046501468904449_1"] ?? "0", //880变电所_5101_Q
                                $baseData["2046501468943361_1"] ?? "0", //880变电所_5101_COS
                            ],
                            [
                                "5102",
                                $baseData["2046501469053953_1"] ?? "0", //880变电所_5102_UB
                                $baseData["2046501468978177_1"] ?? "0", //880变电所_5102_IA
                                $baseData["2046501469092865_1"] ?? "0", //880变电所_5102_P
                                $baseData["2046501469133825_1"] ?? "0", //880变电所_5102_Q
                                $baseData["2046501469174785_1"] ?? "0", //880变电所_5102_COS
                            ],
                            [
                                "5103",
                                $baseData["2046501469287425_1"] ?? "0", //880变电所_5103_UB
                                $baseData["2046501469213697_1"] ?? "0", //880变电所_5103_IA
                                $baseData["2046501469324289_1"] ?? "0", //880变电所_5103_P
                                $baseData["2046501469363201_1"] ?? "0", //880变电所_5103_Q
                                $baseData["2046501469395969_1"] ?? "0", //880变电所_5103_COS
                            ],
                            [
                                "5104",
                                $baseData["2046501469510657_1"] ?? "0", //880变电所_5104_UB
                                $baseData["2046501469434881_1"] ?? "0", //880变电所_5104_IA
                                $baseData["2046501469549569_1"] ?? "0", //880变电所_5104_P
                                $baseData["2046501469590529_1"] ?? "0", //880变电所_5104_Q
                                $baseData["2046501469629441_1"] ?? "0", //880变电所_5104_COS
                            ],
                            [
                                "5001",
                                $baseData["2046501469778945_1"] ?? "0", //880变电所_5001_UB
                                $baseData["2046501469666305_1"] ?? "0", //880变电所_5001_IA
                                $baseData["2046501469817857_1"] ?? "0", //880变电所_5001_P
                                $baseData["2046501469856769_1"] ?? "0", //880变电所_5001_Q
                                $baseData["2046501469907969_1"] ?? "0", //880变电所_5001_COS
                            ],
                            [
                                "5204",
                                $baseData["2046501470028801_1"] ?? "0", //880变电所_5204_UB
                                $baseData["2046501469948929_1"] ?? "0", //880变电所_5204_IA
                                $baseData["2046501470067713_1"] ?? "0", //880变电所_5204_P
                                $baseData["2046501470104577_1"] ?? "0", //880变电所_5204_Q
                                $baseData["2046501470141441_1"] ?? "0", //880变电所_5204_COS
                            ],
                            [
                                "5203",
                                $baseData["2046501470249985_1"] ?? "0", //880变电所_5203_UB
                                $baseData["2046501470176257_1"] ?? "0", //880变电所_5203_IA
                                $baseData["2046501470286849_1"] ?? "0", //880变电所_5203_P
                                $baseData["2046501470323713_1"] ?? "0", //880变电所_5203_Q
                                $baseData["2046501470360577_1"] ?? "0", //880变电所_5203_COS
                            ],
                            [
                                "5202",
                                $baseData["2046501470477313_1"] ?? "0", //880变电所_5202_UB
                                $baseData["2046501470395393_1"] ?? "0", //880变电所_5202_IA
                                $baseData["2046501470514177_1"] ?? "0", //880变电所_5202_P
                                $baseData["2046501470548993_1"] ?? "0", //880变电所_5202_Q
                                $baseData["2046501470585857_1"] ?? "0", //880变电所_5202_COS
                            ],
                            [
                                "5201",
                                $baseData["2046501470690305_1"] ?? "0", //880变电所_5201_UB
                                $baseData["2046501470620673_1"] ?? "0", //880变电所_5201_IA
                                $baseData["2046501470725121_1"] ?? "0", //880变电所_5201_P
                                $baseData["2046501470759937_1"] ?? "0", //880变电所_5201_Q
                                $baseData["2046501470796801_1"] ?? "0", //880变电所_5201_COS
                            ]
                        ],
                    ]
                ],
                [
                    "title"=>"880变电所变接线2",
                    "table"=>[
                        "thead"=>["名称", "Uab", "Ia", "P"] ?? "0",
                        "tbody"=>[
                            [
                                "88Z-1",
                                $baseData["2046501471757313_1"] ?? "0", //880变电所_88Z_1_UCA
                                $baseData["2046501471796225_1"] ?? "0", //880变电所_88Z_1_IA
                                ""
                            ],
                            [
                                "移变高压侧",
                                $baseData["2046501472384001_1"] ?? "0", //880变电所_1号移变高压侧_US
                                $baseData["2046501472238593_1"] ?? "0", //880变电所_1号移变高压侧_IA
                                ""
                            ],
                            [
                                "移变低压侧",
                                $baseData["2046501472730113_1"] ?? "0", //880变电所_1号移变低压侧_US
                                $baseData["2046501472564225_1"] ?? "0", //880变电所_1号移变低压侧_IA
                                ""
                            ],
                            [
                                "88D100",
                                $baseData["2084668368153601_1"] ?? "0", //14采区+880m变电所（节点）备用电源 88d100 电压
                                $baseData["2084668368544769_1"] ?? "0", //14采区+880m变电所（节点）备用电源 88d100
                                ""
                            ],
                            [
                                "88D101",
                                $baseData["2084668368346113_1"] ?? "0", //14采区+880m变电所备用电源 88d101 电压
                                $baseData["2084668370357249_1"] ?? "0", //14采区+880m变电所备用电源 88d101
                                ""
                            ],
                            [
                                "88D1-2",
                                "0", // 88D1-2
                                "0", // 88D1-2
                                ""
                            ],
                            [
                                "88D203",
                                $baseData["2046501470911489_1"] ?? "0", //880变电所_89G203_UB
                                $baseData["2046501470831617_1"] ?? "0", //880变电所_89G203_IA
                                $baseData["2046501470952449_1"] ?? "0", //880变电所_89G203_P
                            ],
                            [
                                "88D202",
                                $baseData["2046501471165441_1"] ?? "0", //880变电所_89G202_UB
                                $baseData["2046501471063041_1"] ?? "0", //880变电所_89G202_IA
                                $baseData["2046501471206401_1"] ?? "0", //880变电所_89G202_P
                            ],
                            [
                                "88D201",
                                $baseData["2046501471388673_1"] ?? "0", //880变电所_89G201_UB
                                $baseData["2046501471314945_1"] ?? "0", //880变电所_89G201_IA
                                $baseData["2046501471427585_1"] ?? "0", //880变电所_89G201_P
                            ],
                            [
                                "88D200",
                                $baseData["2046501471613953_1"] ?? "0", //880变电所_89G200_UB
                                $baseData["2046501471540225_1"] ?? "0", //880变电所_89G200_IA
                                $baseData["2046501471650817_1"] ?? "0", //880变电所_89G200_P
                            ],
                            [
                                "移变低压侧",
                                $baseData["2046501473385473_1"] ?? "0", //880变电所_2号移变低压侧_US
                                $baseData["2046501473235969_1"] ?? "0", //880变电所_2号移变低压侧_IA
                                ""
                            ],
                            [
                                "移变高压侧",
                                $baseData["2046501473055745_1"] ?? "0", //880变电所_2号移变高压侧_US
                                $baseData["2046501472912385_1"] ?? "0", //880变电所_2号移变高压侧_IA
                                ""
                            ],
                            [
                                "88Z-5",
                                $baseData["2046501472091137_1"] ?? "0", //880变电所_88Z_5_UCA
                                $baseData["2046501472128001_1"] ?? "0", //880变电所_88Z_5_IA
                                ""
                            ],
                            [
                                "88Z-4",
                                $baseData["2046501471917057_1"] ?? "0", //880变电所_88Z_4_UCA
                                $baseData["2046501471972353_1"] ?? "0", //880变电所_88Z_4_IA
                                ""
                            ],
                        ]
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 980变电所
     * */
    public function get980mpList() {

        $keys=[

            "2046501459383297_1", // 980变电所_5101_UB
            "2046501459299329_1", // 980变电所_5101_IA
            "2046501459422209_1", // 980变电所_5101_P
            "2046501459461121_1", // 980变电所_5101_Q
            "2046501459500033_1", // 980变电所_5101_COS

            "2046501459614721_1", // 980变电所_5102_UB
            "2046501459536897_1", // 980变电所_5102_IA
            "2046501459682305_1", // 980变电所_5102_P
            "2046501459721217_1", // 980变电所_5102_Q
            "2046501459760129_1", // 980变电所_5102_COS

            "2046501459872769_1", // 980变电所_5103_UB
            "2046501459796993_1", // 980变电所_5103_IA
            "2046501459909633_1", // 980变电所_5103_P
            "2046501459944449_1", // 980变电所_5103_Q
            "2046501459981313_1", // 980变电所_5103_COS

            "2046501460093953_1", // 980变电所_5104_UB
            "2046501460018177_1", // 980变电所_5104_IA
            "2046501460130817_1", // 980变电所_5104_P
            "2046501460163585_1", // 980变电所_5104_Q
            "2046501460202497_1", // 980变电所_5104_COS

            "2046501460315137_1", // 980变电所_5105_UB
            "2046501460239361_1", // 980变电所_5105_IA
            "2046501460352001_1", // 980变电所_5105_P
            "2046501460390913_1", // 980变电所_5105_Q
            "2046501460425729_1", // 980变电所_5105_COS

            "2046501460542465_1", // 980变电所_5106_UB
            "2046501460464641_1", // 980变电所_5106_IA
            "2046501460579329_1", // 980变电所_5106_P
            "2046501460616193_1", // 980变电所_5106_Q
            "2046501460655105_1", // 980变电所_5106_COS

            "2046501460767745_1", // 980变电所_5107_UB
            "2046501460694017_1", // 980变电所_5107_IA
            "2046501460804609_1", // 980变电所_5107_P
            "2046501460841473_1", // 980变电所_5107_Q
            "2046501460884481_1", // 980变电所_5107_COS

            "2046501461003265_1", // 980变电所_5108_UB
            "2046501460925441_1", // 980变电所_5108_IA
            "2046501461042177_1", // 980变电所_5108_P
            "2046501461103617_1", // 980变电所_5108_Q
            "2046501461142529_1", // 980变电所_5108_COS

            "2046501461261313_1", // 980变电所_51_2_UB
            "2046501461181441_1", // 980变电所_51_2_IA
            "2046501461304321_1", // 980变电所_51_2_P
            "2046501461343233_1", // 980变电所_51_2_Q
            "2046501461384193_1", // 980变电所_51_2_COS

            "2046501461507073_1", // 980变电所_5206_UB
            "2046501461427201_1", // 980变电所_5206_IA
            "2046501461560321_1", // 980变电所_5206_P
            "2046501461656577_1", // 980变电所_5206_Q
            "2046501461785601_1", // 980变电所_5206_COS

            "2046501461943297_1", // 980变电所_5205_UB
            "2046501461832705_1", // 980变电所_5205_IA
            "2046501461988353_1", // 980变电所_5205_P
            "2046501462031361_1", // 980变电所_5205_Q
            "2046501462074369_1", // 980变电所_5205_COS

            "2046501462193153_1", // 980变电所_5204_UB
            "2046501462115329_1", // 980变电所_5204_IA
            "2046501462232065_1", // 980变电所_5204_P
            "2046501462273025_1", // 980变电所_5204_Q
            "2046501462311937_1", // 980变电所_5204_COS

            "2046501462434817_1", // 980变电所_5203_UB
            "2046501462348801_1", // 980变电所_5203_IA
            "2046501462471681_1", // 980变电所_5203_P
            "2046501462508545_1", // 980变电所_5203_Q
            "2046501462545409_1", // 980变电所_5203_COS

            "2046501462653953_1", // 980变电所_5202_UB
            "2046501462584321_1", // 980变电所_5202_IA
            "2046501462688769_1", // 980变电所_5202_P
            "2046501462727681_1", // 980变电所_5202_Q
            "2046501462762497_1", // 980变电所_5202_COS

            "2046501462875137_1", // 980变电所_5201_UB
            "2046501462803457_1", // 980变电所_5201_IA
            "2046501462912001_1", // 980变电所_5201_P
            "2046501462950913_1", // 980变电所_5201_Q
            "2046501462989825_1", // 980变电所_5201_COS

            "2046501463346177_1", // 980变电所_5207_UB
            "2046501463266305_1", // 980变电所_5207_IA
            "2046501463383041_1", // 980变电所_5207_P
            "2046501463421953_1", // 980变电所_5207_Q
            "2046501463458817_1", // 980变电所_5207_COS

            "2046501463110657_1", // 980变电所_5208_UB
            "2046501463026689_1", // 980变电所_5208_IA
            "2046501463151617_1", // 980变电所_5208_P
            "2046501463190529_1", // 980变电所_5208_Q
            "2046501463229441_1", // 980变电所_5208_COS

            "2046501466762241_1", // 980变电所_80F000_UX
            "2046501466684417_1", // 980变电所_80F000_IA

            "2046501466940417_1", // 980变电所_80F001_US
            "2046501466797057_1", // 980变电所_80F001_IA

            "2046501467268097_1", // 980变电所_80F002_US
            "2046501467120641_1", // 980变电所_80F002_IA

            "2046501467616257_1", // 980变电所_80F003_US
            "2046501467462657_1", // 980变电所_80F003_IA

            "2046501467986945_1", // 980变电所_80F004_US
            "2046501467827201_1", // 980变电所_80F004_IA

            "2046501468189697_1", // 980变电所_80F005_UCA
            "2046501468230657_1", // 980变电所_80F005_IA

            "2046501468308481_1", // 980变电所_80F006_UCA
            "2046501468347393_1", // 980变电所_80F006_IA

            "2046501468423169_1", // 980变电所_80F007_UCA
            "2046501468457985_1", // 980变电所_80F007_IA

            "2046501464728577_1", // 980变电所_80D200_UX
            "2046501464650753_1", // 980变电所_80D200_IA

            "2046501464923137_1", // 980变电所_80D201_US
            "2046501464765441_1", // 980变电所_80D201_IA

            "2046501465261057_1", // 980变电所_80D202_US
            "2046501465109505_1", // 980变电所_80D202_IA

            "2046501465607169_1", // 980变电所_80D203_US
            "2046501465451521_1", // 980变电所_80D203_IA

            "2046501465865217_1", // 980变电所_80D204_UCA
            "2046501465902081_1", // 980变电所_80D204_IA

            "2046501465973761_1", // 980变电所_80D205_UCA
            "2046501466012673_1", // 980变电所_80D205_IA

            "2046501466084353_1", // 980变电所_80D206_UCA
            "2046501466123265_1", // 980变电所_80D206_IA

            "2046501466201089_1", // 980变电所_80D207_UCA
            "2046501466237953_1", // 980变电所_80D207_IA

            "2046501466475521_1", // 980变电所_80D208_US
            "2046501466315777_1", // 980变电所_80D208_IA

            "2046501464400897_1", // 980变电所_80Z004_UAB
            "2046501464534017_1", // 980变电所_80Z004照明回路_IA

            "2046501468546049_1", // 980变电所_80Z001_UAB
            "2046501468656641_1", // 980变电所_80Z001照明回路_IA

            "2046501463954433_1", // 980变电所_80Z002_UAB
            "2046501464071169_1", // 980变电所_80Z002照明回路_IA

            "2046501463841793_1", // 980变电所_80D103_UCA
            "2046501463882753_1", // 980变电所_80D103_IA

            "2046501463720961_1", // 980变电所_80D102_UCA
            "2046501463763969_1", // 980变电所_80D102_IA

            "2046501463610369_1", // 980变电所_80D101_UCA
            "2046501463647233_1", // 980变电所_80D101_IA

            "2046501463499777_1", // 980变电所_80D100_UCA
            "2046501463536641_1", // 980变电所_80D100_IA

            "2046459479352321_2", // 980变电所_5101_开关
            "2046459479888897_2", // 980变电所_5102_开关
            "2046459480421377_2", // 980变电所_5103_开关
            "2046459480962049_2", // 980变电所_5104_开关
            "2046459481515009_2", // 980变电所_5105_开关
            "2046459482057729_2", // 980变电所_5106_开关
            "2046459482625025_2", // 980变电所_5107_开关
            "2046459483202561_2", // 980变电所_5108_开关
            "2046459483763713_2", // 980变电所_51-2_开关 // 5001
            "2046459484296193_2", // 980变电所_5206_开关
            "2046459484832769_2", // 980变电所_5205_开关
            "2046459485414401_2", // 980变电所_5204_开关
            "2046459485983745_2", // 980变电所_5203_开关
            "2046459486561281_2", // 980变电所_5202_开关
            "2046459487110145_2", // 980变电所_5201_开关
            "2046459488361473_2", // 980变电所_5207_开关
            "2046459487796225_2", // 980变电所_5208_开关
            "2046459491273729_2", // 980变电所_80F000_开关合位
            "2046459491609601_2", // 980变电所_80F001_开关合位
            "2046459491808257_2", // 980变电所_80F002_开关合位
            "2046459492000769_2", // 980变电所_80F003_开关合位
            "2046459492191233_2", // 980变电所_80F004_开关合位
            "2046459492350977_2", // 980变电所_80F005_开关合位
            "2046459492377601_2", // 980变电所_80F006_开关合位
            "2046459492404225_2", // 980变电所_80F007_开关合位
            "2046459490012161_2", // 980变电所_80D200_开关合位
            "2046459490335745_2", // 980变电所_80D201_开关合位
            "2046459490528257_2", // 980变电所_80D202_开关合位
            "2046459490720769_2", // 980变电所_80D203_开关合位
            "2046459490905089_2", // 980变电所_80D204_开关合位
            "2046459490933761_2", // 980变电所_80D205_开关合位
            "2046459490960385_2", // 980变电所_80D206_开关合位
            "2046459490989057_2", // 980变电所_80D207_开关合位
            "2046459491050497_2", // 980变电所_80D208_开关合位
            "2046459489676289_2", // 980变电所_80Z004_开关合位
            "2046459492455425_2", // 980变电所_80Z001_开关合位
            "2046459488971777_2", // 980变电所_80Z002_开关合位

            "2046459488916481_2", // 980变电所_80D103_开关合位
            "2046459488889857_2", // 980变电所_80D102_开关合位
            "2046459488865281_2", // 980变电所_80D101_开关合位
            "2046459488838657_2", // 980变电所_80D100_开关合位

//            "2046459489315841_2", // 980变电所_80Z003_开关合位
//            "2047031548824577_2", // 980变电所_80Z103_开关合位
//            "2048144456528897_2", // 980变电所_80Z102_开关合位
//            "2053367761536001_2", // 980变电所_80Z101_开关合位
//            "2047361299475457_2", // 980变电所_80Z100_开关合位

        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "tip"=>[
                [
                    "color"=>"#00FF00",
                    "text"=>"关"
                ],
                [
                    "color"=>"#FF0000",
                    "text"=>"开"
                ],
            ],
            "state"=>[
                $baseData["2046459479352321_2"] ?? "0", // 980变电所_5101_开关
                $baseData["2046459479888897_2"] ?? "0", // 980变电所_5102_开关
                $baseData["2046459480421377_2"] ?? "0", // 980变电所_5103_开关
                $baseData["2046459480962049_2"] ?? "0", // 980变电所_5104_开关
                $baseData["2046459481515009_2"] ?? "0", // 980变电所_5105_开关
                $baseData["2046459482057729_2"] ?? "0", // 980变电所_5106_开关
                $baseData["2046459482625025_2"] ?? "0", // 980变电所_5107_开关
                $baseData["2046459483202561_2"] ?? "0", // 980变电所_5108_开关

                $baseData["2046459483763713_2"] ?? "0", // 980变电所_51-2_开关 // 5001

                $baseData["2046459484296193_2"] ?? "0", // 980变电所_5206_开关
                $baseData["2046459484832769_2"] ?? "0", // 980变电所_5205_开关
                $baseData["2046459485414401_2"] ?? "0", // 980变电所_5204_开关
                $baseData["2046459485983745_2"] ?? "0", // 980变电所_5203_开关
                $baseData["2046459486561281_2"] ?? "0", // 980变电所_5202_开关
                $baseData["2046459487110145_2"] ?? "0", // 980变电所_5201_开关

                $baseData["2046459487796225_2"] ?? "0", // 980变电所_5208_开关
                $baseData["2046459488361473_2"] ?? "0", // 980变电所_5207_开关

                $baseData["2046459491273729_2"] ?? "0", // 980变电所_80F000_开关合位
                $baseData["2046459491609601_2"] ?? "0", // 980变电所_80F001_开关合位
                $baseData["2046459491808257_2"] ?? "0", // 980变电所_80F002_开关合位
                $baseData["2046459492000769_2"] ?? "0", // 980变电所_80F003_开关合位
                $baseData["2046459492191233_2"] ?? "0", // 980变电所_80F004_开关合位
                $baseData["2046459492350977_2"] ?? "0", // 980变电所_80F005_开关合位
                $baseData["2046459492377601_2"] ?? "0", // 980变电所_80F006_开关合位
                $baseData["2046459492404225_2"] ?? "0", // 980变电所_80F007_开关合位

                $baseData["2046459490012161_2"] ?? "0", // 980变电所_80D200_开关合位
                $baseData["2046459490335745_2"] ?? "0", // 980变电所_80D201_开关合位
                $baseData["2046459490528257_2"] ?? "0", // 980变电所_80D202_开关合位
                $baseData["2046459490720769_2"] ?? "0", // 980变电所_80D203_开关合位
                $baseData["2046459490905089_2"] ?? "0", // 980变电所_80D204_开关合位
                $baseData["2046459490933761_2"] ?? "0", // 980变电所_80D205_开关合位
                $baseData["2046459490960385_2"] ?? "0", // 980变电所_80D206_开关合位
                $baseData["2046459490989057_2"] ?? "0", // 980变电所_80D207_开关合位
                $baseData["2046459491050497_2"] ?? "0", // 980变电所_80D208_开关合位

                $baseData["2046459489676289_2"] ?? "0", // 980变电所_80Z004_开关合位
                $baseData["2046459492455425_2"] ?? "0", // 980变电所_80Z001_开关合位
                $baseData["2046459488971777_2"] ?? "0", // 980变电所_80Z002_开关合位

                $baseData["2046459488916481_2"] ?? "0", // 980变电所_80D103_开关合位
                $baseData["2046459488889857_2"] ?? "0", // 980变电所_80D102_开关合位
                $baseData["2046459488865281_2"] ?? "0", // 980变电所_80D101_开关合位
                $baseData["2046459488838657_2"] ?? "0", // 980变电所_80D100_开关合位

//                $baseData["2046459489315841_2"] ?? "0", // 980变电所_80Z003_开关合位
//
//                $baseData["2047031548824577_2"] ?? "0", // 980变电所_80Z103_开关合位
//                $baseData["2048144456528897_2"] ?? "0", // 980变电所_80Z102_开关合位
//                $baseData["2053367761536001_2"] ?? "0", // 980变电所_80Z101_开关合位
//                $baseData["2047361299475457_2"] ?? "0", // 980变电所_80Z100_开关合位
            ],
            "table_data"=>[
                [
                    "title"=>"880变电所变接线1",
                    "table"=>[
                        "thead"=>["名称", "Uab", "Ia", "P", "Q", "Cos"] ?? "0",
                        "tbody"=>[
                            [
                                "5101",
                                $baseData["2046501459383297_1"] ?? "0", // 980变电所_5101_UB
                                $baseData["2046501459299329_1"] ?? "0", // 980变电所_5101_IA
                                $baseData["2046501459422209_1"] ?? "0", // 980变电所_5101_P
                                $baseData["2046501459461121_1"] ?? "0", // 980变电所_5101_Q
                                $baseData["2046501459500033_1"] ?? "0", // 980变电所_5101_COS
                            ],
                            [
                                "5102",
                                $baseData["2046501459614721_1"] ?? "0", // 980变电所_5102_UB
                                $baseData["2046501459536897_1"] ?? "0", // 980变电所_5102_IA
                                $baseData["2046501459682305_1"] ?? "0", // 980变电所_5102_P
                                $baseData["2046501459721217_1"] ?? "0", // 980变电所_5102_Q
                                $baseData["2046501459760129_1"] ?? "0", // 980变电所_5102_COS
                            ],
                            [
                                "5103",
                                $baseData["2046501459872769_1"] ?? "0", // 980变电所_5103_UB
                                $baseData["2046501459796993_1"] ?? "0", // 980变电所_5103_IA
                                $baseData["2046501459909633_1"] ?? "0", // 980变电所_5103_P
                                $baseData["2046501459944449_1"] ?? "0", // 980变电所_5103_Q
                                $baseData["2046501459981313_1"] ?? "0", // 980变电所_5103_COS
                            ],
                            [
                                "5104",
                                $baseData["2046501460093953_1"] ?? "0", // 980变电所_5104_UB
                                $baseData["2046501460018177_1"] ?? "0", // 980变电所_5104_IA
                                $baseData["2046501460130817_1"] ?? "0", // 980变电所_5104_P
                                $baseData["2046501460163585_1"] ?? "0", // 980变电所_5104_Q
                                $baseData["2046501460202497_1"] ?? "0", // 980变电所_5104_COS
                            ],
                            [
                                "5105",
                                $baseData["2046501460315137_1"] ?? "0", // 980变电所_5105_UB
                                $baseData["2046501460239361_1"] ?? "0", // 980变电所_5105_IA
                                $baseData["2046501460352001_1"] ?? "0", // 980变电所_5105_P
                                $baseData["2046501460390913_1"] ?? "0", // 980变电所_5105_Q
                                $baseData["2046501460425729_1"] ?? "0", // 980变电所_5105_COS
                            ],
                            [
                                "5106",
                                $baseData["2046501460542465_1"] ?? "0", // 980变电所_5106_UB
                                $baseData["2046501460464641_1"] ?? "0", // 980变电所_5106_IA
                                $baseData["2046501460579329_1"] ?? "0", // 980变电所_5106_P
                                $baseData["2046501460616193_1"] ?? "0", // 980变电所_5106_Q
                                $baseData["2046501460655105_1"] ?? "0", // 980变电所_5106_COS
                            ],
                            [
                                "5107",
                                $baseData["2046501460767745_1"] ?? "0", // 980变电所_5107_UB
                                $baseData["2046501460694017_1"] ?? "0", // 980变电所_5107_IA
                                $baseData["2046501460804609_1"] ?? "0", // 980变电所_5107_P
                                $baseData["2046501460841473_1"] ?? "0", // 980变电所_5107_Q
                                $baseData["2046501460884481_1"] ?? "0", // 980变电所_5107_COS
                            ],
                            [
                                "5108",
                                $baseData["2046501461003265_1"] ?? "0", // 980变电所_5108_UB
                                $baseData["2046501460925441_1"] ?? "0", // 980变电所_5108_IA
                                $baseData["2046501461042177_1"] ?? "0", // 980变电所_5108_P
                                $baseData["2046501461103617_1"] ?? "0", // 980变电所_5108_Q
                                $baseData["2046501461142529_1"] ?? "0", // 980变电所_5108_COS
                            ],
                            [
// 5001
                                "5001",
                                $baseData["2046501461261313_1"] ?? "0", // 980变电所_51_2_UB
                                $baseData["2046501461181441_1"] ?? "0", // 980变电所_51_2_IA
                                $baseData["2046501461304321_1"] ?? "0", // 980变电所_51_2_P
                                $baseData["2046501461343233_1"] ?? "0", // 980变电所_51_2_Q
                                $baseData["2046501461384193_1"] ?? "0", // 980变电所_51_2_COS
                            ],
                            [
                                "5206",
                                $baseData["2046501461507073_1"] ?? "0", // 980变电所_5206_UB
                                $baseData["2046501461427201_1"] ?? "0", // 980变电所_5206_IA
                                $baseData["2046501461560321_1"] ?? "0", // 980变电所_5206_P
                                $baseData["2046501461656577_1"] ?? "0", // 980变电所_5206_Q
                                $baseData["2046501461785601_1"] ?? "0", // 980变电所_5206_COS
                            ],
                            [
                                "5205",
                                $baseData["2046501461943297_1"] ?? "0", // 980变电所_5205_UB
                                $baseData["2046501461832705_1"] ?? "0", // 980变电所_5205_IA
                                $baseData["2046501461988353_1"] ?? "0", // 980变电所_5205_P
                                $baseData["2046501462031361_1"] ?? "0", // 980变电所_5205_Q
                                $baseData["2046501462074369_1"] ?? "0", // 980变电所_5205_COS
                            ],
                            [
                                "5204",
                                $baseData["2046501462193153_1"] ?? "0", // 980变电所_5204_UB
                                $baseData["2046501462115329_1"] ?? "0", // 980变电所_5204_IA
                                $baseData["2046501462232065_1"] ?? "0", // 980变电所_5204_P
                                $baseData["2046501462273025_1"] ?? "0", // 980变电所_5204_Q
                                $baseData["2046501462311937_1"] ?? "0", // 980变电所_5204_COS
                            ],
                            [
                                "5203",
                                $baseData["2046501462434817_1"] ?? "0", // 980变电所_5203_UB
                                $baseData["2046501462348801_1"] ?? "0", // 980变电所_5203_IA
                                $baseData["2046501462471681_1"] ?? "0", // 980变电所_5203_P
                                $baseData["2046501462508545_1"] ?? "0", // 980变电所_5203_Q
                                $baseData["2046501462545409_1"] ?? "0", // 980变电所_5203_COS
                            ],
                            [
                                "5202",
                                $baseData["2046501462653953_1"] ?? "0", // 980变电所_5202_UB
                                $baseData["2046501462584321_1"] ?? "0", // 980变电所_5202_IA
                                $baseData["2046501462688769_1"] ?? "0", // 980变电所_5202_P
                                $baseData["2046501462727681_1"] ?? "0", // 980变电所_5202_Q
                                $baseData["2046501462762497_1"] ?? "0", // 980变电所_5202_COS
                            ],
                            [
                                "5201",
                                $baseData["2046501462875137_1"] ?? "0", // 980变电所_5201_UB
                                $baseData["2046501462803457_1"] ?? "0", // 980变电所_5201_IA
                                $baseData["2046501462912001_1"] ?? "0", // 980变电所_5201_P
                                $baseData["2046501462950913_1"] ?? "0", // 980变电所_5201_Q
                                $baseData["2046501462989825_1"] ?? "0", // 980变电所_5201_COS
                            ],
                            [
                                "8208",
                                $baseData["2046501463346177_1"] ?? "0", // 980变电所_5207_UB
                                $baseData["2046501463266305_1"] ?? "0", // 980变电所_5207_IA
                                $baseData["2046501463383041_1"] ?? "0", // 980变电所_5207_P
                                $baseData["2046501463421953_1"] ?? "0", // 980变电所_5207_Q
                                $baseData["2046501463458817_1"] ?? "0", // 980变电所_5207_COS
                            ],
                            [
                                "8207",
                                $baseData["2046501463110657_1"] ?? "0", // 980变电所_5208_UB
                                $baseData["2046501463026689_1"] ?? "0", // 980变电所_5208_IA
                                $baseData["2046501463151617_1"] ?? "0", // 980变电所_5208_P
                                $baseData["2046501463190529_1"] ?? "0", // 980变电所_5208_Q
                                $baseData["2046501463229441_1"] ?? "0", // 980变电所_5208_COS
                            ],
                        ],
                    ]
                ],
                [
                    "title"=>"880变电所变接线2",
                    "table"=>[
                        "thead"=>["名称", "Uab", "Ia"] ?? "0",
                        "tbody"=>[
                            [
                                "80F000",
                                $baseData["2046501466762241_1"] ?? "0", // 980变电所_80F000_UX
                                $baseData["2046501466684417_1"] ?? "0", // 980变电所_80F000_IA
                            ],
                            [
                                "80F001",
                                $baseData["2046501466940417_1"] ?? "0", // 980变电所_80F001_US
                                $baseData["2046501466797057_1"] ?? "0", // 980变电所_80F001_IA
                            ],
                            [
                                "80F002",
                                $baseData["2046501467268097_1"] ?? "0", // 980变电所_80F002_US
                                $baseData["2046501467120641_1"] ?? "0", // 980变电所_80F002_IA
                            ],
                            [
                                "80F003",
                                $baseData["2046501467616257_1"] ?? "0", // 980变电所_80F003_US
                                $baseData["2046501467462657_1"] ?? "0", // 980变电所_80F003_IA
                            ],
                            [
                                "80F004",
                                $baseData["2046501467986945_1"] ?? "0", // 980变电所_80F004_US
                                $baseData["2046501467827201_1"] ?? "0", // 980变电所_80F004_IA
                            ],
                            [
                                "80F005",
                                $baseData["2046501468189697_1"] ?? "0", // 980变电所_80F005_UCA
                                $baseData["2046501468230657_1"] ?? "0", // 980变电所_80F005_IA
                            ],
                            [
                                "80F006",
                                $baseData["2046501468308481_1"] ?? "0", // 980变电所_80F006_UCA
                                $baseData["2046501468347393_1"] ?? "0", // 980变电所_80F006_IA
                            ],
                            [
                                "80F007",
                                $baseData["2046501468423169_1"] ?? "0", // 980变电所_80F007_UCA
                                $baseData["2046501468457985_1"] ?? "0", // 980变电所_80F007_IA
                            ],
                            [
                                "80F200",
                                $baseData["2046501464728577_1"] ?? "0", // 980变电所_80D200_UX
                                $baseData["2046501464650753_1"] ?? "0", // 980变电所_80D200_IA
                            ],
                            [
                                "80F201",
                                $baseData["2046501464923137_1"] ?? "0", // 980变电所_80D201_US
                                $baseData["2046501464765441_1"] ?? "0", // 980变电所_80D201_IA
                            ],
                            [
                                "80F202",
                                $baseData["2046501465261057_1"] ?? "0", // 980变电所_80D202_US
                                $baseData["2046501465109505_1"] ?? "0", // 980变电所_80D202_IA
                            ],
                            [
                                "80F203",
                                $baseData["2046501465607169_1"] ?? "0", // 980变电所_80D203_US
                                $baseData["2046501465451521_1"] ?? "0", // 980变电所_80D203_IA
                            ],
                            [
                                "80F204",
                                $baseData["2046501465865217_1"] ?? "0", // 980变电所_80D204_UCA
                                $baseData["2046501465902081_1"] ?? "0", // 980变电所_80D204_IA
                            ],
                            [
                                "80F205",
                                $baseData["2046501465973761_1"] ?? "0", // 980变电所_80D205_UCA
                                $baseData["2046501466012673_1"] ?? "0", // 980变电所_80D205_IA
                            ],
                            [
                                "80F206",
                                $baseData["2046501466084353_1"] ?? "0", // 980变电所_80D206_UCA
                                $baseData["2046501466123265_1"] ?? "0", // 980变电所_80D206_IA
                            ],
                            [
                                "80F207",
                                $baseData["2046501466201089_1"] ?? "0", // 980变电所_80D207_UCA
                                $baseData["2046501466237953_1"] ?? "0", // 980变电所_80D207_IA
                            ],
                            [
                                "80F208",
                                $baseData["2046501466475521_1"] ?? "0", // 980变电所_80D208_US
                                $baseData["2046501466315777_1"] ?? "0", // 980变电所_80D208_IA
                            ],
                            [
                                "80Z004",
                                $baseData["2046501464400897_1"] ?? "0", // 980变电所_80Z004_UAB
                                $baseData["2046501464534017_1"] ?? "0", // 980变电所_80Z004照明回路_IA
                            ],
                            [
                                "80Z101",
                                $baseData["2046501468546049_1"] ?? "0", // 980变电所_80Z001_UAB
                                $baseData["2046501468656641_1"] ?? "0", // 980变电所_80Z001照明回路_IA
                            ],
                            [
                                "80Z102",
                                $baseData["2046501463954433_1"] ?? "0", // 980变电所_80Z002_UAB
                                $baseData["2046501464071169_1"] ?? "0", // 980变电所_80Z002照明回路_IA
                            ],
                            [
                                "80Z103",
                                $baseData["2046501463841793_1"] ?? "0", // 980变电所_80D103_UCA
                                $baseData["2046501463882753_1"] ?? "0", // 980变电所_80D103_IA
                            ],
                            [
                                "80D102",
                                $baseData["2046501463720961_1"] ?? "0", // 980变电所_80D102_UCA
                                $baseData["2046501463763969_1"] ?? "0", // 980变电所_80D102_IA
                            ],
                            [
                                "80D101",
                                $baseData["2046501463610369_1"] ?? "0", // 980变电所_80D101_UCA
                                $baseData["2046501463647233_1"] ?? "0", // 980变电所_80D101_IA
                            ],
                            [
                                "80D100",
                                $baseData["2046501463499777_1"] ?? "0", // 980变电所_80D100_UCA
                                $baseData["2046501463536641_1"] ?? "0", // 980变电所_80D100_IA
                            ]
                        ]
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }


    /*
     * 1142变电所
     * */
    public function get1142mpList() {

        $keys=[

            "2046501507884033_1", // 1142变电所_5101_UB
            "2046501507804161_1", // 1142变电所_5101_IA
            "2046501507920897_1", // 1142变电所_5101_P
            "2046501507959809_1", // 1142变电所_5101_Q
            "2046501507998721_1", // 1142变电所_5101_COS
            "2046501508117505_1", // 1142变电所_5102_UB
            "2046501508037633_1", // 1142变电所_5102_IA
            "2046501508156417_1", // 1142变电所_5102_P
            "2046501508203521_1", // 1142变电所_5102_Q
            "2046501508242433_1", // 1142变电所_5102_COS
            "2046501508359169_1", // 1142变电所_5103_UB
            "2046501508283393_1", // 1142变电所_5103_IA
            "2046501508402178_1", // 1142变电所_5103_P
            "2046501508463617_1", // 1142变电所_5103_Q
            "2046501508504577_1", // 1142变电所_5103_COS
            "2046501508633601_1", // 1142变电所_5104_UB
            "2046501508547585_1", // 1142变电所_5104_IA
            "2046501508674561_1", // 1142变电所_5104_P
            "2046501508725761_1", // 1142变电所_5104_Q
            "2046501508776961_1", // 1142变电所_5104_COS
            "2046501508905985_1", // 1142变电所_5105_UB
            "2046501508824065_1", // 1142变电所_5105_IA
            "2046501508942849_1", // 1142变电所_5105_P
            "2046501508981761_1", // 1142变电所_5105_Q
            "2046501509022721_1", // 1142变电所_5105_COS
            "2046501509149697_1", // 1142变电所_5106_UB
            "2046501509065729_1", // 1142变电所_5106_IA
            "2046501509192705_1", // 1142变电所_5106_P
            "2046501509229569_1", // 1142变电所_5106_Q
            "2046501509270529_1", // 1142变电所_5106_COS
            "2046501509383169_1", // 1142变电所_5107_UB
            "2046501509307393_1", // 1142变电所_5107_IA
            "2046501509426177_1", // 1142变电所_5107_P
            "2046501509465089_1", // 1142变电所_5107_Q
            "2046501509506049_1", // 1142变电所_5107_COS
            "2046501509622785_1", // 1142变电所_5001_UB
            "2046501509544961_1", // 1142变电所_5001_IA
            "2046501509661697_1", // 1142变电所_5001_P
            "2046501509700609_1", // 1142变电所_5001_Q
            "2046501509739521_1", // 1142变电所_5001_COS
            "2046501510075393_1", // 1142变电所_5207_UB
            "2046501509997569_1", // 1142变电所_5207_IA
            "2046501510114305_1", // 1142变电所_5207_P
            "2046501510153217_1", // 1142变电所_5207_Q
            "2046501510194177_1", // 1142变电所_5207_COS
            "2046501510339585_1", // 1142变电所_5206_UB
            "2046501510253569_1", // 1142变电所_5206_IA
            "2046501510376449_1", // 1142变电所_5206_P
            "2046501510415361_1", // 1142变电所_5206_Q
            "2046501510452225_1", // 1142变电所_5206_COS
            "2046501510562817_1", // 1142变电所_5205_UB
            "2046501510487041_1", // 1142变电所_5205_IA
            "2046501510599681_1", // 1142变电所_5205_P
            "2046501510640641_1", // 1142变电所_5205_Q
            "2046501510681601_1", // 1142变电所_5205_COS
            "2046501510937601_1", // 1142变电所_5204_UB
            "2046501510718465_1", // 1142变电所_5204_IA
            "2046501510980609_1", // 1142变电所_5204_P
            "2046501511015425_1", // 1142变电所_5204_Q
            "2046501511054337_1", // 1142变电所_5204_COS
            "2046501511169025_1", // 1142变电所_5203_UB
            "2046501511093249_1", // 1142变电所_5203_IA
            "2046501511207937_1", // 1142变电所_5203_P
            "2046501511244801_1", // 1142变电所_5203_Q
            "2046501511281665_1", // 1142变电所_5203_COS
            "2046501511402497_1", // 1142变电所_5202_UB
            "2046501511320577_1", // 1142变电所_5202_IA
            "2046501511443457_1", // 1142变电所_5202_P
            "2046501511480321_1", // 1142变电所_5202_Q
            "2046501511519233_1", // 1142变电所_5202_COS
            "2046501511627777_1", // 1142变电所_5201_UB
            "2046501511554049_1", // 1142变电所_5201_IA
            "2046501511664641_1", // 1142变电所_5201_P
            "2046501511703553_1", // 1142变电所_5201_Q
            "2046501511738369_1", // 1142变电所_5201_COS

            "2046501509850113_1", // 1142变电所_5003_UB
            "2046501509776385_1", // 1142变电所_5003_IA
            "2046501509889025_1", // 1142变电所_5003_P
            "2046501509925889_1", // 1142变电所_5003_Q
            "2046501509960705_1", // 1142变电所_5003_COS

            "2046501516555265_1", // 1142变电所_42D103_UB
            "2046501516438529_1", // 1142变电所_42D103_IA
            "2046501516633089_1", // 1142变电所_42D103_P
            "2046501516174337_1", // 1142变电所_42D104_UB
            "2046501516059649_1", // 1142变电所_42D104_IA
            "2046501516252161_1", // 1142变电所_42D104_P
            "2046501517865985_1", // 1142变电所_42DZ003_UB
            "2046501517743105_1", // 1142变电所_42DZ003_IA
            "2046501517947905_1", // 1142变电所_42DZ003_P
            "2046501517552641_1", // 1142变电所_42DZ002_UB
            "2046501517437953_1", // 1142变电所_42DZ002_IA
            "2046501517632513_1", // 1142变电所_42DZ002_P
            "2046501517251585_1", // 1142变电所_42DZ001_UB
            "2046501517132801_1", // 1142变电所_42DZ001_IA
            "2046501517329409_1", // 1142变电所_42DZ001_P
            "2046501515803649_1", // 1142变电所_42D205_UB
            "2046501515684865_1", // 1142变电所_42D205_IA
            "2046501515891713_1", // 1142变电所_42D205_P
            "2046501515445249_1", // 1142变电所_42D204_UB
            "2046501515314177_1", // 1142变电所_42D204_IA
            "2046501515525121_1", // 1142变电所_42D204_P
            "2046501515064321_1", // 1142变电所_42D203_UB
            "2046501514939393_1", // 1142变电所_42D203_IA
            "2046501515152385_1", // 1142变电所_42D203_P
            "2046501514693633_1", // 1142变电所_42D200_UB
            "2046501514572801_1", // 1142变电所_42D200_IA
            "2046501514775553_1", // 1142变电所_42D200_P
            "2046501514331137_1", // 1142变电所_42F100_UB
            "2046501514202113_1", // 1142变电所_42F100_IA
            "2046501514408961_1", // 1142变电所_42F100_P
            "2046501513878529_1", // 1142变电所_42F102_UB
            "2046501513757697_1", // 1142变电所_42F102_IA
            "2046501513978881_1", // 1142变电所_42F102_P
            "2046501513511937_1", // 1142变电所_42F103_UB
            "2046501513378817_1", // 1142变电所_42F103_IA
            "2046501513593857_1", // 1142变电所_42F103_P
            "2046501513147393_1", // 1142变电所_42F204_UB
            "2046501513026561_1", // 1142变电所_42F204_IA
            "2046501513231361_1", // 1142变电所_42F204_P
            "2046501512590337_1", // 1142变电所_42F203_UB
            "2046501512463361_1", // 1142变电所_42F203_IA
            "2046501512682497_1", // 1142变电所_42F203_P
            "2046501512213505_1", // 1142变电所_42F202_UB
            "2046501512104961_1", // 1142变电所_42F202_IA
            "2046501512289281_1", // 1142变电所_42F202_P
            "2046501511887873_1", // 1142变电所_42F200_UB
            "2046501511773185_1", // 1142变电所_42F200_IA
            "2046501511961601_1", // 1142变电所_42F200_P


            "2046459550059521_2", // 1142变电所_5101_开关
            "2046459550602241_2", // 1142变电所_5102_开关
            "2046459551210497_2", // 1142变电所_5103_开关
            "2046459551757313_2", // 1142变电所_5104_开关
            "2046459552310273_2", // 1142变电所_5105_开关
            "2046459552867329_2", // 1142变电所_5106_开关
            "2046459553440769_2", // 1142变电所_5107_开关
            "2046459554018305_2", // 1142变电所_5001_开关
            "2046459555156993_2", // 1142变电所_5207_开关
            "2046459555722241_2", // 1142变电所_5206_开关
            "2046459556267009_2", // 1142变电所_5205_开关
            "2046459556842497_2", // 1142变电所_5204_开关
            "2046459557393409_2", // 1142变电所_5203_开关
            "2046459557927937_2", // 1142变电所_5202_开关
            "2046459558478849_2", // 1142变电所_5201_开关
            "2047202099887105_2", // 4101
            "2046459561274369_2", // 1142变电所_42D103_开关合位
            "2046459561081857_2", // 1142变电所_42D104_开关合位
            "2046459561851905_2", // 1142变电所_42DZ003_开关合位
            "2046459561776129_2", // 1142变电所_42DZ002_开关合位
            "2046459561700353_2", // 1142变电所_42DZ001_开关合位
            "2046459560901633_2", // 1142变电所_42D205_开关合位
            "2046459560719361_2", // 1142变电所_42D204_开关合位
            "2046459560539137_2", // 1142变电所_42D203_开关合位
            "2046459560330241_2", // 1142变电所_42D200_开关合位
            "2046459560152065_2", // 1142变电所_42F100_开关合位
            "2046459559963649_2", // 1142变电所_42F102_开关合位
            "2046459559779329_2", // 1142变电所_42F103_开关合位
            "2046459559590913_2", // 1142变电所_42F204_开关合位
            "2046459559386113_2", // 1142变电所_42F203_开关合位
            "2046459559197697_2", // 1142变电所_42F202_开关合位
            "2046459558980609_2", // 1142变电所_42F200_开关合位
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "tip"=>[
                [
                    "color"=>"#00FF00",
                    "text"=>"关"
                ],
                [
                    "color"=>"#FF0000",
                    "text"=>"开"
                ],
            ],
            "state"=>[
                $baseData["2046459550059521_2"] ?? "0", // 1142变电所_5101_开关
                $baseData["2046459550602241_2"] ?? "0", // 1142变电所_5102_开关
                $baseData["2046459551210497_2"] ?? "0", // 1142变电所_5103_开关
                $baseData["2046459551757313_2"] ?? "0", // 1142变电所_5104_开关
                $baseData["2046459552310273_2"] ?? "0", // 1142变电所_5105_开关
                $baseData["2046459552867329_2"] ?? "0", // 1142变电所_5106_开关
                $baseData["2046459553440769_2"] ?? "0", // 1142变电所_5107_开关

                $baseData["2046459554018305_2"] ?? "0", // 1142变电所_5001_开关
                "0",

                $baseData["2046459555156993_2"] ?? "0", // 1142变电所_5207_开关
                $baseData["2046459555722241_2"] ?? "0", // 1142变电所_5206_开关
                $baseData["2046459556267009_2"] ?? "0", // 1142变电所_5205_开关
                $baseData["2046459556842497_2"] ?? "0", // 1142变电所_5204_开关
                $baseData["2046459557393409_2"] ?? "0", // 1142变电所_5203_开关
                $baseData["2046459557927937_2"] ?? "0", // 1142变电所_5202_开关
                $baseData["2046459558478849_2"] ?? "0", // 1142变电所_5201_开关

                $baseData["2047202099887105_2"] ?? "0", // 4101
                $baseData["2046459561274369_2"] ?? "0", // 1142变电所_42D103_开关合位
                $baseData["2046459561081857_2"] ?? "0", // 1142变电所_42D104_开关合位
                $baseData["2046459561851905_2"] ?? "0", // 1142变电所_42DZ003_开关合位
                $baseData["2046459561776129_2"] ?? "0", // 1142变电所_42DZ002_开关合位
                $baseData["2046459561700353_2"] ?? "0", // 1142变电所_42DZ001_开关合位
                $baseData["2046459560901633_2"] ?? "0", // 1142变电所_42D205_开关合位
                $baseData["2046459560719361_2"] ?? "0", // 1142变电所_42D204_开关合位
                $baseData["2046459560539137_2"] ?? "0", // 1142变电所_42D203_开关合位
                $baseData["2046459560330241_2"] ?? "0", // 1142变电所_42D200_开关合位

                $baseData["2046459560152065_2"] ?? "0", // 1142变电所_42F100_开关合位
                $baseData["2046459559963649_2"] ?? "0", // 1142变电所_42F102_开关合位
                $baseData["2046459559779329_2"] ?? "0", // 1142变电所_42F103_开关合位

                $baseData["2046459559590913_2"] ?? "0", // 1142变电所_42F204_开关合位
                $baseData["2046459559386113_2"] ?? "0", // 1142变电所_42F203_开关合位
                $baseData["2046459559197697_2"] ?? "0", // 1142变电所_42F202_开关合位
                $baseData["2046459558980609_2"] ?? "0", // 1142变电所_42F200_开关合位
            ],
            "table_data"=>[
                [
                    "title"=>"880变电所变接线1",
                    "table"=>[
                        "thead"=>["名称", "Uab", "Ia", "P", "Q", "Cos"] ?? "0",
                        "tbody"=>[
                            [
                                "5101",
                                $baseData["2046501507884033_1"] ?? "0", // 1142变电所_5101_UB
                                $baseData["2046501507804161_1"] ?? "0", // 1142变电所_5101_IA
                                $baseData["2046501507920897_1"] ?? "0", // 1142变电所_5101_P
                                $baseData["2046501507959809_1"] ?? "0", // 1142变电所_5101_Q
                                $baseData["2046501507998721_1"] ?? "0", // 1142变电所_5101_COS
                            ],
                            [
                                "5102",
                                $baseData["2046501508117505_1"] ?? "0", // 1142变电所_5102_UB
                                $baseData["2046501508037633_1"] ?? "0", // 1142变电所_5102_IA
                                $baseData["2046501508156417_1"] ?? "0", // 1142变电所_5102_P
                                $baseData["2046501508203521_1"] ?? "0", // 1142变电所_5102_Q
                                $baseData["2046501508242433_1"] ?? "0", // 1142变电所_5102_COS
                            ],[
                                "5103",
                                $baseData["2046501508359169_1"] ?? "0", // 1142变电所_5103_UB
                                $baseData["2046501508283393_1"] ?? "0", // 1142变电所_5103_IA
                                $baseData["2046501508402178_1"] ?? "0", // 1142变电所_5103_P
                                $baseData["2046501508463617_1"] ?? "0", // 1142变电所_5103_Q
                                $baseData["2046501508504577_1"] ?? "0", // 1142变电所_5103_COS
                            ],[
                                "5104",
                                $baseData["2046501508633601_1"] ?? "0", // 1142变电所_5104_UB
                                $baseData["2046501508547585_1"] ?? "0", // 1142变电所_5104_IA
                                $baseData["2046501508674561_1"] ?? "0", // 1142变电所_5104_P
                                $baseData["2046501508725761_1"] ?? "0", // 1142变电所_5104_Q
                                $baseData["2046501508776961_1"] ?? "0", // 1142变电所_5104_COS
                            ],[
                                "5105",
                                $baseData["2046501508905985_1"] ?? "0", // 1142变电所_5105_UB
                                $baseData["2046501508824065_1"] ?? "0", // 1142变电所_5105_IA
                                $baseData["2046501508942849_1"] ?? "0", // 1142变电所_5105_P
                                $baseData["2046501508981761_1"] ?? "0", // 1142变电所_5105_Q
                                $baseData["2046501509022721_1"] ?? "0", // 1142变电所_5105_COS
                            ],[
                                "5106",
                                $baseData["2046501509149697_1"] ?? "0", // 1142变电所_5106_UB
                                $baseData["2046501509065729_1"] ?? "0", // 1142变电所_5106_IA
                                $baseData["2046501509192705_1"] ?? "0", // 1142变电所_5106_P
                                $baseData["2046501509229569_1"] ?? "0", // 1142变电所_5106_Q
                                $baseData["2046501509270529_1"] ?? "0", // 1142变电所_5106_COS
                            ],[
                                "5107",
                                $baseData["2046501509383169_1"] ?? "0", // 1142变电所_5107_UB
                                $baseData["2046501509307393_1"] ?? "0", // 1142变电所_5107_IA
                                $baseData["2046501509426177_1"] ?? "0", // 1142变电所_5107_P
                                $baseData["2046501509465089_1"] ?? "0", // 1142变电所_5107_Q
                                $baseData["2046501509506049_1"] ?? "0", // 1142变电所_5107_COS
                            ],[
                                "5301",
                                $baseData["2046501509622785_1"] ?? "0", // 1142变电所_5001_UB
                                $baseData["2046501509544961_1"] ?? "0", // 1142变电所_5001_IA
                                $baseData["2046501509661697_1"] ?? "0", // 1142变电所_5001_P
                                $baseData["2046501509700609_1"] ?? "0", // 1142变电所_5001_Q
                                $baseData["2046501509739521_1"] ?? "0", // 1142变电所_5001_COS
                            ],[
                                "5207",
                                $baseData["2046501510075393_1"] ?? "0", // 1142变电所_5207_UB
                                $baseData["2046501509997569_1"] ?? "0", // 1142变电所_5207_IA
                                $baseData["2046501510114305_1"] ?? "0", // 1142变电所_5207_P
                                $baseData["2046501510153217_1"] ?? "0", // 1142变电所_5207_Q
                                $baseData["2046501510194177_1"] ?? "0", // 1142变电所_5207_COS
                            ],[
                                "5206",
                                $baseData["2046501510339585_1"] ?? "0", // 1142变电所_5206_UB
                                $baseData["2046501510253569_1"] ?? "0", // 1142变电所_5206_IA
                                $baseData["2046501510376449_1"] ?? "0", // 1142变电所_5206_P
                                $baseData["2046501510415361_1"] ?? "0", // 1142变电所_5206_Q
                                $baseData["2046501510452225_1"] ?? "0", // 1142变电所_5206_COS
                            ],[
                                "5205",
                                $baseData["2046501510562817_1"] ?? "0", // 1142变电所_5205_UB
                                $baseData["2046501510487041_1"] ?? "0", // 1142变电所_5205_IA
                                $baseData["2046501510599681_1"] ?? "0", // 1142变电所_5205_P
                                $baseData["2046501510640641_1"] ?? "0", // 1142变电所_5205_Q
                                $baseData["2046501510681601_1"] ?? "0", // 1142变电所_5205_COS
                            ],[
                                "5204",
                                $baseData["2046501510937601_1"] ?? "0", // 1142变电所_5204_UB
                                $baseData["2046501510718465_1"] ?? "0", // 1142变电所_5204_IA
                                $baseData["2046501510980609_1"] ?? "0", // 1142变电所_5204_P
                                $baseData["2046501511015425_1"] ?? "0", // 1142变电所_5204_Q
                                $baseData["2046501511054337_1"] ?? "0", // 1142变电所_5204_COS
                            ],[
                                "5203",
                                $baseData["2046501511169025_1"] ?? "0", // 1142变电所_5203_UB
                                $baseData["2046501511093249_1"] ?? "0", // 1142变电所_5203_IA
                                $baseData["2046501511207937_1"] ?? "0", // 1142变电所_5203_P
                                $baseData["2046501511244801_1"] ?? "0", // 1142变电所_5203_Q
                                $baseData["2046501511281665_1"] ?? "0", // 1142变电所_5203_COS
                            ],[
                                "5202",
                                $baseData["2046501511402497_1"] ?? "0", // 1142变电所_5202_UB
                                $baseData["2046501511320577_1"] ?? "0", // 1142变电所_5202_IA
                                $baseData["2046501511443457_1"] ?? "0", // 1142变电所_5202_P
                                $baseData["2046501511480321_1"] ?? "0", // 1142变电所_5202_Q
                                $baseData["2046501511519233_1"] ?? "0", // 1142变电所_5202_COS
                            ],[
                                "5201",
                                $baseData["2046501511627777_1"] ?? "0", // 1142变电所_5201_UB
                                $baseData["2046501511554049_1"] ?? "0", // 1142变电所_5201_IA
                                $baseData["2046501511664641_1"] ?? "0", // 1142变电所_5201_P
                                $baseData["2046501511703553_1"] ?? "0", // 1142变电所_5201_Q
                                $baseData["2046501511738369_1"] ?? "0", // 1142变电所_5201_COS
                            ]
                        ],
                    ]
                ],
                [
                    "title"=>"1142变电所变接线2",
                    "table"=>[
                        "thead"=>["名称", "Uab", "Ia","P"] ?? "0",
                        "tbody"=>[
                            [
                                "42D103",
                                $baseData["2046501516555265_1"] ?? "0", // 1142变电所_42D103_UB
                                $baseData["2046501516438529_1"] ?? "0", // 1142变电所_42D103_IA
                                $baseData["2046501516633089_1"] ?? "0", // 1142变电所_42D103_P
                            ],
                            [
                                "42D104",
                                $baseData["2046501516174337_1"] ?? "0", // 1142变电所_42D104_UB
                                $baseData["2046501516059649_1"] ?? "0", // 1142变电所_42D104_IA
                                $baseData["2046501516252161_1"] ?? "0", // 1142变电所_42D104_P
                            ],
                            [
                                "42DZ003",
                                $baseData["2046501517865985_1"] ?? "0", // 1142变电所_42DZ003_UB
                                $baseData["2046501517743105_1"] ?? "0", // 1142变电所_42DZ003_IA
                                $baseData["2046501517947905_1"] ?? "0", // 1142变电所_42DZ003_P
                            ],
                            [
                                "42DZ002",
                                $baseData["2046501517552641_1"] ?? "0", // 1142变电所_42DZ002_UB
                                $baseData["2046501517437953_1"] ?? "0", // 1142变电所_42DZ002_IA
                                $baseData["2046501517632513_1"] ?? "0", // 1142变电所_42DZ002_P
                            ],
                            [
                                "42DZ001",
                                $baseData["2046501517251585_1"] ?? "0", // 1142变电所_42DZ001_UB
                                $baseData["2046501517132801_1"] ?? "0", // 1142变电所_42DZ001_IA
                                $baseData["2046501517329409_1"] ?? "0", // 1142变电所_42DZ001_P
                            ],
                            [
                                "42D205",
                                $baseData["2046501515803649_1"] ?? "0", // 1142变电所_42D205_UB
                                $baseData["2046501515684865_1"] ?? "0", // 1142变电所_42D205_IA
                                $baseData["2046501515891713_1"] ?? "0", // 1142变电所_42D205_P
                            ],
                            [
                                "42D204",
                                $baseData["2046501515445249_1"] ?? "0", // 1142变电所_42D204_UB
                                $baseData["2046501515314177_1"] ?? "0", // 1142变电所_42D204_IA
                                $baseData["2046501515525121_1"] ?? "0", // 1142变电所_42D204_P
                            ],
                            [
                                "42D203",
                                $baseData["2046501515064321_1"] ?? "0", // 1142变电所_42D203_UB
                                $baseData["2046501514939393_1"] ?? "0", // 1142变电所_42D203_IA
                                $baseData["2046501515152385_1"] ?? "0", // 1142变电所_42D203_P
                            ],
                            [
                                "42D200",
                                $baseData["2046501514693633_1"] ?? "0", // 1142变电所_42D200_UB
                                $baseData["2046501514572801_1"] ?? "0", // 1142变电所_42D200_IA
                                $baseData["2046501514775553_1"] ?? "0", // 1142变电所_42D200_P
                            ],
                            [
                                "42F100",
                                $baseData["2046501514331137_1"] ?? "0", // 1142变电所_42F100_UB
                                $baseData["2046501514202113_1"] ?? "0", // 1142变电所_42F100_IA
                                $baseData["2046501514408961_1"] ?? "0", // 1142变电所_42F100_P
                            ],
                            [
                                "42F102",
                                $baseData["2046501513878529_1"] ?? "0", // 1142变电所_42F102_UB
                                $baseData["2046501513757697_1"] ?? "0", // 1142变电所_42F102_IA
                                $baseData["2046501513978881_1"] ?? "0", // 1142变电所_42F102_P
                            ],
                            [
                                "42F103",
                                $baseData["2046501513511937_1"] ?? "0", // 1142变电所_42F103_UB
                                $baseData["2046501513378817_1"] ?? "0", // 1142变电所_42F103_IA
                                $baseData["2046501513593857_1"] ?? "0", // 1142变电所_42F103_P
                            ],
                            [
                                "42F104",
                                $baseData["2046501513147393_1"] ?? "0", // 1142变电所_42F204_UB
                                $baseData["2046501513026561_1"] ?? "0", // 1142变电所_42F204_IA
                                $baseData["2046501513231361_1"] ?? "0", // 1142变电所_42F204_P
                            ],
                            [
                                "42F203",
                                $baseData["2046501512590337_1"] ?? "0", // 1142变电所_42F203_UB
                                $baseData["2046501512463361_1"] ?? "0", // 1142变电所_42F203_IA
                                $baseData["2046501512682497_1"] ?? "0", // 1142变电所_42F203_P
                            ],
                            [
                                "42F202",
                                $baseData["2046501512213505_1"] ?? "0", // 1142变电所_42F202_UB
                                $baseData["2046501512104961_1"] ?? "0", // 1142变电所_42F202_IA
                                $baseData["2046501512289281_1"] ?? "0", // 1142变电所_42F202_P
                            ],
                            [
                                "42F200",
                                $baseData["2046501511887873_1"] ?? "0", // 1142变电所_42F200_UB
                                $baseData["2046501511773185_1"] ?? "0", // 1142变电所_42F200_IA
                                $baseData["2046501511961601_1"] ?? "0", // 1142变电所_42F200_P
                            ]
                        ]
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }


    /*
     * 22采区变电所低压
     * 问题
     * */
    public function get22DList() {

        $keys=[
            "2046501529854977_1", // 22采区变电所_风机移变高压电压
            "2046501529893889_1", // 22采区变电所_风机移变高压电流

            "2046501529969665_1", // 22采区变电所_风机移变低压电压
            "2046501530010625_1", // 22采区变电所_风机移变低压电流

            "2046501530203137_1", // 22采区变电所_动力移变低压电压
            "2046501530242049_1", // 22采区变电所_动力移变低压电流

            "2046501530086401_1", // 22采区变电所_动力移变高压电压
            "2046501530123265_1", // 22采区变电所_动力移变高压电流

            "2046501525955585_1", // 22采区变电所_22F100_UAC
            "2046501525994497_1", // 22采区变电所_22F100_IA
            "2046501526070273_1", // 22采区变电所_22F100_P

            "2046501526109185_1", // 22采区变电所_22F101_UAC
            "2046501526148097_1", // 22采区变电所_22F101_IA
            "2046501526225921_1", // 22采区变电所_22F101_P

            "2046501526303745_1", // 22采区变电所_22F102_UBC
            "2046501526377473_1", // 22采区变电所_22F102_IA
            "2046501526461441_1", // 22采区变电所_22F102_P

            "2046501526533121_1", // 22采区变电所_22F103_UBC
            "2046501526606849_1", // 22采区变电所_22F103_IA
            "2046501526682625_1", // 22采区变电所_22F103_P

            "2046501526719489_1", // 22采区变电所_22F104_UAC
            "2046501526760449_1", // 22采区变电所_22F104_IA
            "2046501526840321_1", // 22采区变电所_22F104_P

            "2046501526879233_1", // 22采区变电所_22F105_UAC
            "2046501526918145_1", // 22采区变电所_22F105_IA
            "2046501526987777_1", // 22采区变电所_22F105_P

            "2046501527096321_1", // 22采区变电所_22F106_UCA
            "2046501527135233_1", // 22采区变电所_22F106_IA
            "2046501527221249_1", // 22采区变电所_22F106_P

            "2046501529816065_1", // 22采区变电所_22Z001_UCA
            "2046501529781249_1", // 22采区变电所_22Z001照明回路_IA

            "2046501527348225_1", // 22采区变电所_22D207_UCA
            "2046501527387137_1", // 22采区变电所_22D207_IA
            "2046501527460865_1", // 22采区变电所_22D207_P

            "2046501527653377_1", // 22采区变电所_22D206_US
            "2046501527497729_1", // 22采区变电所_22D206_IA
            "2046501527696385_1", // 22采区变电所_22D206_P

            "2046501527983105_1", // 22采区变电所_22D205_UB
            "2046501527864321_1", // 22采区变电所_22D205_IA
            "2046501528054785_1", // 22采区变电所_22D205_P

            "2046501528298497_1", // 22采区变电所_22D204_UCA
            "2046501528337409_1", // 22采区变电所_22D204_IA
            "2046501528413185_1", // 22采区变电所_22D204_P

            "2046501528531969_1", // 22采区变电所_22D203_UCA
            "2046501528568833_1", // 22采区变电所_22D203_IA
            "2046501528642561_1", // 22采区变电所_22D203_P

            "2046501528826881_1", // 22采区变电所_22D202_US
            "2046501528679425_1", // 22采区变电所_22D202_IA
            "2046501528865793_1", // 22采区变电所_22D202_P

            "2046501529201665_1", // 22采区变电所_22D201_US
            "2046501529046017_1", // 22采区变电所_22D201_IA
            "2046501529240577_1", // 22采区变电所_22D201_P

            "2046501529537537_1", // 22采区变电所_22D200_US
            "2046501529392129_1", // 22采区变电所_22D200_IA
            "2046501529576449_1", // 22采区变电所_22D200_P

            "2046829366187009_2", // 22采区_动力移变低压
            "2046501530242049_1", // 22采区变电所_动力移变低压电流

            "2046829262238721_2", // 22采区_动力移变高压
            "2046501530123265_1", // 22采区变电所_动力移变高压电流


            "2046459583054849_2", // 22采区变电所_风机移变高压_开关
            "2046459583312897_2", // 22采区变电所_风机移变低压_开关

            "2046459579759617_2", // 22采区变电所_22F100_开关合位
            "2046459579868161_2", // 22采区变电所_22F101_开关合位
            "2046459580181505_2", // 22采区变电所_22F102_开关合位
            "2046459580486657_2", // 22采区变电所_22F103_开关合位
            "2046459580601345_2", // 22采区变电所_22F104_开关合位
            "2046459580705793_2", // 22采区变电所_22F105_开关合位
            "2046459581012993_2", // 22采区变电所_22F106_开关合位

//            "2046459584152577_2", // 22采区变电所_22Z106_开关合位
            "2046825697680385_2", // 22采区_22Z004
            "2046459583003649_2", // 22采区变电所_22Z001_开关合位
//            "2046459584230401_2", // 22采区变电所_22Z107_开关合位

            "2046459581340673_2", // 22采区变电所_22D207_开关合位
            "2046459581424640_2", // 22采区变电所_22D206_开关合位
            "2046459581658113_2", // 22采区变电所_22D205_开关合位
            "2046459582053377_2", // 22采区变电所_22D204_开关合位
            "2046459582026753_2", // 22采区变电所_22D204_开关跳位
            "2046459582358529_2", // 22采区变电所_22D203_开关合位
            "2046459582434305_2", // 22采区变电所_22D202_开关合位
            "2046459582630913_2", // 22采区变电所_22D201_开关合位
            "2046459582815233_2", // 22采区变电所_22D200_开关合位

            "2046459583833089_2", // 22采区变电所_动力移变低压_开关
            "2046459583579137_2", // 22采区变电所_动力移变高压_开关
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "tip"=>[
                [
                    "color"=>"#FF0000",
                    "text"=>"开"
                ],
                [
                    "color"=>"#00FF00",
                    "text"=>"关"
                ],
            ],
            "state"=>[
                "1", // 22G201高爆开关

                $baseData["2046459583054849_2"] ?? "0", // 22采区变电所_风机移变高压_开关
                $baseData["2046459583312897_2"] ?? "0", // 22采区变电所_风机移变低压_开关

                $baseData["2046459579759617_2"] ?? "0", // 22采区变电所_22F100_开关合位
                $baseData["2046459579868161_2"] ?? "0", // 22采区变电所_22F101_开关合位
                $baseData["2046459580181505_2"] ?? "0", // 22采区变电所_22F102_开关合位
                $baseData["2046459580486657_2"] ?? "0", // 22采区变电所_22F103_开关合位
                $baseData["2046459580601345_2"] ?? "0", // 22采区变电所_22F104_开关合位
                $baseData["2046459580705793_2"] ?? "0", // 22采区变电所_22F105_开关合位
                $baseData["2046459581012993_2"] ?? "0", // 22采区变电所_22F106_开关合位

                ($baseData["2046825697680385_2"] ?? 0) > 0 ? 1 : "0", // 22采区_22Z004

                $baseData["2046459583003649_2"] ?? "0", // 22采区变电所_22Z001_开关合位


//                $baseData["2046459584230401_2"] ?? "0", // 22采区变电所_22Z107_开关合位

                $baseData["2046459581340673_2"] ?? "0", // 22采区变电所_22D207_开关合位
                $baseData["2046459581424640_2"] ?? "0", // 22采区变电所_22D206_开关合位
                $baseData["2046459581658113_2"] ?? "0", // 22采区变电所_22D205_开关合位
                $baseData["2046459582053377_2"] ?? "0", // 22采区变电所_22D204_开关合位
                $baseData["2046459582358529_2"] ?? "0", // 22采区变电所_22D203_开关合位
                $baseData["2046459582434305_2"] ?? "0", // 22采区变电所_22D202_开关合位
                $baseData["2046459582630913_2"] ?? "0", // 22采区变电所_22D201_开关合位
                $baseData["2046459582815233_2"] ?? "0", // 22采区变电所_22D200_开关合位

                $baseData["2046459583833089_2"] ?? "0", // 22采区变电所_动力移变低压_开关
                $baseData["2046459583579137_2"] ?? "0", // 22采区变电所_动力移变高压_开关

                "1", // 22G201高爆开关


            ],
            "table_data"=>[
                [
                    "title"=>"22采区变电所低压",
                    "table"=>[
                        "thead"=>["名称", "Uac", "Ia", "P"] ?? "0",
                        "tbody"=>[

                            [
                                "风机高压",
                                $baseData["2046501529854977_1"] ?? "0", // 22采区变电所_风机移变高压电压
                                $baseData["2046501529893889_1"] ?? "0", // 22采区变电所_风机移变高压电流
                                ""
                            ],
                            [
                                "风机低压",
                                $baseData["2046501529969665_1"] ?? "0", // 22采区变电所_风机移变低压电压
                                $baseData["2046501530010625_1"] ?? "0", // 22采区变电所_风机移变低压电流
                                ""
                            ],

                            [
                                "22F100",
                                $baseData["2046501525955585_1"] ?? "0", // 22采区变电所_22F100_UAC
                                $baseData["2046501525994497_1"] ?? "0", // 22采区变电所_22F100_IA
                                $baseData["2046501526070273_1"] ?? "0", // 22采区变电所_22F100_P
                            ],
                            [
                                "22F101",
                                $baseData["2046501526109185_1"] ?? "0", // 22采区变电所_22F101_UAC
                                $baseData["2046501526148097_1"] ?? "0", // 22采区变电所_22F101_IA
                                $baseData["2046501526225921_1"] ?? "0", // 22采区变电所_22F101_P
                            ],
                            [
                                "22F102",
                                $baseData["2046501526303745_1"] ?? "0", // 22采区变电所_22F102_UBC
                                $baseData["2046501526377473_1"] ?? "0", // 22采区变电所_22F102_IA
                                $baseData["2046501526461441_1"] ?? "0", // 22采区变电所_22F102_P
                            ],
                            [
                                "22F103",
                                $baseData["2046501526533121_1"] ?? "0", // 22采区变电所_22F103_UBC
                                $baseData["2046501526606849_1"] ?? "0", // 22采区变电所_22F103_IA
                                $baseData["2046501526682625_1"] ?? "0", // 22采区变电所_22F103_P
                            ],
                            [
                                "22F104",
                                $baseData["2046501526719489_1"] ?? "0", // 22采区变电所_22F104_UAC
                                $baseData["2046501526760449_1"] ?? "0", // 22采区变电所_22F104_IA
                                $baseData["2046501526840321_1"] ?? "0", // 22采区变电所_22F104_P
                            ],
                            [
                                "22F105",
                                $baseData["2046501526879233_1"] ?? "0", // 22采区变电所_22F105_UAC
                                $baseData["2046501526918145_1"] ?? "0", // 22采区变电所_22F105_IA
                                $baseData["2046501526987777_1"] ?? "0", // 22采区变电所_22F105_P
                            ],
                            [
                                "22F106",
                                $baseData["2046501527096321_1"] ?? "0", // 22采区变电所_22F106_UCA
                                $baseData["2046501527135233_1"] ?? "0", // 22采区变电所_22F106_IA
                                $baseData["2046501527221249_1"] ?? "0", // 22采区变电所_22F106_P
                            ],
                            [
                                "22Z004",
                                $baseData["2046501530547201_1"] ?? "0", // 22采区变电所_22Z107_UCA
                                $baseData["2046501530512385_1"] ?? "0", // 22采区变电所_22Z107照明回路_IA
                                "",
                            ],
                            [
                                "22Z001",
                                $baseData["2046501529816065_1"] ?? "0", // 22采区变电所_22Z001_UCA
                                $baseData["2046501529781249_1"] ?? "0", // 22采区变电所_22Z001照明回路_IA
                                "",
                            ],
                            [
                                "22D207",
                                $baseData["2046501527348225_1"] ?? "0", // 22采区变电所_22D207_UCA
                                $baseData["2046501527387137_1"] ?? "0", // 22采区变电所_22D207_IA
                                $baseData["2046501527460865_1"] ?? "0", // 22采区变电所_22D207_P
                            ],
                            [
                                "22D206",
                                $baseData["2046501527653377_1"] ?? "0", // 22采区变电所_22D206_US
                                $baseData["2046501527497729_1"] ?? "0", // 22采区变电所_22D206_IA
                                $baseData["2046501527696385_1"] ?? "0", // 22采区变电所_22D206_P
                            ],
                            [
                                "22D205",
                                $baseData["2046501527983105_1"] ?? "0", // 22采区变电所_22D205_UB
                                $baseData["2046501527864321_1"] ?? "0", // 22采区变电所_22D205_IA
                                $baseData["2046501528054785_1"] ?? "0", // 22采区变电所_22D205_P
                            ],
                            [
                                "22D204",
                                $baseData["2046501528298497_1"] ?? "0", // 22采区变电所_22D204_UCA
                                $baseData["2046501528337409_1"] ?? "0", // 22采区变电所_22D204_IA
                                $baseData["2046501528413185_1"] ?? "0", // 22采区变电所_22D204_P
                            ],
                            [
                                "22D203",
                                $baseData["2046501528531969_1"] ?? "0", // 22采区变电所_22D203_UCA
                                $baseData["2046501528568833_1"] ?? "0", // 22采区变电所_22D203_IA
                                $baseData["2046501528642561_1"] ?? "0", // 22采区变电所_22D203_P
                            ],
                            [
                                "22D202",
                                $baseData["2046501528826881_1"] ?? "0", // 22采区变电所_22D202_US
                                $baseData["2046501528679425_1"] ?? "0", // 22采区变电所_22D202_IA
                                $baseData["2046501528865793_1"] ?? "0", // 22采区变电所_22D202_P
                            ],
                            [
                                "22D201",
                                $baseData["2046501529201665_1"] ?? "0", // 22采区变电所_22D201_US
                                $baseData["2046501529046017_1"] ?? "0", // 22采区变电所_22D201_IA
                                $baseData["2046501529240577_1"] ?? "0", // 22采区变电所_22D201_P
                            ],
                            [
                                "22D200",
                                $baseData["2046501529537537_1"] ?? "0", // 22采区变电所_22D200_US
                                $baseData["2046501529392129_1"] ?? "0", // 22采区变电所_22D200_IA
                                $baseData["2046501529576449_1"] ?? "0", // 22采区变电所_22D200_P
                            ],

                            [
                                "动力高压",
                                $baseData["2046501530203137_1"] ?? "0", // 22采区变电所_动力移变低压电压
                                $baseData["2046501530242049_1"] ?? "0", // 22采区变电所_动力移变低压电流
                                ""
                            ],
                            [
                                "动力低压",
                                $baseData["2046501530086401_1"] ?? "0", // 22采区变电所_动力移变高压电压
                                $baseData["2046501530123265_1"] ?? "0", // 22采区变电所_动力移变高压电流
                                ""
                            ],
                        ]
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 22采区变电所高压
     * */
    public function get22GList() {

        $keys=[

            "2046501518134273_1", // 22采区变电所_5201_UB
            "2046501518248961_1", // 22采区变电所_5201_COS
            "2046501518060545_1", // 22采区变电所_5201_IA
            "2046501518171137_1", // 22采区变电所_5201_P
            "2046501518208001_1", // 22采区变电所_5201_Q

            "2046501518355457_1", // 22采区变电所_5202_UB
            "2046501518461953_1", // 22采区变电所_5202_COS
            "2046501518285825_1", // 22采区变电所_5202_IA
            "2046501518390273_1", // 22采区变电所_5202_P
            "2046501518427137_1", // 22采区变电所_5202_Q

            "2046501518572545_1", // 22采区变电所_5203_UB
            "2046501518683137_1", // 22采区变电所_5203_COS
            "2046501518498817_1", // 22采区变电所_5203_IA
            "2046501518609409_1", // 22采区变电所_5203_P
            "2046501518648321_1", // 22采区变电所_5203_Q

            "2046501518791681_1", // 22采区变电所_5204_UB
            "2046501518930945_1", // 22采区变电所_5204_COS
            "2046501518720001_1", // 22采区变电所_5204_IA
            "2046501518834689_1", // 22采区变电所_5204_P
            "2046501518883841_1", // 22采区变电所_5204_Q

            "2046501519059969_1", // 22采区变电所_5205_UB
            "2046501519207425_1", // 22采区变电所_5205_COS
            "2046501518973953_1", // 22采区变电所_5205_IA
            "2046501519125505_1", // 22采区变电所_5205_P
            "2046501519166465_1", // 22采区变电所_5205_Q

            "2046501519346689_1", // 22采区变电所_5206_UB
            "2046501519469569_1", // 22采区变电所_5206_COS
            "2046501519248385_1", // 22采区变电所_5206_IA
            "2046501519387649_1", // 22采区变电所_5206_P
            "2046501519430657_1", // 22采区变电所_5206_Q

            "2046501519590401_1", // 22采区变电所_5207_UB
            "2046501519737857_1", // 22采区变电所_5207_COS
            "2046501519510529_1", // 22采区变电所_5207_IA
            "2046501519655937_1", // 22采区变电所_5207_P
            "2046501519698945_1", // 22采区变电所_5207_Q

            "2046501519852545_1", // 22采区变电所_5002_UB
            "2046501519969281_1", // 22采区变电所_5002_COS
            "2046501519776769_1", // 22采区变电所_5002_IA
            "2046501519891457_1", // 22采区变电所_5002_P
            "2046501519930369_1", // 22采区变电所_5002_Q

            "2046501520108545_1", // 22采区变电所_5106_UB
            "2046501520229377_1", // 22采区变电所_5106_COS
            "2046501520008193_1", // 22采区变电所_5106_IA
            "2046501520147457_1", // 22采区变电所_5106_P
            "2046501520190465_1", // 22采区变电所_5106_Q

            "2046501520346113_1", // 22采区变电所_5105_UB
            "2046501520464897_1", // 22采区变电所_5105_COS
            "2046501520266241_1", // 22采区变电所_5105_IA
            "2046501520382977_1", // 22采区变电所_5105_P
            "2046501520421889_1", // 22采区变电所_5105_Q

            "2046501520577537_1", // 22采区变电所_5104_UB
            "2046501520696321_1", // 22采区变电所_5104_COS
            "2046501520505857_1", // 22采区变电所_5104_IA
            "2046501520620545_1", // 22采区变电所_5104_P
            "2046501520661505_1", // 22采区变电所_5104_Q

            "2046501520815105_1", // 22采区变电所_5103_UB
            "2046501520925697_1", // 22采区变电所_5103_COS
            "2046501520735233_1", // 22采区变电所_5103_IA
            "2046501520851969_1", // 22采区变电所_5103_P
            "2046501520888833_1", // 22采区变电所_5103_Q

            "2046501521193985_1", // 22采区变电所_5102_UB
            "2046501521345537_1", // 22采区变电所_5102_COS
            "2046501520978945_1", // 22采区变电所_5102_IA
            "2046501521247233_1", // 22采区变电所_5102_P
            "2046501521302529_1", // 22采区变电所_5102_Q

            "2046501521464321_1", // 22采区变电所_5101_UB
            "2046501521597441_1", // 22采区变电所_5101_COS
            "2046501521386497_1", // 22采区变电所_5101_IA
            "2046501521505281_1", // 22采区变电所_5101_P
            "2046501521546241_1", // 22采区变电所_5101_Q

            "2046501521722369_1", // 22采区变电所_5401_UB
            "2046501521841153_1", // 22采区变电所_5401_COS
            "2046501521644545_1", // 22采区变电所_5401_IA
            "2046501521761281_1", // 22采区变电所_5401_P
            "2046501521802241_1", // 22采区变电所_5401_Q

            "2046501521957889_1", // 22采区变电所_5402_UB
            "2046501522088961_1", // 22采区变电所_5402_COS
            "2046501521880065_1", // 22采区变电所_5402_IA
            "2046501522013185_1", // 22采区变电所_5402_P
            "2046501522050049_1", // 22采区变电所_5402_Q

            "2046501522205697_1", // 22采区变电所_5403_UB
            "2046501522314241_1", // 22采区变电所_5403_COS
            "2046501522125825_1", // 22采区变电所_5403_IA
            "2046501522240513_1", // 22采区变电所_5403_P
            "2046501522279425_1", // 22采区变电所_5403_Q

            "2046501522433025_1", // 22采区变电所_5404_UB
            "2046501522549761_1", // 22采区变电所_5404_COS
            "2046501522355201_1", // 22采区变电所_5404_IA
            "2046501522471937_1", // 22采区变电所_5404_P
            "2046501522510849_1", // 22采区变电所_5404_Q

            "2046501522668545_1", // 22采区变电所_5405_UB
            "2046501522807809_1", // 22采区变电所_5405_COS
            "2046501522588673_1", // 22采区变电所_5405_IA
            "2046501522629633_1", // 22采区变电所_5405_IC
            "2046501522709505_1", // 22采区变电所_5405_P
            "2046501522746369_1", // 22采区变电所_5405_Q

            "2046501522916353_1", // 22采区变电所_5406_UB
            "2046501523037185_1", // 22采区变电所_5406_COS
            "2046501522844673_1", // 22采区变电所_5406_IA
            "2046501522957313_1", // 22采区变电所_5406_P
            "2046501522996225_1", // 22采区变电所_5406_Q

            "2046501523268609_1", // 22采区变电所_5407_UB
            "2046501523397633_1", // 22采区变电所_5407_COS
            "2046501523076097_1", // 22采区变电所_5407_IA
            "2046501523315713_1", // 22采区变电所_5407_P
            "2046501523358721_1", // 22采区变电所_5407_Q

            "2046501523514369_1", // 22采区变电所_5408_UB
            "2046501523651585_1", // 22采区变电所_5408_COS
            "2046501523434497_1", // 22采区变电所_5408_IA
            "2046501523567617_1", // 22采区变电所_5408_P
            "2046501523612673_1", // 22采区变电所_5408_Q

            "2046501524028417_1", // 22采区变电所_5308_UB
            "2046501524147201_1", // 22采区变电所_5308_COS
            "2046501523948545_1", // 22采区变电所_5308_IA
            "2046501524069377_1", // 22采区变电所_5308_P
            "2046501524108289_1", // 22采区变电所_5308_Q

            "2046501524284417_1", // 22采区变电所_5307_UB
            "2046501524421633_1", // 22采区变电所_5307_COS
            "2046501524200449_1", // 22采区变电所_5307_IA
            "2046501524323329_1", // 22采区变电所_5307_P
            "2046501524382721_1", // 22采区变电所_5307_Q

            "2046501524542465_1", // 22采区变电所_5306_UB
            "2046501524659201_1", // 22采区变电所_5306_COS
            "2046501524462593_1", // 22采区变电所_5306_IA
            "2046501524583425_1", // 22采区变电所_5306_P
            "2046501524620289_1", // 22采区变电所_5306_Q

            "2046501524788225_1", // 22采区变电所_5305_UB
            "2046501524907009_1", // 22采区变电所_5305_COS
            "2046501524698113_1", // 22采区变电所_5305_IA
            "2046501524827137_1", // 22采区变电所_5305_P
            "2046501524868097_1", // 22采区变电所_5305_Q

            "2046501525021697_1", // 22采区变电所_5304_UB
            "2046501525154817_1", // 22采区变电所_5304_COS
            "2046501524945921_1", // 22采区变电所_5304_IA
            "2046501525062657_1", // 22采区变电所_5304_P
            "2046501525105665_1", // 22采区变电所_5304_Q

            "2046501525300225_1", // 22采区变电所_5303_UB
            "2046501525425153_1", // 22采区变电所_5303_COS
            "2046501525195777_1", // 22采区变电所_5303_IA
            "2046501525345281_1", // 22采区变电所_5303_P
            "2046501525386241_1", // 22采区变电所_5303_Q

            "2046501525539841_1", // 22采区变电所_5302_UB
            "2046501525660673_1", // 22采区变电所_5302_COS
            "2046501525466113_1", // 22采区变电所_5302_IA
            "2046501525580801_1", // 22采区变电所_5302_P
            "2046501525619713_1", // 22采区变电所_5302_Q

            "2046501525801985_1", // 22采区变电所_5301_UB
            "2046501525918721_1", // 22采区变电所_5301_COS
            "2046501525720065_1", // 22采区变电所_5301_IA
            "2046501525840897_1", // 22采区变电所_5301_P
            "2046501525881857_1", // 22采区变电所_5301_Q



            "2046459562001409_2", // 22采区变电所_5201_开关
            "2046459562548225_2", // 22采区变电所_5202_开关
            "2046459563127809_2", // 22采区变电所_5203_开关
            "2046459563668481_2", // 22采区变电所_5204_开关
            "2046459564258305_2", // 22采区变电所_5205_开关
            "2046459564819457_2", // 22采区变电所_5206_开关
            "2046459565349889_2", // 22采区变电所_5207_开关

            "2046459565890561_2", // 22采区变电所_5002_开关

            "2046459566515201_2", // 22采区变电所_5106_开关
            "2046459567062017_2", // 22采区变电所_5105_开关
            "2046459567639553_2", // 22采区变电所_5104_开关
            "2046459568210945_2", // 22采区变电所_5103_开关
            "2046459568790529_2", // 22采区变电所_5102_开关
            "2046459569372161_2", // 22采区变电所_5101_开关

            "2046459569923073_2", // 22采区变电所_5401_开关
            "2046459570461697_2", // 22采区变电所_5402_开关
            "2046459571033089_2", // 22采区变电所_5403_开关
            "2046459571573761_2", // 22采区变电所_5404_开关
            "2046459572157441_2", // 22采区变电所_5405_开关
            "2046459572689921_2", // 22采区变电所_5406_开关
            "2046459573337089_2", // 22采区变电所_5407_开关
            "2046459573980161_2", // 22采区变电所_5408_开关

            "2046459575133185_2", // 22采区变电所_5308_开关
            "2046459575716865_2", // 22采区变电所_5307_开关
            "2046459576302593_2", // 22采区变电所_5306_开关
            "2046459576914945_2", // 22采区变电所_5305_开关
            "2046459577502721_2", // 22采区变电所_5304_开关
            "2046459578059777_2", // 22采区变电所_5303_开关
            "2046459578651649_2", // 22采区变电所_5302_开关
            "2046459579235329_2", // 22采区变电所_5301_开关

        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "tip"=>[
                [
                    "color"=>"#00FF00",
                    "text"=>"关"
                ],
                [
                    "color"=>"#FF0000",
                    "text"=>"开"
                ],
            ],
            "state"=>[
                $baseData["2046459562001409_2"] ?? "0", // 22采区变电所_5201_开关
                $baseData["2046459562548225_2"] ?? "0", // 22采区变电所_5202_开关
                $baseData["2046459563127809_2"] ?? "0", // 22采区变电所_5203_开关
                $baseData["2046459563668481_2"] ?? "0", // 22采区变电所_5204_开关
                $baseData["2046459564258305_2"] ?? "0", // 22采区变电所_5205_开关
                $baseData["2046459564819457_2"] ?? "0", // 22采区变电所_5206_开关
                $baseData["2046459565349889_2"] ?? "0", // 22采区变电所_5207_开关

                $baseData["2046459565890561_2"] ?? "0", // 22采区变电所_5002_开关

                $baseData["2046459566515201_2"] ?? "0", // 22采区变电所_5106_开关
                $baseData["2046459567062017_2"] ?? "0", // 22采区变电所_5105_开关
                $baseData["2046459567639553_2"] ?? "0", // 22采区变电所_5104_开关
                $baseData["2046459568210945_2"] ?? "0", // 22采区变电所_5103_开关
                $baseData["2046459568790529_2"] ?? "0", // 22采区变电所_5102_开关
                $baseData["2046459569372161_2"] ?? "0", // 22采区变电所_5101_开关

                $baseData["2046459569923073_2"] ?? "0", // 22采区变电所_5401_开关
                $baseData["2046459570461697_2"] ?? "0", // 22采区变电所_5402_开关
                $baseData["2046459571033089_2"] ?? "0", // 22采区变电所_5403_开关
                $baseData["2046459571573761_2"] ?? "0", // 22采区变电所_5404_开关
                $baseData["2046459572157441_2"] ?? "0", // 22采区变电所_5405_开关
                $baseData["2046459572689921_2"] ?? "0", // 22采区变电所_5406_开关
                $baseData["2046459573337089_2"] ?? "0", // 22采区变电所_5407_开关
                $baseData["2046459573980161_2"] ?? "0", // 22采区变电所_5408_开关

                $baseData["2046459575133185_2"] ?? "0", // 22采区变电所_5308_开关
                $baseData["2046459575716865_2"] ?? "0", // 22采区变电所_5307_开关
                $baseData["2046459576302593_2"] ?? "0", // 22采区变电所_5306_开关
                $baseData["2046459576914945_2"] ?? "0", // 22采区变电所_5305_开关
                $baseData["2046459577502721_2"] ?? "0", // 22采区变电所_5304_开关
                $baseData["2046459578059777_2"] ?? "0", // 22采区变电所_5303_开关
                $baseData["2046459578651649_2"] ?? "0", // 22采区变电所_5302_开关
                $baseData["2046459579235329_2"] ?? "0", // 22采区变电所_5301_开关
            ],
            "table_data"=>[
                [
                    "title"=>"22采区变电所低压",
                    "table"=>[
                        "thead"=>["名称",  "Q", "P", "Uac", "Cos", "Ia", ] ?? "0",
                        "tbody"=>[
                            [
                                "5201",
                                $baseData["2046501518208001_1"] ?? "0", // 22采区变电所_5201_Q
                                $baseData["2046501518171137_1"] ?? "0", // 22采区变电所_5201_P
                                $baseData["2046501518134273_1"] ?? "0", // 22采区变电所_5201_UB
                                $baseData["2046501518248961_1"] ?? "0", // 22采区变电所_5201_COS
                                $baseData["2046501518060545_1"] ?? "0", // 22采区变电所_5201_IA
                            ],
                            [
                                "5202",
                                $baseData["2046501518427137_1"] ?? "0", // 22采区变电所_5202_Q
                                $baseData["2046501518390273_1"] ?? "0", // 22采区变电所_5202_P
                                $baseData["2046501518355457_1"] ?? "0", // 22采区变电所_5202_UB
                                $baseData["2046501518461953_1"] ?? "0", // 22采区变电所_5202_COS
                                $baseData["2046501518285825_1"] ?? "0", // 22采区变电所_5202_IA
                            ],
                            [
                                "5203",
                                $baseData["2046501518648321_1"] ?? "0", // 22采区变电所_5203_Q
                                $baseData["2046501518609409_1"] ?? "0", // 22采区变电所_5203_P
                                $baseData["2046501518572545_1"] ?? "0", // 22采区变电所_5203_UB
                                $baseData["2046501518683137_1"] ?? "0", // 22采区变电所_5203_COS
                                $baseData["2046501518498817_1"] ?? "0", // 22采区变电所_5203_IA
                            ],
                            [
                                "5204",
                                $baseData["2046501518883841_1"] ?? "0", // 22采区变电所_5204_Q
                                $baseData["2046501518834689_1"] ?? "0", // 22采区变电所_5204_P
                                $baseData["2046501518791681_1"] ?? "0", // 22采区变电所_5204_UB
                                $baseData["2046501518930945_1"] ?? "0", // 22采区变电所_5204_COS
                                $baseData["2046501518720001_1"] ?? "0", // 22采区变电所_5204_IA
                            ],
                            [
                                "5205",
                                $baseData["2046501519166465_1"] ?? "0", // 22采区变电所_5205_Q
                                $baseData["2046501519125505_1"] ?? "0", // 22采区变电所_5205_P
                                $baseData["2046501519059969_1"] ?? "0", // 22采区变电所_5205_UB
                                $baseData["2046501519207425_1"] ?? "0", // 22采区变电所_5205_COS
                                $baseData["2046501518973953_1"] ?? "0", // 22采区变电所_5205_IA
                            ],
                            [
                                "5206",
                                $baseData["2046501519430657_1"] ?? "0", // 22采区变电所_5206_Q
                                $baseData["2046501519387649_1"] ?? "0", // 22采区变电所_5206_P
                                $baseData["2046501519346689_1"] ?? "0", // 22采区变电所_5206_UB
                                $baseData["2046501519469569_1"] ?? "0", // 22采区变电所_5206_COS
                                $baseData["2046501519248385_1"] ?? "0", // 22采区变电所_5206_IA
                            ],
                            [
                                "5207",
                                $baseData["2046501519698945_1"] ?? "0", // 22采区变电所_5207_Q
                                $baseData["2046501519655937_1"] ?? "0", // 22采区变电所_5207_P
                                $baseData["2046501519590401_1"] ?? "0", // 22采区变电所_5207_UB
                                $baseData["2046501519737857_1"] ?? "0", // 22采区变电所_5207_COS
                                $baseData["2046501519510529_1"] ?? "0", // 22采区变电所_5207_IA
                            ],
                            [
                                "5002",
                                $baseData["2046501519930369_1"] ?? "0", // 22采区变电所_5002_Q
                                $baseData["2046501519891457_1"] ?? "0", // 22采区变电所_5002_P
                                $baseData["2046501519852545_1"] ?? "0", // 22采区变电所_5002_UB
                                $baseData["2046501519969281_1"] ?? "0", // 22采区变电所_5002_COS
                                $baseData["2046501519776769_1"] ?? "0", // 22采区变电所_5002_IA
                            ],
                            [
                                "5106",
                                $baseData["2046501520190465_1"] ?? "0", // 22采区变电所_5106_Q
                                $baseData["2046501520147457_1"] ?? "0", // 22采区变电所_5106_P
                                $baseData["2046501520108545_1"] ?? "0", // 22采区变电所_5106_UB
                                $baseData["2046501520229377_1"] ?? "0", // 22采区变电所_5106_COS
                                $baseData["2046501520008193_1"] ?? "0", // 22采区变电所_5106_IA
                            ],
                            [
                                "5105",
                                $baseData["2046501520421889_1"] ?? "0", // 22采区变电所_5105_Q
                                $baseData["2046501520382977_1"] ?? "0", // 22采区变电所_5105_P
                                $baseData["2046501520346113_1"] ?? "0", // 22采区变电所_5105_UB
                                $baseData["2046501520464897_1"] ?? "0", // 22采区变电所_5105_COS
                                $baseData["2046501520266241_1"] ?? "0", // 22采区变电所_5105_IA
                            ],
                            [
                                "5104",
                                $baseData["2046501520661505_1"] ?? "0", // 22采区变电所_5104_Q
                                $baseData["2046501520620545_1"] ?? "0", // 22采区变电所_5104_P
                                $baseData["2046501520577537_1"] ?? "0", // 22采区变电所_5104_UB
                                $baseData["2046501520696321_1"] ?? "0", // 22采区变电所_5104_COS
                                $baseData["2046501520505857_1"] ?? "0", // 22采区变电所_5104_IA
                            ],
                            [
                                "5103",
                                $baseData["2046501520888833_1"] ?? "0", // 22采区变电所_5103_Q
                                $baseData["2046501520851969_1"] ?? "0", // 22采区变电所_5103_P
                                $baseData["2046501520815105_1"] ?? "0", // 22采区变电所_5103_UB
                                $baseData["2046501520925697_1"] ?? "0", // 22采区变电所_5103_COS
                                $baseData["2046501520735233_1"] ?? "0", // 22采区变电所_5103_IA
                            ],
                            [
                                "5102",
                                $baseData["2046501521302529_1"] ?? "0", // 22采区变电所_5102_Q
                                $baseData["2046501521247233_1"] ?? "0", // 22采区变电所_5102_P
                                $baseData["2046501521193985_1"] ?? "0", // 22采区变电所_5102_UB
                                $baseData["2046501521345537_1"] ?? "0", // 22采区变电所_5102_COS
                                $baseData["2046501520978945_1"] ?? "0", // 22采区变电所_5102_IA
                            ],
                            [
                                "5101",
                                $baseData["2046501521546241_1"] ?? "0", // 22采区变电所_5101_Q
                                $baseData["2046501521505281_1"] ?? "0", // 22采区变电所_5101_P
                                $baseData["2046501521464321_1"] ?? "0", // 22采区变电所_5101_UB
                                $baseData["2046501521597441_1"] ?? "0", // 22采区变电所_5101_COS
                                $baseData["2046501521386497_1"] ?? "0", // 22采区变电所_5101_IA
                            ],
                            [
                                "5401",
                                $baseData["2046501521802241_1"] ?? "0", // 22采区变电所_5401_Q
                                $baseData["2046501521761281_1"] ?? "0", // 22采区变电所_5401_P
                                $baseData["2046501521722369_1"] ?? "0", // 22采区变电所_5401_UB
                                $baseData["2046501521841153_1"] ?? "0", // 22采区变电所_5401_COS
                                $baseData["2046501521644545_1"] ?? "0", // 22采区变电所_5401_IA
                            ],
                            [
                                "5402",
                                $baseData["2046501522050049_1"] ?? "0", // 22采区变电所_5402_Q
                                $baseData["2046501522013185_1"] ?? "0", // 22采区变电所_5402_P
                                $baseData["2046501521957889_1"] ?? "0", // 22采区变电所_5402_UB
                                $baseData["2046501522088961_1"] ?? "0", // 22采区变电所_5402_COS
                                $baseData["2046501521880065_1"] ?? "0", // 22采区变电所_5402_IA
                            ],
                            [
                                "5403",
                                $baseData["2046501522279425_1"] ?? "0", // 22采区变电所_5403_Q
                                $baseData["2046501522240513_1"] ?? "0", // 22采区变电所_5403_P
                                $baseData["2046501522205697_1"] ?? "0", // 22采区变电所_5403_UB
                                $baseData["2046501522314241_1"] ?? "0", // 22采区变电所_5403_COS
                                $baseData["2046501522125825_1"] ?? "0", // 22采区变电所_5403_IA
                            ],
                            [
                                "5404",
                                $baseData["2046501522510849_1"] ?? "0", // 22采区变电所_5404_Q
                                $baseData["2046501522471937_1"] ?? "0", // 22采区变电所_5404_P
                                $baseData["2046501522433025_1"] ?? "0", // 22采区变电所_5404_UB
                                $baseData["2046501522549761_1"] ?? "0", // 22采区变电所_5404_COS
                                $baseData["2046501522355201_1"] ?? "0", // 22采区变电所_5404_IA
                            ],
                            [
                                "5405",
                                $baseData["2046501522746369_1"] ?? "0", // 22采区变电所_5405_Q
                                $baseData["2046501522709505_1"] ?? "0", // 22采区变电所_5405_P
                                $baseData["2046501522668545_1"] ?? "0", // 22采区变电所_5405_UB
                                $baseData["2046501522807809_1"] ?? "0", // 22采区变电所_5405_COS
                                $baseData["2046501522588673_1"] ?? "0", // 22采区变电所_5405_IA
                                $baseData["2046501522629633_1"] ?? "0", // 22采区变电所_5405_IC
                            ],
                            [
                                "5406",
                                $baseData["2046501522996225_1"] ?? "0", // 22采区变电所_5406_Q
                                $baseData["2046501522957313_1"] ?? "0", // 22采区变电所_5406_P
                                $baseData["2046501522916353_1"] ?? "0", // 22采区变电所_5406_UB
                                $baseData["2046501523037185_1"] ?? "0", // 22采区变电所_5406_COS
                                $baseData["2046501522844673_1"] ?? "0", // 22采区变电所_5406_IA
                            ],
                            [
                                "5407",
                                $baseData["2046501523358721_1"] ?? "0", // 22采区变电所_5407_Q
                                $baseData["2046501523315713_1"] ?? "0", // 22采区变电所_5407_P
                                $baseData["2046501523268609_1"] ?? "0", // 22采区变电所_5407_UB
                                $baseData["2046501523397633_1"] ?? "0", // 22采区变电所_5407_COS
                                $baseData["2046501523076097_1"] ?? "0", // 22采区变电所_5407_IA
                            ],
                            [
                                "5408",
                                $baseData["2046501523612673_1"] ?? "0", // 22采区变电所_5408_Q
                                $baseData["2046501523567617_1"] ?? "0", // 22采区变电所_5408_P
                                $baseData["2046501523514369_1"] ?? "0", // 22采区变电所_5408_UB
                                $baseData["2046501523651585_1"] ?? "0", // 22采区变电所_5408_COS
                                $baseData["2046501523434497_1"] ?? "0", // 22采区变电所_5408_IA
                            ],
                            [
                                "5308",
                                $baseData["2046501524108289_1"] ?? "0", // 22采区变电所_5308_Q
                                $baseData["2046501524069377_1"] ?? "0", // 22采区变电所_5308_P
                                $baseData["2046501524028417_1"] ?? "0", // 22采区变电所_5308_UB
                                $baseData["2046501524147201_1"] ?? "0", // 22采区变电所_5308_COS
                                $baseData["2046501523948545_1"] ?? "0", // 22采区变电所_5308_IA
                            ],
                            [
                                "5307",
                                $baseData["2046501524382721_1"] ?? "0", // 22采区变电所_5307_Q
                                $baseData["2046501524323329_1"] ?? "0", // 22采区变电所_5307_P
                                $baseData["2046501524284417_1"] ?? "0", // 22采区变电所_5307_UB
                                $baseData["2046501524421633_1"] ?? "0", // 22采区变电所_5307_COS
                                $baseData["2046501524200449_1"] ?? "0", // 22采区变电所_5307_IA
                            ],
                            [
                                "5306",
                                $baseData["2046501524620289_1"] ?? "0", // 22采区变电所_5306_Q
                                $baseData["2046501524583425_1"] ?? "0", // 22采区变电所_5306_P
                                $baseData["2046501524542465_1"] ?? "0", // 22采区变电所_5306_UB
                                $baseData["2046501524659201_1"] ?? "0", // 22采区变电所_5306_COS
                                $baseData["2046501524462593_1"] ?? "0", // 22采区变电所_5306_IA
                            ],
                            [
                                "5305",
                                $baseData["2046501524868097_1"] ?? "0", // 22采区变电所_5305_Q
                                $baseData["2046501524827137_1"] ?? "0", // 22采区变电所_5305_P
                                $baseData["2046501524788225_1"] ?? "0", // 22采区变电所_5305_UB
                                $baseData["2046501524907009_1"] ?? "0", // 22采区变电所_5305_COS
                                $baseData["2046501524698113_1"] ?? "0", // 22采区变电所_5305_IA
                            ],
                            [
                                "5304",
                                $baseData["2046501525105665_1"] ?? "0", // 22采区变电所_5304_Q
                                $baseData["2046501525062657_1"] ?? "0", // 22采区变电所_5304_P
                                $baseData["2046501525021697_1"] ?? "0", // 22采区变电所_5304_UB
                                $baseData["2046501525154817_1"] ?? "0", // 22采区变电所_5304_COS
                                $baseData["2046501524945921_1"] ?? "0", // 22采区变电所_5304_IA
                            ],
                            [
                                "5303",
                                $baseData["2046501525386241_1"] ?? "0", // 22采区变电所_5303_Q
                                $baseData["2046501525345281_1"] ?? "0", // 22采区变电所_5303_P
                                $baseData["2046501525300225_1"] ?? "0", // 22采区变电所_5303_UB
                                $baseData["2046501525425153_1"] ?? "0", // 22采区变电所_5303_COS
                                $baseData["2046501525195777_1"] ?? "0", // 22采区变电所_5303_IA
                            ],
                            [
                                "5302",
                                $baseData["2046501525619713_1"] ?? "0", // 22采区变电所_5302_Q
                                $baseData["2046501525580801_1"] ?? "0", // 22采区变电所_5302_P
                                $baseData["2046501525539841_1"] ?? "0", // 22采区变电所_5302_UB
                                $baseData["2046501525660673_1"] ?? "0", // 22采区变电所_5302_COS
                                $baseData["2046501525466113_1"] ?? "0", // 22采区变电所_5302_IA
                            ],
                            [
                                "5301",
                                $baseData["2046501525881857_1"] ?? "0", // 22采区变电所_5301_Q
                                $baseData["2046501525840897_1"] ?? "0", // 22采区变电所_5301_P
                                $baseData["2046501525801985_1"] ?? "0", // 22采区变电所_5301_UB
                                $baseData["2046501525918721_1"] ?? "0", // 22采区变电所_5301_COS
                                $baseData["2046501525720065_1"] ?? "0", // 22采区变电所_5301_IA
                            ],
                        ]
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 五分区井下950
     * */
    public function get5fq950List() {

        $keys=[
            "2009923543237633_1", // 五分区井下950m变电所_5101母线A相电压
            "2009923543219201_1", // 五分区井下950m变电所_5101A相电流
            "2009923543270401_1", // 五分区井下950m变电所_5101功率因素
            "2009923543254017_1", // 五分区井下950m变电所_5101有功功率
            "2009923543303169_1", // 五分区井下950m变电所_51-9母线A相电压
            "2009923543286785_1", // 五分区井下950m变电所_51-9A相电流
            "2009923543337985_1", // 五分区井下950m变电所_51-9功率因素
            "2009923543319553_1", // 五分区井下950m变电所_51-9有功功率
            "2009923543368705_1", // 五分区井下950m变电所_5102母线A相电压
            "2009923543356417_1", // 五分区井下950m变电所_5102A相电流
            "2009923543401473_1", // 五分区井下950m变电所_5102功率因素
            "2009923543385089_1", // 五分区井下950m变电所_5102有功功率
            "2009923543436289_1", // 五分区井下950m变电所_5103母线A相电压
            "2009923543415809_1", // 五分区井下950m变电所_5103A相电流
            "2009923543462913_1", // 五分区井下950m变电所_5103功率因素
            "2009923543452673_1", // 五分区井下950m变电所_5103有功功率
            "2009923543493633_1", // 五分区井下950m变电所_5104母线A相电压
            "2009923543479297_1", // 五分区井下950m变电所_5104A相电流
            "2009923543526401_1", // 五分区井下950m变电所_5104功率因素
            "2009923543512065_1", // 五分区井下950m变电所_5104有功功率
            "2009923543561217_1", // 五分区井下950m变电所_5105母线A相电压
            "2009923543544833_1", // 五分区井下950m变电所_5105A相电流
            "2009923543591937_1", // 五分区井下950m变电所_5105功率因素
            "2009923543577601_1", // 五分区井下950m变电所_5105有功功率
            "2009923543626753_1", // 五分区井下950m变电所_5106母线A相电压
            "2009923543608321_1", // 五分区井下950m变电所_5106A相电流
            "2009923543657473_1", // 五分区井下950m变电所_5106功率因素
            "2009923543643137_1", // 五分区井下950m变电所_5106有功功率
            "2009923543686145_1", // 五分区井下950m变电所_5107母线A相电压
            "2009923543671809_1", // 五分区井下950m变电所_5107A相电流
            "2009923543718913_1", // 五分区井下950m变电所_5107功率因素
            "2009923543702529_1", // 五分区井下950m变电所_5107有功功率
            "2009923543751681_1", // 五分区井下950m变电所_5108母线A相电压
            "2009923543733249_1", // 五分区井下950m变电所_5108A相电流
            "2009923543782401_1", // 五分区井下950m变电所_5108功率因素
            "2009923543766017_1", // 五分区井下950m变电所_5108有功功率
            "2009923543813121_1", // 五分区井下950m变电所_5109母线A相电压
            "2009923543796737_1", // 五分区井下950m变电所_5109A相电流
            "2009923543847937_1", // 五分区井下950m变电所_5109功率因素
            "2009923543831553_1", // 五分区井下950m变电所_5109有功功率
            "2009923543874561_1", // 五分区井下950m变电所_5110母线A相电压
            "2009923543862273_1", // 五分区井下950m变电所_5110A相电流
            "2009923543907329_1", // 五分区井下950m变电所_5110功率因素
            "2009923543888897_1", // 五分区井下950m变电所_5110有功功率
            "2009923543936001_1", // 五分区井下950m变电所_5001母线A相电压
            "2009923543923713_1", // 五分区井下950m变电所_5001A相电流
            "2009923543972865_1", // 五分区井下950m变电所_5001功率因素
            "2009923543950337_1", // 五分区井下950m变电所_5001有功功率
            "2009923544009729_1", // 五分区井下950m变电所_5212母线A相电压
            "2009923543991297_1", // 五分区井下950m变电所_5212A相电流
            "2009923544042497_1", // 五分区井下950m变电所_5212功率因素
            "2009923544028161_1", // 五分区井下950m变电所_5212有功功率
            "2009923544073217_1", // 五分区井下950m变电所_5211母线A相电压
            "2009923544056833_1", // 五分区井下950m变电所_5211A相电流
            "2009923544105985_1", // 五分区井下950m变电所_5211功率因素
            "2009923544093697_1", // 五分区井下950m变电所_5211有功功率
            "2009923544138753_1", // 五分区井下950m变电所_5210母线A相电压
            "2009923544122369_1", // 五分区井下950m变电所_5210A相电流
            "2009923544171521_1", // 五分区井下950m变电所_5210功率因素
            "2009923544155137_1", // 五分区井下950m变电所_5210有功功率
            "2009923544198145_1", // 五分区井下950m变电所_5209母线A相电压
            "2009923544185857_1", // 五分区井下950m变电所_5209A相电流
            "2009923544235009_1", // 五分区井下950m变电所_5209功率因素
            "2009923544212481_1", // 五分区井下950m变电所_5209有功功率
            "2009923544267777_1", // 五分区井下950m变电所_5208母线A相电压
            "2009923544251393_1", // 五分区井下950m变电所_5208A相电流
            "2009923544300545_1", // 五分区井下950m变电所_5208功率因素
            "2009923544282113_1", // 五分区井下950m变电所_5208有功功率
            "2009923544333313_1", // 五分区井下950m变电所_5207母线A相电压
            "2009923544314881_1", // 五分区井下950m变电所_5207A相电流
            "2009923544429569_1", // 五分区井下950m变电所_5207功率因素
            "2009923544351745_1", // 五分区井下950m变电所_5207有功功率
            "2009923544450049_1", // 五分区井下950m变电所_5206母线A相电压
            "2009923544439809_1", // 五分区井下950m变电所_5206A相电流
            "2009923544472577_1", // 五分区井下950m变电所_5206功率因素
            "2009923544462337_1", // 五分区井下950m变电所_5206有功功率
            "2009923544501249_1", // 五分区井下950m变电所_5205母线A相电压
            "2009923544484865_1", // 五分区井下950m变电所_5205A相电流
            "2009923544523777_1", // 五分区井下950m变电所_5205功率因素
            "2009923544511489_1", // 五分区井下950m变电所_5205有功功率
            "2009923544556545_1", // 五分区井下950m变电所_5204母线A相电压
            "2009923544540161_1", // 五分区井下950m变电所_5204A相电流
            "2009923544587265_1", // 五分区井下950m变电所_5204功率因素
            "2009923544570881_1", // 五分区井下950m变电所_5204有功功率
            "2009923544620033_1", // 五分区井下950m变电所_5203母线A相电压
            "2009923544605697_1", // 五分区井下950m变电所_5203A相电流
            "2009923544652801_1", // 五分区井下950m变电所_5203功率因素
            "2009923544636417_1", // 五分区井下950m变电所_5203有功功率
            "2009923544687617_1", // 五分区井下950m变电所_5202母线A相电压
            "2009923544671233_1", // 五分区井下950m变电所_5202A相电流
            "2009923544720385_1", // 五分区井下950m变电所_5202功率因素
            "2009923544706049_1", // 五分区井下950m变电所_5202有功功率
            "2009923544751105_1", // 五分区井下950m变电所_52-9母线A相电压
            "2009923544736769_1", // 五分区井下950m变电所_52-9A相电流
            "2009923544785921_1", // 五分区井下950m变电所_52-9功率因素
            "2009923544769537_1", // 五分区井下950m变电所_52-9有功功率
            "2009923544824833_1", // 五分区井下950m变电所_5201母线A相电压
            "2009923544806401_1", // 五分区井下950m变电所_5201A相电流
            "2009923544855553_1", // 五分区井下950m变电所_5201功率因素
            "2009923544839169_1", // 五分区井下950m变电所_5201有功功率
            "2009923545033729_1", // 五分区井下950m变电所_Z104#电压1
            "2009923545056257_1", // 五分区井下950m变电所_Z104#照明电流2
            "2009923544982529_1", // 五分区井下950m变电所_Z103#电压1
            "2009923545000961_1", // 五分区井下950m变电所_Z103#照明电流2
            "2009923544939521_1", // 五分区井下950m变电所_Z102#电压1
            "2009923544951809_1", // 五分区井下950m变电所_Z102#照明电流2
            "2009923544896513_1", // 五分区井下950m变电所_Z101#电压1
            "2009923544914945_1", // 五分区井下950m变电所_Z101#照明电流2
            "2009923545107457_1", // 五分区井下950m变电所_D100_ua
            "2009923545082881_1", // 五分区井下950m变电所_D100_Ia1
            "2009923545144321_1", // 五分区井下950m变电所_D101_ua
            "2009923545119745_1", // 五分区井下950m变电所_D101_Ia1
            "2009923545191425_1", // 五分区井下950m变电所_D102_ua
            "2009923545160705_1", // 五分区井下950m变电所_D102_Ia1
            "2009923545238529_1", // 五分区井下950m变电所_D103#ua
            "2009923545207809_1", // 五分区井下950m变电所_D103#Ia1
            "2009923545281537_1", // 五分区井下950m变电所_D104#ua
            "2009923545254913_1", // 五分区井下950m变电所_D104#Ia1
            "2009923545326593_1", // 五分区井下950m变电所_D105#ua
            "2009923545295873_1", // 五分区井下950m变电所_D105#Ia1
            "2009923545375745_1", // 五分区井下950m变电所_D1-2#ua
            "2009923545345025_1", // 五分区井下950m变电所_D1-2#Ia1
            "2009923545418753_1", // 五分区井下950m变电所_D205#ua
            "2009923545388033_1", // 五分区井下950m变电所_D205#Ia1
            "2009923545463809_1", // 五分区井下950m变电所_D204#ua
            "2009923545433089_1", // 五分区井下950m变电所_D204#Ia1
            "2009923545510913_1", // 五分区井下950m变电所_D203#ua
            "2009923545480193_1", // 五分区井下950m变电所_D203#Ia1
            "2009923545564161_1", // 五分区井下950m变电所_D202#ua
            "2009923545531393_1", // 五分区井下950m变电所_D202#Ia1
            "2009923545615361_1", // 五分区井下950m变电所_D201#ua
            "2009923545578497_1", // 五分区井下950m变电所_D201#Ia1
            "2009923545719809_1", // 五分区井下950m变电所_D200#ua
            "2009923545629697_1", // 五分区井下950m变电所_D200#Ia1
            "2009923545785345_1", // 五分区井下950m变电所_Z202#电压_1
            "2009923545805825_1", // 五分区井下950m变电所_Z202#照明电流2
            "2009923545736193_1", // 五分区井下950m变电所_Z201#电压_1
            "2009923545750529_1", // 五分区井下950m变电所_Z201#照明电流2

            // 开关
            "2041019081769985_2", // 五分区井下_950m变电所5101开关控制
            "2041019081778177_2", // 五分区井下_950m变电所51-9开关控制
            "2041019081788417_2", // 五分区井下_950m变电所5102开关控制
            "2041019081798657_2", // 五分区井下_950m变电所5103开关控制
            "2041019081812993_2", // 五分区井下_950m变电所5104开关控制
            "2041019081821185_2", // 五分区井下_950m变电所5105开关控制
            "2041019081829377_2", // 五分区井下_950m变电所5106开关控制
            "2041019081847809_2", // 五分区井下_950m变电所5107开关控制
            "2041019081874433_2", // 五分区井下_950m变电所5108开关控制
            "2041019081905153_2", // 五分区井下_950m变电所5109开关控制
            "2041019081927681_2", // 五分区井下_950m变电所5110开关控制
            "2041019081948161_2", // 五分区井下_950m变电所5001开关控制
            "2041019081962497_2", // 五分区井下_950m变电所5212开关控制
            "2041019081980929_2", // 五分区井下_950m变电所5211开关控制
            "2041019081997313_2", // 五分区井下_950m变电所5210开关控制
            "2041019082011649_2", // 五分区井下_950m变电所5209开关控制
            "2041019082023937_2", // 五分区井下_950m变电所5208开关控制
            "2041019082036225_2", // 五分区井下_950m变电所5207开关控制
            "2041019082048513_2", // 五分区井下_950m变电所5206开关控制
            "2041019082060801_2", // 五分区井下_950m变电所5205开关控制
            "2041019082073089_2", // 五分区井下_950m变电所5204开关控制
            "2041019082093569_2", // 五分区井下_950m变电所5203开关控制
            "2041019082101761_2", // 五分区井下_950m变电所5202开关控制
            "2041019082112001_2", // 五分区井下_950m变电所52-9开关控制
            "2041019082120193_2", // 五分区井下_950m变电所5201开关控制
            "2041019082300417_2", // 五分区井下_950m变电所550Z104开关控制
            "2041019082290177_2", // 五分区井下_950m变电所550Z103开关控制
            "2041019082277889_2", // 五分区井下_950m变电所550Z102开关控制
            "2041019082269697_2", // 五分区井下_950m变电所550Z101开关控制
            "2041019082130433_2", // 五分区井下_950m变电所550D100开关控制
            "2041019082140673_2", // 五分区井下_950m变电所550D101开关控制
            "2041019082148865_2", // 五分区井下_950m变电所550D102开关控制
            "2041019082159105_2", // 五分区井下_950m变电所550D103开关控制
            "2041019082167297_2", // 五分区井下_950m变电所550D104开关控制
            "2041019082181633_2", // 五分区井下_950m变电所550D105开关控制
            "2041019082193921_2", // 五分区井下_950m变电所550D1-2开关控制
            "2041019082206209_2", // 五分区井下_950m变电所550D205开关控制
            "2041019082218497_2", // 五分区井下_950m变电所550D204开关控制
            "2041019082228737_2", // 五分区井下_950m变电所550D203开关控制
            "2041019082238977_2", // 五分区井下_950m变电所550D202开关控制
            "2041019082251265_2", // 五分区井下_950m变电所550D201开关控制
            "2041019082259457_2", // 五分区井下_950m变电所550D200开关控制
            "2041019082322945_2", // 五分区井下_950m变电所550Z202开关控制
            "2041019082310657_2", // 五分区井下_950m变电所550Z201开关控制
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "tip"=>[
                [
                    "color"=>"#00FF00",
                    "text"=>"关"
                ],
                [
                    "color"=>"#FF0000",
                    "text"=>"开"
                ],
            ],
            "state"=>[
                $baseData["2041019081769985_2"], // 五分区井下_950m变电所5101开关控制
                $baseData["2041019081778177_2"], // 五分区井下_950m变电所51-9开关控制
                $baseData["2041019081788417_2"], // 五分区井下_950m变电所5102开关控制
                $baseData["2041019081798657_2"], // 五分区井下_950m变电所5103开关控制
                $baseData["2041019081812993_2"], // 五分区井下_950m变电所5104开关控制
                $baseData["2041019081821185_2"], // 五分区井下_950m变电所5105开关控制
                $baseData["2041019081829377_2"], // 五分区井下_950m变电所5106开关控制
                $baseData["2041019081847809_2"], // 五分区井下_950m变电所5107开关控制
                $baseData["2041019081874433_2"], // 五分区井下_950m变电所5108开关控制
                $baseData["2041019081905153_2"], // 五分区井下_950m变电所5109开关控制
                $baseData["2041019081927681_2"], // 五分区井下_950m变电所5110开关控制
                $baseData["2041019081948161_2"], // 五分区井下_950m变电所5001开关控制
                $baseData["2041019081962497_2"], // 五分区井下_950m变电所5212开关控制
                $baseData["2041019081980929_2"], // 五分区井下_950m变电所5211开关控制
                $baseData["2041019081997313_2"], // 五分区井下_950m变电所5210开关控制
                $baseData["2041019082011649_2"], // 五分区井下_950m变电所5209开关控制
                $baseData["2041019082023937_2"], // 五分区井下_950m变电所5208开关控制
                $baseData["2041019082036225_2"], // 五分区井下_950m变电所5207开关控制
                $baseData["2041019082048513_2"], // 五分区井下_950m变电所5206开关控制
                $baseData["2041019082060801_2"], // 五分区井下_950m变电所5205开关控制
                $baseData["2041019082073089_2"], // 五分区井下_950m变电所5204开关控制
                $baseData["2041019082093569_2"], // 五分区井下_950m变电所5203开关控制
                $baseData["2041019082101761_2"], // 五分区井下_950m变电所5202开关控制
                $baseData["2041019082112001_2"], // 五分区井下_950m变电所52-9开关控制
                $baseData["2041019082120193_2"], // 五分区井下_950m变电所5201开关控制
                $baseData["2041019082300417_2"], // 五分区井下_950m变电所550Z104开关控制
                $baseData["2041019082290177_2"], // 五分区井下_950m变电所550Z103开关控制
                $baseData["2041019082277889_2"], // 五分区井下_950m变电所550Z102开关控制
                $baseData["2041019082269697_2"], // 五分区井下_950m变电所550Z101开关控制
                $baseData["2041019082130433_2"], // 五分区井下_950m变电所550D100开关控制
                $baseData["2041019082140673_2"], // 五分区井下_950m变电所550D101开关控制
                $baseData["2041019082148865_2"], // 五分区井下_950m变电所550D102开关控制
                $baseData["2041019082159105_2"], // 五分区井下_950m变电所550D103开关控制
                $baseData["2041019082167297_2"], // 五分区井下_950m变电所550D104开关控制
                $baseData["2041019082181633_2"], // 五分区井下_950m变电所550D105开关控制
                $baseData["2041019082193921_2"], // 五分区井下_950m变电所550D1-2开关控制
                $baseData["2041019082206209_2"], // 五分区井下_950m变电所550D205开关控制
                $baseData["2041019082218497_2"], // 五分区井下_950m变电所550D204开关控制
                $baseData["2041019082228737_2"], // 五分区井下_950m变电所550D203开关控制
                $baseData["2041019082238977_2"], // 五分区井下_950m变电所550D202开关控制
                $baseData["2041019082251265_2"], // 五分区井下_950m变电所550D201开关控制
                $baseData["2041019082259457_2"], // 五分区井下_950m变电所550D200开关控制
                $baseData["2041019082322945_2"], // 五分区井下_950m变电所550Z202开关控制
                $baseData["2041019082310657_2"], // 五分区井下_950m变电所550Z201开关控制
            ],
            "table_data"=>[
                [
                    "title"=>"五分区井下+950变电所系统",
                    "table"=>[
                        "thead"=>["名称", "用途", "电压", "电流", "有功功率", "功率因数"] ?? "0",
                        "tbody"=>[
                            [
                                "5101",
                                "高压I回进线",
                                $baseData["2009923543237633_1"], // 五分区井下950m变电所_5101母线A相电压
                                $baseData["2009923543219201_1"], // 五分区井下950m变电所_5101A相电流
                                $baseData["2009923543254017_1"], // 五分区井下950m变电所_5101有功功率
                                $baseData["2009923543270401_1"], // 五分区井下950m变电所_5101功率因素
                            ],[
                                "51-9",
                                "1#PT",
                                $baseData["2009923543303169_1"], // 五分区井下950m变电所_51-9母线A相电压
                                $baseData["2009923543286785_1"], // 五分区井下950m变电所_51-9A相电流
                                $baseData["2009923543319553_1"], // 五分区井下950m变电所_51-9有功功率
                                $baseData["2009923543337985_1"], // 五分区井下950m变电所_51-9功率因素
                            ],[
                                "5102",
                                "1#动力变",
                                $baseData["2009923543368705_1"], // 五分区井下950m变电所_5102母线A相电压
                                $baseData["2009923543356417_1"], // 五分区井下950m变电所_5102A相电流
                                $baseData["2009923543385089_1"], // 五分区井下950m变电所_5102有功功率
                                $baseData["2009923543401473_1"], // 五分区井下950m变电所_5102功率因素
                            ],[
                                "5103",
                                "备用",
                                $baseData["2009923543436289_1"], // 五分区井下950m变电所_5103母线A相电压
                                $baseData["2009923543415809_1"], // 五分区井下950m变电所_5103A相电流
                                $baseData["2009923543452673_1"], // 五分区井下950m变电所_5103有功功率
                                $baseData["2009923543462913_1"], // 五分区井下950m变电所_5103功率因素
                            ],[
                                "5104",
                                "备用",
                                $baseData["2009923543493633_1"], // 五分区井下950m变电所_5104母线A相电压
                                $baseData["2009923543479297_1"], // 五分区井下950m变电所_5104A相电流
                                $baseData["2009923543512065_1"], // 五分区井下950m变电所_5104有功功率
                                $baseData["2009923543526401_1"], // 五分区井下950m变电所_5104功率因素
                            ],[
                                "5105",
                                "备用",
                                $baseData["2009923543561217_1"], // 五分区井下950m变电所_5105母线A相电压
                                $baseData["2009923543544833_1"], // 五分区井下950m变电所_5105A相电流
                                $baseData["2009923543577601_1"], // 五分区井下950m变电所_5105有功功率
                                $baseData["2009923543591937_1"], // 五分区井下950m变电所_5105功率因素
                            ],[
                                "5106",
                                "备用",
                                $baseData["2009923543626753_1"], // 五分区井下950m变电所_5106母线A相电压
                                $baseData["2009923543608321_1"], // 五分区井下950m变电所_5106A相电流
                                $baseData["2009923543643137_1"], // 五分区井下950m变电所_5106有功功率
                                $baseData["2009923543657473_1"], // 五分区井下950m变电所_5106功率因素
                            ],[
                                "5107",
                                "备用",
                                $baseData["2009923543686145_1"], // 五分区井下950m变电所_5107母线A相电压
                                $baseData["2009923543671809_1"], // 五分区井下950m变电所_5107A相电流
                                $baseData["2009923543702529_1"], // 五分区井下950m变电所_5107有功功率
                                $baseData["2009923543718913_1"], // 五分区井下950m变电所_5107功率因素
                            ],[
                                "5108",
                                "备用",
                                $baseData["2009923543751681_1"], // 五分区井下950m变电所_5108母线A相电压
                                $baseData["2009923543733249_1"], // 五分区井下950m变电所_5108A相电流
                                $baseData["2009923543766017_1"], // 五分区井下950m变电所_5108有功功率
                                $baseData["2009923543782401_1"], // 五分区井下950m变电所_5108功率因素
                            ],[
                                "5109",
                                "备用",
                                $baseData["2009923543813121_1"], // 五分区井下950m变电所_5109母线A相电压
                                $baseData["2009923543796737_1"], // 五分区井下950m变电所_5109A相电流
                                $baseData["2009923543831553_1"], // 五分区井下950m变电所_5109有功功率
                                $baseData["2009923543847937_1"], // 五分区井下950m变电所_5109功率因素
                            ],[
                                "5110",
                                "1#水泵电源",
                                $baseData["2009923543874561_1"], // 五分区井下950m变电所_5110母线A相电压
                                $baseData["2009923543862273_1"], // 五分区井下950m变电所_5110A相电流
                                $baseData["2009923543888897_1"], // 五分区井下950m变电所_5110有功功率
                                $baseData["2009923543907329_1"], // 五分区井下950m变电所_5110功率因素
                            ],[
                                "5001",
                                "联络",
                                $baseData["2009923543936001_1"], // 五分区井下950m变电所_5001母线A相电压
                                $baseData["2009923543923713_1"], // 五分区井下950m变电所_5001A相电流
                                $baseData["2009923543950337_1"], // 五分区井下950m变电所_5001有功功率
                                $baseData["2009923543972865_1"], // 五分区井下950m变电所_5001功率因素
                            ],[
                                "5212",
                                "2#水泵电源",
                                $baseData["2009923544009729_1"], // 五分区井下950m变电所_5212母线A相电压
                                $baseData["2009923543991297_1"], // 五分区井下950m变电所_5212A相电流
                                $baseData["2009923544028161_1"], // 五分区井下950m变电所_5212有功功率
                                $baseData["2009923544042497_1"], // 五分区井下950m变电所_5212功率因素
                            ],[
                                "5211",
                                "3#水泵电源",
                                $baseData["2009923544073217_1"], // 五分区井下950m变电所_5211母线A相电压
                                $baseData["2009923544056833_1"], // 五分区井下950m变电所_5211A相电流
                                $baseData["2009923544093697_1"], // 五分区井下950m变电所_5211有功功率
                                $baseData["2009923544105985_1"], // 五分区井下950m变电所_5211功率因素
                            ],[
                                "5210",
                                "备用",
                                $baseData["2009923544138753_1"], // 五分区井下950m变电所_5210母线A相电压
                                $baseData["2009923544122369_1"], // 五分区井下950m变电所_5210A相电流
                                $baseData["2009923544155137_1"], // 五分区井下950m变电所_5210有功功率
                                $baseData["2009923544171521_1"], // 五分区井下950m变电所_5210功率因素
                            ],[
                                "5209",
                                "备用",
                                $baseData["2009923544198145_1"], // 五分区井下950m变电所_5209母线A相电压
                                $baseData["2009923544185857_1"], // 五分区井下950m变电所_5209A相电流
                                $baseData["2009923544212481_1"], // 五分区井下950m变电所_5209有功功率
                                $baseData["2009923544235009_1"], // 五分区井下950m变电所_5209功率因素
                            ],[
                                "5208",
                                "备用",
                                $baseData["2009923544267777_1"], // 五分区井下950m变电所_5208母线A相电压
                                $baseData["2009923544251393_1"], // 五分区井下950m变电所_5208A相电流
                                $baseData["2009923544282113_1"], // 五分区井下950m变电所_5208有功功率
                                $baseData["2009923544300545_1"], // 五分区井下950m变电所_5208功率因素
                            ],[
                                "5207",
                                "备用",
                                $baseData["2009923544333313_1"], // 五分区井下950m变电所_5207母线A相电压
                                $baseData["2009923544314881_1"], // 五分区井下950m变电所_5207A相电流
                                $baseData["2009923544351745_1"], // 五分区井下950m变电所_5207有功功率
                                $baseData["2009923544429569_1"], // 五分区井下950m变电所_5207功率因素
                            ],[
                                "5206",
                                "备用",
                                $baseData["2009923544450049_1"], // 五分区井下950m变电所_5206母线A相电压
                                $baseData["2009923544439809_1"], // 五分区井下950m变电所_5206A相电流
                                $baseData["2009923544462337_1"], // 五分区井下950m变电所_5206有功功率
                                $baseData["2009923544472577_1"], // 五分区井下950m变电所_5206功率因素
                            ],[
                                "5205",
                                "备用",
                                $baseData["2009923544501249_1"], // 五分区井下950m变电所_5205母线A相电压
                                $baseData["2009923544484865_1"], // 五分区井下950m变电所_5205A相电流
                                $baseData["2009923544511489_1"], // 五分区井下950m变电所_5205有功功率
                                $baseData["2009923544523777_1"], // 五分区井下950m变电所_5205功率因素
                            ],[
                                "5204",
                                "备用",
                                $baseData["2009923544556545_1"], // 五分区井下950m变电所_5204母线A相电压
                                $baseData["2009923544540161_1"], // 五分区井下950m变电所_5204A相电流
                                $baseData["2009923544570881_1"], // 五分区井下950m变电所_5204有功功率
                                $baseData["2009923544587265_1"], // 五分区井下950m变电所_5204功率因素
                            ],[
                                "5203",
                                "备用",
                                $baseData["2009923544620033_1"], // 五分区井下950m变电所_5203母线A相电压
                                $baseData["2009923544605697_1"], // 五分区井下950m变电所_5203A相电流
                                $baseData["2009923544636417_1"], // 五分区井下950m变电所_5203有功功率
                                $baseData["2009923544652801_1"], // 五分区井下950m变电所_5203功率因素
                            ],[
                                "5202",
                                "2#动力变",
                                $baseData["2009923544687617_1"], // 五分区井下950m变电所_5202母线A相电压
                                $baseData["2009923544671233_1"], // 五分区井下950m变电所_5202A相电流
                                $baseData["2009923544706049_1"], // 五分区井下950m变电所_5202有功功率
                                $baseData["2009923544720385_1"], // 五分区井下950m变电所_5202功率因素
                            ],[
                                "52-9",
                                "2#PT",
                                $baseData["2009923544751105_1"], // 五分区井下950m变电所_52-9母线A相电压
                                $baseData["2009923544736769_1"], // 五分区井下950m变电所_52-9A相电流
                                $baseData["2009923544769537_1"], // 五分区井下950m变电所_52-9有功功率
                                $baseData["2009923544785921_1"], // 五分区井下950m变电所_52-9功率因素
                            ],[
                                "5201",
                                "高压II回进线",
                                $baseData["2009923544824833_1"], // 五分区井下950m变电所_5201母线A相电压
                                $baseData["2009923544806401_1"], // 五分区井下950m变电所_5201A相电流
                                $baseData["2009923544839169_1"], // 五分区井下950m变电所_5201有功功率
                                $baseData["2009923544855553_1"], // 五分区井下950m变电所_5201功率因素
                            ],[
                                "Z104",
                                "流量计电压",
                                $baseData["2009923545033729_1"], // 五分区井下950m变电所_Z104#电压1
                                $baseData["2009923545056257_1"], // 五分区井下950m变电所_Z104#照明电流2
                                null,null
                            ],[
                                "Z103",
                                "信息化电源",
                                $baseData["2009923544982529_1"], // 五分区井下950m变电所_Z103#电压1
                                $baseData["2009923545000961_1"], // 五分区井下950m变电所_Z103#照明电流2
                                null,null
                            ],[
                                "Z102",
                                "所内照明",
                                $baseData["2009923544939521_1"], // 五分区井下950m变电所_Z102#电压1
                                $baseData["2009923544951809_1"], // 五分区井下950m变电所_Z102#照明电流2
                                null,null
                            ],[
                                "Z101",
                                "备用",
                                $baseData["2009923544896513_1"], // 五分区井下950m变电所_Z101#电压1
                                $baseData["2009923544914945_1"], // 五分区井下950m变电所_Z101#照明电流2
                                null,null
                            ],[
                                "D100",
                                "低压I回进线",
                                $baseData["2009923545107457_1"], // 五分区井下950m变电所_D100_ua
                                $baseData["2009923545082881_1"], // 五分区井下950m变电所_D100_Ia1
                                null,null
                            ],[
                                "D101",
                                "照面综保I回电源",
                                $baseData["2009923545144321_1"], // 五分区井下950m变电所_D101_ua
                                $baseData["2009923545119745_1"], // 五分区井下950m变电所_D101_Ia1
                                null,null
                            ],[
                                "D102",
                                "排矸斜井下端照明",
                                $baseData["2009923545191425_1"], // 五分区井下950m变电所_D102_ua
                                $baseData["2009923545160705_1"], // 五分区井下950m变电所_D102_Ia1
                                null,null
                            ],[
                                "D103",
                                "车场扩帮电源",
                                $baseData["2009923545238529_1"], // 五分区井下950m变电所_D103#ua
                                $baseData["2009923545207809_1"], // 五分区井下950m变电所_D103#Ia1
                                null,null
                            ],[
                                "D104",
                                "皮带机尾综保电源",
                                $baseData["2009923545281537_1"], // 五分区井下950m变电所_D104#ua
                                $baseData["2009923545254913_1"], // 五分区井下950m变电所_D104#Ia1
                                null,null
                            ],[
                                "D105",
                                "电动闸阀控制柜",
                                $baseData["2009923545326593_1"], // 五分区井下950m变电所_D105#ua
                                $baseData["2009923545295873_1"], // 五分区井下950m变电所_D105#Ia1
                                null,null
                            ],[
                                "D1-2",
                                "1-2联络",
                                $baseData["2009923545375745_1"], // 五分区井下950m变电所_D1-2#ua
                                $baseData["2009923545345025_1"], // 五分区井下950m变电所_D1-2#Ia1
                                null,null
                            ],[
                                "D205",
                                "真空泵电源",
                                $baseData["2009923545418753_1"], // 五分区井下950m变电所_D205#ua
                                $baseData["2009923545388033_1"], // 五分区井下950m变电所_D205#Ia1
                                null,null
                            ],[
                                "D204",
                                "猴车巷照明",
                                $baseData["2009923545463809_1"], // 五分区井下950m变电所_D204#ua
                                $baseData["2009923545433089_1"], // 五分区井下950m变电所_D204#Ia1
                                null,null
                            ],[
                                "D203",
                                "PLC电源/照明综保II回电源",
                                $baseData["2009923545510913_1"], // 五分区井下950m变电所_D203#ua
                                $baseData["2009923545480193_1"], // 五分区井下950m变电所_D203#Ia1
                                null,null
                            ],[
                                "D202",
                                "清仓设备照明",
                                $baseData["2009923545564161_1"], // 五分区井下950m变电所_D202#ua
                                $baseData["2009923545531393_1"], // 五分区井下950m变电所_D202#Ia1
                                null,null
                            ],[
                                "D201",
                                "备用",
                                $baseData["2009923545615361_1"], // 五分区井下950m变电所_D201#ua
                                $baseData["2009923545578497_1"], // 五分区井下950m变电所_D201#Ia1
                                null,null
                            ],[
                                "D200",
                                "低压II回进线",
                                $baseData["2009923545719809_1"], // 五分区井下950m变电所_D200#ua
                                $baseData["2009923545629697_1"], // 五分区井下950m变电所_D200#Ia1
                                null,null
                            ],[
                                "Z202",
                                "备用",
                                $baseData["2009923545785345_1"], // 五分区井下950m变电所_Z202#电压_1
                                $baseData["2009923545805825_1"], // 五分区井下950m变电所_Z202#照明电流2
                                null,null
                            ],[
                                "Z201",
                                "备用",
                                $baseData["2009923545736193_1"], // 五分区井下950m变电所_Z201#电压_1
                                $baseData["2009923545750529_1"], // 五分区井下950m变电所_Z201#照明电流2
                                null,null
                            ]
                        ]
                    ]
                ]
            ]
        ];

        return json_encode($info);
    }

    /*
     * 五分区井下1200
     * */
    public function get5fq1200List() {

        $keys=[
            "2009923530689537_2", // 五分区井下1200m变电所_5101柜开关位置
            "2009923531977729_1", // 五分区井下1200m变电所_5101柜母线A相电压
            "2009923531963393_1", // 五分区井下1200m变电所_5101柜A相电流
            "2009923531992065_1", // 五分区井下1200m变电所_5101柜有功功率
            "2009923532004353_1", // 五分区井下1200m变电所_5101柜功率因素
            "2009923530703873_2", // 五分区井下1200m变电所_51-9柜开关位置
            "2009923532035073_1", // 五分区井下1200m变电所_51-9柜母线A相电压
            "2009923532018689_1", // 五分区井下1200m变电所_51-9柜A相电流
            "2009923532053505_1", // 五分区井下1200m变电所_51-9柜有功功率
            "2009923532069889_1", // 五分区井下1200m变电所_51-9柜功率因素
            "2009923530718209_2", // 五分区井下1200m变电所_5102柜开关位置
            "2009923532100609_1", // 五分区井下1200m变电所_5102柜母线A相电压
            "2009923532086273_1", // 五分区井下1200m变电所_5102柜A相电流
            "2009923532114945_1", // 五分区井下1200m变电所_5102柜有功功率
            "2009923532129281_1", // 五分区井下1200m变电所_5102柜功率因素
            "2009923530732545_2", // 五分区井下1200m变电所_5103柜开关位置
            "2009923532166145_1", // 五分区井下1200m变电所_5103柜母线A相电压
            "2009923532149761_1", // 五分区井下1200m变电所_5103柜A相电流
            "2009923532182529_1", // 五分区井下1200m变电所_5103柜有功功率
            "2009923532198913_1", // 五分区井下1200m变电所_5103柜功率因素
            "2009923530744833_2", // 五分区井下1200m变电所_5104柜开关位置
            "2009923532235777_1", // 五分区井下1200m变电所_5104柜母线A相电压
            "2009923532219393_1", // 五分区井下1200m变电所_5104柜A相电流
            "2009923532252161_1", // 五分区井下1200m变电所_5104柜有功功率
            "2009923532272641_1", // 五分区井下1200m变电所_5104柜功率因素
            "2009923530757121_2", // 五分区井下1200m变电所_5105柜开关位置
            "2009923532313601_1", // 五分区井下1200m变电所_5105柜母线A相电压
            "2009923532295169_1", // 五分区井下1200m变电所_5105柜A相电流
            "2009923532325889_1", // 五分区井下1200m变电所_5105柜有功功率
            "2009923532342273_1", // 五分区井下1200m变电所_5105柜功率因素
            "2009923530769409_2", // 五分区井下1200m变电所_5106柜开关位置
            "2009923532377089_1", // 五分区井下1200m变电所_5106柜母线A相电压
            "2009923532360705_1", // 五分区井下1200m变电所_5106柜A相电流
            "2009923532391425_1", // 五分区井下1200m变电所_5106柜有功功率
            "2009923532411905_1", // 五分区井下1200m变电所_5106柜功率因素
            "2009923530783745_2", // 五分区井下1200m变电所_5107柜开关位置
            "2009923532444673_1", // 五分区井下1200m变电所_5107柜母线A相电压
            "2009923532428289_1", // 五分区井下1200m变电所_5107柜A相电流
            "2009923532459009_1", // 五分区井下1200m变电所_5107柜有功功率
            "2009923532473345_1", // 五分区井下1200m变电所_5107柜功率因素
            "2009923530798081_2", // 五分区井下1200m变电所_5108柜开关位置
            "2009923532502017_1", // 五分区井下1200m变电所_5108柜母线A相电压
            "2009923532487681_1", // 五分区井下1200m变电所_5108柜A相电流
            "2009923532520449_1", // 五分区井下1200m变电所_5108柜有功功率
            "2009923532538881_1", // 五分区井下1200m变电所_5108柜功率因素
            "2009923530810369_2", // 五分区井下1200m变电所_5001柜开关位置
            "2009923532575745_1", // 五分区井下1200m变电所_5001柜母线A相电压
            "2009923532559361_1", // 五分区井下1200m变电所_5001柜A相电流
            "2009923532592129_1", // 五分区井下1200m变电所_5001柜有功功率
            "2009923532606465_1", // 五分区井下1200m变电所_5001柜功率因素
            "2009923530822657_2", // 五分区井下1200m变电所_5208柜开关位置
            "2009923532641281_1", // 五分区井下1200m变电所_5208柜母线A相电压
            "2009923532624897_1", // 五分区井下1200m变电所_5208柜A相电流
            "2009923532657665_1", // 五分区井下1200m变电所_5208柜有功功率
            "2009923532672001_1", // 五分区井下1200m变电所_5208柜功率因素
            "2009923530836993_2", // 五分区井下1200m变电所_5207柜开关位置
            "2009923532708865_1", // 五分区井下1200m变电所_5207柜母线A相电压
            "2009923532688385_1", // 五分区井下1200m变电所_5207柜A相电流
            "2009923532727297_1", // 五分区井下1200m变电所_5207柜有功功率
            "2009923532743681_1", // 五分区井下1200m变电所_5207柜功率因素
            "2009923530847233_2", // 五分区井下1200m变电所_5206柜开关位置
            "2009923532774401_1", // 五分区井下1200m变电所_5206柜母线A相电压
            "2009923532760065_1", // 五分区井下1200m变电所_5206柜A相电流
            "2009923532794881_1", // 五分区井下1200m变电所_5206柜有功功率
            "2009923532811265_1", // 五分区井下1200m变电所_5206柜功率因素
            "2009923530859521_2", // 五分区井下1200m变电所_5205柜开关位置
            "2009923532844033_1", // 五分区井下1200m变电所_5205柜母线A相电压
            "2009923532827649_1", // 五分区井下1200m变电所_5205柜A相电流
            "2009923532862465_1", // 五分区井下1200m变电所_5205柜有功功率
            "2009923532880897_1", // 五分区井下1200m变电所_5205柜功率因素
            "2009923530871809_2", // 五分区井下1200m变电所_5204柜开关位置
            "2009923532917761_1", // 五分区井下1200m变电所_5204柜母线A相电压
            "2009923532901377_1", // 五分区井下1200m变电所_5204柜A相电流
            "2009923532934145_1", // 五分区井下1200m变电所_5204柜有功功率
            "2009923532948481_1", // 五分区井下1200m变电所_5204柜功率因素
            "2009923530886145_2", // 五分区井下1200m变电所_5203柜开关位置
            "2009923532981249_1", // 五分区井下1200m变电所_5203柜母线A相电压
            "2009923532964865_1", // 五分区井下1200m变电所_5203柜A相电流
            "2009923532997633_1", // 五分区井下1200m变电所_5203柜有功功率
            "2009923533014017_1", // 五分区井下1200m变电所_5203柜功率因素
            "2009923530898433_2", // 五分区井下1200m变电所_5202柜开关位置
            "2009923533042689_1", // 五分区井下1200m变电所_5202柜母线A相电压
            "2009923533028353_1", // 五分区井下1200m变电所_5202柜A相电流
            "2009923533054977_1", // 五分区井下1200m变电所_5202柜有功功率
            "2009923533071361_1", // 五分区井下1200m变电所_5202柜功率因素
            "2009923530910721_2", // 五分区井下1200m变电所_52-9柜开关位置
            "2009923533104129_1", // 五分区井下1200m变电所_52-9柜母线A相电压
            "2009923533087745_1", // 五分区井下1200m变电所_52-9柜A相电流
            "2009923533120513_1", // 五分区井下1200m变电所_52-9柜有功功率
            "2009923533132801_1", // 五分区井下1200m变电所_52-9柜功率因素
            "2009923530923009_2", // 五分区井下1200m变电所_5201柜开关位置
            "2009923533167617_1", // 五分区井下1200m变电所_5201柜母线A相电压
            "2009923533149185_1", // 五分区井下1200m变电所_5201柜A相电流
            "2009923533186049_1", // 五分区井下1200m变电所_5201柜有功功率
            "2009923533202433_1", // 五分区井下1200m变电所_5201柜功率因素
            "2009923530937345_2", // 五分区井下1200m变电所_5301柜开关位置
            "2009923533231105_1", // 五分区井下1200m变电所_5301柜母线A相电压
            "2009923533216769_1", // 五分区井下1200m变电所_5301柜A相电流
            "2009923533249537_1", // 五分区井下1200m变电所_5301柜有功功率
            "2009923533270017_1", // 五分区井下1200m变电所_5301柜功率因素
            "2009923530951681_2", // 五分区井下1200m变电所_53-9柜开关位置
            "2009923533302785_1", // 五分区井下1200m变电所_53-9柜母线A相电压
            "2009923533286401_1", // 五分区井下1200m变电所_53-9柜A相电流
            "2009923533317121_1", // 五分区井下1200m变电所_53-9柜有功功率
            "2009923533335553_1", // 五分区井下1200m变电所_53-9柜功率因素
            "2009923530963969_2", // 五分区井下1200m变电所_5302柜开关位置
            "2009923533370369_1", // 五分区井下1200m变电所_5302柜母线A相电压
            "2009923533356033_1", // 五分区井下1200m变电所_5302柜A相电流
            "2009923533386753_1", // 五分区井下1200m变电所_5302柜有功功率
            "2009923533403137_1", // 五分区井下1200m变电所_5302柜功率因素
            "2009923530976257_2", // 五分区井下1200m变电所_5303柜开关位置
            "2009923533431809_1", // 五分区井下1200m变电所_5303柜母线A相电压
            "2009923533417473_1", // 五分区井下1200m变电所_5303柜A相电流
            "2009923533444097_1", // 五分区井下1200m变电所_5303柜有功功率
            "2009923533462529_1", // 五分区井下1200m变电所_5303柜功率因素
            "2009923530986497_2", // 五分区井下1200m变电所_5304柜开关位置
            "2009923533491201_1", // 五分区井下1200m变电所_5304柜母线A相电压
            "2009923533476865_1", // 五分区井下1200m变电所_5304柜A相电流
            "2009923533503489_1", // 五分区井下1200m变电所_5304柜有功功率
            "2009923533519873_1", // 五分区井下1200m变电所_5304柜功率因素
            "2009923530996737_2", // 五分区井下1200m变电所_5305柜开关位置
            "2009923533552641_1", // 五分区井下1200m变电所_5305柜母线A相电压
            "2009923533536257_1", // 五分区井下1200m变电所_5305柜A相电流
            "2009923533569025_1", // 五分区井下1200m变电所_5305柜有功功率
            "2009923533585409_1", // 五分区井下1200m变电所_5305柜功率因素
            "2009923531009025_2", // 五分区井下1200m变电所_5306柜开关位置
            "2009923533618177_1", // 五分区井下1200m变电所_5306柜母线A相电压
            "2009923533599745_1", // 五分区井下1200m变电所_5306柜A相电流
            "2009923533638657_1", // 五分区井下1200m变电所_5306柜有功功率
            "2009923533659137_1", // 五分区井下1200m变电所_5306柜功率因素
            "2009923531019265_2", // 五分区井下1200m变电所_5307柜开关位置
            "2009923533689857_1", // 五分区井下1200m变电所_5307柜母线A相电压
            "2009923533677569_1", // 五分区井下1200m变电所_5307柜A相电流
            "2009923533702145_1", // 五分区井下1200m变电所_5307柜有功功率
            "2009923533716481_1", // 五分区井下1200m变电所_5307柜功率因素
            "2009923531031553_2", // 五分区井下1200m变电所_5308柜开关位置
            "2009923533749249_1", // 五分区井下1200m变电所_5308柜母线A相电压
            "2009923533732865_1", // 五分区井下1200m变电所_5308柜A相电流
            "2009923533771777_1", // 五分区井下1200m变电所_5308柜有功功率
            "2009923533788161_1", // 五分区井下1200m变电所_5308柜功率因素
            "2009923531078657_2", // 五分区井下1200m变电所_5309柜开关位置
            "2009923533820929_1", // 五分区井下1200m变电所_5309柜母线A相电压
            "2009923533804545_1", // 五分区井下1200m变电所_5309柜A相电流
            "2009923533837313_1", // 五分区井下1200m变电所_5309柜有功功率
            "2009923533853697_1", // 五分区井下1200m变电所_5309柜功率因素
            "2009923531084801_2", // 五分区井下1200m变电所_5002柜开关位置
            "2009923533882369_1", // 五分区井下1200m变电所_5002柜母线A相电压
            "2009923533868033_1", // 五分区井下1200m变电所_5002柜A相电流
            "2009923533898753_1", // 五分区井下1200m变电所_5002柜有功功率
            "2009923533913089_1", // 五分区井下1200m变电所_5002柜功率因素
            "2009923531092993_2", // 五分区井下1200m变电所_5409柜开关位置
            "2009923533939713_1", // 五分区井下1200m变电所_5409柜母线A相电压
            "2009923533925377_1", // 五分区井下1200m变电所_5409柜A相电流
            "2009923533956097_1", // 五分区井下1200m变电所_5409柜有功功率
            "2009923533970433_1", // 五分区井下1200m变电所_5409柜功率因素
            "2009923531101185_2", // 五分区井下1200m变电所_5408柜开关位置
            "2009923534003201_1", // 五分区井下1200m变电所_5408柜母线A相电压
            "2009923533986817_1", // 五分区井下1200m变电所_5408柜A相电流
            "2009923534023681_1", // 五分区井下1200m变电所_5408柜有功功率
            "2009923534042113_1", // 五分区井下1200m变电所_5408柜功率因素
            "2009923531107329_2", // 五分区井下1200m变电所_5407柜开关位置
            "2009923534087169_1", // 五分区井下1200m变电所_5407柜母线A相电压
            "2009923534068737_1", // 五分区井下1200m变电所_5407柜A相电流
            "2009923534103553_1", // 五分区井下1200m变电所_5407柜有功功率
            "2009923534121985_1", // 五分区井下1200m变电所_5407柜功率因素
            "2009923531115521_2", // 五分区井下1200m变电所_5406柜开关位置
            "2009923534152705_1", // 五分区井下1200m变电所_5406柜母线A相电压
            "2009923534138369_1", // 五分区井下1200m变电所_5406柜A相电流
            "2009923534169089_1", // 五分区井下1200m变电所_5406柜有功功率
            "2009923534181377_1", // 五分区井下1200m变电所_5406柜功率因素
            "2009923531123713_2", // 五分区井下1200m变电所_5405柜开关位置
            "2009923534210049_1", // 五分区井下1200m变电所_5405柜母线A相电压
            "2009923534193665_1", // 五分区井下1200m变电所_5405柜A相电流
            "2009923534228481_1", // 五分区井下1200m变电所_5405柜有功功率
            "2009923534244865_1", // 五分区井下1200m变电所_5405柜功率因素
            "2009923531131905_2", // 五分区井下1200m变电所_5404柜开关位置
            "2009923534271489_1", // 五分区井下1200m变电所_5404柜母线A相电压
            "2009923534259201_1", // 五分区井下1200m变电所_5404柜A相电流
            "2009923534289921_1", // 五分区井下1200m变电所_5404柜有功功率
            "2009923534308353_1", // 五分区井下1200m变电所_5404柜功率因素
            "2009923531142145_2", // 五分区井下1200m变电所_5403柜开关位置
            "2009923534339073_1", // 五分区井下1200m变电所_5403柜母线A相电压
            "2009923534324737_1", // 五分区井下1200m变电所_5403柜A相电流
            "2009923534355457_1", // 五分区井下1200m变电所_5403柜有功功率
            "2009923534371841_1", // 五分区井下1200m变电所_5403柜功率因素
            "2009923531156481_2", // 五分区井下1200m变电所_5402柜开关位置
            "2009923534404609_1", // 五分区井下1200m变电所_5402柜母线A相电压
            "2009923534386177_1", // 五分区井下1200m变电所_5402柜A相电流
            "2009923534423041_1", // 五分区井下1200m变电所_5402柜有功功率
            "2009923534437377_1", // 五分区井下1200m变电所_5402柜功率因素
            "2009923534453761_1", // 五分区井下1200m变电所_54-9柜A相电流
            "2009923534474241_1", // 五分区井下1200m变电所_54-9柜母线A相电压
            "2009923534507009_1", // 五分区井下1200m变电所_54-9柜功率因素
            "2009923531170817_2", // 五分区井下1200m变电所_54-9柜开关位置
            "2009923534490625_1", // 五分区井下1200m变电所_54-9柜有功功率
            "2041019081485313_2", // 五分区井下_1200m变电所5401开关控制
            "2009923534535681_1", // 五分区井下1200m变电所_5401柜母线A相电压
            "2009923534521345_1", // 五分区井下1200m变电所_5401柜A相电流
            "2009923534547969_1", // 五分区井下1200m变电所_5401柜有功功率
            "2009923534564353_1", // 五分区井下1200m变电所_5401柜功率因素
            "2009923531199489_2", // 五分区井下1200m变电所_Z100#开关位置
            "2009923534582785_1", // 五分区井下1200m变电所_Z100#电压1
            "2009923534599169_1", // 五分区井下1200m变电所_Z100#照明电流2
            "2009923531211777_2", // 五分区井下1200m变电所_Z101#开关位置
            "2009923534631937_1", // 五分区井下1200m变电所_Z101#电压1
            "2009923534648321_1", // 五分区井下1200m变电所_Z101#照明电流2
            "2009923531226113_2", // 五分区井下1200m变电所_Z102#开关位置
            "2009923534683137_1", // 五分区井下1200m变电所_Z102#电压1
            "2009923534699521_1", // 五分区井下1200m变电所_Z102#照明电流2
            "2009923531238401_2", // 五分区井下1200m变电所_Z103#开关位置
            "2009923534740481_1", // 五分区井下1200m变电所_Z103#电压1
            "2009923534758913_1", // 五分区井下1200m变电所_Z103#照明电流2
            "2009923531252737_2", // 五分区井下1200m变电所_D100#开关位置
            "2009923534820353_1", // 五分区井下1200m变电所_D100#ua
            "2009923534791681_1", // 五分区井下1200m变电所_D100#Ia1
            "2009923531262977_2", // 五分区井下1200m变电所_D101#开关位置
            "2009923534869505_1", // 五分区井下1200m变电所_D101#ua
            "2009923534838785_1", // 五分区井下1200m变电所_D101#Ia1
            "2009923531275265_2", // 五分区井下1200m变电所_D102#开关位置
            "2009923534920705_1", // 五分区井下1200m变电所_D102#ua
            "2009923534885889_1", // 五分区井下1200m变电所_D102#Ia1
            "2009923531283457_2", // 五分区井下1200m变电所_D103#开关位置
            "2009923534971905_1", // 五分区井下1200m变电所_D103#ua
            "2009923534935041_1", // 五分区井下1200m变电所_D103#Ia1
            "2009923531291649_2", // 五分区井下1200m变电所_D104#开关位置
            "2009923535025153_1", // 五分区井下1200m变电所_D104#ua
            "2009923534990337_1", // 五分区井下1200m变电所_D104#Ia1
            "2009923531301889_2", // 五分区井下1200m变电所_D105#开关位置
            "2009923535076353_1", // 五分区井下1200m变电所_D105#ua
            "2009923535039489_1", // 五分区井下1200m变电所_D105#Ia1
            "2009923531314177_2", // 五分区井下1200m变电所_D106#开关位置
            "2009923535127553_1", // 五分区井下1200m变电所_D106#ua
            "2009923535094785_1", // 五分区井下1200m变电所_D106#Ia1
            "2009923531328513_2", // 五分区井下1200m变电所_D1-2#开关位置
            "2009923535172609_1", // 五分区井下1200m变电所_D1-2#ua
            "2009923535141889_1", // 五分区井下1200m变电所_D1-2#Ia1
            "2009923531342849_2", // 五分区井下1200m变电所_D207#开关位置
            "2009923535225857_1", // 五分区井下1200m变电所_D207#ua
            "2009923535193089_1", // 五分区井下1200m变电所_D207#la1
            "2009923531355137_2", // 五分区井下1200m变电所_D206#开关位置
            "2009923535277057_1", // 五分区井下1200m变电所_D206#ua
            "2009923535244289_1", // 五分区井下1200m变电所_D206#la1
            "2009923531367425_2", // 五分区井下1200m变电所_D205#开关位置
            "2009923535328257_1", // 五分区井下1200m变电所_D205#ua
            "2009923535295489_1", // 五分区井下1200m变电所_D205#la1
            "2009923531379713_2", // 五分区井下1200m变电所_D204#开关位置
            "2009923535385601_1", // 五分区井下1200m变电所_D204#ua
            "2009923535348737_1", // 五分区井下1200m变电所_D204#la1
            "2009923531389953_2", // 五分区井下1200m变电所_D203#开关位置
            "2009923535434753_1", // 五分区井下1200m变电所_D203#ua
            "2009923535401985_1", // 五分区井下1200m变电所_D203#la1
            "2009923531402241_2", // 五分区井下1200m变电所_D202#开关位置
            "2009923535479809_1", // 五分区井下1200m变电所_D202#ua
            "2009923535449089_1", // 五分区井下1200m变电所_D202#la1
            "2009923531416577_2", // 五分区井下1200m变电所_D201#开关位置
            "2009923535531009_1", // 五分区井下1200m变电所_D201#ua
            "2009923535494145_1", // 五分区井下1200m变电所_D201#la1
            "2009923531430913_2", // 五分区井下1200m变电所_D200#开关位置
            "2009923535576065_1", // 五分区井下1200m变电所_D200#ua
            "2009923535549441_1", // 五分区井下1200m变电所_D200#la1
            "2009923531443201_2", // 五分区井下1200m变电所_Z203_开关位置
            "2009923535588353_1", // 五分区井下1200m变电所_Z203#电压1
            "2009923535604737_1", // 五分区井下1200m变电所_Z203#照明电流2
            "2009923531455489_2", // 五分区井下1200m变电所_Z202_开关位置
            "2009923535637505_1", // 五分区井下1200m变电所_Z202#电压1
            "2009923535649793_1", // 五分区井下1200m变电所_Z202#照明电流2
            "2009923531467777_2", // 五分区井下1200m变电所_Z201_开关位置
            "2009923535676417_1", // 五分区井下1200m变电所_Z201#电压1
            "2009923535696897_1", // 五分区井下1200m变电所_Z201#照明电流2
            "2009923531482113_2", // 五分区井下1200m变电所_Z200_开关位置
            "2009923535729665_1", // 五分区井下1200m变电所_Z200#电压1
            "2009923535748097_1", // 五分区井下1200m变电所_Z200#照明电流2

        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "tip"=>[
                [
                    "color"=>"#00FF00",
                    "text"=>"关"
                ],
                [
                    "color"=>"#FF0000",
                    "text"=>"开"
                ],
            ],
            "state"=>[
                $baseData["2009923530689537_2"], // 五分区井下1200m变电所_5101柜开关位置
                $baseData["2009923530703873_2"], // 五分区井下1200m变电所_51-9柜开关位置
                $baseData["2009923530718209_2"], // 五分区井下1200m变电所_5102柜开关位置
                $baseData["2009923530732545_2"], // 五分区井下1200m变电所_5103柜开关位置
                $baseData["2009923530744833_2"], // 五分区井下1200m变电所_5104柜开关位置
                $baseData["2009923530757121_2"], // 五分区井下1200m变电所_5105柜开关位置
                $baseData["2009923530769409_2"], // 五分区井下1200m变电所_5106柜开关位置
                $baseData["2009923530783745_2"], // 五分区井下1200m变电所_5107柜开关位置
                $baseData["2009923530798081_2"], // 五分区井下1200m变电所_5108柜开关位置
                $baseData["2009923530810369_2"], // 五分区井下1200m变电所_5001柜开关位置
                $baseData["2009923530822657_2"], // 五分区井下1200m变电所_5208柜开关位置
                $baseData["2009923530836993_2"], // 五分区井下1200m变电所_5207柜开关位置
                $baseData["2009923530847233_2"], // 五分区井下1200m变电所_5206柜开关位置
                $baseData["2009923530859521_2"], // 五分区井下1200m变电所_5205柜开关位置
                $baseData["2009923530871809_2"], // 五分区井下1200m变电所_5204柜开关位置
                $baseData["2009923530886145_2"], // 五分区井下1200m变电所_5203柜开关位置
                $baseData["2009923530898433_2"], // 五分区井下1200m变电所_5202柜开关位置
                $baseData["2009923530910721_2"], // 五分区井下1200m变电所_52-9柜开关位置
                $baseData["2009923530923009_2"], // 五分区井下1200m变电所_5201柜开关位置
                $baseData["2009923530937345_2"], // 五分区井下1200m变电所_5301柜开关位置
                $baseData["2009923530951681_2"], // 五分区井下1200m变电所_53-9柜开关位置
                $baseData["2009923530963969_2"], // 五分区井下1200m变电所_5302柜开关位置
                $baseData["2009923530976257_2"], // 五分区井下1200m变电所_5303柜开关位置
                $baseData["2009923530986497_2"], // 五分区井下1200m变电所_5304柜开关位置
                $baseData["2009923530996737_2"], // 五分区井下1200m变电所_5305柜开关位置
                $baseData["2009923531009025_2"], // 五分区井下1200m变电所_5306柜开关位置
                $baseData["2009923531019265_2"], // 五分区井下1200m变电所_5307柜开关位置
                $baseData["2009923531031553_2"], // 五分区井下1200m变电所_5308柜开关位置
                $baseData["2009923531078657_2"], // 五分区井下1200m变电所_5309柜开关位置
                $baseData["2009923531084801_2"], // 五分区井下1200m变电所_5002柜开关位置
                $baseData["2009923531092993_2"], // 五分区井下1200m变电所_5409柜开关位置
                $baseData["2009923531101185_2"], // 五分区井下1200m变电所_5408柜开关位置
                $baseData["2009923531107329_2"], // 五分区井下1200m变电所_5407柜开关位置
                $baseData["2009923531115521_2"], // 五分区井下1200m变电所_5406柜开关位置
                $baseData["2009923531123713_2"], // 五分区井下1200m变电所_5405柜开关位置
                $baseData["2009923531131905_2"], // 五分区井下1200m变电所_5404柜开关位置
                $baseData["2009923531142145_2"], // 五分区井下1200m变电所_5403柜开关位置
                $baseData["2009923531156481_2"], // 五分区井下1200m变电所_5402柜开关位置
                $baseData["2009923531170817_2"], // 五分区井下1200m变电所_54-9柜开关位置
                $baseData["2041019081485313_2"], // 五分区井下_1200m变电所5401开关控制
                $baseData["2009923531199489_2"], // 五分区井下1200m变电所_Z100#开关位置
                $baseData["2009923531211777_2"], // 五分区井下1200m变电所_Z101#开关位置
                $baseData["2009923531226113_2"], // 五分区井下1200m变电所_Z102#开关位置
                $baseData["2009923531238401_2"], // 五分区井下1200m变电所_Z103#开关位置
                $baseData["2009923531252737_2"], // 五分区井下1200m变电所_D100#开关位置
                $baseData["2009923531262977_2"], // 五分区井下1200m变电所_D101#开关位置
                $baseData["2009923531275265_2"], // 五分区井下1200m变电所_D102#开关位置
                $baseData["2009923531283457_2"], // 五分区井下1200m变电所_D103#开关位置
                $baseData["2009923531291649_2"], // 五分区井下1200m变电所_D104#开关位置
                $baseData["2009923531301889_2"], // 五分区井下1200m变电所_D105#开关位置
                $baseData["2009923531314177_2"], // 五分区井下1200m变电所_D106#开关位置
                $baseData["2009923531328513_2"], // 五分区井下1200m变电所_D1-2#开关位置
                $baseData["2009923531342849_2"], // 五分区井下1200m变电所_D207#开关位置
                $baseData["2009923531355137_2"], // 五分区井下1200m变电所_D206#开关位置
                $baseData["2009923531367425_2"], // 五分区井下1200m变电所_D205#开关位置
                $baseData["2009923531379713_2"], // 五分区井下1200m变电所_D204#开关位置
                $baseData["2009923531389953_2"], // 五分区井下1200m变电所_D203#开关位置
                $baseData["2009923531402241_2"], // 五分区井下1200m变电所_D202#开关位置
                $baseData["2009923531416577_2"], // 五分区井下1200m变电所_D201#开关位置
                $baseData["2009923531430913_2"], // 五分区井下1200m变电所_D200#开关位置
                $baseData["2009923531443201_2"], // 五分区井下1200m变电所_Z203_开关位置
                $baseData["2009923531455489_2"], // 五分区井下1200m变电所_Z202_开关位置
                $baseData["2009923531467777_2"], // 五分区井下1200m变电所_Z201_开关位置
                $baseData["2009923531482113_2"], // 五分区井下1200m变电所_Z200_开关位置
            ],
            "table_data"=>[
                [
                    "title"=>"五分区井下1200变电所系统1",
                    "table"=>[
                        "thead"=>["名称", "用途", "电压", "电流", "有功功率", "功率因数"],
                        "tbody"=>[
                            [
                                "5101",
                                "高压I回进线",
                                $baseData["2009923531977729_1"], // 五分区井下1200m变电所_5101柜母线A相电压
                                $baseData["2009923531963393_1"], // 五分区井下1200m变电所_5101柜A相电流
                                $baseData["2009923531992065_1"], // 五分区井下1200m变电所_5101柜有功功率
                                $baseData["2009923532004353_1"], // 五分区井下1200m变电所_5101柜功率因素
                            ],[
                                "51-9",
                                "1#PT",
                                $baseData["2009923532035073_1"], // 五分区井下1200m变电所_51-9柜母线A相电压
                                $baseData["2009923532018689_1"], // 五分区井下1200m变电所_51-9柜A相电流
                                $baseData["2009923532053505_1"], // 五分区井下1200m变电所_51-9柜有功功率
                                $baseData["2009923532069889_1"], // 五分区井下1200m变电所_51-9柜功率因素
                            ],[
                                "5102",
                                "1#动力变",
                                $baseData["2009923532100609_1"], // 五分区井下1200m变电所_5102柜母线A相电压
                                $baseData["2009923532086273_1"], // 五分区井下1200m变电所_5102柜A相电流
                                $baseData["2009923532114945_1"], // 五分区井下1200m变电所_5102柜有功功率
                                $baseData["2009923532129281_1"], // 五分区井下1200m变电所_5102柜功率因素
                            ],[
                                "5103",
                                "五分区运输上山转载皮带",
                                $baseData["2009923532166145_1"], // 五分区井下1200m变电所_5103柜母线A相电压
                                $baseData["2009923532149761_1"], // 五分区井下1200m变电所_5103柜A相电流
                                $baseData["2009923532182529_1"], // 五分区井下1200m变电所_5103柜有功功率
                                $baseData["2009923532198913_1"], // 五分区井下1200m变电所_5103柜功率因素
                            ],[
                                "5104",
                                "+1200m车场掘进移变",
                                $baseData["2009923532235777_1"], // 五分区井下1200m变电所_5104柜母线A相电压
                                $baseData["2009923532219393_1"], // 五分区井下1200m变电所_5104柜A相电流
                                $baseData["2009923532252161_1"], // 五分区井下1200m变电所_5104柜有功功率
                                $baseData["2009923532272641_1"], // 五分区井下1200m变电所_5104柜功率因素
                            ],[
                                "5105",
                                "备用",
                                $baseData["2009923532313601_1"], // 五分区井下1200m变电所_5105柜母线A相电压
                                $baseData["2009923532295169_1"], // 五分区井下1200m变电所_5105柜A相电流
                                $baseData["2009923532325889_1"], // 五分区井下1200m变电所_5105柜有功功率
                                $baseData["2009923532342273_1"], // 五分区井下1200m变电所_5105柜功率因素
                            ],[
                                "5106",
                                "备用",
                                $baseData["2009923532377089_1"], // 五分区井下1200m变电所_5106柜母线A相电压
                                $baseData["2009923532360705_1"], // 五分区井下1200m变电所_5106柜A相电流
                                $baseData["2009923532391425_1"], // 五分区井下1200m变电所_5106柜有功功率
                                $baseData["2009923532411905_1"], // 五分区井下1200m变电所_5106柜功率因素
                            ],[
                                "5107",
                                "备用",
                                $baseData["2009923532444673_1"], // 五分区井下1200m变电所_5107柜母线A相电压
                                $baseData["2009923532428289_1"], // 五分区井下1200m变电所_5107柜A相电流
                                $baseData["2009923532459009_1"], // 五分区井下1200m变电所_5107柜有功功率
                                $baseData["2009923532473345_1"], // 五分区井下1200m变电所_5107柜功率因素
                            ],[
                                "5108",
                                "备用",
                                $baseData["2009923532502017_1"], // 五分区井下1200m变电所_5108柜母线A相电压
                                $baseData["2009923532487681_1"], // 五分区井下1200m变电所_5108柜A相电流
                                $baseData["2009923532520449_1"], // 五分区井下1200m变电所_5108柜有功功率
                                $baseData["2009923532538881_1"], // 五分区井下1200m变电所_5108柜功率因素
                            ],[
                                "5001",
                                "联络",
                                $baseData["2009923532575745_1"], // 五分区井下1200m变电所_5001柜母线A相电压
                                $baseData["2009923532559361_1"], // 五分区井下1200m变电所_5001柜A相电流
                                $baseData["2009923532592129_1"], // 五分区井下1200m变电所_5001柜有功功率
                                $baseData["2009923532606465_1"], // 五分区井下1200m变电所_5001柜功率因素
                            ],[
                                "5208",
                                "备用",
                                $baseData["2009923532641281_1"], // 五分区井下1200m变电所_5208柜母线A相电压
                                $baseData["2009923532624897_1"], // 五分区井下1200m变电所_5208柜A相电流
                                $baseData["2009923532657665_1"], // 五分区井下1200m变电所_5208柜有功功率
                                $baseData["2009923532672001_1"], // 五分区井下1200m变电所_5208柜功率因素
                            ],[
                                "5207",
                                "+1200车场风机移变",
                                $baseData["2009923532708865_1"], // 五分区井下1200m变电所_5207柜母线A相电压
                                $baseData["2009923532688385_1"], // 五分区井下1200m变电所_5207柜A相电流
                                $baseData["2009923532727297_1"], // 五分区井下1200m变电所_5207柜有功功率
                                $baseData["2009923532743681_1"], // 五分区井下1200m变电所_5207柜功率因素
                            ],[
                                "5206",
                                "+1200运输石门转载皮带",
                                $baseData["2009923532774401_1"], // 五分区井下1200m变电所_5206柜母线A相电压
                                $baseData["2009923532760065_1"], // 五分区井下1200m变电所_5206柜A相电流
                                $baseData["2009923532794881_1"], // 五分区井下1200m变电所_5206柜有功功率
                                $baseData["2009923532811265_1"], // 五分区井下1200m变电所_5206柜功率因素
                            ],[
                                "5205",
                                "备用",
                                $baseData["2009923532844033_1"], // 五分区井下1200m变电所_5205柜母线A相电压
                                $baseData["2009923532827649_1"], // 五分区井下1200m变电所_5205柜A相电流
                                $baseData["2009923532862465_1"], // 五分区井下1200m变电所_5205柜有功功率
                                $baseData["2009923532880897_1"], // 五分区井下1200m变电所_5205柜功率因素
                            ],[
                                "5204",
                                "150202辅巷2#移变",
                                $baseData["2009923532917761_1"], // 五分区井下1200m变电所_5204柜母线A相电压
                                $baseData["2009923532901377_1"], // 五分区井下1200m变电所_5204柜A相电流
                                $baseData["2009923532934145_1"], // 五分区井下1200m变电所_5204柜有功功率
                                $baseData["2009923532948481_1"], // 五分区井下1200m变电所_5204柜功率因素
                            ],[
                                "5203",
                                "150202机巷皮带电源",
                                $baseData["2009923532981249_1"], // 五分区井下1200m变电所_5203柜母线A相电压
                                $baseData["2009923532964865_1"], // 五分区井下1200m变电所_5203柜A相电流
                                $baseData["2009923532997633_1"], // 五分区井下1200m变电所_5203柜有功功率
                                $baseData["2009923533014017_1"], // 五分区井下1200m变电所_5203柜功率因素
                            ],[
                                "5202",
                                "1#风机变",
                                $baseData["2009923533042689_1"], // 五分区井下1200m变电所_5202柜母线A相电压
                                $baseData["2009923533028353_1"], // 五分区井下1200m变电所_5202柜A相电流
                                $baseData["2009923533054977_1"], // 五分区井下1200m变电所_5202柜有功功率
                                $baseData["2009923533071361_1"], // 五分区井下1200m变电所_5202柜功率因素
                            ],[
                                "52-9",
                                "2#PT",
                                $baseData["2009923533104129_1"], // 五分区井下1200m变电所_52-9柜母线A相电压
                                $baseData["2009923533087745_1"], // 五分区井下1200m变电所_52-9柜A相电流
                                $baseData["2009923533120513_1"], // 五分区井下1200m变电所_52-9柜有功功率
                                $baseData["2009923533132801_1"], // 五分区井下1200m变电所_52-9柜功率因素
                            ],[
                                "5201",
                                "高压II回进线",
                                $baseData["2009923533167617_1"], // 五分区井下1200m变电所_5201柜母线A相电压
                                $baseData["2009923533149185_1"], // 五分区井下1200m变电所_5201柜A相电流
                                $baseData["2009923533186049_1"], // 五分区井下1200m变电所_5201柜有功功率
                                $baseData["2009923533202433_1"], // 五分区井下1200m变电所_5201柜功率因素
                            ],[
                                "5301",
                                "高压III回进线",
                                $baseData["2009923533231105_1"], // 五分区井下1200m变电所_5301柜母线A相电压
                                $baseData["2009923533216769_1"], // 五分区井下1200m变电所_5301柜A相电流
                                $baseData["2009923533249537_1"], // 五分区井下1200m变电所_5301柜有功功率
                                $baseData["2009923533270017_1"], // 五分区井下1200m变电所_5301柜功率因素
                            ],[
                                "53-9",
                                "3#PT",
                                $baseData["2009923533302785_1"], // 五分区井下1200m变电所_53-9柜母线A相电压
                                $baseData["2009923533286401_1"], // 五分区井下1200m变电所_53-9柜A相电流
                                $baseData["2009923533317121_1"], // 五分区井下1200m变电所_53-9柜有功功率
                                $baseData["2009923533335553_1"], // 五分区井下1200m变电所_53-9柜功率因素
                            ],[
                                "5302",
                                "备用",
                                $baseData["2009923533370369_1"], // 五分区井下1200m变电所_5302柜母线A相电压
                                $baseData["2009923533356033_1"], // 五分区井下1200m变电所_5302柜A相电流
                                $baseData["2009923533386753_1"], // 五分区井下1200m变电所_5302柜有功功率
                                $baseData["2009923533403137_1"], // 五分区井下1200m变电所_5302柜功率因素
                            ],[
                                "5303",
                                "备用",
                                $baseData["2009923533431809_1"], // 五分区井下1200m变电所_5303柜母线A相电压
                                $baseData["2009923533417473_1"], // 五分区井下1200m变电所_5303柜A相电流
                                $baseData["2009923533444097_1"], // 五分区井下1200m变电所_5303柜有功功率
                                $baseData["2009923533462529_1"], // 五分区井下1200m变电所_5303柜功率因素
                            ],[
                                "5304",
                                "1200车场掘进移变",
                                $baseData["2009923533491201_1"], // 五分区井下1200m变电所_5304柜母线A相电压
                                $baseData["2009923533476865_1"], // 五分区井下1200m变电所_5304柜A相电流
                                $baseData["2009923533503489_1"], // 五分区井下1200m变电所_5304柜有功功率
                                $baseData["2009923533519873_1"], // 五分区井下1200m变电所_5304柜功率因素
                            ],[
                                "5305",
                                "+1295m车场掘进移变",
                                $baseData["2009923533552641_1"], // 五分区井下1200m变电所_5305柜母线A相电压
                                $baseData["2009923533536257_1"], // 五分区井下1200m变电所_5305柜A相电流
                                $baseData["2009923533569025_1"], // 五分区井下1200m变电所_5305柜有功功率
                                $baseData["2009923533585409_1"], // 五分区井下1200m变电所_5305柜功率因素
                            ],[
                                "5306",
                                "备用",
                                $baseData["2009923533618177_1"], // 五分区井下1200m变电所_5306柜母线A相电压
                                $baseData["2009923533599745_1"], // 五分区井下1200m变电所_5306柜A相电流
                                $baseData["2009923533638657_1"], // 五分区井下1200m变电所_5306柜有功功率
                                $baseData["2009923533659137_1"], // 五分区井下1200m变电所_5306柜功率因素
                            ],[
                                "5307",
                                "备高",
                                $baseData["2009923533689857_1"], // 五分区井下1200m变电所_5307柜母线A相电压
                                $baseData["2009923533677569_1"], // 五分区井下1200m变电所_5307柜A相电流
                                $baseData["2009923533702145_1"], // 五分区井下1200m变电所_5307柜有功功率
                                $baseData["2009923533716481_1"], // 五分区井下1200m变电所_5307柜功率因素
                            ],[
                                "5308",
                                "备用",
                                $baseData["2009923533749249_1"], // 五分区井下1200m变电所_5308柜母线A相电压
                                $baseData["2009923533732865_1"], // 五分区井下1200m变电所_5308柜A相电流
                                $baseData["2009923533771777_1"], // 五分区井下1200m变电所_5308柜有功功率
                                $baseData["2009923533788161_1"], // 五分区井下1200m变电所_5308柜功率因素
                            ],[
                                "5309",
                                "五分区+950m变电所II回",
                                $baseData["2009923533820929_1"], // 五分区井下1200m变电所_5309柜母线A相电压
                                $baseData["2009923533804545_1"], // 五分区井下1200m变电所_5309柜A相电流
                                $baseData["2009923533837313_1"], // 五分区井下1200m变电所_5309柜有功功率
                                $baseData["2009923533853697_1"], // 五分区井下1200m变电所_5309柜功率因素
                            ],[
                                "5002",
                                "联络",
                                $baseData["2009923533882369_1"], // 五分区井下1200m变电所_5002柜母线A相电压
                                $baseData["2009923533868033_1"], // 五分区井下1200m变电所_5002柜A相电流
                                $baseData["2009923533898753_1"], // 五分区井下1200m变电所_5002柜有功功率
                                $baseData["2009923533913089_1"], // 五分区井下1200m变电所_5002柜功率因素
                            ],[
                                "5409",
                                "五分区+950m变电所II回",
                                $baseData["2009923533939713_1"], // 五分区井下1200m变电所_5409柜母线A相电压
                                $baseData["2009923533925377_1"], // 五分区井下1200m变电所_5409柜A相电流
                                $baseData["2009923533956097_1"], // 五分区井下1200m变电所_5409柜有功功率
                                $baseData["2009923533970433_1"], // 五分区井下1200m变电所_5409柜功率因素
                            ],[
                                "5408",
                                "备用",
                                $baseData["2009923534003201_1"], // 五分区井下1200m变电所_5408柜母线A相电压
                                $baseData["2009923533986817_1"], // 五分区井下1200m变电所_5408柜A相电流
                                $baseData["2009923534023681_1"], // 五分区井下1200m变电所_5408柜有功功率
                                $baseData["2009923534042113_1"], // 五分区井下1200m变电所_5408柜功率因素
                            ],[
                                "5407",
                                "备用",
                                $baseData["2009923534087169_1"], // 五分区井下1200m变电所_5407柜母线A相电压
                                $baseData["2009923534068737_1"], // 五分区井下1200m变电所_5407柜A相电流
                                $baseData["2009923534103553_1"], // 五分区井下1200m变电所_5407柜有功功率
                                $baseData["2009923534121985_1"], // 五分区井下1200m变电所_5407柜功率因素
                            ],[
                                "5406",
                                "150202辅助巷1#移变",
                                $baseData["2009923534152705_1"], // 五分区井下1200m变电所_5406柜母线A相电压
                                $baseData["2009923534138369_1"], // 五分区井下1200m变电所_5406柜A相电流
                                $baseData["2009923534169089_1"], // 五分区井下1200m变电所_5406柜有功功率
                                $baseData["2009923534181377_1"], // 五分区井下1200m变电所_5406柜功率因素
                            ],[
                                "5405",
                                "150202风巷排水移变",
                                $baseData["2009923534210049_1"], // 五分区井下1200m变电所_5405柜母线A相电压
                                $baseData["2009923534193665_1"], // 五分区井下1200m变电所_5405柜A相电流
                                $baseData["2009923534228481_1"], // 五分区井下1200m变电所_5405柜有功功率
                                $baseData["2009923534244865_1"], // 五分区井下1200m变电所_5405柜功率因素
                            ],[
                                "5404",
                                "150202机巷电气列车",
                                $baseData["2009923534271489_1"], // 五分区井下1200m变电所_5404柜母线A相电压
                                $baseData["2009923534259201_1"], // 五分区井下1200m变电所_5404柜A相电流
                                $baseData["2009923534289921_1"], // 五分区井下1200m变电所_5404柜有功功率
                                $baseData["2009923534308353_1"], // 五分区井下1200m变电所_5404柜功率因素
                            ],[
                                "5403",
                                "备用",
                                $baseData["2009923534339073_1"], // 五分区井下1200m变电所_5403柜母线A相电压
                                $baseData["2009923534324737_1"], // 五分区井下1200m变电所_5403柜A相电流
                                $baseData["2009923534355457_1"], // 五分区井下1200m变电所_5403柜有功功率
                                $baseData["2009923534371841_1"], // 五分区井下1200m变电所_5403柜功率因素
                            ],[
                                "5402",
                                "备用",
                                $baseData["2009923534404609_1"], // 五分区井下1200m变电所_5402柜母线A相电压
                                $baseData["2009923534386177_1"], // 五分区井下1200m变电所_5402柜A相电流
                                $baseData["2009923534423041_1"], // 五分区井下1200m变电所_5402柜有功功率
                                $baseData["2009923534437377_1"], // 五分区井下1200m变电所_5402柜功率因素
                            ],[
                                "54-9",
                                "备用",
                                $baseData["2009923534474241_1"], // 五分区井下1200m变电所_54-9柜母线A相电压
                                $baseData["2009923534453761_1"], // 五分区井下1200m变电所_54-9柜A相电流
                                $baseData["2009923534490625_1"], // 五分区井下1200m变电所_54-9柜有功功率
                                $baseData["2009923534507009_1"], // 五分区井下1200m变电所_54-9柜功率因素
                            ],[
                                "5401",
                                "高压IV回进线",
                                $baseData["2009923534535681_1"], // 五分区井下1200m变电所_5401柜母线A相电压
                                $baseData["2009923534521345_1"], // 五分区井下1200m变电所_5401柜A相电流
                                $baseData["2009923534547969_1"], // 五分区井下1200m变电所_5401柜有功功率
                                $baseData["2009923534564353_1"], // 五分区井下1200m变电所_5401柜功率因素
                            ],[
                                "Z100",
                                "信息化电源",
                                $baseData["2009923534582785_1"], // 五分区井下1200m变电所_Z100#电压1
                                $baseData["2009923534599169_1"], // 五分区井下1200m变电所_Z100#照明电流2
                                null, null
                            ],[
                                "Z101",
                                "所内照明",
                                $baseData["2009923534631937_1"], // 五分区井下1200m变电所_Z101#电压1
                                $baseData["2009923534648321_1"], // 五分区井下1200m变电所_Z101#照明电流2
                                null, null
                            ],[
                                "Z102",
                                "摄像头监测",
                                $baseData["2009923534683137_1"], // 五分区井下1200m变电所_Z102#电压1
                                $baseData["2009923534699521_1"], // 五分区井下1200m变电所_Z102#照明电流2
                                null, null
                            ],[
                                "Z103",
                                "信息化电源",
                                $baseData["2009923534740481_1"], // 五分区井下1200m变电所_Z103#电压1
                                $baseData["2009923534758913_1"], // 五分区井下1200m变电所_Z103#照明电流2
                                null, null
                            ],[
                                "D100",
                                "低压I回进线",
                                $baseData["2009923534820353_1"], // 五分区井下1200m变电所_D100#ua
                                $baseData["2009923534791681_1"], // 五分区井下1200m变电所_D100#Ia1
                                null, null
                            ],[
                                "D101",
                                "五六分区上山1#给煤机电源",
                                $baseData["2009923534869505_1"], // 五分区井下1200m变电所_D101#ua
                                $baseData["2009923534838785_1"], // 五分区井下1200m变电所_D101#Ia1
                                null, null
                            ],[
                                "D102",
                                "备用",
                                $baseData["2009923534920705_1"], // 五分区井下1200m变电所_D102#ua
                                $baseData["2009923534885889_1"], // 五分区井下1200m变电所_D102#Ia1
                                null, null
                            ],[
                                "D103",
                                "备用",
                                $baseData["2009923534971905_1"], // 五分区井下1200m变电所_D103#ua
                                $baseData["2009923534935041_1"], // 五分区井下1200m变电所_D103#Ia1
                                null, null
                            ],[
                                "D104",
                                "备用",
                                $baseData["2009923535025153_1"], // 五分区井下1200m变电所_D104#ua
                                $baseData["2009923534990337_1"], // 五分区井下1200m变电所_D104#Ia1
                                null, null
                            ],[
                                "D105",
                                "备用",
                                $baseData["2009923535076353_1"], // 五分区井下1200m变电所_D105#ua
                                $baseData["2009923535039489_1"], // 五分区井下1200m变电所_D105#Ia1
                                null, null
                            ],[
                                "D106",
                                "照明综保I回",
                                $baseData["2009923535127553_1"], // 五分区井下1200m变电所_D106#ua
                                $baseData["2009923535094785_1"], // 五分区井下1200m变电所_D106#Ia1
                                null, null
                            ],[
                                "D107",
                                "联络",
                                $baseData["2009923535172609_1"], // 五分区井下1200m变电所_D1-2#ua
                                $baseData["2009923535141889_1"], // 五分区井下1200m变电所_D1-2#Ia1
                                null, null
                            ],[
                                "D108",
                                "照明综保II回",
                                $baseData["2009923535225857_1"], // 五分区井下1200m变电所_D207#ua
                                $baseData["2009923535193089_1"], // 五分区井下1200m变电所_D207#la1
                                null, null
                            ],[
                                "D109",
                                "备用",
                                $baseData["2009923535277057_1"], // 五分区井下1200m变电所_D206#ua
                                $baseData["2009923535244289_1"], // 五分区井下1200m变电所_D206#la1
                                null, null
                            ],[
                                "D110",
                                "备用",
                                $baseData["2009923535328257_1"], // 五分区井下1200m变电所_D205#ua
                                $baseData["2009923535295489_1"], // 五分区井下1200m变电所_D205#la1
                                null, null
                            ],[
                                "F104",
                                "备用",
                                $baseData["2009923535385601_1"], // 五分区井下1200m变电所_D204#ua
                                $baseData["2009923535348737_1"], // 五分区井下1200m变电所_D204#la1
                                null, null
                            ],[
                                "F103",
                                "备用",
                                $baseData["2009923535434753_1"], // 五分区井下1200m变电所_D203#ua
                                $baseData["2009923535401985_1"], // 五分区井下1200m变电所_D203#la1
                                null, null
                            ],[
                                "F102",
                                "备用",
                                $baseData["2009923535479809_1"], // 五分区井下1200m变电所_D202#ua
                                $baseData["2009923535449089_1"], // 五分区井下1200m变电所_D202#la1
                                null, null
                            ],[
                                "F101",
                                "备用",
                                $baseData["2009923535531009_1"], // 五分区井下1200m变电所_D201#ua
                                $baseData["2009923535494145_1"], // 五分区井下1200m变电所_D201#la1
                                null, null
                            ],[
                                "F100",
                                "低压I回进线",
                                $baseData["2009923535576065_1"], // 五分区井下1200m变电所_D200#ua
                                $baseData["2009923535549441_1"], // 五分区井下1200m变电所_D200#la1
                                null, null
                            ],[
                                "Z203",
                                "行人上部照明",
                                $baseData["2009923535588353_1"], // 五分区井下1200m变电所_Z203#电压1
                                $baseData["2009923535604737_1"], // 五分区井下1200m变电所_Z203#照明电流2
                                null, null
                            ],[
                                "Z202",
                                "行人下部照明",
                                $baseData["2009923535637505_1"], // 五分区井下1200m变电所_Z202#电压1
                                $baseData["2009923535649793_1"], // 五分区井下1200m变电所_Z202#照明电流2
                                null, null
                            ],[
                                "Z201",
                                "4G基站",
                                $baseData["2009923535676417_1"], // 五分区井下1200m变电所_Z201#电压1
                                $baseData["2009923535696897_1"], // 五分区井下1200m变电所_Z201#照明电流2
                                null, null
                            ],[
                                "Z200",
                                "电动风门",
                                $baseData["2009923535729665_1"], // 五分区井下1200m变电所_Z200#电压1
                                $baseData["2009923535748097_1"], // 五分区井下1200m变电所_Z200#照明电流2
                                null, null
                            ]
                        ]
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 井下929
     * */
    public function getd929List() {

        $keys=[
            "2046459469167617_2", // 929变电所_5201_开关
            "2046459469741057_2", // 929变电所_5202_开关
            "2046459470359553_2", // 929变电所_5203_开关
            "2046459470935041_2", // 929变电所_5204_开关
            "2046459471543297_2", // 929变电所_5001_开关
            "2046459474347009_2", // 929变电所_5205_开关
            "2046459472092161_2", // 929变电所_5104_开关
            "2046459472669697_2", // 929变电所_5103_开关
            "2046459473208321_2", // 929变电所_5102_29102_开关
            "2046459473783809_2", // 929变电所_5101_开关
            "2047051390798849_2", // 929_29F102
            "2046459475362817_2", // 929变电所_29F101_开关合位
            "2046459475184641_2", // 929变电所_29F100_开关合位
            "2046459477984257_2", // 929变电所_1号风机变低压_开关
            "2046459477730305_2", // 929变电所_1号风机变高压_开关
            "2046459478744065_2", // 929变电所_2号动力变高压_开关
            "2046459478983681_2", // 929变电所_2号动力变低压_开关

            "2046459475739649_2", // 929变电所_29D201_开关合位
            "2047198357621761_2", // 929_1#动力变高压
            "2047198357560321_2", // 929_1#动力变低压
            "2047210845848577_2", // 929_29D100
            "2046459474828289_2", // 929变电所_29D101_开关合位
            "2046459477425153_2", // 929_29Z104
            "2069539272504321_2", // 929_29Z103
            "2046459476429825_2", // 929变电所_29DZ102_开关合位
            "2046459476089857_2", // 929变电所_29DZ101_开关合位


            "2046501453607937_1", // 929变电所5201_Q
            "2046501453569025_1", // 929变电所5201_P
            "2046501453530113_1", // 929变电所5201_UB
            "2046501453650945_1", // 929变电所5201_COS
            "2046501453419521_1", // 929变电所5201_IA

            "2046501453847553_1", // 929变电所5202_Q
            "2046501453808641_1", // 929变电所5202_P
            "2046501453771777_1", // 929变电所5202_UB
            "2046501453886465_1", // 929变电所5202_COS
            "2046501453689857_1", // 929变电所5202_IA

            "2046501454085121_1", // 929变电所5203_Q
            "2046501454048257_1", // 929变电所5203_P
            "2046501454009345_1", // 929变电所5203_UB
            "2046501454158849_1", // 929变电所5203_COS
            "2046501453923329_1", // 929变电所5203_IA

            "2046501454357505_1", // 929变电所5204_Q
            "2046501454318593_1", // 929变电所5204_P
            "2046501454279681_1", // 929变电所5204_UB
            "2046501454394369_1", // 929变电所5204_COS
            "2046501454197761_1", // 929变电所5204_IA

            "2046501454574593_1", // 929变电所5001_Q
            "2046501454535681_1", // 929变电所5001_P
            "2046501454498817_1", // 929变电所5001_UB
            "2046501454621697_1", // 929变电所5001_COS
            "2046501454429185_1", // 929变电所5001_IA

            "2046501455725569_1", // 929变电所5205_Q
            "2046501455686657_1", // 929变电所5205_P
            "2046501455651841_1", // 929变电所5205_UB
            "2046501455760385_1", // 929变电所5205_COS
            "2046501455576065_1", // 929变电所5205_IA

            "2046501454834689_1", // 929变电所5104_Q
            "2046501454799873_1", // 929变电所5104_P
            "2046501454760961_1", // 929变电所5104_UB
            "2046501454871553_1", // 929变电所5104_COS
            "2046501454666753_1", // 929变电所5104_IA

            "2046501455055873_1", // 929变电所5103_Q
            "2046501455021057_1", // 929变电所5103_P
            "2046501454984193_1", // 929变电所5103_UB
            "2046501455092737_1", // 929变电所5103_COS
            "2046501454906369_1", // 929变电所5103_IA

            "2046501455279105_1", // 929变电所5102_29102_Q
            "2046501455240193_1", // 929变电所5102_29102_P
            "2046501455203329_1", // 929变电所5102_29102_UB
            "2046501455315969_1", // 929变电所5102_29102_COS
            "2046501455129601_1", // 929变电所5102_29102_IA

            "2046501455498241_1", // 929变电所5101_Q
            "2046501455465473_1", // 929变电所5101_P
            "2046501455428609_1", // 929变电所5101_UB
            "2046501455537153_1", // 929变电所5101_COS
            "2046501455350785_1", // 929变电所5101_IA


            "2046501457140737_1", // 929变电所29F101_UAB
            "2046501456827393_1", // 929变电所29F101_IA

            "2046501456790529_1", // 929变电所29F100_UAB
            "2046501456485377_1", // 929变电所29F100_IA

            "2046501458723841_1", // 929变电所1_风机变低压电压
            "2046501458762753_1", // 929变电所1_风机变低压电流

            "2046501458607105_1", // 929变电所1_风机变高压电压
            "2046501458643969_1", // 929变电所1_风机变高压电流

            "2046501459072001_1", // 929变电所2_动力变高压电压
            "2046501459108865_1", // 929变电所2_动力变高压电流


            "2046501459184641_1", // 929变电所2_动力变低压电压
            "2046501459223553_1", // 929变电所2_动力变低压电流

            "2046501457800193_1", // 929变电所29D201_UAB
            "2046501457505281_1", // 929变电所29D201_IA

            "2046501458840577_1", // 929变电所1_动力变高压电压
            "2046501458879489_1", // 929变电所1_动力变高压电流

            "2046501458959361_1", // 929变电所1_动力变低压电压
            "2046501458996225_1", // 929变电所1_动力变低压电流

            "2069518548093953_1", // 929变电所29D100_Ia
            "2069524603988993_1", // 929变电所29D100_Uc

            "2046501455834113_1", // 929变电所29D101_IC
            "2046501455954945_1", // 929变电所29D101_US

            "2046501458457601_1", // 929变电所29DZ201_UCA z104
            "2046501458533377_1", // 929变电所29DZ201_IB

            "2069524914854913_1", // 929变电所29Z103照明_Uca
            "2069525340591105_1", // 929变电所29Z103照明_Ic

            "2069525769933825_1", // 929变电所29Z102信息化电源_Uca
            "2069527254408193_1", // 929变电所29Z102信息化电源_Ib

            "2069527816537089_1", // 929变电所29Z1014G电源_Uca
            "2069528080405505_1", // 929变电所29Z1014G电源_Ib

        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "tip"=>[
                [
                    "color"=>"#00FF00",
                    "text"=>"关"
                ],
                [
                    "color"=>"#FF0000",
                    "text"=>"开"
                ],
            ],
            "state"=>[
                ($baseData["2046459469167617_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5201_开关
                ($baseData["2046459469741057_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5202_开关
                ($baseData["2046459470359553_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5203_开关
                ($baseData["2046459470935041_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5204_开关
                ($baseData["2046459471543297_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5001_开关
                ($baseData["2046459474347009_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5205_开关
                ($baseData["2046459472092161_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5104_开关
                ($baseData["2046459472669697_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5103_开关
                ($baseData["2046459473208321_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5102_29102_开关
                ($baseData["2046459473783809_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5101_开关
                ($baseData["2047051390798849_2"] ?? 0) <= 0 ? 0 : 1, // 929_29F102
                ($baseData["2046459475362817_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29F101_开关合位
                ($baseData["2046459475184641_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29F100_开关合位
                ($baseData["2046459477984257_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_1号风机变低压_开关
                ($baseData["2046459477730305_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_1号风机变高压_开关
                ($baseData["2046459478744065_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_2号动力变高压_开关
                ($baseData["2046459478983681_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_2号动力变低压_开关
                0, // 29D200
                ($baseData["2046459475739649_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29D201_开关合位
                ($baseData["2047198357621761_2"] ?? 0) <= 0 ? 0 : 1, // 929_1#动力变高压
                ($baseData["2047198357560321_2"] ?? 0) <= 0 ? 0 : 1, // 929_1#动力变低压
                ($baseData["2047210845848577_2"] ?? 0) <= 0 ? 0 : 1, // 929_29D100
                ($baseData["2046459474828289_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29D101_开关合位
                ($baseData["2046459477425153_2"] ?? 0) <= 0 ? 0 : 1, // 929_29Z104
                ($baseData["2069539272504321_2"] ?? 0) <= 0 ? 0 : 1, // 929_29Z103
                ($baseData["2046459476429825_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29DZ102_开关合位
                ($baseData["2046459476089857_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29DZ101_开关合位
            ],
            "table_data"=>[
                [
                    "title"=>"井下+929m变电所1",
                    "table"=>[
                        "thead"=>["名称", "Q:kVar", "p:kw", "Uab:V", "Cos", "Ia:A"],
                        "tbody"=>[
                            [
                                "5201",
                                $baseData["2046501453607937_1"] ?? 0, // 929变电所5201_Q
                                $baseData["2046501453569025_1"] ?? 0, // 929变电所5201_P
                                $baseData["2046501453530113_1"] ?? 0, // 929变电所5201_UB
                                $baseData["2046501453650945_1"] ?? 0, // 929变电所5201_COS
                                $baseData["2046501453419521_1"] ?? 0, // 929变电所5201_IA
                            ],
                            [
                                "5202",
                                $baseData["2046501453847553_1"] ?? 0, // 929变电所5202_Q
                                $baseData["2046501453808641_1"] ?? 0, // 929变电所5202_P
                                $baseData["2046501453771777_1"] ?? 0, // 929变电所5202_UB
                                $baseData["2046501453886465_1"] ?? 0, // 929变电所5202_COS
                                $baseData["2046501453689857_1"] ?? 0, // 929变电所5202_IA
                            ],
                            [
                                "5203",
                                $baseData["2046501454085121_1"] ?? 0, // 929变电所5203_Q
                                $baseData["2046501454048257_1"] ?? 0, // 929变电所5203_P
                                $baseData["2046501454009345_1"] ?? 0, // 929变电所5203_UB
                                $baseData["2046501454158849_1"] ?? 0, // 929变电所5203_COS
                                $baseData["2046501453923329_1"] ?? 0, // 929变电所5203_IA
                            ],
                            [
                                "5204",
                                $baseData["2046501454357505_1"] ?? 0, // 929变电所5204_Q
                                $baseData["2046501454318593_1"] ?? 0, // 929变电所5204_P
                                $baseData["2046501454279681_1"] ?? 0, // 929变电所5204_UB
                                $baseData["2046501454394369_1"] ?? 0, // 929变电所5204_COS
                                $baseData["2046501454197761_1"] ?? 0, // 929变电所5204_IA
                            ],
                            [
                                "5001",
                                $baseData["2046501454574593_1"] ?? 0, // 929变电所5001_Q
                                $baseData["2046501454535681_1"] ?? 0, // 929变电所5001_P
                                $baseData["2046501454498817_1"] ?? 0, // 929变电所5001_UB
                                $baseData["2046501454621697_1"] ?? 0, // 929变电所5001_COS
                                $baseData["2046501454429185_1"] ?? 0, // 929变电所5001_IA
                            ],
                            [
                                "5205",
                                $baseData["2046501455725569_1"] ?? 0, // 929变电所5205_Q
                                $baseData["2046501455686657_1"] ?? 0, // 929变电所5205_P
                                $baseData["2046501455651841_1"] ?? 0, // 929变电所5205_UB
                                $baseData["2046501455760385_1"] ?? 0, // 929变电所5205_COS
                                $baseData["2046501455576065_1"] ?? 0, // 929变电所5205_IA
                            ],
                            [
                                "5104",
                                $baseData["2046501454834689_1"] ?? 0, // 929变电所5104_Q
                                $baseData["2046501454799873_1"] ?? 0, // 929变电所5104_P
                                $baseData["2046501454760961_1"] ?? 0, // 929变电所5104_UB
                                $baseData["2046501454871553_1"] ?? 0, // 929变电所5104_COS
                                $baseData["2046501454666753_1"] ?? 0, // 929变电所5104_IA
                            ],
                            [
                                "5103",
                                $baseData["2046501455055873_1"] ?? 0, // 929变电所5103_Q
                                $baseData["2046501455021057_1"] ?? 0, // 929变电所5103_P
                                $baseData["2046501454984193_1"] ?? 0, // 929变电所5103_UB
                                $baseData["2046501455092737_1"] ?? 0, // 929变电所5103_COS
                                $baseData["2046501454906369_1"] ?? 0, // 929变电所5103_IA
                            ],
                            [
                                "29G102",
                                $baseData["2046501455279105_1"] ?? 0, // 929变电所5102_29102_Q
                                $baseData["2046501455240193_1"] ?? 0, // 929变电所5102_29102_P
                                $baseData["2046501455203329_1"] ?? 0, // 929变电所5102_29102_UB
                                $baseData["2046501455315969_1"] ?? 0, // 929变电所5102_29102_COS
                                $baseData["2046501455129601_1"] ?? 0, // 929变电所5102_29102_IA
                            ],
                            [
                                "5101",
                                $baseData["2046501455498241_1"] ?? 0, // 929变电所5101_Q
                                $baseData["2046501455465473_1"] ?? 0, // 929变电所5101_P
                                $baseData["2046501455428609_1"] ?? 0, // 929变电所5101_UB
                                $baseData["2046501455537153_1"] ?? 0, // 929变电所5101_COS
                                $baseData["2046501455350785_1"] ?? 0, // 929变电所5101_IA
                            ]
                        ]
                    ]
                ],
                [
                    "title"=>"井下+929m变电所2",
                    "table"=>[
                        "thead"=>["名称", "Uab:V", "Ia:A"],
                        "tbody"=>[
                            [
                                "29F102",
                                "0", "0"
                            ],
                            [
                                "29F101",
                                $baseData["2046501457140737_1"] ?? 0, // 929变电所29F101_UAB
                                $baseData["2046501456827393_1"] ?? 0, // 929变电所29F101_IA
                            ],
                            [
                                "29F100",
                                $baseData["2046501456790529_1"] ?? 0, // 929变电所29F100_UAB
                                $baseData["2046501456485377_1"] ?? 0, // 929变电所29F100_IA
                            ],
                            [
                                "1#风机变低压",
                                $baseData["2046501458723841_1"] ?? 0, // 929变电所1_风机变低压电压
                                $baseData["2046501458762753_1"] ?? 0, // 929变电所1_风机变低压电流
                            ],
                            [
                                "1#风机变高压",
                                $baseData["2046501458607105_1"] ?? 0, // 929变电所1_风机变高压电压
                                $baseData["2046501458643969_1"] ?? 0, // 929变电所1_风机变高压电流
                            ],
                            [
                                "2#动力变高压",
                                $baseData["2046501459072001_1"] ?? 0, // 929变电所2_动力变高压电压
                                $baseData["2046501459108865_1"] ?? 0, // 929变电所2_动力变高压电流
                            ],
                            [
                                "2#动力变低压",
                                $baseData["2046501459184641_1"] ?? 0, // 929变电所2_动力变低压电压
                                $baseData["2046501459223553_1"] ?? 0, // 929变电所2_动力变低压电流
                            ],
                            [
                                "29D200",
                                $baseData["2046501453530113_1"] ?? 0, // 29d200 929变电所5201_UB
                                $baseData["2046501453419521_1"] ?? 0, // 29d200 929变电所5201_IA
                            ],
                            [
                                "29D201",
                                $baseData["2046501457800193_1"] ?? 0, // 929变电所29D201_UAB
                                $baseData["2046501457505281_1"] ?? 0, // 929变电所29D201_IA
                            ],
                            [
                                "1#动力变高压",
                                $baseData["2046501458840577_1"] ?? 0, // 929变电所1_动力变高压电压
                                $baseData["2046501458879489_1"] ?? 0, // 929变电所1_动力变高压电流
                            ],
                            [
                                "1#动力变低压",
                                $baseData["2046501458959361_1"] ?? 0, // 929变电所1_动力变低压电压
                                $baseData["2046501458996225_1"] ?? 0, // 929变电所1_动力变低压电流
                            ],
                            [
                                "29D100",
                                $baseData["2069518548093953_1"] ?? 0, // 929变电所29D100_Ia
                                $baseData["2069524603988993_1"] ?? 0, // 929变电所29D100_Uc
                            ],
                            [
                                "29D101",
                                $baseData["2046501455834113_1"] ?? 0, // 929变电所29D101_IC
                                $baseData["2046501455954945_1"] ?? 0, // 929变电所29D101_US
                            ],
                            [
                                "29Z104",
                                $baseData["2046501458457601_1"] ?? 0, // 929变电所29DZ201_UCA z104
                                $baseData["2046501458533377_1"] ?? 0, // 929变电所29DZ201_IB
                            ],
                            [
                                "29Z103",
                                $baseData["2069524914854913_1"] ?? 0, // 929变电所29Z103照明_Uca
                                $baseData["2069525340591105_1"] ?? 0, // 929变电所29Z103照明_Ic
                            ],
                            [
                                "29Z102",
                                $baseData["2069525769933825_1"] ?? 0, // 929变电所29Z102信息化电源_Uca
                                $baseData["2069527254408193_1"] ?? 0, // 929变电所29Z102信息化电源_Ib
                            ],
                            [
                                "29Z101",
                                $baseData["2069527816537089_1"] ?? 0, // 929变电所29Z1014G电源_Uca
                                $baseData["2069528080405505_1"] ?? 0, // 929变电所29Z1014G电源_Ib
                            ],
                        ]
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 井下950
     * */
    public function getd950List() {

        $keys=[
            "2046459469167617_2", // 929变电所_5201_开关
            "2046459469741057_2", // 929变电所_5202_开关
            "2046459470359553_2", // 929变电所_5203_开关
            "2046459470935041_2", // 929变电所_5204_开关
            "2046459471543297_2", // 929变电所_5001_开关
            "2046459474347009_2", // 929变电所_5205_开关
            "2046459472092161_2", // 929变电所_5104_开关
            "2046459472669697_2", // 929变电所_5103_开关
            "2046459473208321_2", // 929变电所_5102_29102_开关
            "2046459473783809_2", // 929变电所_5101_开关
            "2047051390798849_2", // 929_29F102
            "2046459475362817_2", // 929变电所_29F101_开关合位
            "2046459475184641_2", // 929变电所_29F100_开关合位
            "2046459477984257_2", // 929变电所_1号风机变低压_开关
            "2046459477730305_2", // 929变电所_1号风机变高压_开关
            "2046459478744065_2", // 929变电所_2号动力变高压_开关
            "2046459478983681_2", // 929变电所_2号动力变低压_开关

            "2046459475739649_2", // 929变电所_29D201_开关合位
            "2047198357621761_2", // 929_1#动力变高压
            "2047198357560321_2", // 929_1#动力变低压
            "2047210845848577_2", // 929_29D100
            "2046459474828289_2", // 929变电所_29D101_开关合位
            "2046459477425153_2", // 929_29Z104
            "2069539272504321_2", // 929_29Z103
            "2046459476429825_2", // 929变电所_29DZ102_开关合位
            "2046459476089857_2", // 929变电所_29DZ101_开关合位


            "2046501453607937_1", // 929变电所5201_Q
            "2046501453569025_1", // 929变电所5201_P
            "2046501453530113_1", // 929变电所5201_UB
            "2046501453650945_1", // 929变电所5201_COS
            "2046501453419521_1", // 929变电所5201_IA

            "2046501453847553_1", // 929变电所5202_Q
            "2046501453808641_1", // 929变电所5202_P
            "2046501453771777_1", // 929变电所5202_UB
            "2046501453886465_1", // 929变电所5202_COS
            "2046501453689857_1", // 929变电所5202_IA

            "2046501454085121_1", // 929变电所5203_Q
            "2046501454048257_1", // 929变电所5203_P
            "2046501454009345_1", // 929变电所5203_UB
            "2046501454158849_1", // 929变电所5203_COS
            "2046501453923329_1", // 929变电所5203_IA

            "2046501454357505_1", // 929变电所5204_Q
            "2046501454318593_1", // 929变电所5204_P
            "2046501454279681_1", // 929变电所5204_UB
            "2046501454394369_1", // 929变电所5204_COS
            "2046501454197761_1", // 929变电所5204_IA

            "2046501454574593_1", // 929变电所5001_Q
            "2046501454535681_1", // 929变电所5001_P
            "2046501454498817_1", // 929变电所5001_UB
            "2046501454621697_1", // 929变电所5001_COS
            "2046501454429185_1", // 929变电所5001_IA

            "2046501455725569_1", // 929变电所5205_Q
            "2046501455686657_1", // 929变电所5205_P
            "2046501455651841_1", // 929变电所5205_UB
            "2046501455760385_1", // 929变电所5205_COS
            "2046501455576065_1", // 929变电所5205_IA

            "2046501454834689_1", // 929变电所5104_Q
            "2046501454799873_1", // 929变电所5104_P
            "2046501454760961_1", // 929变电所5104_UB
            "2046501454871553_1", // 929变电所5104_COS
            "2046501454666753_1", // 929变电所5104_IA

            "2046501455055873_1", // 929变电所5103_Q
            "2046501455021057_1", // 929变电所5103_P
            "2046501454984193_1", // 929变电所5103_UB
            "2046501455092737_1", // 929变电所5103_COS
            "2046501454906369_1", // 929变电所5103_IA

            "2046501455279105_1", // 929变电所5102_29102_Q
            "2046501455240193_1", // 929变电所5102_29102_P
            "2046501455203329_1", // 929变电所5102_29102_UB
            "2046501455315969_1", // 929变电所5102_29102_COS
            "2046501455129601_1", // 929变电所5102_29102_IA

            "2046501455498241_1", // 929变电所5101_Q
            "2046501455465473_1", // 929变电所5101_P
            "2046501455428609_1", // 929变电所5101_UB
            "2046501455537153_1", // 929变电所5101_COS
            "2046501455350785_1", // 929变电所5101_IA


            "2046501457140737_1", // 929变电所29F101_UAB
            "2046501456827393_1", // 929变电所29F101_IA

            "2046501456790529_1", // 929变电所29F100_UAB
            "2046501456485377_1", // 929变电所29F100_IA

            "2046501458723841_1", // 929变电所1_风机变低压电压
            "2046501458762753_1", // 929变电所1_风机变低压电流

            "2046501458607105_1", // 929变电所1_风机变高压电压
            "2046501458643969_1", // 929变电所1_风机变高压电流

            "2046501459072001_1", // 929变电所2_动力变高压电压
            "2046501459108865_1", // 929变电所2_动力变高压电流


            "2046501459184641_1", // 929变电所2_动力变低压电压
            "2046501459223553_1", // 929变电所2_动力变低压电流

            "2046501457800193_1", // 929变电所29D201_UAB
            "2046501457505281_1", // 929变电所29D201_IA

            "2046501458840577_1", // 929变电所1_动力变高压电压
            "2046501458879489_1", // 929变电所1_动力变高压电流

            "2046501458959361_1", // 929变电所1_动力变低压电压
            "2046501458996225_1", // 929变电所1_动力变低压电流

            "2069518548093953_1", // 929变电所29D100_Ia
            "2069524603988993_1", // 929变电所29D100_Uc

            "2046501455834113_1", // 929变电所29D101_IC
            "2046501455954945_1", // 929变电所29D101_US

            "2046501458457601_1", // 929变电所29DZ201_UCA z104
            "2046501458533377_1", // 929变电所29DZ201_IB

            "2069524914854913_1", // 929变电所29Z103照明_Uca
            "2069525340591105_1", // 929变电所29Z103照明_Ic

            "2069525769933825_1", // 929变电所29Z102信息化电源_Uca
            "2069527254408193_1", // 929变电所29Z102信息化电源_Ib

            "2069527816537089_1", // 929变电所29Z1014G电源_Uca
            "2069528080405505_1", // 929变电所29Z1014G电源_Ib

        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "tip"=>[
                [
                    "color"=>"#00FF00",
                    "text"=>"关"
                ],
                [
                    "color"=>"#FF0000",
                    "text"=>"开"
                ],
            ],
            "state"=>[
                ($baseData["2046459469167617_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5201_开关
                ($baseData["2046459469741057_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5202_开关
                ($baseData["2046459470359553_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5203_开关
                ($baseData["2046459470935041_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5204_开关
                ($baseData["2046459471543297_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5001_开关
                ($baseData["2046459474347009_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5205_开关
                ($baseData["2046459472092161_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5104_开关
                ($baseData["2046459472669697_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5103_开关
                ($baseData["2046459473208321_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5102_29102_开关
                ($baseData["2046459473783809_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_5101_开关
                ($baseData["2047051390798849_2"] ?? 0) <= 0 ? 0 : 1, // 929_29F102
                ($baseData["2046459475362817_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29F101_开关合位
                ($baseData["2046459475184641_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29F100_开关合位
                ($baseData["2046459477984257_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_1号风机变低压_开关
                ($baseData["2046459477730305_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_1号风机变高压_开关
                ($baseData["2046459478744065_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_2号动力变高压_开关
                ($baseData["2046459478983681_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_2号动力变低压_开关
                0, // 29D200
                ($baseData["2046459475739649_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29D201_开关合位
                ($baseData["2047198357621761_2"] ?? 0) <= 0 ? 0 : 1, // 929_1#动力变高压
                ($baseData["2047198357560321_2"] ?? 0) <= 0 ? 0 : 1, // 929_1#动力变低压
                ($baseData["2047210845848577_2"] ?? 0) <= 0 ? 0 : 1, // 929_29D100
                ($baseData["2046459474828289_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29D101_开关合位
                ($baseData["2046459477425153_2"] ?? 0) <= 0 ? 0 : 1, // 929_29Z104
                ($baseData["2069539272504321_2"] ?? 0) <= 0 ? 0 : 1, // 929_29Z103
                ($baseData["2046459476429825_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29DZ102_开关合位
                ($baseData["2046459476089857_2"] ?? 0) <= 0 ? 0 : 1, // 929变电所_29DZ101_开关合位
            ],
            "table_data"=>[
                [
                    "title"=>"井下+929m变电所1",
                    "table"=>[
                        "thead"=>["名称", "Q:kVar", "p:kw", "Uab:V", "Cos", "Ia:A"],
                        "tbody"=>[
                            [
                                "5201",
                                $baseData["2046501453607937_1"] ?? 0, // 929变电所5201_Q
                                $baseData["2046501453569025_1"] ?? 0, // 929变电所5201_P
                                $baseData["2046501453530113_1"] ?? 0, // 929变电所5201_UB
                                $baseData["2046501453650945_1"] ?? 0, // 929变电所5201_COS
                                $baseData["2046501453419521_1"] ?? 0, // 929变电所5201_IA
                            ],
                            [
                                "5202",
                                $baseData["2046501453847553_1"] ?? 0, // 929变电所5202_Q
                                $baseData["2046501453808641_1"] ?? 0, // 929变电所5202_P
                                $baseData["2046501453771777_1"] ?? 0, // 929变电所5202_UB
                                $baseData["2046501453886465_1"] ?? 0, // 929变电所5202_COS
                                $baseData["2046501453689857_1"] ?? 0, // 929变电所5202_IA
                            ],
                            [
                                "5203",
                                $baseData["2046501454085121_1"] ?? 0, // 929变电所5203_Q
                                $baseData["2046501454048257_1"] ?? 0, // 929变电所5203_P
                                $baseData["2046501454009345_1"] ?? 0, // 929变电所5203_UB
                                $baseData["2046501454158849_1"] ?? 0, // 929变电所5203_COS
                                $baseData["2046501453923329_1"] ?? 0, // 929变电所5203_IA
                            ],
                            [
                                "5204",
                                $baseData["2046501454357505_1"] ?? 0, // 929变电所5204_Q
                                $baseData["2046501454318593_1"] ?? 0, // 929变电所5204_P
                                $baseData["2046501454279681_1"] ?? 0, // 929变电所5204_UB
                                $baseData["2046501454394369_1"] ?? 0, // 929变电所5204_COS
                                $baseData["2046501454197761_1"] ?? 0, // 929变电所5204_IA
                            ],
                            [
                                "5001",
                                $baseData["2046501454574593_1"] ?? 0, // 929变电所5001_Q
                                $baseData["2046501454535681_1"] ?? 0, // 929变电所5001_P
                                $baseData["2046501454498817_1"] ?? 0, // 929变电所5001_UB
                                $baseData["2046501454621697_1"] ?? 0, // 929变电所5001_COS
                                $baseData["2046501454429185_1"] ?? 0, // 929变电所5001_IA
                            ],
                            [
                                "5205",
                                $baseData["2046501455725569_1"] ?? 0, // 929变电所5205_Q
                                $baseData["2046501455686657_1"] ?? 0, // 929变电所5205_P
                                $baseData["2046501455651841_1"] ?? 0, // 929变电所5205_UB
                                $baseData["2046501455760385_1"] ?? 0, // 929变电所5205_COS
                                $baseData["2046501455576065_1"] ?? 0, // 929变电所5205_IA
                            ],
                            [
                                "5104",
                                $baseData["2046501454834689_1"] ?? 0, // 929变电所5104_Q
                                $baseData["2046501454799873_1"] ?? 0, // 929变电所5104_P
                                $baseData["2046501454760961_1"] ?? 0, // 929变电所5104_UB
                                $baseData["2046501454871553_1"] ?? 0, // 929变电所5104_COS
                                $baseData["2046501454666753_1"] ?? 0, // 929变电所5104_IA
                            ],
                            [
                                "5103",
                                $baseData["2046501455055873_1"] ?? 0, // 929变电所5103_Q
                                $baseData["2046501455021057_1"] ?? 0, // 929变电所5103_P
                                $baseData["2046501454984193_1"] ?? 0, // 929变电所5103_UB
                                $baseData["2046501455092737_1"] ?? 0, // 929变电所5103_COS
                                $baseData["2046501454906369_1"] ?? 0, // 929变电所5103_IA
                            ],
                            [
                                "29G102",
                                $baseData["2046501455279105_1"] ?? 0, // 929变电所5102_29102_Q
                                $baseData["2046501455240193_1"] ?? 0, // 929变电所5102_29102_P
                                $baseData["2046501455203329_1"] ?? 0, // 929变电所5102_29102_UB
                                $baseData["2046501455315969_1"] ?? 0, // 929变电所5102_29102_COS
                                $baseData["2046501455129601_1"] ?? 0, // 929变电所5102_29102_IA
                            ],
                            [
                                "5101",
                                $baseData["2046501455498241_1"] ?? 0, // 929变电所5101_Q
                                $baseData["2046501455465473_1"] ?? 0, // 929变电所5101_P
                                $baseData["2046501455428609_1"] ?? 0, // 929变电所5101_UB
                                $baseData["2046501455537153_1"] ?? 0, // 929变电所5101_COS
                                $baseData["2046501455350785_1"] ?? 0, // 929变电所5101_IA
                            ]
                        ]
                    ]
                ],
                [
                    "title"=>"井下+929m变电所2",
                    "table"=>[
                        "thead"=>["名称", "Uab:V", "Ia:A"],
                        "tbody"=>[
                            [
                                "29F102",
                                "0", "0"
                            ],
                            [
                                "29F101",
                                $baseData["2046501457140737_1"] ?? 0, // 929变电所29F101_UAB
                                $baseData["2046501456827393_1"] ?? 0, // 929变电所29F101_IA
                            ],
                            [
                                "29F100",
                                $baseData["2046501456790529_1"] ?? 0, // 929变电所29F100_UAB
                                $baseData["2046501456485377_1"] ?? 0, // 929变电所29F100_IA
                            ],
                            [
                                "1#风机变低压",
                                $baseData["2046501458723841_1"] ?? 0, // 929变电所1_风机变低压电压
                                $baseData["2046501458762753_1"] ?? 0, // 929变电所1_风机变低压电流
                            ],
                            [
                                "1#风机变高压",
                                $baseData["2046501458607105_1"] ?? 0, // 929变电所1_风机变高压电压
                                $baseData["2046501458643969_1"] ?? 0, // 929变电所1_风机变高压电流
                            ],
                            [
                                "2#动力变高压",
                                $baseData["2046501459072001_1"] ?? 0, // 929变电所2_动力变高压电压
                                $baseData["2046501459108865_1"] ?? 0, // 929变电所2_动力变高压电流
                            ],
                            [
                                "2#动力变低压",
                                $baseData["2046501459184641_1"] ?? 0, // 929变电所2_动力变低压电压
                                $baseData["2046501459223553_1"] ?? 0, // 929变电所2_动力变低压电流
                            ],
                            [
                                "29D200",
                                $baseData["2046501453530113_1"] ?? 0, // 29d200 929变电所5201_UB
                                $baseData["2046501453419521_1"] ?? 0, // 29d200 929变电所5201_IA
                            ],
                            [
                                "29D201",
                                $baseData["2046501457800193_1"] ?? 0, // 929变电所29D201_UAB
                                $baseData["2046501457505281_1"] ?? 0, // 929变电所29D201_IA
                            ],
                            [
                                "1#动力变高压",
                                $baseData["2046501458840577_1"] ?? 0, // 929变电所1_动力变高压电压
                                $baseData["2046501458879489_1"] ?? 0, // 929变电所1_动力变高压电流
                            ],
                            [
                                "1#动力变低压",
                                $baseData["2046501458959361_1"] ?? 0, // 929变电所1_动力变低压电压
                                $baseData["2046501458996225_1"] ?? 0, // 929变电所1_动力变低压电流
                            ],
                            [
                                "29D100",
                                $baseData["2069518548093953_1"] ?? 0, // 929变电所29D100_Ia
                                $baseData["2069524603988993_1"] ?? 0, // 929变电所29D100_Uc
                            ],
                            [
                                "29D101",
                                $baseData["2046501455834113_1"] ?? 0, // 929变电所29D101_IC
                                $baseData["2046501455954945_1"] ?? 0, // 929变电所29D101_US
                            ],
                            [
                                "29Z104",
                                $baseData["2046501458457601_1"] ?? 0, // 929变电所29DZ201_UCA z104
                                $baseData["2046501458533377_1"] ?? 0, // 929变电所29DZ201_IB
                            ],
                            [
                                "29Z103",
                                $baseData["2069524914854913_1"] ?? 0, // 929变电所29Z103照明_Uca
                                $baseData["2069525340591105_1"] ?? 0, // 929变电所29Z103照明_Ic
                            ],
                            [
                                "29Z102",
                                $baseData["2069525769933825_1"] ?? 0, // 929变电所29Z102信息化电源_Uca
                                $baseData["2069527254408193_1"] ?? 0, // 929变电所29Z102信息化电源_Ib
                            ],
                            [
                                "29Z101",
                                $baseData["2069527816537089_1"] ?? 0, // 929变电所29Z1014G电源_Uca
                                $baseData["2069528080405505_1"] ?? 0, // 929变电所29Z1014G电源_Ib
                            ],
                        ]
                    ]
                ],
            ]
        ];

        return json_encode($info);
    }
}
